@@ -49,7 +49,26 @@ def WriteReconfigScript(reconfig,slepcdir,usedargs):
   reconfig.write('import os, sys\n')
   if usedargs:
     reconfig.write('sys.argv.extend(\''+usedargs+'\'.split())\n')
-  reconfig.write('execfile(os.path.join(\''+slepcdir+'\',\'config\',\'configure.py\'))\n')
+  reconfig.write('exec(open(os.path.join(\''+slepcdir+'\',\'config\',\'configure.py\')).read())\n')
+
+def ResetConfigureHash(hashfile,log):
+  ''' Removes the configure hash file '''
+  try:
+    log.write('Deleting configure hash file: '+hashfile)
+    os.remove(hashfile)
+  except:
+    log.write('Unable to delete configure hash file: '+hashfile)
+
+def Epilog(slepc,petsc):
+  print()
+  print('xxx'+'='*74+'xxx')
+  print(' Configure stage complete. Now build the SLEPc library with:')
+  if petsc.isinstall:
+    print('   make SLEPC_DIR='+slepc.dir+' PETSC_DIR='+petsc.dir)
+  else:
+    print('   make SLEPC_DIR='+slepc.dir+' PETSC_DIR='+petsc.dir+' PETSC_ARCH='+petsc.archname)
+  print('xxx'+'='*74+'xxx')
+  print()
 
 # Use en_US as language so that compiler messages are in English
 def fixLang(lang):
@@ -100,13 +119,15 @@ else:
   packagesinpetsc = ''
 
 # Load classes for packages and process their command-line options
-import arpack, blopex, elemental, elpa, evsl, feast, hpddm, primme, scalapack, slepc4py, slicot, trlan, sowing, lapack
+import arpack, blopex, elemental, elpa, evsl, feast, hpddm, ksvd, polar, primme, scalapack, slepc4py, slicot, trlan, sowing, lapack
 arpack    = arpack.Arpack(argdb,log)
 blopex    = blopex.Blopex(argdb,log)
 elemental = elemental.Elemental(argdb,log,packagesinpetsc)
 elpa      = elpa.Elpa(argdb,log)
 evsl      = evsl.Evsl(argdb,log)
 feast     = feast.Feast(argdb,log,packagesinpetsc)
+ksvd      = ksvd.Ksvd(argdb,log)
+polar     = polar.Polar(argdb,log)
 primme    = primme.Primme(argdb,log)
 trlan     = trlan.Trlan(argdb,log)
 sowing    = sowing.Sowing(argdb,log)
@@ -116,10 +137,15 @@ slepc4py  = slepc4py.Slepc4py(argdb,log)
 slicot    = slicot.Slicot(argdb,log)
 hpddm     = hpddm.HPDDM(argdb,log)
 
-externalpackages = [arpack, blopex, elpa, evsl, hpddm, primme, slicot, trlan]
+# The next list sorts the packages in a way that dependencies of X appear before X.
+# SLEPc's configure does not build a graph of package dependencies, every dependency is searched linearly
+externalwithdeps = [arpack, blopex, elpa, evsl, hpddm, polar, ksvd, primme, slicot, trlan]
+# List of packages in alphabetical order
+externalpackages = sorted(externalwithdeps, key=lambda p: p.packagename.upper())
+
 petscpackages    = [lapack, elemental, feast, scalapack]
 specialpackages  = [slepc, petsc, slepc4py, sowing]
-checkpackages    = specialpackages + petscpackages + externalpackages
+checkpackages    = specialpackages + petscpackages + externalwithdeps
 
 # Print help if requested and check for wrong command-line options
 if showhelp:
@@ -186,7 +212,7 @@ log.write('SLEPc version: '+slepc.lversion)
 # Clean previous configuration if needed
 if archdirexisted:
   if slepc.isinstall and not slepc.clean:
-    log.Exit('You are requesting a prefix install but the arch directory '+archdir+' already exists and may contain files from previous builds; consider adding option --with-clean')
+    log.Warn('You are requesting a prefix install but the arch directory '+archdir+' already exists and may contain files from previous builds; consider adding option --with-clean')
   try:
     os.unlink(os.path.join(confdir,'files'))
   except: pass
@@ -204,6 +230,28 @@ if archdirexisted:
         shutil.rmtree(os.path.join(archdir,rdir))
       except: pass
 
+# Generate/check configure hash file
+configurehash = slepc.GetConfigureHash(argdb,petsc)
+hashfile = os.path.join(confdir,'configure-hash')
+log.write('Checking configure hashfile')
+if slepc.force:
+  ResetConfigureHash(hashfile,log)
+else:
+  # compare hash with existing configure-hash file
+  a = ''
+  try:
+    with open(hashfile,'r') as f:
+      a = f.read()
+  except:
+    log.write('No previous hashfile found')
+  if a == configurehash:
+    log.Println('\n')
+    log.write('configure hash file '+hashfile+' matches; no need to run configure.')
+    log.Println('Your configure options and state have not changed; no need to rerun configure.')
+    log.Println('However you can force a configure run using the option: --force')
+    Epilog(slepc,petsc)
+    sys.exit(0)
+
 # Write main configuration files
 if not slepc.prefixdir:
   slepc.prefixdir = archdir
@@ -248,6 +296,14 @@ if not slepc.isinstall:
   except OSError as e:
     log.Exit('Unable to make reconfigure script executable:\n'+str(e))
 
+# Configure successful, write configure-hash file
+ResetConfigureHash(hashfile,log)
+try:
+  with open(hashfile,'w') as f:
+    f.write(configurehash)
+except:
+  log.write('Error when writing configure-hash file')
+
 # Print summary
 log.NewSection('')
 log.Println('')
@@ -258,12 +314,5 @@ for pkg in checkpackages:
   pkg.ShowInfo()
 log.write('\nFinishing Configure Run at '+time.ctime(time.time()))
 log.write('='*80)
-print()
-print('xxx'+'='*74+'xxx')
-print(' Configure stage complete. Now build the SLEPc library with:')
-if petsc.isinstall:
-  print('   make SLEPC_DIR='+slepc.dir+' PETSC_DIR='+petsc.dir)
-else:
-  print('   make SLEPC_DIR='+slepc.dir+' PETSC_DIR='+petsc.dir+' PETSC_ARCH='+petsc.archname)
-print('xxx'+'='*74+'xxx')
-print()
+log.Close()
+Epilog(slepc,petsc)
