@@ -13,7 +13,7 @@ class Installer:
     if len(args)<6:
       print('********************************************************************')
       print('Installation script error - not enough arguments:')
-      print('./config/install.py SLEPC_DIR PETSC_DIR SLEPC_INSTALLDIR -destDir=DESTDIR PETSC_ARCH LIB_SUFFIX RANLIB')
+      print('./config/install.py SLEPC_DIR PETSC_DIR SLEPC_INSTALLDIR -destDir=DESTDIR [-no-examples] PETSC_ARCH LIB_SUFFIX RANLIB')
       print('********************************************************************')
       sys.exit(1)
     self.rootDir     = args[0]
@@ -28,6 +28,10 @@ class Installer:
       print('Error in argument, should start with -destDir=')
       print('********************************************************************')
       sys.exit(1)
+    self.copyexamples = True
+    if args[4] == '-no-examples':
+      self.copyexamples = False
+      del args[4]
     self.arch        = args[4]
     self.arLibSuffix = args[5]
     self.ranlib      = ' '.join(args[6:])
@@ -141,10 +145,10 @@ class Installer:
     newlines+='PETSC_DIR='+self.petscDir+'\n'
     newlines+='PETSC_ARCH=\n'
     for line in alllines.split('\n')[1:]:
-      if line.startswith('TESTLOGFILE'):
-        newlines+='TESTLOGFILE = $(TESTDIR)/examples-install.log\n'
-      elif line.startswith('CONFIGDIR'):
-        newlines+='CONFIGDIR:=$(SLEPC_DIR)/$(PETSC_ARCH)/share/slepc/examples/config\n'
+      if line.startswith('TESTLOGTAPFILE'):
+        newlines+='TESTLOGTAPFILE = $(TESTDIR)/test_install_tap.log\n'
+      elif line.startswith('TESTLOGERRFILE'):
+        newlines+='TESTLOGERRFILE = $(TESTDIR)/test_install_err.log\n'
       elif line.startswith('$(generatedtest)') and 'slepcvariables' in line:
         newlines+='all: test\n\n'+line+'\n'
       else:
@@ -169,7 +173,7 @@ class Installer:
       if not name.startswith('arch') and os.path.isdir(srcname) and os.path.isfile(os.path.join(srcname,'makefile')):
         os.mkdir(dstname)
         nret = self.copyExamples(srcname,dstname)
-        if name == 'tests' or name == 'tutorials' or name == 'nlevp':
+        if name == 'tests' or name == 'tutorials' or name == 'nlevp' or name == 'cnetwork':
           self.copyexamplefiles(srcname,dstname)
           if os.path.isdir(os.path.join(srcname,'output')):
             os.mkdir(os.path.join(dstname,'output'))
@@ -273,7 +277,7 @@ class Installer:
 
   def fixConf(self):
     import shutil
-    for file in ['slepc_rules', 'slepc_variables', 'slepcrules', 'slepcvariables']:
+    for file in ['slepc_rules', 'slepc_rules.doc', 'slepc_rules.utils', 'slepc_variables', 'slepcrules', 'slepcvariables']:
       self.fixConfFile(os.path.join(self.destConfDir,file))
     self.fixConfFile(os.path.join(self.destLibDir,'pkgconfig','slepc.pc'))
     self.fixConfFile(os.path.join(self.destIncludeDir,'slepcconf.h'))
@@ -319,7 +323,7 @@ for dir in dirs:
 
   def installConf(self):
     self.copies.extend(self.copytree(self.rootConfDir, self.destConfDir, exclude = ['install.py','bfort-base.txt','bfort-mpi.txt','bfort-petsc.txt','bfort-slepc.txt']))
-    self.copies.extend(self.copytree(self.archConfDir, self.destConfDir, exclude = ['configure.log','error.log','files','gmake.log','make.log','test.log']))
+    self.copies.extend(self.copytree(self.archConfDir, self.destConfDir, exclude = ['configure.log','error.log','files','gmake.log','make.log','test.log','memoryerror.log']))
     return
 
   def installBin(self):
@@ -331,14 +335,15 @@ for dir in dirs:
 
   def installShare(self):
     self.copies.extend(self.copytree(self.rootShareDir, self.destShareDir))
-    examplesdir=os.path.join(self.destShareDir,'slepc','examples')
-    if os.path.exists(examplesdir):
-      shutil.rmtree(examplesdir)
-    os.mkdir(examplesdir)
-    os.mkdir(os.path.join(examplesdir,'src'))
-    self.copyExamples(self.rootSrcDir,os.path.join(examplesdir,'src'))
-    self.copyConfig(self.rootDir,examplesdir)
-    self.fixExamplesMakefile(os.path.join(examplesdir,'gmakefile.test'))
+    if self.copyexamples:
+      examplesdir=os.path.join(self.destShareDir,'slepc','examples')
+      if os.path.exists(examplesdir):
+        shutil.rmtree(examplesdir)
+      os.mkdir(examplesdir)
+      os.mkdir(os.path.join(examplesdir,'src'))
+      self.copyExamples(self.rootSrcDir,os.path.join(examplesdir,'src'))
+      self.copyConfig(self.rootDir,examplesdir)
+      self.fixExamplesMakefile(os.path.join(examplesdir,'gmakefile.test'))
     return
 
   def copyLib(self, src, dst):
