@@ -1,7 +1,7 @@
 #
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #  SLEPc - Scalable Library for Eigenvalue Problem Computations
-#  Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+#  Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 #
 #  This file is part of SLEPc.
 #  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -56,10 +56,10 @@ class Feast(package.Package):
 
   def Check(self,slepcconf,slepcvars,petsc,archdir):
     if not 'mkl' in petsc.packages:
-      self.log.Exit('The FEAST interface requires that PETSc has been built with Intel MKL')
+      self.log.Exit('The FEAST interface requires that PETSc has been built with Intel MKL (libraries and includes)')
     code = self.SampleCode(petsc)
 
-    (result,output) = self.Link([],[],[],code)
+    (result,output) = self.Link([],[],'',code)
     if not result:
       self.log.write('WARNING: Unable to link with FEAST, maybe your MKL version does not contain it')
       self.log.write('If you do not want to check for FEAST, rerun configure adding --with-feast=0')
