@@ -16,6 +16,30 @@ class PETSc(package.Package):
     package.Package.__init__(self,argdb,log)
     self.packagename = 'petsc'
 
+  def __str__(self):
+    ''' String conversion, used when writing the configure-hash file '''
+    if not hasattr(self,'dir'): return ''
+    conf = 'PETSC_DIR=' + self.dir + '\n'
+    if not hasattr(self,'lversion'): return conf
+    conf += 'PETSc version: ' + self.lversion + '\n'
+    if not hasattr(self,'arch'): return conf
+    conf += 'PETSC_ARCH=' + self.arch + '\n'
+    conf += 'PETSC_SCALAR=' + self.scalar + '\n'
+    conf += 'PETSC_PRECISION=' + self.precision + '\n'
+    conf += 'BLASLAPACK_LIB=' + self.blaslapack_lib + '\n'
+    conf += 'CC=' + self.cc + '\n'
+    conf += 'CC_FLAGS=' + self.cc_flags + '\n'
+    if hasattr(self,'fc'):
+      conf += 'FC=' + self.fc + '\n'
+      conf += 'FC_FLAGS=' + (self.fc_flags if hasattr(self,'fc_flags') else '') + '\n'
+    if hasattr(self,'cxx'):
+      conf += 'CXX=' + self.cxx + '\n'
+      conf += 'CXX_FLAGS=' + (self.cxx_flags if hasattr(self,'cxx_flags') else '') + '\n'
+    conf += 'PETSc configure options:\n'
+    args = sorted(set(self.configure_options.split()))
+    conf += '\n'.join('    '+a for a in args) + '\n'
+    return conf
+
   def ShowHelp(self):
     pass
 
@@ -75,17 +99,17 @@ class PETSc(package.Package):
         suggest = os.path.basename(self.arch)
         if not suggest: suggest = os.path.basename(self.arch[0:-1])
         self.log.Exit('Variable PETSC_ARCH must not be a full path\nYou set PETSC_ARCH=%s, maybe you meant PETSC_ARCH=%s'% (self.arch,suggest))
-      petscvariables = os.path.join(self.dir,self.arch,'lib','petsc','conf','petscvariables')
+      self.petscvariables = os.path.join(self.dir,self.arch,'lib','petsc','conf','petscvariables')
       petscconf_h = os.path.join(self.dir,self.arch,'include','petscconf.h')
     else:
       self.isinstall = True
-      petscvariables = os.path.join(self.dir,'lib','petsc','conf','petscvariables')
+      self.petscvariables = os.path.join(self.dir,'lib','petsc','conf','petscvariables')
       petscconf_h = os.path.join(self.dir,'include','petscconf.h')
 
     self.buildsharedlib = False
     self.bfort = 'nobfortinpetsc'
     try:
-      with open(petscvariables) as f:
+      with open(self.petscvariables) as f:
         for l in f.readlines():
           r = l.split('=',1)
           if len(r)!=2: continue
@@ -101,10 +125,10 @@ class PETSc(package.Package):
           elif k == 'BUILDSHAREDLIB' and v=='yes':
             self.buildsharedlib = True
           else:
-            if k in ['AR','AR_FLAGS','AR_LIB_SUFFIX','BFORT','BLASLAPACK_LIB','CC','CC_FLAGS','CC_LINKER_SLFLAG','CMAKE','CPP','CXX','CXX_FLAGS','FC_FLAGS','MAKE','MAKE_NP','PREFIXDIR','RANLIB','SCALAPACK_LIB','SL_LINKER_SUFFIX']:
+            if k in ['AR','AR_FLAGS','AR_LIB_SUFFIX','BFORT','BLASLAPACK_LIB','CC','CC_FLAGS','CC_LINKER_SLFLAG','CMAKE','CONFIGURE_OPTIONS','CPP','CXX','CXX_FLAGS','FC_FLAGS','FC_VERSION','MAKE','MAKE_NP','PREFIXDIR','RANLIB','SCALAPACK_LIB','SEDINPLACE','SL_LINKER_SUFFIX']:
               setattr(self,k.lower(),v)
     except:
-      self.log.Exit('Cannot process file ' + petscvariables)
+      self.log.Exit('Cannot process file ' + self.petscvariables)
 
     self.ind64 = False
     self.mpiuni = False
@@ -215,7 +239,7 @@ class PETSc(package.Package):
     try:
       (result, output) = self.RunCommand(self.fc+' --version',)
       import re
-      strmatch = re.match('GNU Fortran\s+\(.*\)\s+(\d+)\.(\d+)',output)
+      strmatch = re.match(r'GNU Fortran\s+\(.*\)\s+(\d+)\.(\d+)',output)
       if strmatch:
         VMAJOR,VMINOR = strmatch.groups()
         if (int(VMAJOR),int(VMINOR)) >= (10,0):
@@ -235,12 +259,18 @@ class PETSc(package.Package):
     return ' '.join(outflags)
 
   def getCXXFlags(self):
-    outflags = self.removeWarningFlags(self.cxx_flags.split())
-    return ' '.join(outflags)
+    if hasattr(self,'cxx_flags'):
+      outflags = self.removeWarningFlags(self.cxx_flags.split())
+      return ' '.join(outflags)
+    else:
+      return ''
 
   def getFFlags(self):
-    outflags = self.removeWarningFlags(self.fc_flags.split())
-    if self.isGfortran100plus():
-      outflags.append('-fallow-argument-mismatch')
-    return ' '.join(outflags)
+    if hasattr(self,'fc_flags'):
+      outflags = self.removeWarningFlags(self.fc_flags.split())
+      if self.isGfortran100plus():
+        outflags.append('-fallow-argument-mismatch')
+      return ' '.join(outflags)
+    else:
+      return ''
 
