@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -101,6 +101,12 @@
 
 /* subroutines with different signature in real/complex */
 #define LAPACKggev_  PETSCBLAS(ggev,GGEV)
+#if !defined(SLEPC_MISSING_LAPACK_GGSVD)
+#define LAPACKggsvd_ PETSCBLAS(ggsvd,GGSVD)
+#endif
+#if !defined(SLEPC_MISSING_LAPACK_GGSVD3)
+#define LAPACKggsvd3_ PETSCBLAS(ggsvd3,GGSVD3)
+#endif
 #if !defined(SLEPC_MISSING_LAPACK_TREVC)
 #define LAPACKtrevc_ PETSCBLAS(trevc,TREVC)
 #endif
