@@ -47,6 +47,7 @@ typedef const char* SVDType;
 #define SVDTRLANCZOS   "trlanczos"
 #define SVDRANDOMIZED  "randomized"
 #define SVDSCALAPACK   "scalapack"
+#define SVDKSVD        "ksvd"
 #define SVDELEMENTAL   "elemental"
 #define SVDPRIMME      "primme"
 
@@ -141,14 +142,14 @@ SLEPC_EXTERN PetscErrorCode SVDGetProblemType(SVD,SVDProblemType*);
 SLEPC_EXTERN PetscErrorCode SVDIsGeneralized(SVD,PetscBool*);
 SLEPC_EXTERN PetscErrorCode SVDIsHyperbolic(SVD,PetscBool*);
 SLEPC_EXTERN PetscErrorCode SVDSetOperators(SVD,Mat,Mat);
-PETSC_DEPRECATED_FUNCTION("Use SVDSetOperators()") static inline PetscErrorCode SVDSetOperator(SVD svd,Mat A) {return SVDSetOperators(svd,A,NULL);}
+PETSC_DEPRECATED_FUNCTION("Use SVDSetOperators()") static inline PetscErrorCode SVDSetOperator(SVD svd,Mat A) {return SVDSetOperators(svd,A,PETSC_NULLPTR);}
 SLEPC_EXTERN PetscErrorCode SVDGetOperators(SVD,Mat*,Mat*);
-PETSC_DEPRECATED_FUNCTION("Use SVDGetOperators()") static inline PetscErrorCode SVDGetOperator(SVD svd,Mat *A) {return SVDGetOperators(svd,A,NULL);}
+PETSC_DEPRECATED_FUNCTION("Use SVDGetOperators()") static inline PetscErrorCode SVDGetOperator(SVD svd,Mat *A) {return SVDGetOperators(svd,A,PETSC_NULLPTR);}
 SLEPC_EXTERN PetscErrorCode SVDSetSignature(SVD,Vec);
 SLEPC_EXTERN PetscErrorCode SVDGetSignature(SVD,Vec*);
 SLEPC_EXTERN PetscErrorCode SVDSetInitialSpaces(SVD,PetscInt,Vec[],PetscInt,Vec[]);
-PETSC_DEPRECATED_FUNCTION("Use SVDSetInitialSpaces()") static inline PetscErrorCode SVDSetInitialSpace(SVD svd,PetscInt nr,Vec *isr) {return SVDSetInitialSpaces(svd,nr,isr,0,NULL);}
-PETSC_DEPRECATED_FUNCTION("Use SVDSetInitialSpaces()") static inline PetscErrorCode SVDSetInitialSpaceLeft(SVD svd,PetscInt nl,Vec *isl) {return SVDSetInitialSpaces(svd,0,NULL,nl,isl);}
+PETSC_DEPRECATED_FUNCTION("Use SVDSetInitialSpaces()") static inline PetscErrorCode SVDSetInitialSpace(SVD svd,PetscInt nr,Vec *isr) {return SVDSetInitialSpaces(svd,nr,isr,0,PETSC_NULLPTR);}
+PETSC_DEPRECATED_FUNCTION("Use SVDSetInitialSpaces()") static inline PetscErrorCode SVDSetInitialSpaceLeft(SVD svd,PetscInt nl,Vec *isl) {return SVDSetInitialSpaces(svd,0,PETSC_NULLPTR,nl,isl);}
 SLEPC_EXTERN PetscErrorCode SVDSetImplicitTranspose(SVD,PetscBool);
 SLEPC_EXTERN PetscErrorCode SVDGetImplicitTranspose(SVD,PetscBool*);
 SLEPC_EXTERN PetscErrorCode SVDSetDimensions(SVD,PetscInt,PetscInt,PetscInt);
@@ -161,6 +162,7 @@ SLEPC_EXTERN PetscErrorCode SVDSetFromOptions(SVD);
 SLEPC_EXTERN PetscErrorCode SVDSetOptionsPrefix(SVD,const char*);
 SLEPC_EXTERN PetscErrorCode SVDAppendOptionsPrefix(SVD,const char*);
 SLEPC_EXTERN PetscErrorCode SVDGetOptionsPrefix(SVD,const char*[]);
+SLEPC_EXTERN PetscErrorCode SVDSetDSType(SVD);
 SLEPC_EXTERN PetscErrorCode SVDSetUp(SVD);
 SLEPC_EXTERN PetscErrorCode SVDSolve(SVD);
 SLEPC_EXTERN PetscErrorCode SVDGetIterationNumber(SVD,PetscInt*);
@@ -291,4 +293,32 @@ SLEPC_EXTERN PetscErrorCode SVDPRIMMEGetBlockSize(SVD,PetscInt*);
 SLEPC_EXTERN PetscErrorCode SVDPRIMMESetMethod(SVD,SVDPRIMMEMethod);
 SLEPC_EXTERN PetscErrorCode SVDPRIMMEGetMethod(SVD,SVDPRIMMEMethod*);
 
+/*E
+    SVDKSVDEigenMethod - determines the method to solve the eigenproblem within KSVD
+
+    Level: advanced
+
+.seealso: SVDKSVDSetEigenMethod(), SVDKSVDGetEigenMethod()
+E*/
+typedef enum { SVD_KSVD_EIGEN_MRRR=1,
+               SVD_KSVD_EIGEN_DC,
+               SVD_KSVD_EIGEN_ELPA } SVDKSVDEigenMethod;
+SLEPC_EXTERN const char *SVDKSVDEigenMethods[];
+
+/*E
+    SVDKSVDPolarMethod - determines the method to compute the polar decomposition within KSVD
+
+    Level: advanced
+
+.seealso: SVDKSVDSetPolarMethod(), SVDKSVDGetPolarMethod()
+E*/
+typedef enum { SVD_KSVD_POLAR_QDWH=1,
+               SVD_KSVD_POLAR_ZOLOPD } SVDKSVDPolarMethod;
+SLEPC_EXTERN const char *SVDKSVDPolarMethods[];
+
+SLEPC_EXTERN PetscErrorCode SVDKSVDSetEigenMethod(SVD,SVDKSVDEigenMethod);
+SLEPC_EXTERN PetscErrorCode SVDKSVDGetEigenMethod(SVD,SVDKSVDEigenMethod*);
+SLEPC_EXTERN PetscErrorCode SVDKSVDSetPolarMethod(SVD,SVDKSVDPolarMethod);
+SLEPC_EXTERN PetscErrorCode SVDKSVDGetPolarMethod(SVD,SVDKSVDPolarMethod*);
+
 #endif
