@@ -13,17 +13,17 @@
 
 #define SLEPC_VERSION_RELEASE    1
 #define SLEPC_VERSION_MAJOR      3
-#define SLEPC_VERSION_MINOR      18
-#define SLEPC_VERSION_SUBMINOR   3
-#define SLEPC_RELEASE_DATE       "October 1, 2022"
-#define SLEPC_VERSION_DATE       "Mar 24, 2023"
+#define SLEPC_VERSION_MINOR      19
+#define SLEPC_VERSION_SUBMINOR   2
+#define SLEPC_RELEASE_DATE       "March 31, 2023"
+#define SLEPC_VERSION_DATE       "Sep 05, 2023"
 
 #if !defined (SLEPC_VERSION_GIT)
-#define SLEPC_VERSION_GIT        "v3.18.3"
+#define SLEPC_VERSION_GIT        "v3.19.2"
 #endif
 
 #if !defined(SLEPC_VERSION_DATE_GIT)
-#define SLEPC_VERSION_DATE_GIT   "2023-03-24 12:32:49 +0100"
+#define SLEPC_VERSION_DATE_GIT   "2023-09-05 12:12:04 +0200"
 #endif
 
 #define SLEPC_VERSION_EQ(MAJOR,MINOR,SUBMINOR) \
