@@ -1,7 +1,7 @@
 !
 !  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 !  SLEPc - Scalable Library for Eigenvalue Problem Computations
-!  Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+!  Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 !
 !  This file is part of SLEPc.
 !  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -101,6 +101,13 @@
       PetscEnum, parameter :: EPS_CISS_EXTRACTION_RITZ       =  0
       PetscEnum, parameter :: EPS_CISS_EXTRACTION_HANKEL     =  1
 
+      PetscEnum, parameter :: EPS_EVSL_DOS_KPM               =  0
+      PetscEnum, parameter :: EPS_EVSL_DOS_LANCZOS           =  1
+
+      PetscEnum, parameter :: EPS_EVSL_DAMPING_NONE          =  0
+      PetscEnum, parameter :: EPS_EVSL_DAMPING_JACKSON       =  1
+      PetscEnum, parameter :: EPS_EVSL_DAMPING_SIGMA         =  2
+
 !
 !   Possible arguments to EPSMonitorSet()
 !
@@ -110,3 +117,6 @@
 
       external EPSMonitorConvergedDestroy
 
+#if defined(_WIN32) && defined(PETSC_USE_SHARED_LIBRARIES)
+!DEC$ ATTRIBUTES DLLEXPORT::SLEPC_NULL_EPS
+#endif
