@@ -74,7 +74,7 @@ PetscErrorCode EPSSetUp_FEAST(EPS eps)
 
   PetscCall(EPSAllocateSolution(eps,0));
   PetscCall(EPSSetWorkVecs(eps,2));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode EPSSolve_FEAST(EPS eps)
@@ -123,7 +123,7 @@ PetscErrorCode EPSSolve_FEAST(EPS eps)
 
     FEAST_RCI(&ijob,&n,&Ze,SCALAR_CAST ctx->work1,ctx->work2,SCALAR_CAST ctx->Aq,SCALAR_CAST ctx->Bq,fpm,&epsout,&loop,&eps->inta,&eps->intb,&ncv,evals,SCALAR_CAST pV,&nconv,eps->errest,&info);
 
-    PetscCheck(ncv==eps->ncv,PetscObjectComm((PetscObject)eps),PETSC_ERR_LIB,"FEAST changed value of ncv to %d",ncv);
+    PetscCheck(ncv==eps->ncv,PetscObjectComm((PetscObject)eps),PETSC_ERR_LIB,"FEAST changed value of ncv to %d",(int)ncv);
     if (ijob == 10) {
       /* set new quadrature point */
       PetscCall(STSetShift(eps->st,Ze.real));
@@ -167,7 +167,7 @@ PetscErrorCode EPSSolve_FEAST(EPS eps)
         PetscCall(VecResetArray(x));
         PetscCall(VecResetArray(y));
       }
-    } else PetscCheck(ijob==0 || ijob==-2,PetscObjectComm((PetscObject)eps),PETSC_ERR_LIB,"Internal error in FEAST reverse communication interface (ijob=%d)",ijob);
+    } else PetscCheck(ijob==0 || ijob==-2,PetscObjectComm((PetscObject)eps),PETSC_ERR_LIB,"Internal error in FEAST reverse communication interface (ijob=%d)",(int)ijob);
 
   } while (ijob);
 
@@ -183,7 +183,7 @@ PetscErrorCode EPSSolve_FEAST(EPS eps)
         eps->reason = EPS_DIVERGED_ITS;
         break;
       default:
-        SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_LIB,"Error reported by FEAST (%d)",info);
+        SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_LIB,"Error reported by FEAST (%d)",(int)info);
     }
   }
 
@@ -193,7 +193,7 @@ PetscErrorCode EPSSolve_FEAST(EPS eps)
   PetscCall(VecDestroy(&x));
   PetscCall(VecDestroy(&y));
   PetscCall(PetscFree(evals));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode EPSReset_FEAST(EPS eps)
@@ -202,7 +202,7 @@ PetscErrorCode EPSReset_FEAST(EPS eps)
 
   PetscFunctionBegin;
   PetscCall(PetscFree4(ctx->work1,ctx->work2,ctx->Aq,ctx->Bq));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode EPSDestroy_FEAST(EPS eps)
@@ -211,7 +211,7 @@ PetscErrorCode EPSDestroy_FEAST(EPS eps)
   PetscCall(PetscFree(eps->data));
   PetscCall(PetscObjectComposeFunction((PetscObject)eps,"EPSFEASTSetNumPoints_C",NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)eps,"EPSFEASTGetNumPoints_C",NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode EPSSetFromOptions_FEAST(EPS eps,PetscOptionItems *PetscOptionsObject)
@@ -228,7 +228,7 @@ PetscErrorCode EPSSetFromOptions_FEAST(EPS eps,PetscOptionItems *PetscOptionsObj
     if (flg) PetscCall(EPSFEASTSetNumPoints(eps,n));
 
   PetscOptionsHeadEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode EPSView_FEAST(EPS eps,PetscViewer viewer)
@@ -239,14 +239,14 @@ PetscErrorCode EPSView_FEAST(EPS eps,PetscViewer viewer)
   PetscFunctionBegin;
   PetscCall(PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii));
   if (isascii) PetscCall(PetscViewerASCIIPrintf(viewer,"  number of contour integration points=%" PetscInt_FMT "\n",ctx->npoints));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode EPSSetDefaultST_FEAST(EPS eps)
 {
   PetscFunctionBegin;
   if (!((PetscObject)eps->st)->type_name) PetscCall(STSetType(eps->st,STSINVERT));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode EPSFEASTSetNumPoints_FEAST(EPS eps,PetscInt npoints)
@@ -256,14 +256,14 @@ static PetscErrorCode EPSFEASTSetNumPoints_FEAST(EPS eps,PetscInt npoints)
   PetscFunctionBegin;
   if (npoints == PETSC_DEFAULT) ctx->npoints = 8;
   else ctx->npoints = npoints;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    EPSFEASTSetNumPoints - Sets the number of contour integration points for
    the FEAST package.
 
-   Collective on EPS
+   Logically Collective
 
    Input Parameters:
 +  eps     - the eigenproblem solver context
@@ -282,7 +282,7 @@ PetscErrorCode EPSFEASTSetNumPoints(EPS eps,PetscInt npoints)
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   PetscValidLogicalCollectiveInt(eps,npoints,2);
   PetscTryMethod(eps,"EPSFEASTSetNumPoints_C",(EPS,PetscInt),(eps,npoints));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode EPSFEASTGetNumPoints_FEAST(EPS eps,PetscInt *npoints)
@@ -291,14 +291,14 @@ static PetscErrorCode EPSFEASTGetNumPoints_FEAST(EPS eps,PetscInt *npoints)
 
   PetscFunctionBegin;
   *npoints = ctx->npoints;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    EPSFEASTGetNumPoints - Gets the number of contour integration points for
    the FEAST package.
 
-   Collective on EPS
+   Not Collective
 
    Input Parameter:
 .  eps     - the eigenproblem solver context
@@ -316,7 +316,7 @@ PetscErrorCode EPSFEASTGetNumPoints(EPS eps,PetscInt *npoints)
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   PetscValidPointer(npoints,2);
   PetscUseMethod(eps,"EPSFEASTGetNumPoints_C",(EPS,PetscInt*),(eps,npoints));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 SLEPC_EXTERN PetscErrorCode EPSCreate_FEAST(EPS eps)
@@ -340,5 +340,5 @@ SLEPC_EXTERN PetscErrorCode EPSCreate_FEAST(EPS eps)
 
   PetscCall(PetscObjectComposeFunction((PetscObject)eps,"EPSFEASTSetNumPoints_C",EPSFEASTSetNumPoints_FEAST));
   PetscCall(PetscObjectComposeFunction((PetscObject)eps,"EPSFEASTGetNumPoints_C",EPSFEASTGetNumPoints_FEAST));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
