@@ -19,7 +19,7 @@
    EPSMonitorSetFromOptions - Sets a monitor function and viewer appropriate for the type
    indicated by the user.
 
-   Collective on eps
+   Collective
 
    Input Parameters:
 +  eps      - the eigensolver context
@@ -46,7 +46,7 @@ PetscErrorCode EPSMonitorSetFromOptions(EPS eps,const char opt[],const char name
 
   PetscFunctionBegin;
   PetscCall(PetscOptionsGetViewer(PetscObjectComm((PetscObject)eps),((PetscObject)eps)->options,((PetscObject)eps)->prefix,opt,&viewer,&format,&flg));
-  if (!flg) PetscFunctionReturn(0);
+  if (!flg) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscViewerGetType(viewer,&vtype));
   PetscCall(SlepcMonitorMakeKey_Internal(name,vtype,format,key));
@@ -61,7 +61,7 @@ PetscErrorCode EPSMonitorSetFromOptions(EPS eps,const char opt[],const char name
   PetscCall(PetscObjectDereference((PetscObject)viewer));
   PetscCall(EPSMonitorSet(eps,mfunc,vf,(PetscErrorCode(*)(void **))dfunc));
   if (trackall) PetscCall(EPSSetTrackAll(eps,PETSC_TRUE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -69,7 +69,7 @@ PetscErrorCode EPSMonitorSetFromOptions(EPS eps,const char opt[],const char name
    This routine must be called before EPSSetUp() if the user is to be
    allowed to set the solver type.
 
-   Collective on eps
+   Collective
 
    Input Parameters:
 .  eps - the eigensolver context
@@ -232,12 +232,13 @@ PetscErrorCode EPSSetFromOptions(EPS eps)
   PetscCall(RGSetFromOptions(eps->rg));
   if (eps->useds) {
     if (!eps->ds) PetscCall(EPSGetDS(eps,&eps->ds));
+    PetscCall(EPSSetDSType(eps));
     PetscCall(DSSetFromOptions(eps->ds));
   }
   if (!eps->st) PetscCall(EPSGetST(eps,&eps->st));
   PetscCall(EPSSetDefaultST(eps));
   PetscCall(STSetFromOptions(eps->st));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -266,14 +267,14 @@ PetscErrorCode EPSGetTolerances(EPS eps,PetscReal *tol,PetscInt *maxits)
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   if (tol)    *tol    = eps->tol;
   if (maxits) *maxits = eps->max_it;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    EPSSetTolerances - Sets the tolerance and maximum iteration count used
    by the EPS convergence tests.
 
-   Logically Collective on eps
+   Logically Collective
 
    Input Parameters:
 +  eps - the eigensolver context
@@ -297,7 +298,7 @@ PetscErrorCode EPSSetTolerances(EPS eps,PetscReal tol,PetscInt maxits)
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   PetscValidLogicalCollectiveReal(eps,tol,2);
   PetscValidLogicalCollectiveInt(eps,maxits,3);
-  if (tol == PETSC_DEFAULT) {
+  if (tol == (PetscReal)PETSC_DEFAULT) {
     eps->tol   = PETSC_DEFAULT;
     eps->state = EPS_STATE_INITIAL;
   } else {
@@ -311,7 +312,7 @@ PetscErrorCode EPSSetTolerances(EPS eps,PetscReal tol,PetscInt maxits)
     PetscCheck(maxits>0,PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of maxits. Must be > 0");
     eps->max_it = maxits;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -339,14 +340,14 @@ PetscErrorCode EPSGetDimensions(EPS eps,PetscInt *nev,PetscInt *ncv,PetscInt *mp
   if (nev) *nev = eps->nev;
   if (ncv) *ncv = eps->ncv;
   if (mpd) *mpd = eps->mpd;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    EPSSetDimensions - Sets the number of eigenvalues to compute
    and the dimension of the subspace.
 
-   Logically Collective on eps
+   Logically Collective
 
    Input Parameters:
 +  eps - the eigensolver context
@@ -402,34 +403,19 @@ PetscErrorCode EPSSetDimensions(EPS eps,PetscInt nev,PetscInt ncv,PetscInt mpd)
     eps->mpd = mpd;
   }
   eps->state = EPS_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    EPSSetWhichEigenpairs - Specifies which portion of the spectrum is
    to be sought.
 
-   Logically Collective on eps
+   Logically Collective
 
    Input Parameters:
 +  eps   - eigensolver context obtained from EPSCreate()
 -  which - the portion of the spectrum to be sought
 
-   Possible values:
-   The parameter 'which' can have one of these values
-
-+     EPS_LARGEST_MAGNITUDE - largest eigenvalues in magnitude (default)
-.     EPS_SMALLEST_MAGNITUDE - smallest eigenvalues in magnitude
-.     EPS_LARGEST_REAL - largest real parts
-.     EPS_SMALLEST_REAL - smallest real parts
-.     EPS_LARGEST_IMAGINARY - largest imaginary parts
-.     EPS_SMALLEST_IMAGINARY - smallest imaginary parts
-.     EPS_TARGET_MAGNITUDE - eigenvalues closest to the target (in magnitude)
-.     EPS_TARGET_REAL - eigenvalues with real part closest to target
-.     EPS_TARGET_IMAGINARY - eigenvalues with imaginary part closest to target
-.     EPS_ALL - all eigenvalues contained in a given interval or region
--     EPS_WHICH_USER - user defined ordering set with EPSSetEigenvalueComparison()
-
    Options Database Keys:
 +   -eps_largest_magnitude - Sets largest eigenvalues in magnitude
 .   -eps_smallest_magnitude - Sets smallest eigenvalues in magnitude
@@ -443,6 +429,20 @@ PetscErrorCode EPSSetDimensions(EPS eps,PetscInt nev,PetscInt ncv,PetscInt mpd)
 -   -eps_all - Sets all eigenvalues in an interval or region
 
    Notes:
+   The parameter 'which' can have one of these values
+
++     EPS_LARGEST_MAGNITUDE - largest eigenvalues in magnitude (default)
+.     EPS_SMALLEST_MAGNITUDE - smallest eigenvalues in magnitude
+.     EPS_LARGEST_REAL - largest real parts
+.     EPS_SMALLEST_REAL - smallest real parts
+.     EPS_LARGEST_IMAGINARY - largest imaginary parts
+.     EPS_SMALLEST_IMAGINARY - smallest imaginary parts
+.     EPS_TARGET_MAGNITUDE - eigenvalues closest to the target (in magnitude)
+.     EPS_TARGET_REAL - eigenvalues with real part closest to target
+.     EPS_TARGET_IMAGINARY - eigenvalues with imaginary part closest to target
+.     EPS_ALL - all eigenvalues contained in a given interval or region
+-     EPS_WHICH_USER - user defined ordering set with EPSSetEigenvalueComparison()
+
    Not all eigensolvers implemented in EPS account for all the possible values
    stated above. Also, some values make sense only for certain types of
    problems. If SLEPc is compiled for real numbers EPS_LARGEST_IMAGINARY
@@ -496,7 +496,7 @@ PetscErrorCode EPSSetWhichEigenpairs(EPS eps,EPSWhich which)
     default:
       SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_OUTOFRANGE,"Invalid 'which' value");
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -524,23 +524,22 @@ PetscErrorCode EPSGetWhichEigenpairs(EPS eps,EPSWhich *which)
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   PetscValidPointer(which,2);
   *which = eps->which;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    EPSSetEigenvalueComparison - Specifies the eigenvalue comparison function
    when EPSSetWhichEigenpairs() is set to EPS_WHICH_USER.
 
-   Logically Collective on eps
+   Logically Collective
 
    Input Parameters:
 +  eps  - eigensolver context obtained from EPSCreate()
 .  func - a pointer to the comparison function
 -  ctx  - a context pointer (the last parameter to the comparison function)
 
-   Calling Sequence of func:
-$   func(PetscScalar ar,PetscScalar ai,PetscScalar br,PetscScalar bi,PetscInt *res,void *ctx)
-
+   Calling sequence of func:
+$  PetscErrorCode func(PetscScalar ar,PetscScalar ai,PetscScalar br,PetscScalar bi,PetscInt *res,void *ctx)
 +   ar     - real part of the 1st eigenvalue
 .   ai     - imaginary part of the 1st eigenvalue
 .   br     - real part of the 2nd eigenvalue
@@ -558,14 +557,14 @@ $   func(PetscScalar ar,PetscScalar ai,PetscScalar br,PetscScalar bi,PetscInt *r
 
 .seealso: EPSSetWhichEigenpairs(), EPSWhich
 @*/
-PetscErrorCode EPSSetEigenvalueComparison(EPS eps,PetscErrorCode (*func)(PetscScalar,PetscScalar,PetscScalar,PetscScalar,PetscInt*,void*),void* ctx)
+PetscErrorCode EPSSetEigenvalueComparison(EPS eps,PetscErrorCode (*func)(PetscScalar ar,PetscScalar ai,PetscScalar br,PetscScalar bi,PetscInt *res,void *ctx),void* ctx)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   eps->sc->comparison    = func;
   eps->sc->comparisonctx = ctx;
   eps->which             = EPS_WHICH_USER;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -573,16 +572,15 @@ PetscErrorCode EPSSetEigenvalueComparison(EPS eps,PetscErrorCode (*func)(PetscSc
    eigenvalues according to an arbitrary selection criterion. This criterion
    can be based on a computation involving the current eigenvector approximation.
 
-   Logically Collective on eps
+   Logically Collective
 
    Input Parameters:
 +  eps  - eigensolver context obtained from EPSCreate()
 .  func - a pointer to the evaluation function
 -  ctx  - a context pointer (the last parameter to the evaluation function)
 
-   Calling Sequence of func:
-$   func(PetscScalar er,PetscScalar ei,Vec xr,Vec xi,PetscScalar *rr,PetscScalar *ri,void *ctx)
-
+   Calling sequence of func:
+$  PetscErrorCode func(PetscScalar er,PetscScalar ei,Vec xr,Vec xi,PetscScalar *rr,PetscScalar *ri,void *ctx)
 +   er     - real part of the current eigenvalue approximation
 .   ei     - imaginary part of the current eigenvalue approximation
 .   xr     - real part of the current eigenvector approximation
@@ -615,21 +613,21 @@ $   func(PetscScalar er,PetscScalar ei,Vec xr,Vec xi,PetscScalar *rr,PetscScalar
 
 .seealso: EPSSetWhichEigenpairs()
 @*/
-PetscErrorCode EPSSetArbitrarySelection(EPS eps,PetscErrorCode (*func)(PetscScalar,PetscScalar,Vec,Vec,PetscScalar*,PetscScalar*,void*),void* ctx)
+PetscErrorCode EPSSetArbitrarySelection(EPS eps,PetscErrorCode (*func)(PetscScalar er,PetscScalar ei,Vec xr,Vec xi,PetscScalar *rr,PetscScalar *ri,void *ctx),void* ctx)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   eps->arbitrary    = func;
   eps->arbitraryctx = ctx;
   eps->state        = EPS_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    EPSSetConvergenceTestFunction - Sets a function to compute the error estimate
    used in the convergence test.
 
-   Logically Collective on eps
+   Logically Collective
 
    Input Parameters:
 +  eps     - eigensolver context obtained from EPSCreate()
@@ -637,9 +635,8 @@ PetscErrorCode EPSSetArbitrarySelection(EPS eps,PetscErrorCode (*func)(PetscScal
 .  ctx     - context for private data for the convergence routine (may be null)
 -  destroy - a routine for destroying the context (may be null)
 
-   Calling Sequence of func:
-$   func(EPS eps,PetscScalar eigr,PetscScalar eigi,PetscReal res,PetscReal *errest,void *ctx)
-
+   Calling sequence of func:
+$  PetscErrorCode func(EPS eps,PetscScalar eigr,PetscScalar eigi,PetscReal res,PetscReal *errest,void *ctx)
 +   eps    - eigensolver context obtained from EPSCreate()
 .   eigr   - real part of the eigenvalue
 .   eigi   - imaginary part of the eigenvalue
@@ -655,7 +652,7 @@ $   func(EPS eps,PetscScalar eigr,PetscScalar eigi,PetscReal res,PetscReal *erre
 
 .seealso: EPSSetConvergenceTest(), EPSSetTolerances()
 @*/
-PetscErrorCode EPSSetConvergenceTestFunction(EPS eps,PetscErrorCode (*func)(EPS,PetscScalar,PetscScalar,PetscReal,PetscReal*,void*),void* ctx,PetscErrorCode (*destroy)(void*))
+PetscErrorCode EPSSetConvergenceTestFunction(EPS eps,PetscErrorCode (*func)(EPS eps,PetscScalar eigr,PetscScalar eigi,PetscReal res,PetscReal *errest,void *ctx),void* ctx,PetscErrorCode (*destroy)(void*))
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
@@ -670,14 +667,14 @@ PetscErrorCode EPSSetConvergenceTestFunction(EPS eps,PetscErrorCode (*func)(EPS,
     eps->conv      = EPS_CONV_USER;
     eps->converged = eps->convergeduser;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    EPSSetConvergenceTest - Specifies how to compute the error estimate
    used in the convergence test.
 
-   Logically Collective on eps
+   Logically Collective
 
    Input Parameters:
 +  eps  - eigensolver context obtained from EPSCreate()
@@ -717,7 +714,7 @@ PetscErrorCode EPSSetConvergenceTest(EPS eps,EPSConv conv)
       SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_OUTOFRANGE,"Invalid 'conv' value");
   }
   eps->conv = conv;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -742,14 +739,14 @@ PetscErrorCode EPSGetConvergenceTest(EPS eps,EPSConv *conv)
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   PetscValidPointer(conv,2);
   *conv = eps->conv;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    EPSSetStoppingTestFunction - Sets a function to decide when to stop the outer
    iteration of the eigensolver.
 
-   Logically Collective on eps
+   Logically Collective
 
    Input Parameters:
 +  eps     - eigensolver context obtained from EPSCreate()
@@ -757,9 +754,8 @@ PetscErrorCode EPSGetConvergenceTest(EPS eps,EPSConv *conv)
 .  ctx     - context for private data for the stopping routine (may be null)
 -  destroy - a routine for destroying the context (may be null)
 
-   Calling Sequence of func:
-$   func(EPS eps,PetscInt its,PetscInt max_it,PetscInt nconv,PetscInt nev,EPSConvergedReason *reason,void *ctx)
-
+   Calling sequence of func:
+$  PetscErrorCode func(EPS eps,PetscInt its,PetscInt max_it,PetscInt nconv,PetscInt nev,EPSConvergedReason *reason,void *ctx)
 +   eps    - eigensolver context obtained from EPSCreate()
 .   its    - current number of iterations
 .   max_it - maximum number of iterations
@@ -778,7 +774,7 @@ $   func(EPS eps,PetscInt its,PetscInt max_it,PetscInt nconv,PetscInt nev,EPSCon
 
 .seealso: EPSSetStoppingTest(), EPSStoppingBasic()
 @*/
-PetscErrorCode EPSSetStoppingTestFunction(EPS eps,PetscErrorCode (*func)(EPS,PetscInt,PetscInt,PetscInt,PetscInt,EPSConvergedReason*,void*),void* ctx,PetscErrorCode (*destroy)(void*))
+PetscErrorCode EPSSetStoppingTestFunction(EPS eps,PetscErrorCode (*func)(EPS eps,PetscInt its,PetscInt max_it,PetscInt nconv,PetscInt nev,EPSConvergedReason *reason,void *ctx),void* ctx,PetscErrorCode (*destroy)(void*))
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
@@ -791,14 +787,14 @@ PetscErrorCode EPSSetStoppingTestFunction(EPS eps,PetscErrorCode (*func)(EPS,Pet
     eps->stop     = EPS_STOP_USER;
     eps->stopping = eps->stoppinguser;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    EPSSetStoppingTest - Specifies how to decide the termination of the outer
    loop of the eigensolver.
 
-   Logically Collective on eps
+   Logically Collective
 
    Input Parameters:
 +  eps  - eigensolver context obtained from EPSCreate()
@@ -832,7 +828,7 @@ PetscErrorCode EPSSetStoppingTest(EPS eps,EPSStop stop)
       SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_OUTOFRANGE,"Invalid 'stop' value");
   }
   eps->stop = stop;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -857,13 +853,13 @@ PetscErrorCode EPSGetStoppingTest(EPS eps,EPSStop *stop)
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   PetscValidPointer(stop,2);
   *stop = eps->stop;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    EPSSetProblemType - Specifies the type of the eigenvalue problem.
 
-   Logically Collective on eps
+   Logically Collective
 
    Input Parameters:
 +  eps      - the eigensolver context
@@ -900,7 +896,7 @@ PetscErrorCode EPSSetProblemType(EPS eps,EPSProblemType type)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   PetscValidLogicalCollectiveEnum(eps,type,2);
-  if (type == eps->problem_type) PetscFunctionReturn(0);
+  if (type == eps->problem_type) PetscFunctionReturn(PETSC_SUCCESS);
   switch (type) {
     case EPS_HEP:
       eps->isgeneralized = PETSC_FALSE;
@@ -937,7 +933,7 @@ PetscErrorCode EPSSetProblemType(EPS eps,EPSProblemType type)
   }
   eps->problem_type = type;
   eps->state = EPS_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -961,14 +957,14 @@ PetscErrorCode EPSGetProblemType(EPS eps,EPSProblemType *type)
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   PetscValidPointer(type,2);
   *type = eps->problem_type;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    EPSSetExtraction - Specifies the type of extraction technique to be employed
    by the eigensolver.
 
-   Logically Collective on eps
+   Logically Collective
 
    Input Parameters:
 +  eps  - the eigensolver context
@@ -1003,7 +999,7 @@ PetscErrorCode EPSSetExtraction(EPS eps,EPSExtraction extr)
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   PetscValidLogicalCollectiveEnum(eps,extr,2);
   eps->extraction = extr;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1027,14 +1023,14 @@ PetscErrorCode EPSGetExtraction(EPS eps,EPSExtraction *extr)
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   PetscValidPointer(extr,2);
   *extr = eps->extraction;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    EPSSetBalance - Specifies the balancing technique to be employed by the
    eigensolver, and some parameters associated to it.
 
-   Logically Collective on eps
+   Logically Collective
 
    Input Parameters:
 +  eps    - the eigensolver context
@@ -1097,12 +1093,12 @@ PetscErrorCode EPSSetBalance(EPS eps,EPSBalance bal,PetscInt its,PetscReal cutof
     PetscCheck(its>0,PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of its. Must be > 0");
     eps->balance_its = its;
   }
-  if (cutoff==PETSC_DECIDE || cutoff==PETSC_DEFAULT) eps->balance_cutoff = 1e-8;
+  if (cutoff==(PetscReal)PETSC_DECIDE || cutoff==(PetscReal)PETSC_DEFAULT) eps->balance_cutoff = 1e-8;
   else {
     PetscCheck(cutoff>0.0,PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of cutoff. Must be > 0");
     eps->balance_cutoff = cutoff;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1133,14 +1129,14 @@ PetscErrorCode EPSGetBalance(EPS eps,EPSBalance *bal,PetscInt *its,PetscReal *cu
   if (bal)    *bal = eps->balance;
   if (its)    *its = eps->balance_its;
   if (cutoff) *cutoff = eps->balance_cutoff;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    EPSSetTwoSided - Sets the solver to use a two-sided variant so that left
    eigenvectors are also computed.
 
-   Logically Collective on eps
+   Logically Collective
 
    Input Parameters:
 +  eps      - the eigensolver context
@@ -1170,7 +1166,7 @@ PetscErrorCode EPSSetTwoSided(EPS eps,PetscBool twosided)
     eps->twosided = twosided;
     eps->state    = EPS_STATE_INITIAL;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1195,14 +1191,14 @@ PetscErrorCode EPSGetTwoSided(EPS eps,PetscBool *twosided)
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   PetscValidBoolPointer(twosided,2);
   *twosided = eps->twosided;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    EPSSetTrueResidual - Specifies if the solver must compute the true residual
    explicitly or not.
 
-   Logically Collective on eps
+   Logically Collective
 
    Input Parameters:
 +  eps     - the eigensolver context
@@ -1231,7 +1227,7 @@ PetscErrorCode EPSSetTrueResidual(EPS eps,PetscBool trueres)
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   PetscValidLogicalCollectiveBool(eps,trueres,2);
   eps->trueres = trueres;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1256,14 +1252,14 @@ PetscErrorCode EPSGetTrueResidual(EPS eps,PetscBool *trueres)
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   PetscValidBoolPointer(trueres,2);
   *trueres = eps->trueres;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    EPSSetTrackAll - Specifies if the solver must compute the residual norm of all
    approximate eigenpairs or not.
 
-   Logically Collective on eps
+   Logically Collective
 
    Input Parameters:
 +  eps      - the eigensolver context
@@ -1287,7 +1283,7 @@ PetscErrorCode EPSSetTrackAll(EPS eps,PetscBool trackall)
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   PetscValidLogicalCollectiveBool(eps,trackall,2);
   eps->trackall = trackall;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1312,13 +1308,13 @@ PetscErrorCode EPSGetTrackAll(EPS eps,PetscBool *trackall)
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   PetscValidBoolPointer(trackall,2);
   *trackall = eps->trackall;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    EPSSetPurify - Deactivate eigenvector purification (which is activated by default).
 
-   Logically Collective on eps
+   Logically Collective
 
    Input Parameters:
 +  eps    - the eigensolver context
@@ -1346,7 +1342,7 @@ PetscErrorCode EPSSetPurify(EPS eps,PetscBool purify)
     eps->purify = purify;
     eps->state  = EPS_STATE_INITIAL;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1371,14 +1367,14 @@ PetscErrorCode EPSGetPurify(EPS eps,PetscBool *purify)
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   PetscValidBoolPointer(purify,2);
   *purify = eps->purify;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    EPSSetOptionsPrefix - Sets the prefix used for searching for all
    EPS options in the database.
 
-   Logically Collective on eps
+   Logically Collective
 
    Input Parameters:
 +  eps - the eigensolver context
@@ -1413,14 +1409,14 @@ PetscErrorCode EPSSetOptionsPrefix(EPS eps,const char *prefix)
   if (!eps->rg) PetscCall(EPSGetRG(eps,&eps->rg));
   PetscCall(RGSetOptionsPrefix(eps->rg,prefix));
   PetscCall(PetscObjectSetOptionsPrefix((PetscObject)eps,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    EPSAppendOptionsPrefix - Appends to the prefix used for searching for all
    EPS options in the database.
 
-   Logically Collective on eps
+   Logically Collective
 
    Input Parameters:
 +  eps - the eigensolver context
@@ -1447,7 +1443,7 @@ PetscErrorCode EPSAppendOptionsPrefix(EPS eps,const char *prefix)
   if (!eps->rg) PetscCall(EPSGetRG(eps,&eps->rg));
   PetscCall(RGAppendOptionsPrefix(eps->rg,prefix));
   PetscCall(PetscObjectAppendOptionsPrefix((PetscObject)eps,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1476,5 +1472,5 @@ PetscErrorCode EPSGetOptionsPrefix(EPS eps,const char *prefix[])
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
   PetscValidPointer(prefix,2);
   PetscCall(PetscObjectGetOptionsPrefix((PetscObject)eps,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
