@@ -30,7 +30,7 @@ PetscBool         LMEMonitorRegisterAllCalled = PETSC_FALSE;
 /*@C
    LMEView - Prints the LME data structure.
 
-   Collective on lme
+   Collective
 
    Input Parameters:
 +  lme - the linear matrix equation solver context
@@ -87,13 +87,13 @@ PetscErrorCode LMEView(LME lme,PetscViewer viewer)
   if (!lme->V) PetscCall(LMEGetBV(lme,&lme->V));
   PetscCall(BVView(lme->V,viewer));
   PetscCall(PetscViewerPopFormat(viewer));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    LMEViewFromOptions - View from options
 
-   Collective on LME
+   Collective
 
    Input Parameters:
 +  lme  - the linear matrix equation context
@@ -109,12 +109,12 @@ PetscErrorCode LMEViewFromOptions(LME lme,PetscObject obj,const char name[])
   PetscFunctionBegin;
   PetscValidHeaderSpecific(lme,LME_CLASSID,1);
   PetscCall(PetscObjectViewFromOptions((PetscObject)lme,obj,name));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 /*@C
    LMEConvergedReasonView - Displays the reason an LME solve converged or diverged.
 
-   Collective on lme
+   Collective
 
    Input Parameters:
 +  lme - the linear matrix equation context
@@ -148,14 +148,14 @@ PetscErrorCode LMEConvergedReasonView(LME lme,PetscViewer viewer)
     else if (lme->reason <= 0) PetscCall(PetscViewerASCIIPrintf(viewer,"%s Linear matrix equation solve did not converge due to %s; iterations %" PetscInt_FMT "\n",((PetscObject)lme)->prefix?((PetscObject)lme)->prefix:"",LMEConvergedReasons[lme->reason],lme->its));
     PetscCall(PetscViewerASCIISubtractTab(viewer,((PetscObject)lme)->tablevel));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    LMEConvergedReasonViewFromOptions - Processes command line options to determine if/how
    the LME converged reason is to be viewed.
 
-   Collective on lme
+   Collective
 
    Input Parameter:
 .  lme - the linear matrix equation context
@@ -172,7 +172,7 @@ PetscErrorCode LMEConvergedReasonViewFromOptions(LME lme)
   PetscViewerFormat format;
 
   PetscFunctionBegin;
-  if (incall) PetscFunctionReturn(0);
+  if (incall) PetscFunctionReturn(PETSC_SUCCESS);
   incall = PETSC_TRUE;
   PetscCall(PetscOptionsGetViewer(PetscObjectComm((PetscObject)lme),((PetscObject)lme)->options,((PetscObject)lme)->prefix,"-lme_converged_reason",&viewer,&format,&flg));
   if (flg) {
@@ -182,7 +182,7 @@ PetscErrorCode LMEConvergedReasonViewFromOptions(LME lme)
     PetscCall(PetscViewerDestroy(&viewer));
   }
   incall = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -238,13 +238,13 @@ PetscErrorCode LMECreate(MPI_Comm comm,LME *outlme)
   lme->reason          = LME_CONVERGED_ITERATING;
 
   *outlme = lme;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    LMESetType - Selects the particular solver to be used in the LME object.
 
-   Logically Collective on lme
+   Logically Collective
 
    Input Parameters:
 +  lme  - the linear matrix equation context
@@ -280,7 +280,7 @@ PetscErrorCode LMESetType(LME lme,LMEType type)
   PetscValidCharPointer(type,2);
 
   PetscCall(PetscObjectTypeCompare((PetscObject)lme,type,&match));
-  if (match) PetscFunctionReturn(0);
+  if (match) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscFunctionListFind(LMEList,type,&r));
   PetscCheck(r,PetscObjectComm((PetscObject)lme),PETSC_ERR_ARG_UNKNOWN_TYPE,"Unknown LME type given: %s",type);
@@ -291,7 +291,7 @@ PetscErrorCode LMESetType(LME lme,LMEType type)
   lme->setupcalled = 0;
   PetscCall(PetscObjectChangeTypeName((PetscObject)lme,type));
   PetscCall((*r)(lme));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -315,7 +315,7 @@ PetscErrorCode LMEGetType(LME lme,LMEType *type)
   PetscValidHeaderSpecific(lme,LME_CLASSID,1);
   PetscValidPointer(type,2);
   *type = ((PetscObject)lme)->type_name;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -330,7 +330,7 @@ PetscErrorCode LMEGetType(LME lme,LMEType *type)
    Notes:
    LMERegister() may be called multiple times to add several user-defined solvers.
 
-   Sample usage:
+   Example Usage:
 .vb
     LMERegister("my_solver",MySolverCreate);
 .ve
@@ -349,7 +349,7 @@ PetscErrorCode LMERegister(const char *name,PetscErrorCode (*function)(LME))
   PetscFunctionBegin;
   PetscCall(LMEInitializePackage());
   PetscCall(PetscFunctionListAdd(&LMEList,name,function));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -368,7 +368,7 @@ PetscErrorCode LMERegister(const char *name,PetscErrorCode (*function)(LME))
    Notes:
    LMEMonitorRegister() may be called multiple times to add several user-defined monitors.
 
-   Sample usage:
+   Example Usage:
 .vb
    LMEMonitorRegister("my_monitor",PETSCVIEWERASCII,PETSC_VIEWER_ASCII_INFO_DETAIL,MyMonitor,NULL,NULL);
 .ve
@@ -392,14 +392,14 @@ PetscErrorCode LMEMonitorRegister(const char name[],PetscViewerType vtype,PetscV
   PetscCall(PetscFunctionListAdd(&LMEMonitorList,key,monitor));
   if (create)  PetscCall(PetscFunctionListAdd(&LMEMonitorCreateList,key,create));
   if (destroy) PetscCall(PetscFunctionListAdd(&LMEMonitorDestroyList,key,destroy));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    LMEReset - Resets the LME context to the initial state (prior to setup)
    and destroys any allocated Vecs and Mats.
 
-   Collective on lme
+   Collective
 
    Input Parameter:
 .  lme - linear matrix equation context obtained from LMECreate()
@@ -412,7 +412,7 @@ PetscErrorCode LMEReset(LME lme)
 {
   PetscFunctionBegin;
   if (lme) PetscValidHeaderSpecific(lme,LME_CLASSID,1);
-  if (!lme) PetscFunctionReturn(0);
+  if (!lme) PetscFunctionReturn(PETSC_SUCCESS);
   PetscTryTypeMethod(lme,reset);
   PetscCall(MatDestroy(&lme->A));
   PetscCall(MatDestroy(&lme->B));
@@ -424,13 +424,13 @@ PetscErrorCode LMEReset(LME lme)
   PetscCall(VecDestroyVecs(lme->nwork,&lme->work));
   lme->nwork = 0;
   lme->setupcalled = 0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    LMEDestroy - Destroys the LME context.
 
-   Collective on lme
+   Collective
 
    Input Parameter:
 .  lme - linear matrix equation context obtained from LMECreate()
@@ -442,20 +442,20 @@ PetscErrorCode LMEReset(LME lme)
 PetscErrorCode LMEDestroy(LME *lme)
 {
   PetscFunctionBegin;
-  if (!*lme) PetscFunctionReturn(0);
+  if (!*lme) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeaderSpecific(*lme,LME_CLASSID,1);
-  if (--((PetscObject)(*lme))->refct > 0) { *lme = NULL; PetscFunctionReturn(0); }
+  if (--((PetscObject)(*lme))->refct > 0) { *lme = NULL; PetscFunctionReturn(PETSC_SUCCESS); }
   PetscCall(LMEReset(*lme));
   PetscTryTypeMethod(*lme,destroy);
   PetscCall(LMEMonitorCancel(*lme));
   PetscCall(PetscHeaderDestroy(lme));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    LMESetBV - Associates a basis vectors object to the linear matrix equation solver.
 
-   Collective on lme
+   Collective
 
    Input Parameters:
 +  lme - linear matrix equation context obtained from LMECreate()
@@ -478,7 +478,7 @@ PetscErrorCode LMESetBV(LME lme,BV bv)
   PetscCall(PetscObjectReference((PetscObject)bv));
   PetscCall(BVDestroy(&lme->V));
   lme->V = bv;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -508,5 +508,5 @@ PetscErrorCode LMEGetBV(LME lme,BV *bv)
     PetscCall(PetscObjectSetOptions((PetscObject)lme->V,((PetscObject)lme)->options));
   }
   *bv = lme->V;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
