@@ -30,7 +30,7 @@ PetscErrorCode LMEMonitorLGCreate(MPI_Comm comm,const char host[],const char lab
   PetscCall(PetscDrawAxisSetLabels(axis,"Convergence","Iteration",metric));
   PetscCall(PetscDrawDestroy(&draw));
   *lgctx = lg;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -42,14 +42,14 @@ PetscErrorCode LMEMonitor(LME lme,PetscInt it,PetscReal errest)
 
   PetscFunctionBegin;
   for (i=0;i<n;i++) PetscCall((*lme->monitor[i])(lme,it,errest,lme->monitorcontext[i]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    LMEMonitorSet - Sets an ADDITIONAL function to be called at every
    iteration to monitor convergence.
 
-   Logically Collective on lme
+   Logically Collective
 
    Input Parameters:
 +  lme     - linear matrix equation solver context obtained from LMECreate()
@@ -58,9 +58,8 @@ PetscErrorCode LMEMonitor(LME lme,PetscInt it,PetscReal errest)
              monitor routine (use NULL if no context is desired)
 -  monitordestroy - [optional] routine that frees monitor context (may be NULL)
 
-   Calling Sequence of monitor:
-$   monitor(LME lme,PetscInt its,PetscReal errest,void *mctx)
-
+   Calling sequence of monitor:
+$  PetscErrorCode monitor(LME lme,PetscInt its,PetscReal errest,void*mctx)
 +  lme    - linear matrix equation solver context obtained from LMECreate()
 .  its    - iteration number
 .  errest - error estimate
@@ -82,7 +81,7 @@ $   monitor(LME lme,PetscInt its,PetscReal errest,void *mctx)
 
 .seealso: LMEMonitorCancel()
 @*/
-PetscErrorCode LMEMonitorSet(LME lme,PetscErrorCode (*monitor)(LME,PetscInt,PetscReal,void*),void *mctx,PetscErrorCode (*monitordestroy)(void**))
+PetscErrorCode LMEMonitorSet(LME lme,PetscErrorCode (*monitor)(LME lme,PetscInt its,PetscReal errest,void*mctx),void *mctx,PetscErrorCode (*monitordestroy)(void**))
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(lme,LME_CLASSID,1);
@@ -90,13 +89,13 @@ PetscErrorCode LMEMonitorSet(LME lme,PetscErrorCode (*monitor)(LME,PetscInt,Pets
   lme->monitor[lme->numbermonitors]           = monitor;
   lme->monitorcontext[lme->numbermonitors]    = (void*)mctx;
   lme->monitordestroy[lme->numbermonitors++]  = monitordestroy;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    LMEMonitorCancel - Clears all monitors for an LME object.
 
-   Logically Collective on lme
+   Logically Collective
 
    Input Parameters:
 .  lme - linear matrix equation solver context obtained from LMECreate()
@@ -120,7 +119,7 @@ PetscErrorCode LMEMonitorCancel(LME lme)
     if (lme->monitordestroy[i]) PetscCall((*lme->monitordestroy[i])(&lme->monitorcontext[i]));
   }
   lme->numbermonitors = 0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -144,14 +143,14 @@ PetscErrorCode LMEGetMonitorContext(LME lme,void *ctx)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(lme,LME_CLASSID,1);
   *(void**)ctx = lme->monitorcontext[0];
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    LMEMonitorDefault - Print the error estimate of the current approximation at each
    iteration of the linear matrix equation solver.
 
-   Collective on lme
+   Collective
 
    Input Parameters:
 +  lme    - linear matrix equation solver context
@@ -179,14 +178,14 @@ PetscErrorCode LMEMonitorDefault(LME lme,PetscInt its,PetscReal errest,PetscView
   PetscCall(PetscViewerASCIIPrintf(viewer,"%3" PetscInt_FMT " LME Error estimate %14.12e\n",its,(double)errest));
   PetscCall(PetscViewerASCIISubtractTab(viewer,((PetscObject)lme)->tablevel));
   PetscCall(PetscViewerPopFormat(viewer));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    LMEMonitorDefaultDrawLG - Plots the error estimate of the current approximation at each
    iteration of the linear matrix equation solver.
 
-   Collective on lme
+   Collective
 
    Input Parameters:
 +  lme    - linear matrix equation solver context
@@ -226,13 +225,13 @@ PetscErrorCode LMEMonitorDefaultDrawLG(LME lme,PetscInt its,PetscReal errest,Pet
     PetscCall(PetscDrawLGSave(lg));
   }
   PetscCall(PetscViewerPopFormat(viewer));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    LMEMonitorDefaultDrawLGCreate - Creates the plotter for the error estimate.
 
-   Collective on viewer
+   Collective
 
    Input Parameters:
 +  viewer - the viewer
@@ -252,5 +251,5 @@ PetscErrorCode LMEMonitorDefaultDrawLGCreate(PetscViewer viewer,PetscViewerForma
   PetscCall(PetscViewerAndFormatCreate(viewer,format,vf));
   (*vf)->data = ctx;
   PetscCall(LMEMonitorLGCreate(PetscObjectComm((PetscObject)viewer),NULL,"Error Estimate","Log Error Estimate",1,NULL,PETSC_DECIDE,PETSC_DECIDE,400,300,&(*vf)->lg));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
