@@ -19,7 +19,7 @@
    MFNMonitorSetFromOptions - Sets a monitor function and viewer appropriate for the type
    indicated by the user.
 
-   Collective on mfn
+   Collective
 
    Input Parameters:
 +  mfn  - the matrix function context
@@ -45,7 +45,7 @@ PetscErrorCode MFNMonitorSetFromOptions(MFN mfn,const char opt[],const char name
 
   PetscFunctionBegin;
   PetscCall(PetscOptionsGetViewer(PetscObjectComm((PetscObject)mfn),((PetscObject)mfn)->options,((PetscObject)mfn)->prefix,opt,&viewer,&format,&flg));
-  if (!flg) PetscFunctionReturn(0);
+  if (!flg) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscViewerGetType(viewer,&vtype));
   PetscCall(SlepcMonitorMakeKey_Internal(name,vtype,format,key));
@@ -59,7 +59,7 @@ PetscErrorCode MFNMonitorSetFromOptions(MFN mfn,const char opt[],const char name
   PetscCall((*cfunc)(viewer,format,ctx,&vf));
   PetscCall(PetscObjectDereference((PetscObject)viewer));
   PetscCall(MFNMonitorSet(mfn,mfunc,vf,(PetscErrorCode(*)(void **))dfunc));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -67,7 +67,7 @@ PetscErrorCode MFNMonitorSetFromOptions(MFN mfn,const char opt[],const char name
    This routine must be called before MFNSetUp() if the user is to be
    allowed to set the solver type.
 
-   Collective on mfn
+   Collective
 
    Input Parameters:
 .  mfn - the matrix function context
@@ -125,7 +125,7 @@ PetscErrorCode MFNSetFromOptions(MFN mfn)
   PetscCall(BVSetFromOptions(mfn->V));
   if (!mfn->fn) PetscCall(MFNGetFN(mfn,&mfn->fn));
   PetscCall(FNSetFromOptions(mfn->fn));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -154,14 +154,14 @@ PetscErrorCode MFNGetTolerances(MFN mfn,PetscReal *tol,PetscInt *maxits)
   PetscValidHeaderSpecific(mfn,MFN_CLASSID,1);
   if (tol)    *tol    = mfn->tol;
   if (maxits) *maxits = mfn->max_it;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MFNSetTolerances - Sets the tolerance and maximum iteration count used
    by the MFN convergence tests.
 
-   Logically Collective on mfn
+   Logically Collective
 
    Input Parameters:
 +  mfn - the matrix function context
@@ -185,7 +185,7 @@ PetscErrorCode MFNSetTolerances(MFN mfn,PetscReal tol,PetscInt maxits)
   PetscValidHeaderSpecific(mfn,MFN_CLASSID,1);
   PetscValidLogicalCollectiveReal(mfn,tol,2);
   PetscValidLogicalCollectiveInt(mfn,maxits,3);
-  if (tol == PETSC_DEFAULT) {
+  if (tol == (PetscReal)PETSC_DEFAULT) {
     mfn->tol = PETSC_DEFAULT;
     mfn->setupcalled = 0;
   } else {
@@ -199,7 +199,7 @@ PetscErrorCode MFNSetTolerances(MFN mfn,PetscReal tol,PetscInt maxits)
     PetscCheck(maxits>0,PetscObjectComm((PetscObject)mfn),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of maxits. Must be > 0");
     mfn->max_it = maxits;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -223,13 +223,13 @@ PetscErrorCode MFNGetDimensions(MFN mfn,PetscInt *ncv)
   PetscValidHeaderSpecific(mfn,MFN_CLASSID,1);
   PetscValidIntPointer(ncv,2);
   *ncv = mfn->ncv;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MFNSetDimensions - Sets the dimension of the subspace to be used by the solver.
 
-   Logically Collective on mfn
+   Logically Collective
 
    Input Parameters:
 +  mfn - the matrix function context
@@ -258,14 +258,14 @@ PetscErrorCode MFNSetDimensions(MFN mfn,PetscInt ncv)
     mfn->ncv = ncv;
   }
   mfn->setupcalled = 0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MFNSetErrorIfNotConverged - Causes MFNSolve() to generate an error if the
    solver has not converged.
 
-   Logically Collective on mfn
+   Logically Collective
 
    Input Parameters:
 +  mfn - the matrix function context
@@ -288,7 +288,7 @@ PetscErrorCode MFNSetErrorIfNotConverged(MFN mfn,PetscBool flg)
   PetscValidHeaderSpecific(mfn,MFN_CLASSID,1);
   PetscValidLogicalCollectiveBool(mfn,flg,2);
   mfn->errorifnotconverged = flg;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -313,14 +313,14 @@ PetscErrorCode MFNGetErrorIfNotConverged(MFN mfn,PetscBool *flag)
   PetscValidHeaderSpecific(mfn,MFN_CLASSID,1);
   PetscValidBoolPointer(flag,2);
   *flag = mfn->errorifnotconverged;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    MFNSetOptionsPrefix - Sets the prefix used for searching for all
    MFN options in the database.
 
-   Logically Collective on mfn
+   Logically Collective
 
    Input Parameters:
 +  mfn - the matrix function context
@@ -351,14 +351,14 @@ PetscErrorCode MFNSetOptionsPrefix(MFN mfn,const char *prefix)
   if (!mfn->fn) PetscCall(MFNGetFN(mfn,&mfn->fn));
   PetscCall(FNSetOptionsPrefix(mfn->fn,prefix));
   PetscCall(PetscObjectSetOptionsPrefix((PetscObject)mfn,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    MFNAppendOptionsPrefix - Appends to the prefix used for searching for all
    MFN options in the database.
 
-   Logically Collective on mfn
+   Logically Collective
 
    Input Parameters:
 +  mfn - the matrix function context
@@ -381,7 +381,7 @@ PetscErrorCode MFNAppendOptionsPrefix(MFN mfn,const char *prefix)
   if (!mfn->fn) PetscCall(MFNGetFN(mfn,&mfn->fn));
   PetscCall(FNAppendOptionsPrefix(mfn->fn,prefix));
   PetscCall(PetscObjectAppendOptionsPrefix((PetscObject)mfn,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -410,5 +410,5 @@ PetscErrorCode MFNGetOptionsPrefix(MFN mfn,const char *prefix[])
   PetscValidHeaderSpecific(mfn,MFN_CLASSID,1);
   PetscValidPointer(prefix,2);
   PetscCall(PetscObjectGetOptionsPrefix((PetscObject)mfn,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
