@@ -120,13 +120,13 @@ PetscErrorCode NEPCreate(MPI_Comm comm,NEP *outnep)
 
   PetscCall(PetscNew(&nep->sc));
   *outnep = nep;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    NEPSetType - Selects the particular solver to be used in the NEP object.
 
-   Logically Collective on nep
+   Logically Collective
 
    Input Parameters:
 +  nep      - the nonlinear eigensolver context
@@ -161,7 +161,7 @@ PetscErrorCode NEPSetType(NEP nep,NEPType type)
   PetscValidCharPointer(type,2);
 
   PetscCall(PetscObjectTypeCompare((PetscObject)nep,type,&match));
-  if (match) PetscFunctionReturn(0);
+  if (match) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscFunctionListFind(NEPList,type,&r));
   PetscCheck(r,PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_UNKNOWN_TYPE,"Unknown NEP type given: %s",type);
@@ -172,7 +172,7 @@ PetscErrorCode NEPSetType(NEP nep,NEPType type)
   nep->state = NEP_STATE_INITIAL;
   PetscCall(PetscObjectChangeTypeName((PetscObject)nep,type));
   PetscCall((*r)(nep));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -196,7 +196,7 @@ PetscErrorCode NEPGetType(NEP nep,NEPType *type)
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
   PetscValidPointer(type,2);
   *type = ((PetscObject)nep)->type_name;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -211,7 +211,7 @@ PetscErrorCode NEPGetType(NEP nep,NEPType *type)
    Notes:
    NEPRegister() may be called multiple times to add several user-defined solvers.
 
-   Sample usage:
+   Example Usage:
 .vb
     NEPRegister("my_solver",MySolverCreate);
 .ve
@@ -230,7 +230,7 @@ PetscErrorCode NEPRegister(const char *name,PetscErrorCode (*function)(NEP))
   PetscFunctionBegin;
   PetscCall(NEPInitializePackage());
   PetscCall(PetscFunctionListAdd(&NEPList,name,function));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -249,7 +249,7 @@ PetscErrorCode NEPRegister(const char *name,PetscErrorCode (*function)(NEP))
    Notes:
    NEPMonitorRegister() may be called multiple times to add several user-defined monitors.
 
-   Sample usage:
+   Example Usage:
 .vb
    NEPMonitorRegister("my_monitor",PETSCVIEWERASCII,PETSC_VIEWER_ASCII_INFO_DETAIL,MyMonitor,NULL,NULL);
 .ve
@@ -273,7 +273,7 @@ PetscErrorCode NEPMonitorRegister(const char name[],PetscViewerType vtype,PetscV
   PetscCall(PetscFunctionListAdd(&NEPMonitorList,key,monitor));
   if (create)  PetscCall(PetscFunctionListAdd(&NEPMonitorCreateList,key,create));
   if (destroy) PetscCall(PetscFunctionListAdd(&NEPMonitorDestroyList,key,destroy));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -296,13 +296,13 @@ PetscErrorCode NEPReset_Problem(NEP nep)
     if (nep->P) PetscCall(MatDestroyMatrices(nep->nt,&nep->P));
     nep->nt = 0;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 /*@
    NEPReset - Resets the NEP context to the initial state (prior to setup)
    and destroys any allocated Vecs and Mats.
 
-   Collective on nep
+   Collective
 
    Input Parameter:
 .  nep - eigensolver context obtained from NEPCreate()
@@ -315,7 +315,7 @@ PetscErrorCode NEPReset(NEP nep)
 {
   PetscFunctionBegin;
   if (nep) PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
-  if (!nep) PetscFunctionReturn(0);
+  if (!nep) PetscFunctionReturn(PETSC_SUCCESS);
   PetscTryTypeMethod(nep,reset);
   if (nep->refineksp) PetscCall(KSPReset(nep->refineksp));
   PetscCall(NEPReset_Problem(nep));
@@ -325,13 +325,13 @@ PetscErrorCode NEPReset(NEP nep)
   PetscCall(MatDestroy(&nep->resolvent));
   nep->nwork = 0;
   nep->state = NEP_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    NEPDestroy - Destroys the NEP context.
 
-   Collective on nep
+   Collective
 
    Input Parameter:
 .  nep - eigensolver context obtained from NEPCreate()
@@ -343,9 +343,9 @@ PetscErrorCode NEPReset(NEP nep)
 PetscErrorCode NEPDestroy(NEP *nep)
 {
   PetscFunctionBegin;
-  if (!*nep) PetscFunctionReturn(0);
+  if (!*nep) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeaderSpecific(*nep,NEP_CLASSID,1);
-  if (--((PetscObject)(*nep))->refct > 0) { *nep = NULL; PetscFunctionReturn(0); }
+  if (--((PetscObject)(*nep))->refct > 0) { *nep = NULL; PetscFunctionReturn(PETSC_SUCCESS); }
   PetscCall(NEPReset(*nep));
   PetscTryTypeMethod(*nep,destroy);
   if ((*nep)->eigr) PetscCall(PetscFree4((*nep)->eigr,(*nep)->eigi,(*nep)->errest,(*nep)->perm));
@@ -359,13 +359,13 @@ PetscErrorCode NEPDestroy(NEP *nep)
   if ((*nep)->convergeddestroy) PetscCall((*(*nep)->convergeddestroy)((*nep)->convergedctx));
   PetscCall(NEPMonitorCancel(*nep));
   PetscCall(PetscHeaderDestroy(nep));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    NEPSetBV - Associates a basis vectors object to the nonlinear eigensolver.
 
-   Collective on nep
+   Collective
 
    Input Parameters:
 +  nep - eigensolver context obtained from NEPCreate()
@@ -388,7 +388,7 @@ PetscErrorCode NEPSetBV(NEP nep,BV bv)
   PetscCall(PetscObjectReference((PetscObject)bv));
   PetscCall(BVDestroy(&nep->V));
   nep->V = bv;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -418,13 +418,13 @@ PetscErrorCode NEPGetBV(NEP nep,BV *bv)
     PetscCall(PetscObjectSetOptions((PetscObject)nep->V,((PetscObject)nep)->options));
   }
   *bv = nep->V;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    NEPSetRG - Associates a region object to the nonlinear eigensolver.
 
-   Collective on nep
+   Collective
 
    Input Parameters:
 +  nep - eigensolver context obtained from NEPCreate()
@@ -449,7 +449,7 @@ PetscErrorCode NEPSetRG(NEP nep,RG rg)
   PetscCall(PetscObjectReference((PetscObject)rg));
   PetscCall(RGDestroy(&nep->rg));
   nep->rg = rg;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -479,13 +479,13 @@ PetscErrorCode NEPGetRG(NEP nep,RG *rg)
     PetscCall(PetscObjectSetOptions((PetscObject)nep->rg,((PetscObject)nep)->options));
   }
   *rg = nep->rg;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    NEPSetDS - Associates a direct solver object to the nonlinear eigensolver.
 
-   Collective on nep
+   Collective
 
    Input Parameters:
 +  nep - eigensolver context obtained from NEPCreate()
@@ -508,7 +508,7 @@ PetscErrorCode NEPSetDS(NEP nep,DS ds)
   PetscCall(PetscObjectReference((PetscObject)ds));
   PetscCall(DSDestroy(&nep->ds));
   nep->ds = ds;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -538,14 +538,14 @@ PetscErrorCode NEPGetDS(NEP nep,DS *ds)
     PetscCall(PetscObjectSetOptions((PetscObject)nep->ds,((PetscObject)nep)->options));
   }
   *ds = nep->ds;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    NEPRefineGetKSP - Obtain the ksp object used by the eigensolver
    object in the refinement phase.
 
-   Not Collective
+   Collective
 
    Input Parameters:
 .  nep - eigensolver context obtained from NEPCreate()
@@ -580,13 +580,13 @@ PetscErrorCode NEPRefineGetKSP(NEP nep,KSP *ksp)
     PetscCall(KSPSetTolerances(nep->refineksp,SlepcDefaultTol(nep->rtol),PETSC_DEFAULT,PETSC_DEFAULT,PETSC_DEFAULT));
   }
   *ksp = nep->refineksp;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    NEPSetTarget - Sets the value of the target.
 
-   Logically Collective on nep
+   Logically Collective
 
    Input Parameters:
 +  nep    - eigensolver context
@@ -613,7 +613,7 @@ PetscErrorCode NEPSetTarget(NEP nep,PetscScalar target)
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
   PetscValidLogicalCollectiveScalar(nep,target,2);
   nep->target = target;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -640,14 +640,14 @@ PetscErrorCode NEPGetTarget(NEP nep,PetscScalar* target)
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
   PetscValidScalarPointer(target,2);
   *target = nep->target;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    NEPSetFunction - Sets the function to compute the nonlinear Function T(lambda)
    as well as the location to store the matrix.
 
-   Logically Collective on nep
+   Collective
 
    Input Parameters:
 +  nep - the NEP context
@@ -659,9 +659,8 @@ PetscErrorCode NEPGetTarget(NEP nep,PetscScalar* target)
          evaluation routine (may be NULL) (if NULL then NEP retains any
          previously set value)
 
-   Calling Sequence of fun:
-$   fun(NEP nep,PetscScalar lambda,Mat T,Mat P,void *ctx)
-
+   Calling sequence of fun:
+$  PetscErrorCode fun(NEP nep,PetscScalar lambda,Mat T,Mat P,void *ctx)
 +  nep    - the NEP context
 .  lambda - the scalar argument where T(.) must be evaluated
 .  T      - matrix that will contain T(lambda)
@@ -672,7 +671,7 @@ $   fun(NEP nep,PetscScalar lambda,Mat T,Mat P,void *ctx)
 
 .seealso: NEPGetFunction(), NEPSetJacobian()
 @*/
-PetscErrorCode NEPSetFunction(NEP nep,Mat A,Mat B,PetscErrorCode (*fun)(NEP,PetscScalar,Mat,Mat,void*),void *ctx)
+PetscErrorCode NEPSetFunction(NEP nep,Mat A,Mat B,PetscErrorCode (*fun)(NEP nep,PetscScalar lambda,Mat T,Mat P,void *ctx),void *ctx)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
@@ -698,14 +697,14 @@ PetscErrorCode NEPSetFunction(NEP nep,Mat A,Mat B,PetscErrorCode (*fun)(NEP,Pets
   }
   nep->fui   = NEP_USER_INTERFACE_CALLBACK;
   nep->state = NEP_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    NEPGetFunction - Returns the Function matrix and optionally the user
    provided context for evaluating the Function.
 
-   Not Collective, but Mat object will be parallel if NEP object is
+   Not Collective
 
    Input Parameter:
 .  nep - the nonlinear eigensolver context
@@ -729,14 +728,14 @@ PetscErrorCode NEPGetFunction(NEP nep,Mat *A,Mat *B,PetscErrorCode (**fun)(NEP,P
   if (B)   *B   = nep->function_pre;
   if (fun) *fun = nep->computefunction;
   if (ctx) *ctx = nep->functionctx;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    NEPSetJacobian - Sets the function to compute the Jacobian T'(lambda) as well
    as the location to store the matrix.
 
-   Logically Collective on nep
+   Collective
 
    Input Parameters:
 +  nep - the NEP context
@@ -747,9 +746,8 @@ PetscErrorCode NEPGetFunction(NEP nep,Mat *A,Mat *B,PetscErrorCode (**fun)(NEP,P
          evaluation routine (may be NULL) (if NULL then NEP retains any
          previously set value)
 
-   Calling Sequence of jac:
-$   jac(NEP nep,PetscScalar lambda,Mat J,void *ctx)
-
+   Calling sequence of jac:
+$  PetscErrorCode jac(NEP nep,PetscScalar lambda,Mat J,void *ctx)
 +  nep    - the NEP context
 .  lambda - the scalar argument where T'(.) must be evaluated
 .  J      - matrix that will contain T'(lambda)
@@ -759,7 +757,7 @@ $   jac(NEP nep,PetscScalar lambda,Mat J,void *ctx)
 
 .seealso: NEPSetFunction(), NEPGetJacobian()
 @*/
-PetscErrorCode NEPSetJacobian(NEP nep,Mat A,PetscErrorCode (*jac)(NEP,PetscScalar,Mat,void*),void *ctx)
+PetscErrorCode NEPSetJacobian(NEP nep,Mat A,PetscErrorCode (*jac)(NEP nep,PetscScalar lambda,Mat J,void *ctx),void *ctx)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
@@ -778,14 +776,14 @@ PetscErrorCode NEPSetJacobian(NEP nep,Mat A,PetscErrorCode (*jac)(NEP,PetscScala
   }
   nep->fui   = NEP_USER_INTERFACE_CALLBACK;
   nep->state = NEP_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    NEPGetJacobian - Returns the Jacobian matrix and optionally the user
    provided routine and context for evaluating the Jacobian.
 
-   Not Collective, but Mat object will be parallel if NEP object is
+   Not Collective
 
    Input Parameter:
 .  nep - the nonlinear eigensolver context
@@ -807,14 +805,14 @@ PetscErrorCode NEPGetJacobian(NEP nep,Mat *A,PetscErrorCode (**jac)(NEP,PetscSca
   if (A)   *A   = nep->jacobian;
   if (jac) *jac = nep->computejacobian;
   if (ctx) *ctx = nep->jacobianctx;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    NEPSetSplitOperator - Sets the operator of the nonlinear eigenvalue problem
    in split form.
 
-   Collective on nep
+   Collective
 
    Input Parameters:
 +  nep - the nonlinear eigensolver context
@@ -884,14 +882,14 @@ PetscErrorCode NEPSetSplitOperator(NEP nep,PetscInt nt,Mat A[],FN f[],MatStructu
   nep->mstr  = str;
   nep->fui   = NEP_USER_INTERFACE_SPLIT;
   nep->state = NEP_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    NEPGetSplitOperatorTerm - Gets the matrices and functions associated with
    the nonlinear operator in split form.
 
-   Not collective, though parallel Mats and FNs are returned if the NEP is parallel
+   Not Collective
 
    Input Parameters:
 +  nep - the nonlinear eigensolver context
@@ -914,14 +912,14 @@ PetscErrorCode NEPGetSplitOperatorTerm(NEP nep,PetscInt k,Mat *A,FN *f)
   PetscCheck(k>=0 && k<nep->nt,PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"k must be between 0 and %" PetscInt_FMT,nep->nt-1);
   if (A) *A = nep->A[k];
   if (f) *f = nep->f[k];
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    NEPGetSplitOperatorInfo - Returns the number of terms of the split form of
    the nonlinear operator, as well as the structure flag for matrices.
 
-   Not collective
+   Not Collective
 
    Input Parameter:
 .  nep - the nonlinear eigensolver context
@@ -941,7 +939,7 @@ PetscErrorCode NEPGetSplitOperatorInfo(NEP nep,PetscInt *n,MatStructure *str)
   NEPCheckSplit(nep,1);
   if (n)   *n = nep->nt;
   if (str) *str = nep->mstr;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -949,7 +947,7 @@ PetscErrorCode NEPGetSplitOperatorInfo(NEP nep,PetscInt *n,MatStructure *str)
    to build the preconditioner to be used when solving the nonlinear
    eigenvalue problem in split form.
 
-   Collective on nep
+   Collective
 
    Input Parameters:
 +  nep  - the nonlinear eigensolver context
@@ -1014,14 +1012,14 @@ PetscErrorCode NEPSetSplitPreconditioner(NEP nep,PetscInt ntp,Mat P[],MatStructu
   }
   nep->mstrp = strp;
   nep->state = NEP_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    NEPGetSplitPreconditionerTerm - Gets the matrices associated with
    the split preconditioner.
 
-   Not collective, though parallel Mats are returned if the NEP is parallel
+   Not Collective
 
    Input Parameters:
 +  nep - the nonlinear eigensolver context
@@ -1044,14 +1042,14 @@ PetscErrorCode NEPGetSplitPreconditionerTerm(NEP nep,PetscInt k,Mat *P)
   PetscCheck(k>=0 && k<nep->nt,PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"k must be between 0 and %" PetscInt_FMT,nep->nt-1);
   PetscCheck(nep->P,PetscObjectComm((PetscObject)nep),PETSC_ERR_ORDER,"You have not called NEPSetSplitPreconditioner()");
   *P = nep->P[k];
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    NEPGetSplitPreconditionerInfo - Returns the number of terms of the split
    preconditioner, as well as the structure flag for matrices.
 
-   Not collective
+   Not Collective
 
    Input Parameter:
 .  nep - the nonlinear eigensolver context
@@ -1071,5 +1069,5 @@ PetscErrorCode NEPGetSplitPreconditionerInfo(NEP nep,PetscInt *n,MatStructure *s
   NEPCheckSplit(nep,1);
   if (n)    *n    = nep->P? nep->nt: 0;
   if (strp) *strp = nep->mstrp;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
