@@ -19,7 +19,7 @@
    NEPMonitorSetFromOptions - Sets a monitor function and viewer appropriate for the type
    indicated by the user.
 
-   Collective on nep
+   Collective
 
    Input Parameters:
 +  nep      - the nonlinear eigensolver context
@@ -46,7 +46,7 @@ PetscErrorCode NEPMonitorSetFromOptions(NEP nep,const char opt[],const char name
 
   PetscFunctionBegin;
   PetscCall(PetscOptionsGetViewer(PetscObjectComm((PetscObject)nep),((PetscObject)nep)->options,((PetscObject)nep)->prefix,opt,&viewer,&format,&flg));
-  if (!flg) PetscFunctionReturn(0);
+  if (!flg) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscViewerGetType(viewer,&vtype));
   PetscCall(SlepcMonitorMakeKey_Internal(name,vtype,format,key));
@@ -61,7 +61,7 @@ PetscErrorCode NEPMonitorSetFromOptions(NEP nep,const char opt[],const char name
   PetscCall(PetscObjectDereference((PetscObject)viewer));
   PetscCall(NEPMonitorSet(nep,mfunc,vf,(PetscErrorCode(*)(void **))dfunc));
   if (trackall) PetscCall(NEPSetTrackAll(nep,PETSC_TRUE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -69,7 +69,7 @@ PetscErrorCode NEPMonitorSetFromOptions(NEP nep,const char opt[],const char name
    This routine must be called before NEPSetUp() if the user is to be
    allowed to set the solver type.
 
-   Collective on nep
+   Collective
 
    Input Parameters:
 .  nep - the nonlinear eigensolver context
@@ -109,7 +109,7 @@ PetscErrorCode NEPSetFromOptions(NEP nep)
     i = nep->npart;
     PetscCall(PetscOptionsInt("-nep_refine_partitions","Number of partitions of the communicator for iterative refinement","NEPSetRefine",nep->npart,&i,&flg2));
     r = nep->rtol;
-    PetscCall(PetscOptionsReal("-nep_refine_tol","Tolerance for iterative refinement","NEPSetRefine",nep->rtol==PETSC_DEFAULT?SLEPC_DEFAULT_TOL/1000:nep->rtol,&r,&flg3));
+    PetscCall(PetscOptionsReal("-nep_refine_tol","Tolerance for iterative refinement","NEPSetRefine",nep->rtol==(PetscReal)PETSC_DEFAULT?SLEPC_DEFAULT_TOL/1000:nep->rtol,&r,&flg3));
     j = nep->rits;
     PetscCall(PetscOptionsInt("-nep_refine_its","Maximum number of iterations for iterative refinement","NEPSetRefine",nep->rits,&j,&flg4));
     scheme = nep->scheme;
@@ -202,12 +202,13 @@ PetscErrorCode NEPSetFromOptions(NEP nep)
   PetscCall(RGSetFromOptions(nep->rg));
   if (nep->useds) {
     if (!nep->ds) PetscCall(NEPGetDS(nep,&nep->ds));
+    PetscCall(NEPSetDSType(nep));
     PetscCall(DSSetFromOptions(nep->ds));
   }
   if (!nep->refineksp) PetscCall(NEPRefineGetKSP(nep,&nep->refineksp));
   PetscCall(KSPSetFromOptions(nep->refineksp));
   if (nep->fui==NEP_USER_INTERFACE_SPLIT) for (i=0;i<nep->nt;i++) PetscCall(FNSetFromOptions(nep->f[i]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -236,14 +237,14 @@ PetscErrorCode NEPGetTolerances(NEP nep,PetscReal *tol,PetscInt *maxits)
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
   if (tol)    *tol    = nep->tol;
   if (maxits) *maxits = nep->max_it;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    NEPSetTolerances - Sets the tolerance and maximum iteration count used
    by the NEP convergence tests.
 
-   Logically Collective on nep
+   Logically Collective
 
    Input Parameters:
 +  nep    - the nonlinear eigensolver context
@@ -267,7 +268,7 @@ PetscErrorCode NEPSetTolerances(NEP nep,PetscReal tol,PetscInt maxits)
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
   PetscValidLogicalCollectiveReal(nep,tol,2);
   PetscValidLogicalCollectiveInt(nep,maxits,3);
-  if (tol == PETSC_DEFAULT) {
+  if (tol == (PetscReal)PETSC_DEFAULT) {
     nep->tol   = PETSC_DEFAULT;
     nep->state = NEP_STATE_INITIAL;
   } else {
@@ -281,7 +282,7 @@ PetscErrorCode NEPSetTolerances(NEP nep,PetscReal tol,PetscInt maxits)
     PetscCheck(maxits>0,PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of maxits. Must be > 0");
     nep->max_it = maxits;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -312,14 +313,14 @@ PetscErrorCode NEPGetDimensions(NEP nep,PetscInt *nev,PetscInt *ncv,PetscInt *mp
   if (nev) *nev = nep->nev;
   if (ncv) *ncv = nep->ncv;
   if (mpd) *mpd = nep->mpd;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    NEPSetDimensions - Sets the number of eigenvalues to compute
    and the dimension of the subspace.
 
-   Logically Collective on nep
+   Logically Collective
 
    Input Parameters:
 +  nep - the nonlinear eigensolver context
@@ -371,34 +372,19 @@ PetscErrorCode NEPSetDimensions(NEP nep,PetscInt nev,PetscInt ncv,PetscInt mpd)
     nep->mpd = mpd;
   }
   nep->state = NEP_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     NEPSetWhichEigenpairs - Specifies which portion of the spectrum is
     to be sought.
 
-    Logically Collective on nep
+    Logically Collective
 
     Input Parameters:
 +   nep   - eigensolver context obtained from NEPCreate()
 -   which - the portion of the spectrum to be sought
 
-    Possible values:
-    The parameter 'which' can have one of these values
-
-+     NEP_LARGEST_MAGNITUDE - largest eigenvalues in magnitude (default)
-.     NEP_SMALLEST_MAGNITUDE - smallest eigenvalues in magnitude
-.     NEP_LARGEST_REAL - largest real parts
-.     NEP_SMALLEST_REAL - smallest real parts
-.     NEP_LARGEST_IMAGINARY - largest imaginary parts
-.     NEP_SMALLEST_IMAGINARY - smallest imaginary parts
-.     NEP_TARGET_MAGNITUDE - eigenvalues closest to the target (in magnitude)
-.     NEP_TARGET_REAL - eigenvalues with real part closest to target
-.     NEP_TARGET_IMAGINARY - eigenvalues with imaginary part closest to target
-.     NEP_ALL - all eigenvalues contained in a given region
--     NEP_WHICH_USER - user defined ordering set with NEPSetEigenvalueComparison()
-
     Options Database Keys:
 +   -nep_largest_magnitude - Sets largest eigenvalues in magnitude
 .   -nep_smallest_magnitude - Sets smallest eigenvalues in magnitude
@@ -412,6 +398,20 @@ PetscErrorCode NEPSetDimensions(NEP nep,PetscInt nev,PetscInt ncv,PetscInt mpd)
 -   -nep_all - Sets all eigenvalues in a region
 
     Notes:
+    The parameter 'which' can have one of these values
+
++     NEP_LARGEST_MAGNITUDE - largest eigenvalues in magnitude (default)
+.     NEP_SMALLEST_MAGNITUDE - smallest eigenvalues in magnitude
+.     NEP_LARGEST_REAL - largest real parts
+.     NEP_SMALLEST_REAL - smallest real parts
+.     NEP_LARGEST_IMAGINARY - largest imaginary parts
+.     NEP_SMALLEST_IMAGINARY - smallest imaginary parts
+.     NEP_TARGET_MAGNITUDE - eigenvalues closest to the target (in magnitude)
+.     NEP_TARGET_REAL - eigenvalues with real part closest to target
+.     NEP_TARGET_IMAGINARY - eigenvalues with imaginary part closest to target
+.     NEP_ALL - all eigenvalues contained in a given region
+-     NEP_WHICH_USER - user defined ordering set with NEPSetEigenvalueComparison()
+
     Not all eigensolvers implemented in NEP account for all the possible values
     stated above. If SLEPc is compiled for real numbers NEP_LARGEST_IMAGINARY
     and NEP_SMALLEST_IMAGINARY use the absolute value of the imaginary part
@@ -457,7 +457,7 @@ PetscErrorCode NEPSetWhichEigenpairs(NEP nep,NEPWhich which)
     default:
       SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"Invalid 'which' value");
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -485,23 +485,22 @@ PetscErrorCode NEPGetWhichEigenpairs(NEP nep,NEPWhich *which)
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
   PetscValidPointer(which,2);
   *which = nep->which;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    NEPSetEigenvalueComparison - Specifies the eigenvalue comparison function
    when NEPSetWhichEigenpairs() is set to NEP_WHICH_USER.
 
-   Logically Collective on nep
+   Logically Collective
 
    Input Parameters:
 +  nep  - eigensolver context obtained from NEPCreate()
-.  func - a pointer to the comparison function
+.  comp - a pointer to the comparison function
 -  ctx  - a context pointer (the last parameter to the comparison function)
 
-   Calling Sequence of func:
-$   func(PetscScalar ar,PetscScalar ai,PetscScalar br,PetscScalar bi,PetscInt *res,void *ctx)
-
+   Calling sequence of comp:
+$  PetscErrorCode comp(PetscScalar ar,PetscScalar ai,PetscScalar br,PetscScalar bi,PetscInt *res,void *ctx)
 +   ar     - real part of the 1st eigenvalue
 .   ai     - imaginary part of the 1st eigenvalue
 .   br     - real part of the 2nd eigenvalue
@@ -519,20 +518,20 @@ $   func(PetscScalar ar,PetscScalar ai,PetscScalar br,PetscScalar bi,PetscInt *r
 
 .seealso: NEPSetWhichEigenpairs(), NEPWhich
 @*/
-PetscErrorCode NEPSetEigenvalueComparison(NEP nep,PetscErrorCode (*func)(PetscScalar,PetscScalar,PetscScalar,PetscScalar,PetscInt*,void*),void* ctx)
+PetscErrorCode NEPSetEigenvalueComparison(NEP nep,PetscErrorCode (*comp)(PetscScalar ar,PetscScalar ai,PetscScalar br,PetscScalar bi,PetscInt *res,void *ctx),void* ctx)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
-  nep->sc->comparison    = func;
+  nep->sc->comparison    = comp;
   nep->sc->comparisonctx = ctx;
   nep->which             = NEP_WHICH_USER;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    NEPSetProblemType - Specifies the type of the nonlinear eigenvalue problem.
 
-   Logically Collective on nep
+   Logically Collective
 
    Input Parameters:
 +  nep  - the nonlinear eigensolver context
@@ -564,7 +563,7 @@ PetscErrorCode NEPSetProblemType(NEP nep,NEPProblemType type)
     nep->problem_type = type;
     nep->state = NEP_STATE_INITIAL;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -588,14 +587,14 @@ PetscErrorCode NEPGetProblemType(NEP nep,NEPProblemType *type)
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
   PetscValidPointer(type,2);
   *type = nep->problem_type;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    NEPSetTwoSided - Sets the solver to use a two-sided variant so that left
    eigenvectors are also computed.
 
-   Logically Collective on nep
+   Logically Collective
 
    Input Parameters:
 +  nep      - the eigensolver context
@@ -625,7 +624,7 @@ PetscErrorCode NEPSetTwoSided(NEP nep,PetscBool twosided)
     nep->twosided = twosided;
     nep->state    = NEP_STATE_INITIAL;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -650,24 +649,23 @@ PetscErrorCode NEPGetTwoSided(NEP nep,PetscBool *twosided)
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
   PetscValidBoolPointer(twosided,2);
   *twosided = nep->twosided;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    NEPSetConvergenceTestFunction - Sets a function to compute the error estimate
    used in the convergence test.
 
-   Logically Collective on nep
+   Logically Collective
 
    Input Parameters:
 +  nep     - nonlinear eigensolver context obtained from NEPCreate()
-.  func    - a pointer to the convergence test function
+.  conv    - a pointer to the convergence test function
 .  ctx     - context for private data for the convergence routine (may be null)
 -  destroy - a routine for destroying the context (may be null)
 
-   Calling Sequence of func:
-$   func(NEP nep,PetscScalar eigr,PetscScalar eigi,PetscReal res,PetscReal *errest,void *ctx)
-
+   Calling sequence of conv:
+$  PetscErrorCode conv(NEP nep,PetscScalar eigr,PetscScalar eigi,PetscReal res,PetscReal *errest,void *ctx)
 +   nep    - nonlinear eigensolver context obtained from NEPCreate()
 .   eigr   - real part of the eigenvalue
 .   eigi   - imaginary part of the eigenvalue
@@ -683,29 +681,29 @@ $   func(NEP nep,PetscScalar eigr,PetscScalar eigi,PetscReal res,PetscReal *erre
 
 .seealso: NEPSetConvergenceTest(), NEPSetTolerances()
 @*/
-PetscErrorCode NEPSetConvergenceTestFunction(NEP nep,PetscErrorCode (*func)(NEP,PetscScalar,PetscScalar,PetscReal,PetscReal*,void*),void* ctx,PetscErrorCode (*destroy)(void*))
+PetscErrorCode NEPSetConvergenceTestFunction(NEP nep,PetscErrorCode (*conv)(NEP nep,PetscScalar eigr,PetscScalar eigi,PetscReal res,PetscReal *errest,void *ctx),void* ctx,PetscErrorCode (*destroy)(void*))
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
   if (nep->convergeddestroy) PetscCall((*nep->convergeddestroy)(nep->convergedctx));
-  nep->convergeduser    = func;
+  nep->convergeduser    = conv;
   nep->convergeddestroy = destroy;
   nep->convergedctx     = ctx;
-  if (func == NEPConvergedRelative) nep->conv = NEP_CONV_REL;
-  else if (func == NEPConvergedNorm) nep->conv = NEP_CONV_NORM;
-  else if (func == NEPConvergedAbsolute) nep->conv = NEP_CONV_ABS;
+  if (conv == NEPConvergedRelative) nep->conv = NEP_CONV_REL;
+  else if (conv == NEPConvergedNorm) nep->conv = NEP_CONV_NORM;
+  else if (conv == NEPConvergedAbsolute) nep->conv = NEP_CONV_ABS;
   else {
     nep->conv      = NEP_CONV_USER;
     nep->converged = nep->convergeduser;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    NEPSetConvergenceTest - Specifies how to compute the error estimate
    used in the convergence test.
 
-   Logically Collective on nep
+   Logically Collective
 
    Input Parameters:
 +  nep  - nonlinear eigensolver context obtained from NEPCreate()
@@ -744,7 +742,7 @@ PetscErrorCode NEPSetConvergenceTest(NEP nep,NEPConv conv)
       SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"Invalid 'conv' value");
   }
   nep->conv = conv;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -769,27 +767,26 @@ PetscErrorCode NEPGetConvergenceTest(NEP nep,NEPConv *conv)
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
   PetscValidPointer(conv,2);
   *conv = nep->conv;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    NEPSetStoppingTestFunction - Sets a function to decide when to stop the outer
    iteration of the eigensolver.
 
-   Logically Collective on nep
+   Logically Collective
 
    Input Parameters:
 +  nep     - nonlinear eigensolver context obtained from NEPCreate()
-.  func    - pointer to the stopping test function
+.  stop    - pointer to the stopping test function
 .  ctx     - context for private data for the stopping routine (may be null)
 -  destroy - a routine for destroying the context (may be null)
 
-   Calling Sequence of func:
-$   func(NEP nep,PetscInt its,PetscInt max_it,PetscInt nconv,PetscInt nev,NEPConvergedReason *reason,void *ctx)
-
+   Calling sequence of stop:
+$  PetscErrorCode stop(NEP nep,PetscInt its,PetscInt max_its,PetscInt nconv,PetscInt nev,NEPConvergedReason *reason,void *ctx)
 +   nep    - nonlinear eigensolver context obtained from NEPCreate()
 .   its    - current number of iterations
-.   max_it - maximum number of iterations
+.   max_its - maximum number of iterations
 .   nconv  - number of currently converged eigenpairs
 .   nev    - number of requested eigenpairs
 .   reason - (output) result of the stopping test
@@ -805,27 +802,27 @@ $   func(NEP nep,PetscInt its,PetscInt max_it,PetscInt nconv,PetscInt nev,NEPCon
 
 .seealso: NEPSetStoppingTest(), NEPStoppingBasic()
 @*/
-PetscErrorCode NEPSetStoppingTestFunction(NEP nep,PetscErrorCode (*func)(NEP,PetscInt,PetscInt,PetscInt,PetscInt,NEPConvergedReason*,void*),void* ctx,PetscErrorCode (*destroy)(void*))
+PetscErrorCode NEPSetStoppingTestFunction(NEP nep,PetscErrorCode (*stop)(NEP nep,PetscInt its,PetscInt max_its,PetscInt nconv,PetscInt nev,NEPConvergedReason *reason,void *ctx),void* ctx,PetscErrorCode (*destroy)(void*))
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
   if (nep->stoppingdestroy) PetscCall((*nep->stoppingdestroy)(nep->stoppingctx));
-  nep->stoppinguser    = func;
+  nep->stoppinguser    = stop;
   nep->stoppingdestroy = destroy;
   nep->stoppingctx     = ctx;
-  if (func == NEPStoppingBasic) nep->stop = NEP_STOP_BASIC;
+  if (stop == NEPStoppingBasic) nep->stop = NEP_STOP_BASIC;
   else {
     nep->stop     = NEP_STOP_USER;
     nep->stopping = nep->stoppinguser;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    NEPSetStoppingTest - Specifies how to decide the termination of the outer
    loop of the eigensolver.
 
-   Logically Collective on nep
+   Logically Collective
 
    Input Parameters:
 +  nep  - nonlinear eigensolver context obtained from NEPCreate()
@@ -859,7 +856,7 @@ PetscErrorCode NEPSetStoppingTest(NEP nep,NEPStop stop)
       SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"Invalid 'stop' value");
   }
   nep->stop = stop;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -884,14 +881,14 @@ PetscErrorCode NEPGetStoppingTest(NEP nep,NEPStop *stop)
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
   PetscValidPointer(stop,2);
   *stop = nep->stop;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    NEPSetTrackAll - Specifies if the solver must compute the residual of all
    approximate eigenpairs or not.
 
-   Logically Collective on nep
+   Logically Collective
 
    Input Parameters:
 +  nep      - the eigensolver context
@@ -915,7 +912,7 @@ PetscErrorCode NEPSetTrackAll(NEP nep,PetscBool trackall)
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
   PetscValidLogicalCollectiveBool(nep,trackall,2);
   nep->trackall = trackall;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -940,14 +937,14 @@ PetscErrorCode NEPGetTrackAll(NEP nep,PetscBool *trackall)
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
   PetscValidBoolPointer(trackall,2);
   *trackall = nep->trackall;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    NEPSetRefine - Specifies the refinement type (and options) to be used
    after the solve.
 
-   Logically Collective on nep
+   Logically Collective
 
    Input Parameters:
 +  nep    - the nonlinear eigensolver context
@@ -1015,7 +1012,7 @@ PetscErrorCode NEPSetRefine(NEP nep,NEPRefine refine,PetscInt npart,PetscReal to
       PetscCheck(npart>0 && npart<=size,PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of npart");
       nep->npart = npart;
     }
-    if (tol == PETSC_DEFAULT || tol == PETSC_DECIDE) {
+    if (tol == (PetscReal)PETSC_DEFAULT || tol == (PetscReal)PETSC_DECIDE) {
       nep->rtol = PETSC_DEFAULT;
     } else {
       PetscCheck(tol>0.0,PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of tol. Must be > 0");
@@ -1030,7 +1027,7 @@ PetscErrorCode NEPSetRefine(NEP nep,NEPRefine refine,PetscInt npart,PetscReal to
     nep->scheme = scheme;
   }
   nep->state = NEP_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1065,14 +1062,14 @@ PetscErrorCode NEPGetRefine(NEP nep,NEPRefine *refine,PetscInt *npart,PetscReal
   if (tol)    *tol    = nep->rtol;
   if (its)    *its    = nep->rits;
   if (scheme) *scheme = nep->scheme;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    NEPSetOptionsPrefix - Sets the prefix used for searching for all
    NEP options in the database.
 
-   Logically Collective on nep
+   Logically Collective
 
    Input Parameters:
 +  nep - the nonlinear eigensolver context
@@ -1105,14 +1102,14 @@ PetscErrorCode NEPSetOptionsPrefix(NEP nep,const char *prefix)
   if (!nep->rg) PetscCall(NEPGetRG(nep,&nep->rg));
   PetscCall(RGSetOptionsPrefix(nep->rg,prefix));
   PetscCall(PetscObjectSetOptionsPrefix((PetscObject)nep,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    NEPAppendOptionsPrefix - Appends to the prefix used for searching for all
    NEP options in the database.
 
-   Logically Collective on nep
+   Logically Collective
 
    Input Parameters:
 +  nep - the nonlinear eigensolver context
@@ -1137,7 +1134,7 @@ PetscErrorCode NEPAppendOptionsPrefix(NEP nep,const char *prefix)
   if (!nep->rg) PetscCall(NEPGetRG(nep,&nep->rg));
   PetscCall(RGAppendOptionsPrefix(nep->rg,prefix));
   PetscCall(PetscObjectAppendOptionsPrefix((PetscObject)nep,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1166,5 +1163,5 @@ PetscErrorCode NEPGetOptionsPrefix(NEP nep,const char *prefix[])
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
   PetscValidPointer(prefix,2);
   PetscCall(PetscObjectGetOptionsPrefix((PetscObject)nep,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
