@@ -64,7 +64,7 @@ static PetscErrorCode MatMult_Resolvent(Mat M,Vec v,Vec r)
       PetscCall(BVRestoreColumn(nep->W,i,&y));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatDestroy_Resolvent(Mat M)
@@ -77,13 +77,13 @@ static PetscErrorCode MatDestroy_Resolvent(Mat M)
     PetscCall(PetscFree4(ctx->nfactor,ctx->nfactor_avail,ctx->dots,ctx->dots_avail));
     PetscCall(PetscFree(ctx));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    NEPApplyResolvent - Applies the resolvent T^{-1}(z) to a given vector.
 
-   Collective on nep
+   Collective
 
    Input Parameters:
 +  nep   - eigensolver context obtained from NEPCreate()
@@ -132,5 +132,5 @@ PetscErrorCode NEPApplyResolvent(NEP nep,RG rg,PetscScalar omega,Vec v,Vec r)
   ctx->omega = omega;
   PetscCall(MatMult(nep->resolvent,v,r));
   PetscCall(PetscLogEventEnd(NEP_Resolvent,nep,0,0,0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
