@@ -13,11 +13,36 @@
 
 #include <slepc/private/nepimpl.h>       /*I "slepcnep.h" I*/
 
+/*@
+   NEPSetDSType - Sets the type of the internal DS object based on the current
+   settings of the nonlinear eigensolver.
+
+   Collective
+
+   Input Parameter:
+.  nep - nonlinear eigensolver context
+
+   Note:
+   This function need not be called explicitly, since it will be called at
+   both NEPSetFromOptions() and NEPSetUp().
+
+   Level: developer
+
+.seealso: NEPSetFromOptions(), NEPSetUp()
+@*/
+PetscErrorCode NEPSetDSType(NEP nep)
+{
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
+  PetscTryTypeMethod(nep,setdstype);
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
 /*@
    NEPSetUp - Sets up all the internal data structures necessary for the
    execution of the NEP solver.
 
-   Collective on nep
+   Collective
 
    Input Parameter:
 .  nep   - solver context
@@ -45,7 +70,7 @@ PetscErrorCode NEPSetUp(NEP nep)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
   NEPCheckProblem(nep,1);
-  if (nep->state) PetscFunctionReturn(0);
+  if (nep->state) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscLogEventBegin(NEP_SetUp,nep,0,0,0));
 
   /* reset the convergence flag from the previous solves */
@@ -54,6 +79,7 @@ PetscErrorCode NEPSetUp(NEP nep)
   /* set default solver type (NEPSetFromOptions was not called) */
   if (!((PetscObject)nep)->type_name) PetscCall(NEPSetType(nep,NEPRII));
   if (nep->useds && !nep->ds) PetscCall(NEPGetDS(nep,&nep->ds));
+  if (nep->useds) PetscCall(NEPSetDSType(nep));
   if (!nep->rg) PetscCall(NEPGetRG(nep,&nep->rg));
   if (!((PetscObject)nep->rg)->type_name) PetscCall(RGSetType(nep->rg,RGINTERVAL));
 
@@ -107,10 +133,10 @@ PetscErrorCode NEPSetUp(NEP nep)
   PetscUseTypeMethod(nep,setup);
 
   /* set tolerance if not yet set */
-  if (nep->tol==PETSC_DEFAULT) nep->tol = SLEPC_DEFAULT_TOL;
+  if (nep->tol==(PetscReal)PETSC_DEFAULT) nep->tol = SLEPC_DEFAULT_TOL;
   if (nep->refine) {
-    if (nep->rtol==PETSC_DEFAULT) nep->rtol = PetscMax(nep->tol/1000,PETSC_MACHINE_EPSILON);
-    if (nep->rits==PETSC_DEFAULT) nep->rits = (nep->refine==NEP_REFINE_SIMPLE)? 10: 1;
+    if (nep->rtol==(PetscReal)PETSC_DEFAULT) nep->rtol = PetscMax(nep->tol/1000,PETSC_MACHINE_EPSILON);
+    if (nep->rits==(PetscReal)PETSC_DEFAULT) nep->rits = (nep->refine==NEP_REFINE_SIMPLE)? 10: 1;
   }
 
   /* fill sorting criterion context */
@@ -187,14 +213,14 @@ PetscErrorCode NEPSetUp(NEP nep)
   }
   PetscCall(PetscLogEventEnd(NEP_SetUp,nep,0,0,0));
   nep->state = NEP_STATE_SETUP;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    NEPSetInitialSpace - Specify a basis of vectors that constitute the initial
    space, that is, the subspace from which the solver starts to iterate.
 
-   Collective on nep
+   Collective
 
    Input Parameters:
 +  nep   - the nonlinear eigensolver context
@@ -230,7 +256,7 @@ PetscErrorCode NEPSetInitialSpace(NEP nep,PetscInt n,Vec is[])
   }
   PetscCall(SlepcBasisReference_Private(n,is,&nep->nini,&nep->IS));
   if (n>0) nep->state = NEP_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -252,14 +278,14 @@ PetscErrorCode NEPSetDimensions_Default(NEP nep,PetscInt nev,PetscInt *ncv,Petsc
     }
   }
   if (*mpd==PETSC_DEFAULT) *mpd = *ncv;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    NEPAllocateSolution - Allocate memory storage for common variables such
    as eigenvalues and eigenvectors.
 
-   Collective on nep
+   Collective
 
    Input Parameters:
 +  nep   - eigensolver context
@@ -310,5 +336,5 @@ PetscErrorCode NEPAllocateSolution(NEP nep,PetscInt extra)
     PetscCall(BVDestroy(&nep->W));
     PetscCall(BVDuplicate(nep->V,&nep->W));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
