@@ -208,7 +208,7 @@ PetscErrorCode MyStoppingTest(NEP nep,PetscInt its,PetscInt max_it,PetscInt ncon
     /* check if no eigenvalues converged in last 10 restarts */
     if (nconv && ctx->nreps>10) *reason = NEP_CONVERGED_USER;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*TEST
