@@ -19,7 +19,7 @@
    PEPMonitorSetFromOptions - Sets a monitor function and viewer appropriate for the type
    indicated by the user.
 
-   Collective on pep
+   Collective
 
    Input Parameters:
 +  pep      - the polynomial eigensolver context
@@ -46,7 +46,7 @@ PetscErrorCode PEPMonitorSetFromOptions(PEP pep,const char opt[],const char name
 
   PetscFunctionBegin;
   PetscCall(PetscOptionsGetViewer(PetscObjectComm((PetscObject)pep),((PetscObject)pep)->options,((PetscObject)pep)->prefix,opt,&viewer,&format,&flg));
-  if (!flg) PetscFunctionReturn(0);
+  if (!flg) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscViewerGetType(viewer,&vtype));
   PetscCall(SlepcMonitorMakeKey_Internal(name,vtype,format,key));
@@ -61,7 +61,7 @@ PetscErrorCode PEPMonitorSetFromOptions(PEP pep,const char opt[],const char name
   PetscCall(PetscObjectDereference((PetscObject)viewer));
   PetscCall(PEPMonitorSet(pep,mfunc,vf,(PetscErrorCode(*)(void **))dfunc));
   if (trackall) PetscCall(PEPSetTrackAll(pep,PETSC_TRUE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -69,7 +69,7 @@ PetscErrorCode PEPMonitorSetFromOptions(PEP pep,const char opt[],const char name
    This routine must be called before PEPSetUp() if the user is to be
    allowed to set the solver type.
 
-   Collective on pep
+   Collective
 
    Input Parameters:
 .  pep - the polynomial eigensolver context
@@ -127,7 +127,7 @@ PetscErrorCode PEPSetFromOptions(PEP pep)
     i = pep->npart;
     PetscCall(PetscOptionsInt("-pep_refine_partitions","Number of partitions of the communicator for iterative refinement","PEPSetRefine",pep->npart,&i,&flg2));
     r = pep->rtol;
-    PetscCall(PetscOptionsReal("-pep_refine_tol","Tolerance for iterative refinement","PEPSetRefine",pep->rtol==PETSC_DEFAULT?SLEPC_DEFAULT_TOL/1000:pep->rtol,&r,&flg3));
+    PetscCall(PetscOptionsReal("-pep_refine_tol","Tolerance for iterative refinement","PEPSetRefine",pep->rtol==(PetscReal)PETSC_DEFAULT?SLEPC_DEFAULT_TOL/1000:pep->rtol,&r,&flg3));
     j = pep->rits;
     PetscCall(PetscOptionsInt("-pep_refine_its","Maximum number of iterations for iterative refinement","PEPSetRefine",pep->rits,&j,&flg4));
     scheme = pep->scheme;
@@ -227,13 +227,14 @@ PetscErrorCode PEPSetFromOptions(PEP pep)
   if (!pep->rg) PetscCall(PEPGetRG(pep,&pep->rg));
   PetscCall(RGSetFromOptions(pep->rg));
   if (!pep->ds) PetscCall(PEPGetDS(pep,&pep->ds));
+  PetscCall(PEPSetDSType(pep));
   PetscCall(DSSetFromOptions(pep->ds));
   if (!pep->st) PetscCall(PEPGetST(pep,&pep->st));
   PetscCall(PEPSetDefaultST(pep));
   PetscCall(STSetFromOptions(pep->st));
   if (!pep->refineksp) PetscCall(PEPRefineGetKSP(pep,&pep->refineksp));
   PetscCall(KSPSetFromOptions(pep->refineksp));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -262,14 +263,14 @@ PetscErrorCode PEPGetTolerances(PEP pep,PetscReal *tol,PetscInt *maxits)
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
   if (tol)    *tol    = pep->tol;
   if (maxits) *maxits = pep->max_it;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PEPSetTolerances - Sets the tolerance and maximum iteration count used
    by the PEP convergence tests.
 
-   Logically Collective on pep
+   Logically Collective
 
    Input Parameters:
 +  pep - the polynomial eigensolver context
@@ -293,7 +294,7 @@ PetscErrorCode PEPSetTolerances(PEP pep,PetscReal tol,PetscInt maxits)
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
   PetscValidLogicalCollectiveReal(pep,tol,2);
   PetscValidLogicalCollectiveInt(pep,maxits,3);
-  if (tol == PETSC_DEFAULT) {
+  if (tol == (PetscReal)PETSC_DEFAULT) {
     pep->tol   = PETSC_DEFAULT;
     pep->state = PEP_STATE_INITIAL;
   } else {
@@ -307,7 +308,7 @@ PetscErrorCode PEPSetTolerances(PEP pep,PetscReal tol,PetscInt maxits)
     PetscCheck(maxits>0,PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of maxits. Must be > 0");
     pep->max_it = maxits;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -338,14 +339,14 @@ PetscErrorCode PEPGetDimensions(PEP pep,PetscInt *nev,PetscInt *ncv,PetscInt *mp
   if (nev) *nev = pep->nev;
   if (ncv) *ncv = pep->ncv;
   if (mpd) *mpd = pep->mpd;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PEPSetDimensions - Sets the number of eigenvalues to compute
    and the dimension of the subspace.
 
-   Logically Collective on pep
+   Logically Collective
 
    Input Parameters:
 +  pep - the polynomial eigensolver context
@@ -400,34 +401,19 @@ PetscErrorCode PEPSetDimensions(PEP pep,PetscInt nev,PetscInt ncv,PetscInt mpd)
     pep->mpd = mpd;
   }
   pep->state = PEP_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PEPSetWhichEigenpairs - Specifies which portion of the spectrum is
    to be sought.
 
-   Logically Collective on pep
+   Logically Collective
 
    Input Parameters:
 +  pep   - eigensolver context obtained from PEPCreate()
 -  which - the portion of the spectrum to be sought
 
-   Possible values:
-   The parameter 'which' can have one of these values
-
-+     PEP_LARGEST_MAGNITUDE - largest eigenvalues in magnitude (default)
-.     PEP_SMALLEST_MAGNITUDE - smallest eigenvalues in magnitude
-.     PEP_LARGEST_REAL - largest real parts
-.     PEP_SMALLEST_REAL - smallest real parts
-.     PEP_LARGEST_IMAGINARY - largest imaginary parts
-.     PEP_SMALLEST_IMAGINARY - smallest imaginary parts
-.     PEP_TARGET_MAGNITUDE - eigenvalues closest to the target (in magnitude)
-.     PEP_TARGET_REAL - eigenvalues with real part closest to target
-.     PEP_TARGET_IMAGINARY - eigenvalues with imaginary part closest to target
-.     PEP_ALL - all eigenvalues contained in a given interval or region
--     PEP_WHICH_USER - user defined ordering set with PEPSetEigenvalueComparison()
-
    Options Database Keys:
 +   -pep_largest_magnitude - Sets largest eigenvalues in magnitude
 .   -pep_smallest_magnitude - Sets smallest eigenvalues in magnitude
@@ -441,6 +427,20 @@ PetscErrorCode PEPSetDimensions(PEP pep,PetscInt nev,PetscInt ncv,PetscInt mpd)
 -   -pep_all - Sets all eigenvalues in an interval or region
 
    Notes:
+   The parameter 'which' can have one of these values
+
++     PEP_LARGEST_MAGNITUDE - largest eigenvalues in magnitude (default)
+.     PEP_SMALLEST_MAGNITUDE - smallest eigenvalues in magnitude
+.     PEP_LARGEST_REAL - largest real parts
+.     PEP_SMALLEST_REAL - smallest real parts
+.     PEP_LARGEST_IMAGINARY - largest imaginary parts
+.     PEP_SMALLEST_IMAGINARY - smallest imaginary parts
+.     PEP_TARGET_MAGNITUDE - eigenvalues closest to the target (in magnitude)
+.     PEP_TARGET_REAL - eigenvalues with real part closest to target
+.     PEP_TARGET_IMAGINARY - eigenvalues with imaginary part closest to target
+.     PEP_ALL - all eigenvalues contained in a given interval or region
+-     PEP_WHICH_USER - user defined ordering set with PEPSetEigenvalueComparison()
+
    Not all eigensolvers implemented in PEP account for all the possible values
    stated above. If SLEPc is compiled for real numbers PEP_LARGEST_IMAGINARY
    and PEP_SMALLEST_IMAGINARY use the absolute value of the imaginary part
@@ -493,7 +493,7 @@ PetscErrorCode PEPSetWhichEigenpairs(PEP pep,PEPWhich which)
     default:
       SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_OUTOFRANGE,"Invalid 'which' value");
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -521,23 +521,22 @@ PetscErrorCode PEPGetWhichEigenpairs(PEP pep,PEPWhich *which)
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
   PetscValidPointer(which,2);
   *which = pep->which;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PEPSetEigenvalueComparison - Specifies the eigenvalue comparison function
    when PEPSetWhichEigenpairs() is set to PEP_WHICH_USER.
 
-   Logically Collective on pep
+   Logically Collective
 
    Input Parameters:
 +  pep  - eigensolver context obtained from PEPCreate()
-.  func - a pointer to the comparison function
+.  comp - a pointer to the comparison function
 -  ctx  - a context pointer (the last parameter to the comparison function)
 
-   Calling Sequence of func:
-$   func(PetscScalar ar,PetscScalar ai,PetscScalar br,PetscScalar bi,PetscInt *res,void *ctx)
-
+   Calling sequence of comp:
+$  PetscErrorCode comp(PetscScalar ar,PetscScalar ai,PetscScalar br,PetscScalar bi,PetscInt *res,void *ctx)
 +   ar     - real part of the 1st eigenvalue
 .   ai     - imaginary part of the 1st eigenvalue
 .   br     - real part of the 2nd eigenvalue
@@ -555,20 +554,20 @@ $   func(PetscScalar ar,PetscScalar ai,PetscScalar br,PetscScalar bi,PetscInt *r
 
 .seealso: PEPSetWhichEigenpairs(), PEPWhich
 @*/
-PetscErrorCode PEPSetEigenvalueComparison(PEP pep,PetscErrorCode (*func)(PetscScalar,PetscScalar,PetscScalar,PetscScalar,PetscInt*,void*),void* ctx)
+PetscErrorCode PEPSetEigenvalueComparison(PEP pep,PetscErrorCode (*comp)(PetscScalar ar,PetscScalar ai,PetscScalar br,PetscScalar bi,PetscInt *res,void *ctx),void* ctx)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
-  pep->sc->comparison    = func;
+  pep->sc->comparison    = comp;
   pep->sc->comparisonctx = ctx;
   pep->which             = PEP_WHICH_USER;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PEPSetProblemType - Specifies the type of the polynomial eigenvalue problem.
 
-   Logically Collective on pep
+   Logically Collective
 
    Input Parameters:
 +  pep  - the polynomial eigensolver context
@@ -607,7 +606,7 @@ PetscErrorCode PEPSetProblemType(PEP pep,PEPProblemType type)
     pep->problem_type = type;
     pep->state = PEP_STATE_INITIAL;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -631,14 +630,14 @@ PetscErrorCode PEPGetProblemType(PEP pep,PEPProblemType *type)
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
   PetscValidPointer(type,2);
   *type = pep->problem_type;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PEPSetBasis - Specifies the type of polynomial basis used to describe the
    polynomial eigenvalue problem.
 
-   Logically Collective on pep
+   Logically Collective
 
    Input Parameters:
 +  pep   - the polynomial eigensolver context
@@ -664,7 +663,7 @@ PetscErrorCode PEPSetBasis(PEP pep,PEPBasis basis)
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
   PetscValidLogicalCollectiveEnum(pep,basis,2);
   pep->basis = basis;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -688,14 +687,14 @@ PetscErrorCode PEPGetBasis(PEP pep,PEPBasis *basis)
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
   PetscValidPointer(basis,2);
   *basis = pep->basis;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PEPSetTrackAll - Specifies if the solver must compute the residual of all
    approximate eigenpairs or not.
 
-   Logically Collective on pep
+   Logically Collective
 
    Input Parameters:
 +  pep      - the eigensolver context
@@ -719,7 +718,7 @@ PetscErrorCode PEPSetTrackAll(PEP pep,PetscBool trackall)
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
   PetscValidLogicalCollectiveBool(pep,trackall,2);
   pep->trackall = trackall;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -744,24 +743,23 @@ PetscErrorCode PEPGetTrackAll(PEP pep,PetscBool *trackall)
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
   PetscValidBoolPointer(trackall,2);
   *trackall = pep->trackall;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PEPSetConvergenceTestFunction - Sets a function to compute the error estimate
    used in the convergence test.
 
-   Logically Collective on pep
+   Logically Collective
 
    Input Parameters:
 +  pep     - eigensolver context obtained from PEPCreate()
-.  func    - a pointer to the convergence test function
+.  conv    - a pointer to the convergence test function
 .  ctx     - context for private data for the convergence routine (may be null)
 -  destroy - a routine for destroying the context (may be null)
 
-   Calling Sequence of func:
-$   func(PEP pep,PetscScalar eigr,PetscScalar eigi,PetscReal res,PetscReal *errest,void *ctx)
-
+   Calling sequence of conv:
+$  PetscErrorCode conv(PEP pep,PetscScalar eigr,PetscScalar eigi,PetscReal res,PetscReal *errest,void *ctx)
 +   pep    - eigensolver context obtained from PEPCreate()
 .   eigr   - real part of the eigenvalue
 .   eigi   - imaginary part of the eigenvalue
@@ -777,29 +775,29 @@ $   func(PEP pep,PetscScalar eigr,PetscScalar eigi,PetscReal res,PetscReal *erre
 
 .seealso: PEPSetConvergenceTest(), PEPSetTolerances()
 @*/
-PetscErrorCode PEPSetConvergenceTestFunction(PEP pep,PetscErrorCode (*func)(PEP,PetscScalar,PetscScalar,PetscReal,PetscReal*,void*),void* ctx,PetscErrorCode (*destroy)(void*))
+PetscErrorCode PEPSetConvergenceTestFunction(PEP pep,PetscErrorCode (*conv)(PEP pep,PetscScalar eigr,PetscScalar eigi,PetscReal res,PetscReal *errest,void *ctx),void* ctx,PetscErrorCode (*destroy)(void*))
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
   if (pep->convergeddestroy) PetscCall((*pep->convergeddestroy)(pep->convergedctx));
-  pep->convergeduser    = func;
+  pep->convergeduser    = conv;
   pep->convergeddestroy = destroy;
   pep->convergedctx     = ctx;
-  if (func == PEPConvergedRelative) pep->conv = PEP_CONV_REL;
-  else if (func == PEPConvergedNorm) pep->conv = PEP_CONV_NORM;
-  else if (func == PEPConvergedAbsolute) pep->conv = PEP_CONV_ABS;
+  if (conv == PEPConvergedRelative) pep->conv = PEP_CONV_REL;
+  else if (conv == PEPConvergedNorm) pep->conv = PEP_CONV_NORM;
+  else if (conv == PEPConvergedAbsolute) pep->conv = PEP_CONV_ABS;
   else {
     pep->conv      = PEP_CONV_USER;
     pep->converged = pep->convergeduser;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PEPSetConvergenceTest - Specifies how to compute the error estimate
    used in the convergence test.
 
-   Logically Collective on pep
+   Logically Collective
 
    Input Parameters:
 +  pep  - eigensolver context obtained from PEPCreate()
@@ -839,7 +837,7 @@ PetscErrorCode PEPSetConvergenceTest(PEP pep,PEPConv conv)
       SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_OUTOFRANGE,"Invalid 'conv' value");
   }
   pep->conv = conv;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -864,24 +862,23 @@ PetscErrorCode PEPGetConvergenceTest(PEP pep,PEPConv *conv)
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
   PetscValidPointer(conv,2);
   *conv = pep->conv;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PEPSetStoppingTestFunction - Sets a function to decide when to stop the outer
    iteration of the eigensolver.
 
-   Logically Collective on pep
+   Logically Collective
 
    Input Parameters:
 +  pep     - eigensolver context obtained from PEPCreate()
-.  func    - pointer to the stopping test function
+.  stop    - pointer to the stopping test function
 .  ctx     - context for private data for the stopping routine (may be null)
 -  destroy - a routine for destroying the context (may be null)
 
-   Calling Sequence of func:
-$   func(PEP pep,PetscInt its,PetscInt max_it,PetscInt nconv,PetscInt nev,PEPConvergedReason *reason,void *ctx)
-
+   Calling sequence of stop:
+$  PetscErrorCode stop(PEP pep,PetscInt its,PetscInt max_it,PetscInt nconv,PetscInt nev,PEPConvergedReason *reason,void *ctx)
 +   pep    - eigensolver context obtained from PEPCreate()
 .   its    - current number of iterations
 .   max_it - maximum number of iterations
@@ -900,27 +897,27 @@ $   func(PEP pep,PetscInt its,PetscInt max_it,PetscInt nconv,PetscInt nev,PEPCon
 
 .seealso: PEPSetStoppingTest(), PEPStoppingBasic()
 @*/
-PetscErrorCode PEPSetStoppingTestFunction(PEP pep,PetscErrorCode (*func)(PEP,PetscInt,PetscInt,PetscInt,PetscInt,PEPConvergedReason*,void*),void* ctx,PetscErrorCode (*destroy)(void*))
+PetscErrorCode PEPSetStoppingTestFunction(PEP pep,PetscErrorCode (*stop)(PEP pep,PetscInt its,PetscInt max_it,PetscInt nconv,PetscInt nev,PEPConvergedReason *reason,void *ctx),void* ctx,PetscErrorCode (*destroy)(void*))
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
   if (pep->stoppingdestroy) PetscCall((*pep->stoppingdestroy)(pep->stoppingctx));
-  pep->stoppinguser    = func;
+  pep->stoppinguser    = stop;
   pep->stoppingdestroy = destroy;
   pep->stoppingctx     = ctx;
-  if (func == PEPStoppingBasic) pep->stop = PEP_STOP_BASIC;
+  if (stop == PEPStoppingBasic) pep->stop = PEP_STOP_BASIC;
   else {
     pep->stop     = PEP_STOP_USER;
     pep->stopping = pep->stoppinguser;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PEPSetStoppingTest - Specifies how to decide the termination of the outer
    loop of the eigensolver.
 
-   Logically Collective on pep
+   Logically Collective
 
    Input Parameters:
 +  pep  - eigensolver context obtained from PEPCreate()
@@ -954,7 +951,7 @@ PetscErrorCode PEPSetStoppingTest(PEP pep,PEPStop stop)
       SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_OUTOFRANGE,"Invalid 'stop' value");
   }
   pep->stop = stop;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -979,13 +976,13 @@ PetscErrorCode PEPGetStoppingTest(PEP pep,PEPStop *stop)
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
   PetscValidPointer(stop,2);
   *stop = pep->stop;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PEPSetScale - Specifies the scaling strategy to be used.
 
-   Logically Collective on pep
+   Collective
 
    Input Parameters:
 +  pep    - the eigensolver context
@@ -1033,7 +1030,7 @@ PetscErrorCode PEPSetScale(PEP pep,PEPScale scale,PetscReal alpha,Vec Dl,Vec Dr,
   pep->scale = scale;
   if (scale==PEP_SCALE_SCALAR || scale==PEP_SCALE_BOTH) {
     PetscValidLogicalCollectiveReal(pep,alpha,3);
-    if (alpha == PETSC_DEFAULT || alpha == PETSC_DECIDE) {
+    if (alpha == (PetscReal)PETSC_DEFAULT || alpha == (PetscReal)PETSC_DECIDE) {
       pep->sfactor = 0.0;
       pep->sfactor_set = PETSC_FALSE;
     } else {
@@ -1061,21 +1058,21 @@ PetscErrorCode PEPSetScale(PEP pep,PEPScale scale,PetscReal alpha,Vec Dl,Vec Dr,
     PetscValidLogicalCollectiveReal(pep,lambda,7);
     if (its==PETSC_DECIDE || its==PETSC_DEFAULT) pep->sits = 5;
     else pep->sits = its;
-    if (lambda==PETSC_DECIDE || lambda==PETSC_DEFAULT) pep->slambda = 1.0;
+    if (lambda == (PetscReal)PETSC_DECIDE || lambda == (PetscReal)PETSC_DEFAULT) pep->slambda = 1.0;
     else {
       PetscCheck(lambda>0.0,PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of lambda. Must be > 0");
       pep->slambda = lambda;
     }
   }
   pep->state = PEP_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PEPGetScale - Gets the scaling strategy used by the PEP object, and the
    associated parameters.
 
-   Not Collectiv, but vectors are shared by all processors that share the PEP
+   Not Collective
 
    Input Parameter:
 .  pep - the eigensolver context
@@ -1108,13 +1105,13 @@ PetscErrorCode PEPGetScale(PEP pep,PEPScale *scale,PetscReal *alpha,Vec *Dl,Vec
   if (Dr)     *Dr     = pep->Dr;
   if (its)    *its    = pep->sits;
   if (lambda) *lambda = pep->slambda;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PEPSetExtract - Specifies the extraction strategy to be used.
 
-   Logically Collective on pep
+   Logically Collective
 
    Input Parameters:
 +  pep     - the eigensolver context
@@ -1133,7 +1130,7 @@ PetscErrorCode PEPSetExtract(PEP pep,PEPExtract extract)
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
   PetscValidLogicalCollectiveEnum(pep,extract,2);
   pep->extract = extract;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1157,14 +1154,14 @@ PetscErrorCode PEPGetExtract(PEP pep,PEPExtract *extract)
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
   PetscValidPointer(extract,2);
   *extract = pep->extract;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PEPSetRefine - Specifies the refinement type (and options) to be used
    after the solve.
 
-   Logically Collective on pep
+   Logically Collective
 
    Input Parameters:
 +  pep    - the polynomial eigensolver context
@@ -1232,7 +1229,7 @@ PetscErrorCode PEPSetRefine(PEP pep,PEPRefine refine,PetscInt npart,PetscReal to
       PetscCheck(npart>0 && npart<=size,PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of npart");
       pep->npart = npart;
     }
-    if (tol == PETSC_DEFAULT || tol == PETSC_DECIDE) {
+    if (tol == (PetscReal)PETSC_DEFAULT || tol == (PetscReal)PETSC_DECIDE) {
       pep->rtol = PETSC_DEFAULT;
     } else {
       PetscCheck(tol>0.0,PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of tol. Must be > 0");
@@ -1247,7 +1244,7 @@ PetscErrorCode PEPSetRefine(PEP pep,PEPRefine refine,PetscInt npart,PetscReal to
     pep->scheme = scheme;
   }
   pep->state = PEP_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1282,14 +1279,14 @@ PetscErrorCode PEPGetRefine(PEP pep,PEPRefine *refine,PetscInt *npart,PetscReal
   if (tol)    *tol    = pep->rtol;
   if (its)    *its    = pep->rits;
   if (scheme) *scheme = pep->scheme;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PEPSetOptionsPrefix - Sets the prefix used for searching for all
    PEP options in the database.
 
-   Logically Collective on pep
+   Logically Collective
 
    Input Parameters:
 +  pep - the polynomial eigensolver context
@@ -1324,14 +1321,14 @@ PetscErrorCode PEPSetOptionsPrefix(PEP pep,const char *prefix)
   if (!pep->rg) PetscCall(PEPGetRG(pep,&pep->rg));
   PetscCall(RGSetOptionsPrefix(pep->rg,prefix));
   PetscCall(PetscObjectSetOptionsPrefix((PetscObject)pep,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PEPAppendOptionsPrefix - Appends to the prefix used for searching for all
    PEP options in the database.
 
-   Logically Collective on pep
+   Logically Collective
 
    Input Parameters:
 +  pep - the polynomial eigensolver context
@@ -1358,7 +1355,7 @@ PetscErrorCode PEPAppendOptionsPrefix(PEP pep,const char *prefix)
   if (!pep->rg) PetscCall(PEPGetRG(pep,&pep->rg));
   PetscCall(RGAppendOptionsPrefix(pep->rg,prefix));
   PetscCall(PetscObjectAppendOptionsPrefix((PetscObject)pep,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1387,5 +1384,5 @@ PetscErrorCode PEPGetOptionsPrefix(PEP pep,const char *prefix[])
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
   PetscValidPointer(prefix,2);
   PetscCall(PetscObjectGetOptionsPrefix((PetscObject)pep,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
