@@ -24,7 +24,7 @@ PetscErrorCode PEPSetDefaultST(PEP pep)
   PetscFunctionBegin;
   PetscTryTypeMethod(pep,setdefaultst);
   if (!((PetscObject)pep->st)->type_name) PetscCall(STSetType(pep->st,STSHIFT));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -35,14 +35,39 @@ PetscErrorCode PEPSetDefaultST_Transform(PEP pep)
 {
   PetscFunctionBegin;
   PetscCall(STSetTransform(pep->st,PETSC_TRUE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+/*@
+   PEPSetDSType - Sets the type of the internal DS object based on the current
+   settings of the polynomial eigensolver.
+
+   Collective
+
+   Input Parameter:
+.  pep - polynomial eigensolver context
+
+   Note:
+   This function need not be called explicitly, since it will be called at
+   both PEPSetFromOptions() and PEPSetUp().
+
+   Level: developer
+
+.seealso: PEPSetFromOptions(), PEPSetUp()
+@*/
+PetscErrorCode PEPSetDSType(PEP pep)
+{
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
+  PetscTryTypeMethod(pep,setdstype);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PEPSetUp - Sets up all the internal data structures necessary for the
    execution of the PEP solver.
 
-   Collective on pep
+   Collective
 
    Input Parameter:
 .  pep   - solver context
@@ -68,7 +93,7 @@ PetscErrorCode PEPSetUp(PEP pep)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
-  if (pep->state) PetscFunctionReturn(0);
+  if (pep->state) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscLogEventBegin(PEP_SetUp,pep,0,0,0));
 
   /* reset the convergence flag from the previous solves */
@@ -79,6 +104,7 @@ PetscErrorCode PEPSetUp(PEP pep)
   if (!pep->st) PetscCall(PEPGetST(pep,&pep->st));
   PetscCall(PEPSetDefaultST(pep));
   if (!pep->ds) PetscCall(PEPGetDS(pep,&pep->ds));
+  PetscCall(PEPSetDSType(pep));
   if (!pep->rg) PetscCall(PEPGetRG(pep,&pep->rg));
   if (!((PetscObject)pep->rg)->type_name) PetscCall(RGSetType(pep->rg,RGINTERVAL));
 
@@ -125,9 +151,9 @@ PetscErrorCode PEPSetUp(PEP pep)
   PetscUseTypeMethod(pep,setup);
 
   /* set tolerance if not yet set */
-  if (pep->tol==PETSC_DEFAULT) pep->tol = SLEPC_DEFAULT_TOL;
+  if (pep->tol==(PetscReal)PETSC_DEFAULT) pep->tol = SLEPC_DEFAULT_TOL;
   if (pep->refine) {
-    if (pep->rtol==PETSC_DEFAULT) pep->rtol = PetscMax(pep->tol/1000,PETSC_MACHINE_EPSILON);
+    if (pep->rtol==(PetscReal)PETSC_DEFAULT) pep->rtol = PetscMax(pep->tol/1000,PETSC_MACHINE_EPSILON);
     if (pep->rits==PETSC_DEFAULT) pep->rits = (pep->refine==PEP_REFINE_SIMPLE)? 10: 1;
   }
 
@@ -227,14 +253,14 @@ PetscErrorCode PEPSetUp(PEP pep)
   }
   PetscCall(PetscLogEventEnd(PEP_SetUp,pep,0,0,0));
   pep->state = PEP_STATE_SETUP;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PEPSetOperators - Sets the coefficient matrices associated with the polynomial
    eigenvalue problem.
 
-   Collective on pep
+   Collective
 
    Input Parameters:
 +  pep  - the eigenproblem solver context
@@ -290,13 +316,13 @@ PetscErrorCode PEPSetOperators(PEP pep,PetscInt nmat,Mat A[])
   }
   pep->nmat = nmat;
   pep->state = PEP_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PEPGetOperators - Gets the matrices associated with the polynomial eigensystem.
 
-   Not collective, though parallel Mats are returned if the PEP is parallel
+   Not Collective
 
    Input Parameters:
 +  pep - the PEP context
@@ -316,13 +342,13 @@ PetscErrorCode PEPGetOperators(PEP pep,PetscInt k,Mat *A)
   PetscValidPointer(A,3);
   PetscCheck(k>=0 && k<pep->nmat,PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_OUTOFRANGE,"k must be between 0 and %" PetscInt_FMT,pep->nmat-1);
   *A = pep->A[k];
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PEPGetNumMatrices - Returns the number of matrices stored in the PEP.
 
-   Not collective
+   Not Collective
 
    Input Parameter:
 .  pep - the PEP context
@@ -340,14 +366,14 @@ PetscErrorCode PEPGetNumMatrices(PEP pep,PetscInt *nmat)
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
   PetscValidIntPointer(nmat,2);
   *nmat = pep->nmat;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PEPSetInitialSpace - Specify a basis of vectors that constitute the initial
    space, that is, the subspace from which the solver starts to iterate.
 
-   Collective on pep
+   Collective
 
    Input Parameters:
 +  pep   - the polynomial eigensolver context
@@ -383,7 +409,7 @@ PetscErrorCode PEPSetInitialSpace(PEP pep,PetscInt n,Vec is[])
   }
   PetscCall(SlepcBasisReference_Private(n,is,&pep->nini,&pep->IS));
   if (n>0) pep->state = PEP_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -414,14 +440,14 @@ PetscErrorCode PEPSetDimensions_Default(PEP pep,PetscInt nev,PetscInt *ncv,Petsc
     }
   }
   if (*mpd==PETSC_DEFAULT) *mpd = *ncv;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PEPAllocateSolution - Allocate memory storage for common variables such
    as eigenvalues and eigenvectors.
 
-   Collective on pep
+   Collective
 
    Input Parameters:
 +  pep   - eigensolver context
@@ -462,5 +488,5 @@ PetscErrorCode PEPAllocateSolution(PEP pep,PetscInt extra)
     PetscCall(BVSetSizesFromVec(pep->V,t,requestedbv));
     PetscCall(VecDestroy(&t));
   } else PetscCall(BVResize(pep->V,requestedbv,PETSC_FALSE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
