@@ -14,6 +14,7 @@
 */
 
 #include <slepc/private/svdimpl.h>                /*I "slepcsvd.h" I*/
+#include <slepc/private/bvimpl.h>
 #include "cyclic.h"
 
 static PetscErrorCode MatMult_Cyclic(Mat B,Vec x,Vec y)
@@ -40,14 +41,14 @@ static PetscErrorCode MatMult_Cyclic(Mat B,Vec x,Vec y)
   PetscCall(VecResetArray(ctx->y2));
   PetscCall(VecRestoreArrayRead(x,&px));
   PetscCall(VecRestoreArrayWrite(y,&py));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatGetDiagonal_Cyclic(Mat B,Vec diag)
 {
   PetscFunctionBegin;
   PetscCall(VecSet(diag,0.0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatDestroy_Cyclic(Mat B)
@@ -61,7 +62,7 @@ static PetscErrorCode MatDestroy_Cyclic(Mat B)
   PetscCall(VecDestroy(&ctx->y1));
   PetscCall(VecDestroy(&ctx->y2));
   PetscCall(PetscFree(ctx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -123,7 +124,7 @@ static PetscErrorCode SVDCyclicGetCyclicMat(SVD svd,Mat A,Mat AT,Mat *C)
     PetscCall(MatGetVecType(A,&vtype));
     PetscCall(MatSetVecType(*C,vtype));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatMult_ECross(Mat B,Vec x,Vec y)
@@ -153,7 +154,7 @@ static PetscErrorCode MatMult_ECross(Mat B,Vec x,Vec y)
   PetscCall(VecResetArray(ctx->y2));
   PetscCall(VecRestoreArrayRead(x,&px));
   PetscCall(VecRestoreArrayWrite(y,&py));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatGetDiagonal_ECross(Mat B,Vec d)
@@ -207,7 +208,7 @@ static PetscErrorCode MatGetDiagonal_ECross(Mat B,Vec d)
   PetscCall(VecCopy(ctx->diag,ctx->y2));
   PetscCall(VecResetArray(ctx->y2));
   PetscCall(VecRestoreArrayWrite(d,&pd));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatDestroy_ECross(Mat B)
@@ -223,7 +224,7 @@ static PetscErrorCode MatDestroy_ECross(Mat B)
   PetscCall(VecDestroy(&ctx->diag));
   PetscCall(VecDestroy(&ctx->w));
   PetscCall(PetscFree(ctx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -303,7 +304,7 @@ static PetscErrorCode SVDCyclicGetECrossMat(SVD svd,Mat A,Mat AT,Mat *C,Vec t)
     PetscCall(MatGetVecType(A,&vtype));
     PetscCall(MatSetVecType(*C,vtype));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* Convergence test relative to the norm of R (used in GSVD only) */
@@ -313,7 +314,7 @@ static PetscErrorCode EPSConv_Cyclic(EPS eps,PetscScalar eigr,PetscScalar eigi,P
 
   PetscFunctionBegin;
   *errest = res/PetscMax(svd->nrma,svd->nrmb);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode SVDSetUp_Cyclic(SVD svd)
@@ -398,7 +399,7 @@ PetscErrorCode SVDSetUp_Cyclic(SVD svd)
     if (mpd==PETSC_DEFAULT && svd->mpd!=PETSC_DEFAULT) mpd = svd->mpd;
     PetscCall(EPSSetDimensions(cyclic->eps,nev,ncv,mpd));
     PetscCall(EPSGetTolerances(cyclic->eps,&tol,&maxit));
-    if (tol==PETSC_DEFAULT) tol = svd->tol==PETSC_DEFAULT? SLEPC_DEFAULT_TOL/10.0: svd->tol;
+    if (tol==(PetscReal)PETSC_DEFAULT) tol = svd->tol==(PetscReal)PETSC_DEFAULT? SLEPC_DEFAULT_TOL/10.0: svd->tol;
     if (maxit==PETSC_DEFAULT && svd->max_it!=PETSC_DEFAULT) maxit = svd->max_it;
     PetscCall(EPSSetTolerances(cyclic->eps,tol,maxit));
     switch (svd->conv) {
@@ -466,11 +467,11 @@ PetscErrorCode SVDSetUp_Cyclic(SVD svd)
   PetscCall(EPSGetDimensions(cyclic->eps,NULL,&svd->ncv,&svd->mpd));
   svd->ncv = PetscMin(svd->ncv,PetscMin(M,N));
   PetscCall(EPSGetTolerances(cyclic->eps,NULL,&svd->max_it));
-  if (svd->tol==PETSC_DEFAULT) svd->tol = SLEPC_DEFAULT_TOL;
+  if (svd->tol==(PetscReal)PETSC_DEFAULT) svd->tol = SLEPC_DEFAULT_TOL;
 
   svd->leftbasis = PETSC_TRUE;
   PetscCall(SVDAllocateSolution(svd,0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode SVDCyclicCheckEigenvalue(SVD svd,PetscScalar er,PetscScalar ei,PetscReal *sigma,PetscBool *isreal)
@@ -486,7 +487,7 @@ PetscErrorCode SVDCyclicCheckEigenvalue(SVD svd,PetscScalar er,PetscScalar ei,Pe
     *sigma = PetscRealPart(er);
     if (isreal) *isreal = PETSC_TRUE;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode SVDSolve_Cyclic(SVD svd)
@@ -511,7 +512,7 @@ PetscErrorCode SVDSolve_Cyclic(SVD svd)
     }
   }
   svd->nconv = j;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDComputeVectors_Cyclic_Standard(SVD svd)
@@ -547,7 +548,7 @@ static PetscErrorCode SVDComputeVectors_Cyclic_Standard(SVD svd)
   PetscCall(VecDestroy(&x));
   PetscCall(VecDestroy(&x1));
   PetscCall(VecDestroy(&x2));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDComputeVectors_Cyclic_Generalized(SVD svd)
@@ -619,7 +620,7 @@ static PetscErrorCode SVDComputeVectors_Cyclic_Generalized(SVD svd)
   PetscCall(VecDestroy(&x2));
   PetscCall(VecDestroy(&u));
   PetscCall(VecDestroy(&v));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #if defined(PETSC_USE_COMPLEX)
@@ -646,21 +647,19 @@ static PetscErrorCode VecMaxAbs(Vec x,Vec w,PetscScalar *v)
     PetscCall(VecRestoreArrayRead(x,&xx));
   }
   PetscCallMPI(MPI_Bcast(v,1,MPIU_SCALAR,root,PetscObjectComm((PetscObject)x)));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 #endif
 
 static PetscErrorCode SVDComputeVectors_Cyclic_Hyperbolic(SVD svd)
 {
   SVD_CYCLIC        *cyclic = (SVD_CYCLIC*)svd->data;
-  PetscInt          i,j,m,n,N,nconv;
+  PetscInt          i,j,m,n,nconv;
   PetscScalar       er,ei;
   PetscReal         sigma,nrm;
   PetscBool         isreal;
   const PetscScalar *px;
   Vec               u,x,xi=NULL,x1,x2,x1i=NULL,x2i;
-  Mat               Omega;
-  MatType           Atype;
   BV                U=NULL,V=NULL;
 #if !defined(PETSC_USE_COMPLEX)
   const PetscScalar *pxi;
@@ -681,16 +680,8 @@ static PetscErrorCode SVDComputeVectors_Cyclic_Hyperbolic(SVD svd)
   /* set-up Omega-normalization of U */
   U = svd->swapped? svd->V: svd->U;
   V = svd->swapped? svd->U: svd->V;
-  PetscCall(MatGetType(svd->A,&Atype));
-  PetscCall(BVGetSizes(U,&n,&N,NULL));
-  PetscCall(MatCreate(PetscObjectComm((PetscObject)svd),&Omega));
-  PetscCall(MatSetSizes(Omega,n,n,N,N));
-  PetscCall(MatSetType(Omega,Atype));
-  PetscCall(MatSetUp(Omega));
-  PetscCall(MatDiagonalSet(Omega,svd->omega,INSERT_VALUES));
-  PetscCall(BVSetMatrix(U,Omega,PETSC_TRUE));
-  PetscCall(MatDestroy(&Omega));
-
+  PetscCall(BVGetSizes(U,&n,NULL,NULL));
+  PetscCall(BV_SetMatrixDiagonal(U,svd->omega,svd->A));
   PetscCall(EPSGetConverged(cyclic->eps,&nconv));
   for (i=0,j=0;i<nconv;i++) {
     PetscCall(EPSGetEigenpair(cyclic->eps,i,&er,&ei,x,xi));
@@ -764,7 +755,7 @@ static PetscErrorCode SVDComputeVectors_Cyclic_Hyperbolic(SVD svd)
   PetscCall(VecDestroy(&xi));
   PetscCall(VecDestroy(&x1i));
   PetscCall(VecDestroy(&x2i));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode SVDComputeVectors_Cyclic(SVD svd)
@@ -783,7 +774,7 @@ PetscErrorCode SVDComputeVectors_Cyclic(SVD svd)
     default:
       SETERRQ(PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_WRONG,"Unknown singular value problem type");
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode EPSMonitor_Cyclic(EPS eps,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,void *ctx)
@@ -810,7 +801,7 @@ static PetscErrorCode EPSMonitor_Cyclic(EPS eps,PetscInt its,PetscInt nconv,Pets
   }
   nest = j;
   PetscCall(SVDMonitor(svd,its,nconv,svd->sigma,svd->errest,nest));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode SVDSetFromOptions_Cyclic(SVD svd,PetscOptionItems *PetscOptionsObject)
@@ -834,7 +825,7 @@ PetscErrorCode SVDSetFromOptions_Cyclic(SVD svd,PetscOptionItems *PetscOptionsOb
     PetscCall(STSetMatMode(st,ST_MATMODE_SHELL));
   }
   PetscCall(EPSSetFromOptions(cyclic->eps));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDCyclicSetExplicitMatrix_Cyclic(SVD svd,PetscBool explicitmat)
@@ -846,14 +837,14 @@ static PetscErrorCode SVDCyclicSetExplicitMatrix_Cyclic(SVD svd,PetscBool explic
     cyclic->explicitmatrix = explicitmat;
     svd->state = SVD_STATE_INITIAL;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDCyclicSetExplicitMatrix - Indicate if the eigensolver operator
    H(A) = [ 0  A ; A^T 0 ] must be computed explicitly.
 
-   Logically Collective on svd
+   Logically Collective
 
    Input Parameters:
 +  svd         - singular value solver
@@ -872,7 +863,7 @@ PetscErrorCode SVDCyclicSetExplicitMatrix(SVD svd,PetscBool explicitmat)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidLogicalCollectiveBool(svd,explicitmat,2);
   PetscTryMethod(svd,"SVDCyclicSetExplicitMatrix_C",(SVD,PetscBool),(svd,explicitmat));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDCyclicGetExplicitMatrix_Cyclic(SVD svd,PetscBool *explicitmat)
@@ -881,7 +872,7 @@ static PetscErrorCode SVDCyclicGetExplicitMatrix_Cyclic(SVD svd,PetscBool *expli
 
   PetscFunctionBegin;
   *explicitmat = cyclic->explicitmatrix;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -905,7 +896,7 @@ PetscErrorCode SVDCyclicGetExplicitMatrix(SVD svd,PetscBool *explicitmat)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidBoolPointer(explicitmat,2);
   PetscUseMethod(svd,"SVDCyclicGetExplicitMatrix_C",(SVD,PetscBool*),(svd,explicitmat));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDCyclicSetEPS_Cyclic(SVD svd,EPS eps)
@@ -918,14 +909,14 @@ static PetscErrorCode SVDCyclicSetEPS_Cyclic(SVD svd,EPS eps)
   cyclic->eps     = eps;
   cyclic->usereps = PETSC_TRUE;
   svd->state      = SVD_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDCyclicSetEPS - Associate an eigensolver object (EPS) to the
    singular value solver.
 
-   Collective on svd
+   Collective
 
    Input Parameters:
 +  svd - singular value solver
@@ -942,7 +933,7 @@ PetscErrorCode SVDCyclicSetEPS(SVD svd,EPS eps)
   PetscValidHeaderSpecific(eps,EPS_CLASSID,2);
   PetscCheckSameComm(svd,1,eps,2);
   PetscTryMethod(svd,"SVDCyclicSetEPS_C",(SVD,EPS),(svd,eps));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDCyclicGetEPS_Cyclic(SVD svd,EPS *eps)
@@ -960,14 +951,14 @@ static PetscErrorCode SVDCyclicGetEPS_Cyclic(SVD svd,EPS *eps)
     PetscCall(EPSMonitorSet(cyclic->eps,EPSMonitor_Cyclic,svd,NULL));
   }
   *eps = cyclic->eps;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDCyclicGetEPS - Retrieve the eigensolver object (EPS) associated
    to the singular value solver.
 
-   Not Collective
+   Collective
 
    Input Parameter:
 .  svd - singular value solver
@@ -985,7 +976,7 @@ PetscErrorCode SVDCyclicGetEPS(SVD svd,EPS *eps)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidPointer(eps,2);
   PetscUseMethod(svd,"SVDCyclicGetEPS_C",(SVD,EPS*),(svd,eps));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode SVDView_Cyclic(SVD svd,PetscViewer viewer)
@@ -1002,7 +993,7 @@ PetscErrorCode SVDView_Cyclic(SVD svd,PetscViewer viewer)
     PetscCall(EPSView(cyclic->eps,viewer));
     PetscCall(PetscViewerASCIIPopTab(viewer));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode SVDReset_Cyclic(SVD svd)
@@ -1013,7 +1004,7 @@ PetscErrorCode SVDReset_Cyclic(SVD svd)
   PetscCall(EPSReset(cyclic->eps));
   PetscCall(MatDestroy(&cyclic->C));
   PetscCall(MatDestroy(&cyclic->D));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode SVDDestroy_Cyclic(SVD svd)
@@ -1027,7 +1018,7 @@ PetscErrorCode SVDDestroy_Cyclic(SVD svd)
   PetscCall(PetscObjectComposeFunction((PetscObject)svd,"SVDCyclicGetEPS_C",NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)svd,"SVDCyclicSetExplicitMatrix_C",NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)svd,"SVDCyclicGetExplicitMatrix_C",NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 SLEPC_EXTERN PetscErrorCode SVDCreate_Cyclic(SVD svd)
@@ -1050,5 +1041,5 @@ SLEPC_EXTERN PetscErrorCode SVDCreate_Cyclic(SVD svd)
   PetscCall(PetscObjectComposeFunction((PetscObject)svd,"SVDCyclicGetEPS_C",SVDCyclicGetEPS_Cyclic));
   PetscCall(PetscObjectComposeFunction((PetscObject)svd,"SVDCyclicSetExplicitMatrix_C",SVDCyclicSetExplicitMatrix_Cyclic));
   PetscCall(PetscObjectComposeFunction((PetscObject)svd,"SVDCyclicGetExplicitMatrix_C",SVDCyclicGetExplicitMatrix_Cyclic));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
