@@ -29,6 +29,7 @@
 */
 
 #include <slepc/private/svdimpl.h>          /*I "slepcsvd.h" I*/
+#include <slepc/private/bvimpl.h>
 
 static PetscBool  cited = PETSC_FALSE,citedg = PETSC_FALSE;
 static const char citation[] =
@@ -85,7 +86,7 @@ static PetscErrorCode MatZCreateContext(SVD svd,MatZData **zdata)
   PetscCall(MatCreateVecsEmpty(svd->B,NULL,&(*zdata)->y2));
   PetscCall(VecGetLocalSize((*zdata)->y1,&(*zdata)->m));
   PetscCall(BVCreateVec(svd->U,&(*zdata)->y));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* Update scale factor for B in Z=[A;B]
@@ -128,7 +129,7 @@ static PetscErrorCode MatZUpdateScale(SVD svd)
   PetscCall(SVD_KSPSetOperators(lanczos->ksp,lanczos->Z,normal));
   PetscCall(KSPSetUp(lanczos->ksp));
   PetscCall(MatDestroy(&normal));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatDestroy_Z(Mat Z)
@@ -141,7 +142,7 @@ static PetscErrorCode MatDestroy_Z(Mat Z)
   PetscCall(VecDestroy(&zdata->y2));
   PetscCall(VecDestroy(&zdata->y));
   PetscCall(PetscFree(zdata));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatMult_Z(Mat Z,Vec x,Vec y)
@@ -162,7 +163,7 @@ static PetscErrorCode MatMult_Z(Mat Z,Vec x,Vec y)
   PetscCall(VecResetArray(zdata->y1));
   PetscCall(VecResetArray(zdata->y2));
   PetscCall(VecRestoreArray(y,&y_elems));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatMultTranspose_Z(Mat Z,Vec y,Vec x)
@@ -183,7 +184,7 @@ static PetscErrorCode MatMultTranspose_Z(Mat Z,Vec y,Vec x)
   PetscCall(VecResetArray(zdata->y1));
   PetscCall(VecResetArray(zdata->y2));
   PetscCall(VecRestoreArrayRead(y,&y_elems));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatCreateVecs_Z(Mat Z,Vec *right,Vec *left)
@@ -194,21 +195,19 @@ static PetscErrorCode MatCreateVecs_Z(Mat Z,Vec *right,Vec *left)
   PetscCall(MatShellGetContext(Z,&zdata));
   if (right) PetscCall(MatCreateVecs(zdata->A,right,NULL));
   if (left) PetscCall(VecDuplicate(zdata->y,left));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-#define SWAP(a,b,t) {t=a;a=b;b=t;}
+#define SWAP(a,b,t) do {t=a;a=b;b=t;} while (0)
 
 PetscErrorCode SVDSetUp_TRLanczos(SVD svd)
 {
   PetscInt       M,N,P,m,n,p;
   SVD_TRLANCZOS  *lanczos = (SVD_TRLANCZOS*)svd->data;
-  DSType         dstype;
   MatZData       *zdata;
   Mat            aux;
 
   PetscFunctionBegin;
-  SVDCheckDefinite(svd);
   PetscCall(MatGetSize(svd->A,&M,&N));
   PetscCall(SVDSetDimensions_Default(svd));
   PetscCheck(svd->ncv<=svd->nsv+svd->mpd,PetscObjectComm((PetscObject)svd),PETSC_ERR_USER_INPUT,"The value of ncv must not be larger than nsv+mpd");
@@ -217,7 +216,6 @@ PetscErrorCode SVDSetUp_TRLanczos(SVD svd)
   if (!lanczos->keep) lanczos->keep = 0.5;
   svd->leftbasis = PETSC_TRUE;
   PetscCall(SVDAllocateSolution(svd,1));
-  dstype = DSSVD;
   if (svd->isgeneralized) {
     PetscCall(MatGetSize(svd->B,&P,NULL));
     if (lanczos->bidiag == SVD_TRLANCZOS_GBIDIAG_LOWER && ((svd->which==SVD_LARGEST && P<=N) || (svd->which==SVD_SMALLEST && M>N && P<=N))) {
@@ -226,7 +224,6 @@ PetscErrorCode SVDSetUp_TRLanczos(SVD svd)
       svd->swapped = PETSC_TRUE;
     } else svd->swapped = PETSC_FALSE;
 
-    if (lanczos->bidiag==SVD_TRLANCZOS_GBIDIAG_UPPER || lanczos->bidiag==SVD_TRLANCZOS_GBIDIAG_LOWER) dstype = DSGSVD;
     PetscCall(SVDSetWorkVecs(svd,1,1));
 
     if (svd->conv==SVD_CONV_ABS) {  /* Residual norms are multiplied by matrix norms */
@@ -252,12 +249,15 @@ PetscErrorCode SVDSetUp_TRLanczos(SVD svd)
     }
     /* Explicit matrix is created here, when updating the scale */
     PetscCall(MatZUpdateScale(svd));
+
+  } else if (svd->ishyperbolic) {
+    PetscCall(BV_SetMatrixDiagonal(svd->swapped?svd->V:svd->U,svd->omega,svd->OP));
+    PetscCall(SVDSetWorkVecs(svd,1,0));
   }
-  PetscCall(DSSetType(svd->ds,dstype));
   PetscCall(DSSetCompact(svd->ds,PETSC_TRUE));
   PetscCall(DSSetExtraRow(svd->ds,PETSC_TRUE));
   PetscCall(DSAllocate(svd->ds,svd->ncv+1));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDOneSideTRLanczosMGS(SVD svd,PetscReal *alpha,PetscReal *beta,BV V,BV U,PetscInt nconv,PetscInt l,PetscInt n,PetscScalar* work)
@@ -310,7 +310,7 @@ static PetscErrorCode SVDOneSideTRLanczosMGS(SVD svd,PetscReal *alpha,PetscReal
   PetscCall(BVRestoreColumn(U,n-1,&ui1));
   PetscCall(BVOrthogonalizeColumn(V,n,NULL,&b,NULL));
   beta[n-1] = b;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -351,7 +351,7 @@ static PetscErrorCode SVDOrthogonalizeCGS(BV V,PetscInt i,PetscScalar* h,PetscRe
     }
     break;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDOneSideTRLanczosCGS(SVD svd,PetscReal *alpha,PetscReal *beta,BV V,BV U,PetscInt nconv,PetscInt l,PetscInt n,PetscScalar* work)
@@ -444,7 +444,7 @@ static PetscErrorCode SVDOneSideTRLanczosCGS(SVD svd,PetscReal *alpha,PetscReal
   PetscCall(BVSetActiveColumns(V,nconv,n));
   alpha[n-1] = a;
   beta[n-1] = b;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode SVDSolve_TRLanczos(SVD svd)
@@ -547,7 +547,168 @@ PetscErrorCode SVDSolve_TRLanczos(SVD svd)
   PetscCall(PetscFree(w));
   if (swork) PetscCall(PetscFree(swork));
   PetscCall(DSTruncate(svd->ds,svd->nconv,PETSC_TRUE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+PetscErrorCode SVDLanczosHSVD(SVD svd,PetscReal *alpha,PetscReal *beta,PetscReal *omega,Mat A,Mat AT,BV V,BV U,PetscInt k,PetscInt *n,PetscBool *breakdown)
+{
+  PetscInt       i;
+  Vec            u,v,ou=svd->workl[0];
+  PetscBool      lindep=PETSC_FALSE;
+  PetscReal      norm;
+
+  PetscFunctionBegin;
+  for (i=k;i<*n;i++) {
+    PetscCall(BVGetColumn(V,i,&v));
+    PetscCall(BVGetColumn(U,i,&u));
+    PetscCall(MatMult(A,v,u));
+    PetscCall(BVRestoreColumn(V,i,&v));
+    PetscCall(BVRestoreColumn(U,i,&u));
+    PetscCall(BVOrthonormalizeColumn(U,i,PETSC_FALSE,alpha+i,&lindep));
+    omega[i] = PetscSign(alpha[i]);
+    if (PetscUnlikely(lindep)) {
+      *n = i;
+      break;
+    }
+
+    PetscCall(BVGetColumn(V,i+1,&v));
+    PetscCall(BVGetColumn(U,i,&u));
+    PetscCall(VecPointwiseMult(ou,svd->omega,u));
+    PetscCall(MatMult(AT,ou,v));
+    PetscCall(BVRestoreColumn(V,i+1,&v));
+    PetscCall(BVRestoreColumn(U,i,&u));
+    PetscCall(BVOrthonormalizeColumn(V,i+1,PETSC_FALSE,&norm,&lindep));
+    beta[i] = omega[i]*norm;
+    if (PetscUnlikely(lindep)) {
+      *n = i+1;
+      break;
+    }
+  }
+
+  if (breakdown) *breakdown = lindep;
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+PetscErrorCode SVDSolve_TRLanczos_HSVD(SVD svd)
+{
+  SVD_TRLANCZOS  *lanczos = (SVD_TRLANCZOS*)svd->data;
+  PetscReal      *alpha,*beta,*omega;
+  PetscScalar    *w;
+  PetscInt       i,k,l,nv,ld,nini;
+  Mat            UU,VV,D,A,AT;
+  BV             U,V;
+  PetscBool      breakdown=PETSC_FALSE;
+  BVOrthogType   orthog;
+  Vec            vomega;
+
+  PetscFunctionBegin;
+  /* undo the effect of swapping in this function */
+  if (svd->swapped) {
+    A = svd->AT;
+    AT = svd->A;
+    U = svd->V;
+    V = svd->U;
+    nini = svd->ninil;
+  } else {
+    A = svd->A;
+    AT = svd->AT;
+    U = svd->U;
+    V = svd->V;
+    nini = svd->nini;
+  }
+  /* allocate working space */
+  PetscCall(DSGetLeadingDimension(svd->ds,&ld));
+  PetscCall(BVGetOrthogonalization(V,&orthog,NULL,NULL,NULL));
+  PetscCall(PetscMalloc1(ld,&w));
+  PetscCheck(!lanczos->oneside,PetscObjectComm((PetscObject)svd),PETSC_ERR_SUP,"Oneside orthogonalization not supported for HSVD");
+
+  /* normalize start vector */
+  if (!nini) {
+    PetscCall(BVSetRandomColumn(V,0));
+    PetscCall(BVOrthonormalizeColumn(V,0,PETSC_TRUE,NULL,NULL));
+  }
+
+  l = 0;
+  while (svd->reason == SVD_CONVERGED_ITERATING) {
+    svd->its++;
+
+    /* inner loop */
+    nv = PetscMin(svd->nconv+svd->mpd,svd->ncv);
+    PetscCall(DSGetArrayReal(svd->ds,DS_MAT_T,&alpha));
+    beta = alpha + ld;
+    PetscCall(DSGetArrayReal(svd->ds,DS_MAT_D,&omega));
+    PetscCall(SVDLanczosHSVD(svd,alpha,beta,omega,A,AT,V,U,svd->nconv+l,&nv,&breakdown));
+    PetscCall(DSRestoreArrayReal(svd->ds,DS_MAT_T,&alpha));
+    PetscCall(DSRestoreArrayReal(svd->ds,DS_MAT_D,&omega));
+    PetscCall(BVSetActiveColumns(V,svd->nconv,nv));
+    PetscCall(BVSetActiveColumns(U,svd->nconv,nv));
+
+    /* solve projected problem */
+    PetscCall(DSSetDimensions(svd->ds,nv,svd->nconv,svd->nconv+l));
+    PetscCall(DSHSVDSetDimensions(svd->ds,nv));
+    PetscCall(DSSetState(svd->ds,l?DS_STATE_RAW:DS_STATE_INTERMEDIATE));
+    PetscCall(DSSolve(svd->ds,w,NULL));
+    PetscCall(DSSort(svd->ds,w,NULL,NULL,NULL,NULL));
+    PetscCall(DSUpdateExtraRow(svd->ds));
+    PetscCall(DSSynchronize(svd->ds,w,NULL));
+    PetscCall(DSGetArrayReal(svd->ds,DS_MAT_D,&omega));
+    for (i=svd->nconv;i<nv;i++) {
+      svd->sigma[i] = PetscRealPart(w[i]);
+      svd->sign[i] = omega[i];
+    }
+    PetscCall(DSRestoreArrayReal(svd->ds,DS_MAT_D,&omega));
+
+    /* check convergence */
+    PetscCall(SVDKrylovConvergence(svd,PETSC_FALSE,svd->nconv,nv-svd->nconv,1.0,&k));
+    PetscCall((*svd->stopping)(svd,svd->its,svd->max_it,k,svd->nsv,&svd->reason,svd->stoppingctx));
+
+    /* update l */
+    if (svd->reason != SVD_CONVERGED_ITERATING || breakdown || k==nv) l = 0;
+    else l = PetscMax(1,(PetscInt)((nv-k)*lanczos->keep));
+    if (!lanczos->lock && l>0) { l += k; k = 0; } /* non-locking variant: reset no. of converged triplets */
+    if (l) PetscCall(PetscInfo(svd,"Preparing to restart keeping l=%" PetscInt_FMT " vectors\n",l));
+
+    if (svd->reason == SVD_CONVERGED_ITERATING) {
+      if (PetscUnlikely(breakdown || k==nv)) {
+        /* Start a new bidiagonalization */
+        PetscCall(PetscInfo(svd,"Breakdown in bidiagonalization (it=%" PetscInt_FMT ")\n",svd->its));
+        if (k<svd->nsv) {
+          PetscCall(BVSetRandomColumn(V,k));
+          PetscCall(BVOrthonormalizeColumn(V,k,PETSC_FALSE,NULL,&breakdown));
+          if (breakdown) {
+            svd->reason = SVD_DIVERGED_BREAKDOWN;
+            PetscCall(PetscInfo(svd,"Unable to generate more start vectors\n"));
+          }
+        }
+      } else PetscCall(DSTruncate(svd->ds,k+l,PETSC_FALSE));
+    }
+
+    /* compute converged singular vectors and restart vectors */
+    PetscCall(DSGetMat(svd->ds,DS_MAT_V,&VV));
+    PetscCall(BVMultInPlace(V,VV,svd->nconv,k+l));
+    PetscCall(DSRestoreMat(svd->ds,DS_MAT_V,&VV));
+    PetscCall(DSGetMat(svd->ds,DS_MAT_U,&UU));
+    PetscCall(BVMultInPlace(U,UU,svd->nconv,k+l));
+    PetscCall(DSRestoreMat(svd->ds,DS_MAT_U,&UU));
+
+    /* copy the last vector of V to be the next initial vector
+       and change signature matrix of U */
+    if (svd->reason == SVD_CONVERGED_ITERATING && !breakdown) {
+      PetscCall(BVCopyColumn(V,nv,k+l));
+      PetscCall(BVSetActiveColumns(U,0,k+l));
+      PetscCall(DSGetMatAndColumn(svd->ds,DS_MAT_D,0,&D,&vomega));
+      PetscCall(BVSetSignature(U,vomega));
+      PetscCall(DSRestoreMatAndColumn(svd->ds,DS_MAT_D,0,&D,&vomega));
+    }
+
+    svd->nconv = k;
+    PetscCall(SVDMonitor(svd,svd->its,svd->nconv,svd->sigma,svd->errest,nv));
+  }
+
+  /* free working space */
+  PetscCall(PetscFree(w));
+  PetscCall(DSTruncate(svd->ds,svd->nconv,PETSC_TRUE));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* Given n computed generalized singular values in sigmain, backtransform them
@@ -577,7 +738,7 @@ static PetscErrorCode SVDLanczosBackTransform(SVD svd,PetscInt n,PetscReal *sigm
       if (svd->swapped) sigmain[i] = 1.0/sigmain[i];
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDLanczosGSingle(SVD svd,PetscReal *alpha,PetscReal *beta,Mat Z,BV V,BV U,KSP ksp,PetscInt k,PetscInt *n,PetscBool *breakdown)
@@ -614,7 +775,7 @@ static PetscErrorCode SVDLanczosGSingle(SVD svd,PetscReal *alpha,PetscReal *beta
   if (PetscUnlikely(lindep)) {
     *n = k;
     if (breakdown) *breakdown = lindep;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   for (i=k+1; i<*n; i++) {
@@ -682,7 +843,7 @@ static PetscErrorCode SVDLanczosGSingle(SVD svd,PetscReal *alpha,PetscReal *beta
   }
   if (breakdown) *breakdown = lindep;
   PetscCall(VecDestroy(&v1));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* solve generalized problem with single bidiagonalization of Q_A */
@@ -786,7 +947,7 @@ PetscErrorCode SVDSolve_TRLanczosGSingle(SVD svd,BV U1,BV V)
   }
 
   PetscCall(PetscFree2(w,sigma));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* Move generalized left singular vectors (0..nconv) from U1 and U2 to its final destination svd->U (single variant) */
@@ -827,7 +988,7 @@ static inline PetscErrorCode SVDLeftSingularVectors_Single(SVD svd,BV U1,BV U2)
     PetscCall(BVRestoreColumn(U2,i,&u2));
     PetscCall(BVRestoreColumn(svd->U,i,&u));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDLanczosGUpper(SVD svd,PetscReal *alpha,PetscReal *beta,PetscReal *alphah,PetscReal *betah,Mat Z,BV U1,BV U2,BV V,KSP ksp,PetscInt k,PetscInt *n,PetscBool *breakdown)
@@ -919,7 +1080,7 @@ static PetscErrorCode SVDLanczosGUpper(SVD svd,PetscReal *alpha,PetscReal *beta,
   }
   if (breakdown) *breakdown = lindep;
   PetscCall(VecDestroy(&v1));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* generate random initial vector in column k for joint upper-upper bidiagonalization */
@@ -949,7 +1110,7 @@ static inline PetscErrorCode SVDInitialVectorGUpper(SVD svd,BV V,BV U1,PetscInt
   PetscCall(BVRestoreColumn(V,k,&v));
   if (breakdown) PetscCall(BVOrthonormalizeColumn(V,k,PETSC_FALSE,NULL,breakdown));
   else PetscCall(BVOrthonormalizeColumn(V,k,PETSC_TRUE,NULL,NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* solve generalized problem with joint upper-upper bidiagonalization */
@@ -1057,7 +1218,7 @@ PetscErrorCode SVDSolve_TRLanczosGUpper(SVD svd,BV U1,BV U2,BV V)
   }
 
   PetscCall(PetscFree2(w,sigma));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* Move generalized left singular vectors (0..nconv) from U1 and U2 to its final destination svd->U (upper and lower variants) */
@@ -1089,7 +1250,7 @@ static inline PetscErrorCode SVDLeftSingularVectors(SVD svd,BV U1,BV U2)
     PetscCall(BVRestoreColumn(U2,i,&u2));
     PetscCall(BVRestoreColumn(svd->U,i,&u));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDLanczosGLower(SVD svd,PetscReal *alpha,PetscReal *beta,PetscReal *alphah,PetscReal *betah,Mat Z,BV U1,BV U2,BV V,KSP ksp,PetscInt k,PetscInt *n,PetscBool *breakdown)
@@ -1183,7 +1344,7 @@ static PetscErrorCode SVDLanczosGLower(SVD svd,PetscReal *alpha,PetscReal *beta,
   }
   if (breakdown) *breakdown = lindep;
   PetscCall(VecDestroy(&v1));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* generate random initial vector in column k for joint lower-upper bidiagonalization */
@@ -1244,7 +1405,7 @@ static inline PetscErrorCode SVDInitialVectorGLower(SVD svd,BV V,BV U1,BV U2,Pet
     else PetscCall(BVOrthonormalizeColumn(V,k,PETSC_TRUE,alpha+k,NULL));
     PetscCall(DSRestoreArrayReal(svd->ds,DS_MAT_T,&alpha));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* solve generalized problem with joint lower-upper bidiagonalization */
@@ -1356,7 +1517,7 @@ PetscErrorCode SVDSolve_TRLanczosGLower(SVD svd,BV U1,BV U2,BV V)
   }
 
   PetscCall(PetscFree2(w,sigma));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode SVDSolve_TRLanczos_GSVD(SVD svd)
@@ -1450,7 +1611,7 @@ PetscErrorCode SVDSolve_TRLanczos_GSVD(SVD svd)
   PetscCall(BVDestroy(&U2));
   PetscCall(DSTruncate(svd->ds,svd->nconv,PETSC_TRUE));
   if (convchg) svd->converged = SVDConvergedNorm;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode SVDSetFromOptions_TRLanczos(SVD svd,PetscOptionItems *PetscOptionsObject)
@@ -1488,7 +1649,7 @@ PetscErrorCode SVDSetFromOptions_TRLanczos(SVD svd,PetscOptionItems *PetscOption
     if (!lanczos->ksp) PetscCall(SVDTRLanczosGetKSP(svd,&lanczos->ksp));
     PetscCall(KSPSetFromOptions(lanczos->ksp));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDTRLanczosSetOneSide_TRLanczos(SVD svd,PetscBool oneside)
@@ -1500,14 +1661,14 @@ static PetscErrorCode SVDTRLanczosSetOneSide_TRLanczos(SVD svd,PetscBool oneside
     lanczos->oneside = oneside;
     svd->state = SVD_STATE_INITIAL;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDTRLanczosSetOneSide - Indicate if the variant of the Lanczos method
    to be used is one-sided or two-sided.
 
-   Logically Collective on svd
+   Logically Collective
 
    Input Parameters:
 +  svd     - singular value solver
@@ -1534,7 +1695,7 @@ PetscErrorCode SVDTRLanczosSetOneSide(SVD svd,PetscBool oneside)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidLogicalCollectiveBool(svd,oneside,2);
   PetscTryMethod(svd,"SVDTRLanczosSetOneSide_C",(SVD,PetscBool),(svd,oneside));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDTRLanczosGetOneSide_TRLanczos(SVD svd,PetscBool *oneside)
@@ -1543,7 +1704,7 @@ static PetscErrorCode SVDTRLanczosGetOneSide_TRLanczos(SVD svd,PetscBool *onesid
 
   PetscFunctionBegin;
   *oneside = lanczos->oneside;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1568,7 +1729,7 @@ PetscErrorCode SVDTRLanczosGetOneSide(SVD svd,PetscBool *oneside)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidBoolPointer(oneside,2);
   PetscUseMethod(svd,"SVDTRLanczosGetOneSide_C",(SVD,PetscBool*),(svd,oneside));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDTRLanczosSetGBidiag_TRLanczos(SVD svd,SVDTRLanczosGBidiag bidiag)
@@ -1588,14 +1749,14 @@ static PetscErrorCode SVDTRLanczosSetGBidiag_TRLanczos(SVD svd,SVDTRLanczosGBidi
     default:
       SETERRQ(PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"Invalid bidiagonalization choice");
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDTRLanczosSetGBidiag - Sets the bidiagonalization choice to use in
    the GSVD TRLanczos solver.
 
-   Logically Collective on svd
+   Logically Collective
 
    Input Parameters:
 +  svd - the singular value solver
@@ -1615,7 +1776,7 @@ PetscErrorCode SVDTRLanczosSetGBidiag(SVD svd,SVDTRLanczosGBidiag bidiag)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidLogicalCollectiveEnum(svd,bidiag,2);
   PetscTryMethod(svd,"SVDTRLanczosSetGBidiag_C",(SVD,SVDTRLanczosGBidiag),(svd,bidiag));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDTRLanczosGetGBidiag_TRLanczos(SVD svd,SVDTRLanczosGBidiag *bidiag)
@@ -1624,7 +1785,7 @@ static PetscErrorCode SVDTRLanczosGetGBidiag_TRLanczos(SVD svd,SVDTRLanczosGBidi
 
   PetscFunctionBegin;
   *bidiag = lanczos->bidiag;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1649,7 +1810,7 @@ PetscErrorCode SVDTRLanczosGetGBidiag(SVD svd,SVDTRLanczosGBidiag *bidiag)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidPointer(bidiag,2);
   PetscUseMethod(svd,"SVDTRLanczosGetGBidiag_C",(SVD,SVDTRLanczosGBidiag*),(svd,bidiag));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDTRLanczosSetKSP_TRLanczos(SVD svd,KSP ksp)
@@ -1661,13 +1822,13 @@ static PetscErrorCode SVDTRLanczosSetKSP_TRLanczos(SVD svd,KSP ksp)
   PetscCall(KSPDestroy(&ctx->ksp));
   ctx->ksp   = ksp;
   svd->state = SVD_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDTRLanczosSetKSP - Associate a linear solver object (KSP) to the SVD solver.
 
-   Collective on svd
+   Collective
 
    Input Parameters:
 +  svd - SVD solver
@@ -1687,7 +1848,7 @@ PetscErrorCode SVDTRLanczosSetKSP(SVD svd,KSP ksp)
   PetscValidHeaderSpecific(ksp,KSP_CLASSID,2);
   PetscCheckSameComm(svd,1,ksp,2);
   PetscTryMethod(svd,"SVDTRLanczosSetKSP_C",(SVD,KSP),(svd,ksp));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDTRLanczosGetKSP_TRLanczos(SVD svd,KSP *ksp)
@@ -1710,14 +1871,14 @@ static PetscErrorCode SVDTRLanczosGetKSP_TRLanczos(SVD svd,KSP *ksp)
     PetscCall(KSPSetTolerances(ctx->ksp,SlepcDefaultTol(svd->tol)/10.0,PETSC_DEFAULT,PETSC_DEFAULT,PETSC_DEFAULT));
   }
   *ksp = ctx->ksp;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDTRLanczosGetKSP - Retrieve the linear solver object (KSP) associated with
    the SVD solver.
 
-   Not Collective
+   Collective
 
    Input Parameter:
 .  svd - SVD solver
@@ -1735,7 +1896,7 @@ PetscErrorCode SVDTRLanczosGetKSP(SVD svd,KSP *ksp)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidPointer(ksp,2);
   PetscUseMethod(svd,"SVDTRLanczosGetKSP_C",(SVD,KSP*),(svd,ksp));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDTRLanczosSetRestart_TRLanczos(SVD svd,PetscReal keep)
@@ -1743,12 +1904,12 @@ static PetscErrorCode SVDTRLanczosSetRestart_TRLanczos(SVD svd,PetscReal keep)
   SVD_TRLANCZOS *ctx = (SVD_TRLANCZOS*)svd->data;
 
   PetscFunctionBegin;
-  if (keep==PETSC_DEFAULT) ctx->keep = 0.5;
+  if (keep==(PetscReal)PETSC_DEFAULT) ctx->keep = 0.5;
   else {
     PetscCheck(keep>=0.1 && keep<=0.9,PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"The keep argument %g must be in the range [0.1,0.9]",(double)keep);
     ctx->keep = keep;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1756,7 +1917,7 @@ static PetscErrorCode SVDTRLanczosSetRestart_TRLanczos(SVD svd,PetscReal keep)
    Lanczos method, in particular the proportion of basis vectors that must be
    kept after restart.
 
-   Logically Collective on svd
+   Logically Collective
 
    Input Parameters:
 +  svd  - the singular value solver
@@ -1778,7 +1939,7 @@ PetscErrorCode SVDTRLanczosSetRestart(SVD svd,PetscReal keep)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidLogicalCollectiveReal(svd,keep,2);
   PetscTryMethod(svd,"SVDTRLanczosSetRestart_C",(SVD,PetscReal),(svd,keep));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDTRLanczosGetRestart_TRLanczos(SVD svd,PetscReal *keep)
@@ -1787,7 +1948,7 @@ static PetscErrorCode SVDTRLanczosGetRestart_TRLanczos(SVD svd,PetscReal *keep)
 
   PetscFunctionBegin;
   *keep = ctx->keep;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1812,7 +1973,7 @@ PetscErrorCode SVDTRLanczosGetRestart(SVD svd,PetscReal *keep)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidRealPointer(keep,2);
   PetscUseMethod(svd,"SVDTRLanczosGetRestart_C",(SVD,PetscReal*),(svd,keep));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDTRLanczosSetLocking_TRLanczos(SVD svd,PetscBool lock)
@@ -1821,14 +1982,14 @@ static PetscErrorCode SVDTRLanczosSetLocking_TRLanczos(SVD svd,PetscBool lock)
 
   PetscFunctionBegin;
   ctx->lock = lock;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDTRLanczosSetLocking - Choose between locking and non-locking variants of
    the thick-restart Lanczos method.
 
-   Logically Collective on svd
+   Logically Collective
 
    Input Parameters:
 +  svd  - the singular value solver
@@ -1853,7 +2014,7 @@ PetscErrorCode SVDTRLanczosSetLocking(SVD svd,PetscBool lock)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidLogicalCollectiveBool(svd,lock,2);
   PetscTryMethod(svd,"SVDTRLanczosSetLocking_C",(SVD,PetscBool),(svd,lock));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDTRLanczosGetLocking_TRLanczos(SVD svd,PetscBool *lock)
@@ -1862,7 +2023,7 @@ static PetscErrorCode SVDTRLanczosGetLocking_TRLanczos(SVD svd,PetscBool *lock)
 
   PetscFunctionBegin;
   *lock = ctx->lock;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1887,7 +2048,7 @@ PetscErrorCode SVDTRLanczosGetLocking(SVD svd,PetscBool *lock)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidBoolPointer(lock,2);
   PetscUseMethod(svd,"SVDTRLanczosGetLocking_C",(SVD,PetscBool*),(svd,lock));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDTRLanczosSetExplicitMatrix_TRLanczos(SVD svd,PetscBool explicitmat)
@@ -1899,14 +2060,14 @@ static PetscErrorCode SVDTRLanczosSetExplicitMatrix_TRLanczos(SVD svd,PetscBool
     lanczos->explicitmatrix = explicitmat;
     svd->state = SVD_STATE_INITIAL;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDTRLanczosSetExplicitMatrix - Indicate if the matrix Z=[A;B] must
    be built explicitly.
 
-   Logically Collective on svd
+   Logically Collective
 
    Input Parameters:
 +  svd         - singular value solver
@@ -1929,7 +2090,7 @@ PetscErrorCode SVDTRLanczosSetExplicitMatrix(SVD svd,PetscBool explicitmat)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidLogicalCollectiveBool(svd,explicitmat,2);
   PetscTryMethod(svd,"SVDTRLanczosSetExplicitMatrix_C",(SVD,PetscBool),(svd,explicitmat));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDTRLanczosGetExplicitMatrix_TRLanczos(SVD svd,PetscBool *explicitmat)
@@ -1938,7 +2099,7 @@ static PetscErrorCode SVDTRLanczosGetExplicitMatrix_TRLanczos(SVD svd,PetscBool
 
   PetscFunctionBegin;
   *explicitmat = lanczos->explicitmatrix;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1962,7 +2123,7 @@ PetscErrorCode SVDTRLanczosGetExplicitMatrix(SVD svd,PetscBool *explicitmat)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidBoolPointer(explicitmat,2);
   PetscUseMethod(svd,"SVDTRLanczosGetExplicitMatrix_C",(SVD,PetscBool*),(svd,explicitmat));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDTRLanczosSetScale_TRLanczos(SVD svd,PetscReal scale)
@@ -1977,13 +2138,13 @@ static PetscErrorCode SVDTRLanczosSetScale_TRLanczos(SVD svd,PetscReal scale)
     ctx->scalef  = scale;
     ctx->scaleth = 0.0;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDTRLanczosSetScale - Sets the scale parameter for the GSVD.
 
-   Logically Collective on svd
+   Logically Collective
 
    Input Parameters:
 +  svd   - singular value solver
@@ -2011,7 +2172,7 @@ PetscErrorCode SVDTRLanczosSetScale(SVD svd,PetscReal scale)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidLogicalCollectiveReal(svd,scale,2);
   PetscTryMethod(svd,"SVDTRLanczosSetScale_C",(SVD,PetscReal),(svd,scale));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDTRLanczosGetScale_TRLanczos(SVD svd,PetscReal *scale)
@@ -2021,7 +2182,7 @@ static PetscErrorCode SVDTRLanczosGetScale_TRLanczos(SVD svd,PetscReal *scale)
   PetscFunctionBegin;
   if (ctx->scaleth==0) *scale = ctx->scalef;
   else                 *scale = -ctx->scaleth;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -2050,7 +2211,7 @@ PetscErrorCode SVDTRLanczosGetScale(SVD svd,PetscReal *scale)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidRealPointer(scale,2);
   PetscUseMethod(svd,"SVDTRLanczosGetScale_C",(SVD,PetscReal*),(svd,scale));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode SVDReset_TRLanczos(SVD svd)
@@ -2062,7 +2223,7 @@ PetscErrorCode SVDReset_TRLanczos(SVD svd)
     PetscCall(KSPReset(lanczos->ksp));
     PetscCall(MatDestroy(&lanczos->Z));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode SVDDestroy_TRLanczos(SVD svd)
@@ -2086,7 +2247,7 @@ PetscErrorCode SVDDestroy_TRLanczos(SVD svd)
   PetscCall(PetscObjectComposeFunction((PetscObject)svd,"SVDTRLanczosGetExplicitMatrix_C",NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)svd,"SVDTRLanczosSetScale_C",NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)svd,"SVDTRLanczosGetScale_C",NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode SVDView_TRLanczos(SVD svd,PetscViewer viewer)
@@ -2117,7 +2278,19 @@ PetscErrorCode SVDView_TRLanczos(SVD svd,PetscViewer viewer)
       PetscCall(PetscViewerASCIIPopTab(viewer));
     } else PetscCall(PetscViewerASCIIPrintf(viewer,"  %s-sided reorthogonalization\n",lanczos->oneside? "one": "two"));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+PetscErrorCode SVDSetDSType_TRLanczos(SVD svd)
+{
+  SVD_TRLANCZOS  *lanczos = (SVD_TRLANCZOS*)svd->data;
+  DSType         dstype;
+
+  PetscFunctionBegin;
+  dstype = svd->ishyperbolic? DSHSVD: DSSVD;
+  if (svd->OPb && (lanczos->bidiag==SVD_TRLANCZOS_GBIDIAG_UPPER || lanczos->bidiag==SVD_TRLANCZOS_GBIDIAG_LOWER)) dstype = DSGSVD;
+  PetscCall(DSSetType(svd->ds,dstype));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 SLEPC_EXTERN PetscErrorCode SVDCreate_TRLanczos(SVD svd)
@@ -2136,10 +2309,12 @@ SLEPC_EXTERN PetscErrorCode SVDCreate_TRLanczos(SVD svd)
   svd->ops->setup          = SVDSetUp_TRLanczos;
   svd->ops->solve          = SVDSolve_TRLanczos;
   svd->ops->solveg         = SVDSolve_TRLanczos_GSVD;
+  svd->ops->solveh         = SVDSolve_TRLanczos_HSVD;
   svd->ops->destroy        = SVDDestroy_TRLanczos;
   svd->ops->reset          = SVDReset_TRLanczos;
   svd->ops->setfromoptions = SVDSetFromOptions_TRLanczos;
   svd->ops->view           = SVDView_TRLanczos;
+  svd->ops->setdstype      = SVDSetDSType_TRLanczos;
   PetscCall(PetscObjectComposeFunction((PetscObject)svd,"SVDTRLanczosSetOneSide_C",SVDTRLanczosSetOneSide_TRLanczos));
   PetscCall(PetscObjectComposeFunction((PetscObject)svd,"SVDTRLanczosGetOneSide_C",SVDTRLanczosGetOneSide_TRLanczos));
   PetscCall(PetscObjectComposeFunction((PetscObject)svd,"SVDTRLanczosSetGBidiag_C",SVDTRLanczosSetGBidiag_TRLanczos));
@@ -2154,5 +2329,5 @@ SLEPC_EXTERN PetscErrorCode SVDCreate_TRLanczos(SVD svd)
   PetscCall(PetscObjectComposeFunction((PetscObject)svd,"SVDTRLanczosGetExplicitMatrix_C",SVDTRLanczosGetExplicitMatrix_TRLanczos));
   PetscCall(PetscObjectComposeFunction((PetscObject)svd,"SVDTRLanczosSetScale_C",SVDTRLanczosSetScale_TRLanczos));
   PetscCall(PetscObjectComposeFunction((PetscObject)svd,"SVDTRLanczosGetScale_C",SVDTRLanczosGetScale_TRLanczos));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
