@@ -30,7 +30,7 @@ PetscErrorCode SVDMonitorLGCreate(MPI_Comm comm,const char host[],const char lab
   PetscCall(PetscDrawAxisSetLabels(axis,"Convergence","Iteration",metric));
   PetscCall(PetscDrawDestroy(&draw));
   *lgctx = lg;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -42,14 +42,14 @@ PetscErrorCode SVDMonitor(SVD svd,PetscInt it,PetscInt nconv,PetscReal *sigma,Pe
 
   PetscFunctionBegin;
   for (i=0;i<n;i++) PetscCall((*svd->monitor[i])(svd,it,nconv,sigma,errest,nest,svd->monitorcontext[i]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SVDMonitorSet - Sets an ADDITIONAL function to be called at every
    iteration to monitor the error estimates for each requested singular triplet.
 
-   Logically Collective on svd
+   Logically Collective
 
    Input Parameters:
 +  svd     - singular value solver context obtained from SVDCreate()
@@ -58,9 +58,8 @@ PetscErrorCode SVDMonitor(SVD svd,PetscInt it,PetscInt nconv,PetscReal *sigma,Pe
              monitor routine (use NULL if no context is desired)
 -  monitordestroy - [optional] routine that frees monitor context (may be NULL)
 
-   Calling Sequence of monitor:
-$   monitor(SVD svd,PetscInt its,PetscInt nconv,PetscReal *sigma,PetscReal *errest,PetscInt nest,void *mctx)
-
+   Calling sequence of monitor:
+$  PetscErrorCode monitor(SVD svd,PetscInt its,PetscInt nconv,PetscReal *sigma,PetscReal *errest,PetscInt nest,void *mctx)
 +  svd    - singular value solver context obtained from SVDCreate()
 .  its    - iteration number
 .  nconv  - number of converged singular triplets
@@ -93,7 +92,7 @@ $   monitor(SVD svd,PetscInt its,PetscInt nconv,PetscReal *sigma,PetscReal *erre
 
 .seealso: SVDMonitorFirst(), SVDMonitorAll(), SVDMonitorConditioning(), SVDMonitorCancel()
 @*/
-PetscErrorCode SVDMonitorSet(SVD svd,PetscErrorCode (*monitor)(SVD,PetscInt,PetscInt,PetscReal*,PetscReal*,PetscInt,void*),void *mctx,PetscErrorCode (*monitordestroy)(void**))
+PetscErrorCode SVDMonitorSet(SVD svd,PetscErrorCode (*monitor)(SVD svd,PetscInt its,PetscInt nconv,PetscReal *sigma,PetscReal *errest,PetscInt nest,void *mctx),void *mctx,PetscErrorCode (*monitordestroy)(void**))
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
@@ -101,13 +100,13 @@ PetscErrorCode SVDMonitorSet(SVD svd,PetscErrorCode (*monitor)(SVD,PetscInt,Pets
   svd->monitor[svd->numbermonitors]           = monitor;
   svd->monitorcontext[svd->numbermonitors]    = (void*)mctx;
   svd->monitordestroy[svd->numbermonitors++]  = monitordestroy;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDMonitorCancel - Clears all monitors for an SVD object.
 
-   Logically Collective on svd
+   Logically Collective
 
    Input Parameters:
 .  svd - singular value solver context obtained from SVDCreate()
@@ -131,7 +130,7 @@ PetscErrorCode SVDMonitorCancel(SVD svd)
     if (svd->monitordestroy[i]) PetscCall((*svd->monitordestroy[i])(&svd->monitorcontext[i]));
   }
   svd->numbermonitors = 0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -155,14 +154,14 @@ PetscErrorCode SVDGetMonitorContext(SVD svd,void *ctx)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   *(void**)ctx = svd->monitorcontext[0];
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SVDMonitorFirst - Print the first unconverged approximate value and
    error estimate at each iteration of the singular value solver.
 
-   Collective on svd
+   Collective
 
    Input Parameters:
 +  svd    - singular value solver context
@@ -198,14 +197,14 @@ PetscErrorCode SVDMonitorFirst(SVD svd,PetscInt its,PetscInt nconv,PetscReal *si
     PetscCall(PetscViewerASCIISubtractTab(viewer,((PetscObject)svd)->tablevel));
     PetscCall(PetscViewerPopFormat(viewer));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SVDMonitorAll - Print the current approximate values and
    error estimates at each iteration of the singular value solver.
 
-   Collective on svd
+   Collective
 
    Input Parameters:
 +  svd    - singular value solver context
@@ -241,14 +240,14 @@ PetscErrorCode SVDMonitorAll(SVD svd,PetscInt its,PetscInt nconv,PetscReal *sigm
   PetscCall(PetscViewerASCIIUseTabs(viewer,PETSC_TRUE));
   PetscCall(PetscViewerASCIISubtractTab(viewer,((PetscObject)svd)->tablevel));
   PetscCall(PetscViewerPopFormat(viewer));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SVDMonitorConverged - Print the approximate values and
    error estimates as they converge.
 
-   Collective on svd
+   Collective
 
    Input Parameters:
 +  svd    - singular value solver context
@@ -291,7 +290,7 @@ PetscErrorCode SVDMonitorConverged(SVD svd,PetscInt its,PetscInt nconv,PetscReal
     PetscCall(PetscViewerPopFormat(viewer));
     ctx->oldnconv = nconv;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode SVDMonitorConvergedCreate(PetscViewer viewer,PetscViewerFormat format,void *ctx,PetscViewerAndFormat **vf)
@@ -303,30 +302,29 @@ PetscErrorCode SVDMonitorConvergedCreate(PetscViewer viewer,PetscViewerFormat fo
   PetscCall(PetscNew(&mctx));
   mctx->ctx = ctx;
   (*vf)->data = (void*)mctx;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode SVDMonitorConvergedDestroy(PetscViewerAndFormat **vf)
 {
   PetscFunctionBegin;
-  if (!*vf) PetscFunctionReturn(0);
+  if (!*vf) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscFree((*vf)->data));
   PetscCall(PetscViewerDestroy(&(*vf)->viewer));
   PetscCall(PetscDrawLGDestroy(&(*vf)->lg));
   PetscCall(PetscFree(*vf));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SVDMonitorFirstDrawLG - Plots the error estimate of the first unconverged
    approximation at each iteration of the singular value solver.
 
-   Collective on svd
+   Collective
 
    Input Parameters:
 +  svd    - singular value solver context
 .  its    - iteration number
-.  its    - iteration number
 .  nconv  - number of converged singular triplets so far
 .  sigma  - singular values
 .  errest - error estimates
@@ -367,13 +365,13 @@ PetscErrorCode SVDMonitorFirstDrawLG(SVD svd,PetscInt its,PetscInt nconv,PetscRe
     }
   }
   PetscCall(PetscViewerPopFormat(viewer));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SVDMonitorFirstDrawLGCreate - Creates the plotter for the first error estimate.
 
-   Collective on viewer
+   Collective
 
    Input Parameters:
 +  viewer - the viewer
@@ -393,19 +391,18 @@ PetscErrorCode SVDMonitorFirstDrawLGCreate(PetscViewer viewer,PetscViewerFormat
   PetscCall(PetscViewerAndFormatCreate(viewer,format,vf));
   (*vf)->data = ctx;
   PetscCall(SVDMonitorLGCreate(PetscObjectComm((PetscObject)viewer),NULL,"First Error Estimate","Log Error Estimate",1,NULL,PETSC_DECIDE,PETSC_DECIDE,400,300,&(*vf)->lg));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SVDMonitorAllDrawLG - Plots the error estimate of all unconverged
    approximations at each iteration of the singular value solver.
 
-   Collective on svd
+   Collective
 
    Input Parameters:
 +  svd    - singular value solver context
 .  its    - iteration number
-.  its    - iteration number
 .  nconv  - number of converged singular triplets so far
 .  sigma  - singular values
 .  errest - error estimates
@@ -449,13 +446,13 @@ PetscErrorCode SVDMonitorAllDrawLG(SVD svd,PetscInt its,PetscInt nconv,PetscReal
   }
   PetscCall(PetscFree2(x,y));
   PetscCall(PetscViewerPopFormat(viewer));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SVDMonitorAllDrawLGCreate - Creates the plotter for all the error estimates.
 
-   Collective on viewer
+   Collective
 
    Input Parameters:
 +  viewer - the viewer
@@ -475,19 +472,18 @@ PetscErrorCode SVDMonitorAllDrawLGCreate(PetscViewer viewer,PetscViewerFormat fo
   PetscCall(PetscViewerAndFormatCreate(viewer,format,vf));
   (*vf)->data = ctx;
   PetscCall(SVDMonitorLGCreate(PetscObjectComm((PetscObject)viewer),NULL,"All Error Estimates","Log Error Estimate",1,NULL,PETSC_DECIDE,PETSC_DECIDE,400,300,&(*vf)->lg));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SVDMonitorConvergedDrawLG - Plots the number of converged eigenvalues
    at each iteration of the singular value solver.
 
-   Collective on svd
+   Collective
 
    Input Parameters:
 +  svd    - singular value solver context
 .  its    - iteration number
-.  its    - iteration number
 .  nconv  - number of converged singular triplets so far
 .  sigma  - singular values
 .  errest - error estimates
@@ -525,13 +521,13 @@ PetscErrorCode SVDMonitorConvergedDrawLG(SVD svd,PetscInt its,PetscInt nconv,Pet
     PetscCall(PetscDrawLGSave(lg));
   }
   PetscCall(PetscViewerPopFormat(viewer));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SVDMonitorConvergedDrawLGCreate - Creates the plotter for the convergence history.
 
-   Collective on viewer
+   Collective
 
    Input Parameters:
 +  viewer - the viewer
@@ -555,14 +551,14 @@ PetscErrorCode SVDMonitorConvergedDrawLGCreate(PetscViewer viewer,PetscViewerFor
   mctx->ctx = ctx;
   (*vf)->data = (void*)mctx;
   PetscCall(SVDMonitorLGCreate(PetscObjectComm((PetscObject)viewer),NULL,"Convergence History","Number Converged",1,NULL,PETSC_DECIDE,PETSC_DECIDE,400,300,&(*vf)->lg));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SVDMonitorConditioning - Print the condition number at each iteration of the singular
    value solver.
 
-   Collective on svd
+   Collective
 
    Input Parameters:
 +  svd    - singular value solver context
@@ -594,7 +590,7 @@ PetscErrorCode SVDMonitorConditioning(SVD svd,PetscInt its,PetscInt nconv,PetscR
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidHeaderSpecific(viewer,PETSC_VIEWER_CLASSID,7);
   PetscCall(PetscObjectTypeCompare((PetscObject)svd->ds,DSGSVD,&isgsvd));
-  if (!isgsvd) PetscFunctionReturn(0);
+  if (!isgsvd) PetscFunctionReturn(PETSC_SUCCESS);
   if (its==1 && ((PetscObject)svd)->prefix) PetscCall(PetscViewerASCIIPrintf(viewer,"  Condition number of bidiagonal matrices for %s solve.\n",((PetscObject)svd)->prefix));
   PetscCall(PetscViewerPushFormat(viewer,vf->format));
   PetscCall(PetscViewerASCIIAddTab(viewer,((PetscObject)svd)->tablevel));
@@ -602,5 +598,5 @@ PetscErrorCode SVDMonitorConditioning(SVD svd,PetscInt its,PetscInt nconv,PetscR
   PetscCall(PetscViewerASCIIPrintf(viewer,"%3" PetscInt_FMT " SVD condition number = %g\n",its,(double)cond));
   PetscCall(PetscViewerASCIISubtractTab(viewer,((PetscObject)svd)->tablevel));
   PetscCall(PetscViewerPopFormat(viewer));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
