@@ -18,7 +18,7 @@
    SVDSetImplicitTranspose - Indicates how to handle the transpose of the matrix
    associated with the singular value problem.
 
-   Logically Collective on svd
+   Logically Collective
 
    Input Parameters:
 +  svd  - the singular value solver context
@@ -50,7 +50,7 @@ PetscErrorCode SVDSetImplicitTranspose(SVD svd,PetscBool impl)
     svd->impltrans = impl;
     svd->state     = SVD_STATE_INITIAL;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -75,14 +75,14 @@ PetscErrorCode SVDGetImplicitTranspose(SVD svd,PetscBool *impl)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidBoolPointer(impl,2);
   *impl = svd->impltrans;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDSetTolerances - Sets the tolerance and maximum
    iteration count used by the default SVD convergence testers.
 
-   Logically Collective on svd
+   Logically Collective
 
    Input Parameters:
 +  svd - the singular value solver context
@@ -106,7 +106,7 @@ PetscErrorCode SVDSetTolerances(SVD svd,PetscReal tol,PetscInt maxits)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidLogicalCollectiveReal(svd,tol,2);
   PetscValidLogicalCollectiveInt(svd,maxits,3);
-  if (tol == PETSC_DEFAULT) {
+  if (tol == (PetscReal)PETSC_DEFAULT) {
     svd->tol   = PETSC_DEFAULT;
     svd->state = SVD_STATE_INITIAL;
   } else {
@@ -120,7 +120,7 @@ PetscErrorCode SVDSetTolerances(SVD svd,PetscReal tol,PetscInt maxits)
     PetscCheck(maxits>0,PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of maxits. Must be > 0");
     svd->max_it = maxits;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -149,14 +149,14 @@ PetscErrorCode SVDGetTolerances(SVD svd,PetscReal *tol,PetscInt *maxits)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   if (tol)    *tol    = svd->tol;
   if (maxits) *maxits = svd->max_it;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDSetDimensions - Sets the number of singular values to compute
    and the dimension of the subspace.
 
-   Logically Collective on svd
+   Logically Collective
 
    Input Parameters:
 +  svd - the singular value solver context
@@ -208,7 +208,7 @@ PetscErrorCode SVDSetDimensions(SVD svd,PetscInt nsv,PetscInt ncv,PetscInt mpd)
     svd->mpd = mpd;
   }
   svd->state = SVD_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -239,14 +239,14 @@ PetscErrorCode SVDGetDimensions(SVD svd,PetscInt *nsv,PetscInt *ncv,PetscInt *mp
   if (nsv) *nsv = svd->nsv;
   if (ncv) *ncv = svd->ncv;
   if (mpd) *mpd = svd->mpd;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     SVDSetWhichSingularTriplets - Specifies which singular triplets are
     to be sought.
 
-    Logically Collective on svd
+    Logically Collective
 
     Input Parameter:
 .   svd - singular value solver context obtained from SVDCreate()
@@ -254,16 +254,16 @@ PetscErrorCode SVDGetDimensions(SVD svd,PetscInt *nsv,PetscInt *ncv,PetscInt *mp
     Output Parameter:
 .   which - which singular triplets are to be sought
 
-    Possible values:
+    Options Database Keys:
++   -svd_largest  - Sets largest singular values
+-   -svd_smallest - Sets smallest singular values
+
+    Notes:
     The parameter 'which' can have one of these values
 
 +     SVD_LARGEST  - largest singular values
 -     SVD_SMALLEST - smallest singular values
 
-    Options Database Keys:
-+   -svd_largest  - Sets largest singular values
--   -svd_smallest - Sets smallest singular values
-
     Level: intermediate
 
 .seealso: SVDGetWhichSingularTriplets(), SVDWhich
@@ -284,7 +284,7 @@ PetscErrorCode SVDSetWhichSingularTriplets(SVD svd,SVDWhich which)
   default:
     SETERRQ(PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"Invalid 'which' parameter");
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -312,24 +312,23 @@ PetscErrorCode SVDGetWhichSingularTriplets(SVD svd,SVDWhich *which)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidPointer(which,2);
   *which = svd->which;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SVDSetConvergenceTestFunction - Sets a function to compute the error estimate
    used in the convergence test.
 
-   Logically Collective on svd
+   Logically Collective
 
    Input Parameters:
 +  svd     - singular value solver context obtained from SVDCreate()
-.  func    - a pointer to the convergence test function
+.  conv    - a pointer to the convergence test function
 .  ctx     - context for private data for the convergence routine (may be null)
 -  destroy - a routine for destroying the context (may be null)
 
-   Calling Sequence of func:
-$   func(SVD svd,PetscReal sigma,PetscReal res,PetscReal *errest,void *ctx)
-
+   Calling sequence of conv:
+$  PetscErrorCode conv(SVD svd,PetscReal sigma,PetscReal res,PetscReal *errest,void *ctx)
 +   svd    - singular value solver context obtained from SVDCreate()
 .   sigma  - computed singular value
 .   res    - residual norm associated to the singular triplet
@@ -344,30 +343,30 @@ $   func(SVD svd,PetscReal sigma,PetscReal res,PetscReal *errest,void *ctx)
 
 .seealso: SVDSetConvergenceTest(), SVDSetTolerances()
 @*/
-PetscErrorCode SVDSetConvergenceTestFunction(SVD svd,PetscErrorCode (*func)(SVD,PetscReal,PetscReal,PetscReal*,void*),void* ctx,PetscErrorCode (*destroy)(void*))
+PetscErrorCode SVDSetConvergenceTestFunction(SVD svd,PetscErrorCode (*conv)(SVD svd,PetscReal sigma,PetscReal res,PetscReal *errest,void *ctx),void* ctx,PetscErrorCode (*destroy)(void*))
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   if (svd->convergeddestroy) PetscCall((*svd->convergeddestroy)(svd->convergedctx));
-  svd->convergeduser    = func;
+  svd->convergeduser    = conv;
   svd->convergeddestroy = destroy;
   svd->convergedctx     = ctx;
-  if (func == SVDConvergedAbsolute) svd->conv = SVD_CONV_ABS;
-  else if (func == SVDConvergedRelative) svd->conv = SVD_CONV_REL;
-  else if (func == SVDConvergedNorm) svd->conv = SVD_CONV_NORM;
-  else if (func == SVDConvergedMaxIt) svd->conv = SVD_CONV_MAXIT;
+  if (conv == SVDConvergedAbsolute) svd->conv = SVD_CONV_ABS;
+  else if (conv == SVDConvergedRelative) svd->conv = SVD_CONV_REL;
+  else if (conv == SVDConvergedNorm) svd->conv = SVD_CONV_NORM;
+  else if (conv == SVDConvergedMaxIt) svd->conv = SVD_CONV_MAXIT;
   else {
     svd->conv      = SVD_CONV_USER;
     svd->converged = svd->convergeduser;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDSetConvergenceTest - Specifies how to compute the error estimate
    used in the convergence test.
 
-   Logically Collective on svd
+   Logically Collective
 
    Input Parameters:
 +  svd  - singular value solver context obtained from SVDCreate()
@@ -412,7 +411,7 @@ PetscErrorCode SVDSetConvergenceTest(SVD svd,SVDConv conv)
       SETERRQ(PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"Invalid 'conv' value");
   }
   svd->conv = conv;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -437,24 +436,23 @@ PetscErrorCode SVDGetConvergenceTest(SVD svd,SVDConv *conv)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidPointer(conv,2);
   *conv = svd->conv;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SVDSetStoppingTestFunction - Sets a function to decide when to stop the outer
    iteration of the singular value solver.
 
-   Logically Collective on svd
+   Logically Collective
 
    Input Parameters:
 +  svd     - singular value solver context obtained from SVDCreate()
-.  func    - pointer to the stopping test function
+.  stop    - pointer to the stopping test function
 .  ctx     - context for private data for the stopping routine (may be null)
 -  destroy - a routine for destroying the context (may be null)
 
-   Calling Sequence of func:
-$   func(SVD svd,PetscInt its,PetscInt max_it,PetscInt nconv,PetscInt nsv,SVDConvergedReason *reason,void *ctx)
-
+   Calling sequence of stop:
+$  PetscErrorCode stop(SVD svd,PetscInt its,PetscInt max_it,PetscInt nconv,PetscInt nsv,SVDConvergedReason *reason,void *ctx)
 +   svd    - singular value solver context obtained from SVDCreate()
 .   its    - current number of iterations
 .   max_it - maximum number of iterations
@@ -473,27 +471,27 @@ $   func(SVD svd,PetscInt its,PetscInt max_it,PetscInt nconv,PetscInt nsv,SVDCon
 
 .seealso: SVDSetStoppingTest(), SVDStoppingBasic()
 @*/
-PetscErrorCode SVDSetStoppingTestFunction(SVD svd,PetscErrorCode (*func)(SVD,PetscInt,PetscInt,PetscInt,PetscInt,SVDConvergedReason*,void*),void* ctx,PetscErrorCode (*destroy)(void*))
+PetscErrorCode SVDSetStoppingTestFunction(SVD svd,PetscErrorCode (*stop)(SVD svd,PetscInt its,PetscInt max_it,PetscInt nconv,PetscInt nsv,SVDConvergedReason *reason,void *ctx),void* ctx,PetscErrorCode (*destroy)(void*))
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   if (svd->stoppingdestroy) PetscCall((*svd->stoppingdestroy)(svd->stoppingctx));
-  svd->stoppinguser    = func;
+  svd->stoppinguser    = stop;
   svd->stoppingdestroy = destroy;
   svd->stoppingctx     = ctx;
-  if (func == SVDStoppingBasic) svd->stop = SVD_STOP_BASIC;
+  if (stop == SVDStoppingBasic) svd->stop = SVD_STOP_BASIC;
   else {
     svd->stop     = SVD_STOP_USER;
     svd->stopping = svd->stoppinguser;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDSetStoppingTest - Specifies how to decide the termination of the outer
    loop of the singular value solver.
 
-   Logically Collective on svd
+   Logically Collective
 
    Input Parameters:
 +  svd  - singular value solver context obtained from SVDCreate()
@@ -527,7 +525,7 @@ PetscErrorCode SVDSetStoppingTest(SVD svd,SVDStop stop)
       SETERRQ(PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"Invalid 'stop' value");
   }
   svd->stop = stop;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -552,14 +550,14 @@ PetscErrorCode SVDGetStoppingTest(SVD svd,SVDStop *stop)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidPointer(stop,2);
   *stop = svd->stop;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SVDMonitorSetFromOptions - Sets a monitor function and viewer appropriate for the type
    indicated by the user.
 
-   Collective on svd
+   Collective
 
    Input Parameters:
 +  svd      - the singular value solver context
@@ -586,7 +584,7 @@ PetscErrorCode SVDMonitorSetFromOptions(SVD svd,const char opt[],const char name
 
   PetscFunctionBegin;
   PetscCall(PetscOptionsGetViewer(PetscObjectComm((PetscObject)svd),((PetscObject)svd)->options,((PetscObject)svd)->prefix,opt,&viewer,&format,&flg));
-  if (!flg) PetscFunctionReturn(0);
+  if (!flg) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscViewerGetType(viewer,&vtype));
   PetscCall(SlepcMonitorMakeKey_Internal(name,vtype,format,key));
@@ -601,7 +599,7 @@ PetscErrorCode SVDMonitorSetFromOptions(SVD svd,const char opt[],const char name
   PetscCall(PetscObjectDereference((PetscObject)viewer));
   PetscCall(SVDMonitorSet(svd,mfunc,vf,(PetscErrorCode(*)(void **))dfunc));
   if (trackall) PetscCall(SVDSetTrackAll(svd,PETSC_TRUE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -609,7 +607,7 @@ PetscErrorCode SVDMonitorSetFromOptions(SVD svd,const char opt[],const char name
    This routine must be called before SVDSetUp() if the user is to be
    allowed to set the solver type.
 
-   Collective on svd
+   Collective
 
    Input Parameters:
 .  svd - the singular value solver context
@@ -710,14 +708,15 @@ PetscErrorCode SVDSetFromOptions(SVD svd)
   if (!svd->U) PetscCall(SVDGetBV(svd,NULL,&svd->U));
   PetscCall(BVSetFromOptions(svd->U));
   if (!svd->ds) PetscCall(SVDGetDS(svd,&svd->ds));
+  PetscCall(SVDSetDSType(svd));
   PetscCall(DSSetFromOptions(svd->ds));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDSetProblemType - Specifies the type of the singular value problem.
 
-   Logically Collective on svd
+   Logically Collective
 
    Input Parameters:
 +  svd  - the singular value solver context
@@ -741,7 +740,7 @@ PetscErrorCode SVDSetProblemType(SVD svd,SVDProblemType type)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidLogicalCollectiveEnum(svd,type,2);
-  if (type == svd->problem_type) PetscFunctionReturn(0);
+  if (type == svd->problem_type) PetscFunctionReturn(PETSC_SUCCESS);
   switch (type) {
     case SVD_STANDARD:
       svd->isgeneralized = PETSC_FALSE;
@@ -760,7 +759,7 @@ PetscErrorCode SVDSetProblemType(SVD svd,SVDProblemType type)
   }
   svd->problem_type = type;
   svd->state = SVD_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -784,14 +783,14 @@ PetscErrorCode SVDGetProblemType(SVD svd,SVDProblemType *type)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidPointer(type,2);
   *type = svd->problem_type;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDIsGeneralized - Ask if the SVD object corresponds to a generalized
    singular value problem.
 
-   Not collective
+   Not Collective
 
    Input Parameter:
 .  svd - the singular value solver context
@@ -809,14 +808,14 @@ PetscErrorCode SVDIsGeneralized(SVD svd,PetscBool* is)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidBoolPointer(is,2);
   *is = svd->isgeneralized;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDIsHyperbolic - Ask if the SVD object corresponds to a hyperbolic
    singular value problem.
 
-   Not collective
+   Not Collective
 
    Input Parameter:
 .  svd - the singular value solver context
@@ -834,14 +833,14 @@ PetscErrorCode SVDIsHyperbolic(SVD svd,PetscBool* is)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidBoolPointer(is,2);
   *is = svd->ishyperbolic;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDSetTrackAll - Specifies if the solver must compute the residual norm of all
    approximate singular value or not.
 
-   Logically Collective on svd
+   Logically Collective
 
    Input Parameters:
 +  svd      - the singular value solver context
@@ -865,7 +864,7 @@ PetscErrorCode SVDSetTrackAll(SVD svd,PetscBool trackall)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidLogicalCollectiveBool(svd,trackall,2);
   svd->trackall = trackall;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -890,14 +889,14 @@ PetscErrorCode SVDGetTrackAll(SVD svd,PetscBool *trackall)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidBoolPointer(trackall,2);
   *trackall = svd->trackall;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SVDSetOptionsPrefix - Sets the prefix used for searching for all
    SVD options in the database.
 
-   Logically Collective on svd
+   Logically Collective
 
    Input Parameters:
 +  svd - the singular value solver context
@@ -929,14 +928,14 @@ PetscErrorCode SVDSetOptionsPrefix(SVD svd,const char *prefix)
   if (!svd->ds) PetscCall(SVDGetDS(svd,&svd->ds));
   PetscCall(DSSetOptionsPrefix(svd->ds,prefix));
   PetscCall(PetscObjectSetOptionsPrefix((PetscObject)svd,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SVDAppendOptionsPrefix - Appends to the prefix used for searching for all
    SVD options in the database.
 
-   Logically Collective on svd
+   Logically Collective
 
    Input Parameters:
 +  svd - the singular value solver context
@@ -960,7 +959,7 @@ PetscErrorCode SVDAppendOptionsPrefix(SVD svd,const char *prefix)
   if (!svd->ds) PetscCall(SVDGetDS(svd,&svd->ds));
   PetscCall(DSAppendOptionsPrefix(svd->ds,prefix));
   PetscCall(PetscObjectAppendOptionsPrefix((PetscObject)svd,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -989,5 +988,5 @@ PetscErrorCode SVDGetOptionsPrefix(SVD svd,const char *prefix[])
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidPointer(prefix,2);
   PetscCall(PetscObjectGetOptionsPrefix((PetscObject)svd,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
