@@ -16,7 +16,7 @@
 /*@
    SVDSetOperators - Set the matrices associated with the singular value problem.
 
-   Collective on svd
+   Collective
 
    Input Parameters:
 +  svd - the singular value solver context
@@ -75,13 +75,13 @@ PetscErrorCode SVDSetOperators(SVD svd,Mat A,Mat B)
   svd->OP   = A;
   svd->OPb  = B;
   svd->state = SVD_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDGetOperators - Get the matrices associated with the singular value problem.
 
-   Collective on svd
+   Not Collective
 
    Input Parameter:
 .  svd - the singular value solver context
@@ -100,13 +100,13 @@ PetscErrorCode SVDGetOperators(SVD svd,Mat *A,Mat *B)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   if (A) *A = svd->OP;
   if (B) *B = svd->OPb;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDSetSignature - Set the signature matrix defining a hyperbolic singular value problem.
 
-   Collective on svd
+   Collective
 
    Input Parameters:
 +  svd   - the singular value solver context
@@ -144,13 +144,13 @@ PetscErrorCode SVDSetSignature(SVD svd,Vec omega)
   PetscCall(VecDestroy(&svd->omega));
   svd->omega = omega;
   svd->state = SVD_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDGetSignature - Get the signature matrix defining a hyperbolic singular value problem.
 
-   Collective on svd
+   Not Collective
 
    Input Parameter:
 .  svd - the singular value solver context
@@ -168,14 +168,39 @@ PetscErrorCode SVDGetSignature(SVD svd,Vec *omega)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidPointer(omega,2);
   *omega = svd->omega;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+/*@
+   SVDSetDSType - Sets the type of the internal DS object based on the current
+   settings of the singular value solver.
+
+   Collective
+
+   Input Parameter:
+.  svd - singular value solver context
+
+   Note:
+   This function need not be called explicitly, since it will be called at
+   both SVDSetFromOptions() and SVDSetUp().
+
+   Level: developer
+
+.seealso: SVDSetFromOptions(), SVDSetUp()
+@*/
+PetscErrorCode SVDSetDSType(SVD svd)
+{
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
+  PetscTryTypeMethod(svd,setdstype);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDSetUp - Sets up all the internal data structures necessary for the
    execution of the singular value solver.
 
-   Collective on svd
+   Collective
 
    Input Parameter:
 .  svd   - singular value solver context
@@ -199,7 +224,7 @@ PetscErrorCode SVDSetUp(SVD svd)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
-  if (svd->state) PetscFunctionReturn(0);
+  if (svd->state) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscLogEventBegin(SVD_SetUp,svd,0,0,0));
 
   /* reset the convergence flag from the previous solves */
@@ -208,6 +233,7 @@ PetscErrorCode SVDSetUp(SVD svd)
   /* set default solver type (SVDSetFromOptions was not called) */
   if (!((PetscObject)svd)->type_name) PetscCall(SVDSetType(svd,SVDCROSS));
   if (!svd->ds) PetscCall(SVDGetDS(svd,&svd->ds));
+  PetscCall(SVDSetDSType(svd));
 
   /* check matrices */
   PetscCheck(svd->OP,PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_WRONGSTATE,"SVDSetOperators() must be called first");
@@ -238,7 +264,7 @@ PetscErrorCode SVDSetUp(SVD svd)
     PetscCall(MatHasOperation(svd->OP,MATOP_TRANSPOSE,&flg));
     if (!flg) svd->expltrans = PETSC_FALSE;
     else {
-      PetscCall(PetscObjectTypeCompareAny((PetscObject)svd,&flg,SVDLAPACK,SVDSCALAPACK,SVDELEMENTAL,""));
+      PetscCall(PetscObjectTypeCompareAny((PetscObject)svd,&flg,SVDLAPACK,SVDSCALAPACK,SVDKSVD,SVDELEMENTAL,""));
       if (flg) svd->expltrans = PETSC_FALSE;
     }
   }
@@ -315,7 +341,7 @@ PetscErrorCode SVDSetUp(SVD svd)
   PetscUseTypeMethod(svd,setup);
 
   /* set tolerance if not yet set */
-  if (svd->tol==PETSC_DEFAULT) svd->tol = SLEPC_DEFAULT_TOL;
+  if (svd->tol==(PetscReal)PETSC_DEFAULT) svd->tol = SLEPC_DEFAULT_TOL;
 
   /* fill sorting criterion context */
   PetscCall(DSGetSlepcSC(svd->ds,&sc));
@@ -345,14 +371,14 @@ PetscErrorCode SVDSetUp(SVD svd)
 
   PetscCall(PetscLogEventEnd(SVD_SetUp,svd,0,0,0));
   svd->state = SVD_STATE_SETUP;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SVDSetInitialSpaces - Specify two basis of vectors that constitute the initial
    right and/or left spaces.
 
-   Collective on svd
+   Collective
 
    Input Parameters:
 +  svd   - the singular value solver context
@@ -401,7 +427,7 @@ PetscErrorCode SVDSetInitialSpaces(SVD svd,PetscInt nr,Vec isr[],PetscInt nl,Vec
   PetscCall(SlepcBasisReference_Private(nr,isr,&svd->nini,&svd->IS));
   PetscCall(SlepcBasisReference_Private(nl,isl,&svd->ninil,&svd->ISL));
   if (nr>0 || nl>0) svd->state = SVD_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -431,14 +457,14 @@ PetscErrorCode SVDSetDimensions_Default(SVD svd)
     }
   }
   if (svd->mpd==PETSC_DEFAULT) svd->mpd = svd->ncv;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDAllocateSolution - Allocate memory storage for common variables such
    as the singular values and the basis vectors.
 
-   Collective on svd
+   Collective
 
    Input Parameters:
 +  svd   - eigensolver context
@@ -499,5 +525,5 @@ PetscErrorCode SVDAllocateSolution(SVD svd,PetscInt extra)
       PetscCall(VecDestroy(&tl));
     } else PetscCall(BVResize(svd->U,requested,PETSC_FALSE));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
