@@ -12,6 +12,7 @@
 */
 
 #include <slepc/private/svdimpl.h>   /*I "slepcsvd.h" I*/
+#include <slepc/private/bvimpl.h>
 
 /*
   SVDComputeVectors_Left - Compute left singular vectors as U=A*V.
@@ -20,10 +21,8 @@
 PetscErrorCode SVDComputeVectors_Left(SVD svd)
 {
   Vec                tl,omega2,u,v,w;
-  PetscInt           i,n,N,oldsize;
-  MatType            Atype;
+  PetscInt           i,oldsize;
   VecType            vtype;
-  Mat                Omega;
   const PetscScalar* varray;
 
   PetscFunctionBegin;
@@ -52,16 +51,8 @@ PetscErrorCode SVDComputeVectors_Left(SVD svd)
       }
       PetscCall(VecDestroy(&w));
     } else {  /* compute left singular vectors as usual U=A*V, and set-up Omega-orthogonalization of U */
-      PetscCall(MatGetType(svd->A,&Atype));
-      PetscCall(BVGetSizes(svd->U,&n,&N,NULL));
-      PetscCall(MatCreate(PetscObjectComm((PetscObject)svd),&Omega));
-      PetscCall(MatSetSizes(Omega,n,n,N,N));
-      PetscCall(MatSetType(Omega,Atype));
-      PetscCall(MatSetUp(Omega));
-      PetscCall(MatDiagonalSet(Omega,svd->omega,INSERT_VALUES));
+      PetscCall(BV_SetMatrixDiagonal(svd->U,svd->omega,svd->A));
       PetscCall(BVMatMult(svd->V,svd->A,svd->U));
-      PetscCall(BVSetMatrix(svd->U,Omega,PETSC_TRUE));
-      PetscCall(MatDestroy(&Omega));
     }
     PetscCall(BVOrthogonalize(svd->U,NULL));
     if (svd->ishyperbolic && !svd->swapped) {  /* store signature after Omega-orthogonalization */
@@ -79,7 +70,7 @@ PetscErrorCode SVDComputeVectors_Left(SVD svd)
       PetscCall(VecDestroy(&omega2));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode SVDComputeVectors(SVD svd)
@@ -88,13 +79,13 @@ PetscErrorCode SVDComputeVectors(SVD svd)
   SVDCheckSolved(svd,1);
   if (svd->state==SVD_STATE_SOLVED) PetscTryTypeMethod(svd,computevectors);
   svd->state = SVD_STATE_VECTORS;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDSolve - Solves the singular value problem.
 
-   Collective on svd
+   Collective
 
    Input Parameter:
 .  svd - singular value solver context obtained from SVDCreate()
@@ -128,7 +119,7 @@ PetscErrorCode SVDSolve(SVD svd)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
-  if (svd->state>=SVD_STATE_SOLVED) PetscFunctionReturn(0);
+  if (svd->state>=SVD_STATE_SOLVED) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscLogEventBegin(SVD_Solve,svd,0,0,0));
 
   /* call setup */
@@ -179,7 +170,7 @@ PetscErrorCode SVDSolve(SVD svd)
   /* Remove the initial subspaces */
   svd->nini = 0;
   svd->ninil = 0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -212,7 +203,7 @@ PetscErrorCode SVDGetIterationNumber(SVD svd,PetscInt *its)
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscValidIntPointer(its,2);
   *its = svd->its;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -252,7 +243,7 @@ PetscErrorCode SVDGetConvergedReason(SVD svd,SVDConvergedReason *reason)
   PetscValidIntPointer(reason,2);
   SVDCheckSolved(svd,1);
   *reason = svd->reason;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -280,7 +271,7 @@ PetscErrorCode SVDGetConverged(SVD svd,PetscInt *nconv)
   PetscValidIntPointer(nconv,2);
   SVDCheckSolved(svd,1);
   *nconv = svd->nconv;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -288,7 +279,7 @@ PetscErrorCode SVDGetConverged(SVD svd,PetscInt *nconv)
    as computed by SVDSolve(). The solution consists in the singular value and its left
    and right singular vectors.
 
-   Not Collective, but vectors are shared by all processors that share the SVD
+   Collective
 
    Input Parameters:
 +  svd - singular value solver context
@@ -342,7 +333,7 @@ PetscErrorCode SVDGetSingularTriplet(SVD svd,PetscInt i,PetscReal *sigma,Vec u,V
     if (u) PetscCall(BVCopyVec(svd->U,svd->perm[i],u));
     if (v) PetscCall(BVCopyVec(svd->V,svd->perm[i],v));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -373,7 +364,7 @@ static PetscErrorCode SVDComputeResidualNorms_Standard(SVD svd,PetscReal sigma,V
     PetscCall(VecAXPY(y,-sigma,v));
     PetscCall(VecNorm(y,NORM_2,norm2));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -426,7 +417,7 @@ static PetscErrorCode SVDComputeResidualNorms_Generalized(SVD svd,PetscReal sigm
   PetscCall(VecDestroy(&v));
   PetscCall(VecDestroy(&u));
   PetscCall(VecDestroy(&nest));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -459,14 +450,14 @@ static PetscErrorCode SVDComputeResidualNorms_Hyperbolic(SVD svd,PetscReal sigma
     PetscCall(VecAXPY(y,-sigma*sign,v));
     PetscCall(VecNorm(y,NORM_2,norm2));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDComputeError - Computes the error (based on the residual norm) associated
    with the i-th singular triplet.
 
-   Collective on svd
+   Collective
 
    Input Parameters:
 +  svd  - the singular value solver context
@@ -558,5 +549,5 @@ PetscErrorCode SVDComputeError(SVD svd,PetscInt i,SVDErrorType type,PetscReal *e
     default:
       SETERRQ(PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"Invalid error type");
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
