@@ -17,7 +17,7 @@
 /*@C
    SVDView - Prints the SVD data structure.
 
-   Collective on svd
+   Collective
 
    Input Parameters:
 +  svd - the singular value solver context
@@ -44,7 +44,7 @@
 PetscErrorCode SVDView(SVD svd,PetscViewer viewer)
 {
   const char     *type=NULL;
-  PetscBool      isascii,isshell;
+  PetscBool      isascii,isshell,isexternal;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
@@ -96,8 +96,9 @@ PetscErrorCode SVDView(SVD svd,PetscViewer viewer)
     if (svd->nini) PetscCall(PetscViewerASCIIPrintf(viewer,"  dimension of user-provided initial space: %" PetscInt_FMT "\n",PetscAbs(svd->nini)));
     if (svd->ninil) PetscCall(PetscViewerASCIIPrintf(viewer,"  dimension of user-provided initial left space: %" PetscInt_FMT "\n",PetscAbs(svd->ninil)));
   } else PetscTryTypeMethod(svd,view,viewer);
-  PetscCall(PetscObjectTypeCompareAny((PetscObject)svd,&isshell,SVDCROSS,SVDCYCLIC,SVDSCALAPACK,SVDELEMENTAL,SVDPRIMME,""));
-  if (!isshell) {
+  PetscCall(PetscObjectTypeCompareAny((PetscObject)svd,&isshell,SVDCROSS,SVDCYCLIC,""));
+  PetscCall(PetscObjectTypeCompareAny((PetscObject)svd,&isexternal,SVDSCALAPACK,SVDKSVD,SVDELEMENTAL,SVDPRIMME,""));
+  if (!isshell && !isexternal) {
     PetscCall(PetscViewerPushFormat(viewer,PETSC_VIEWER_ASCII_INFO));
     if (!svd->V) PetscCall(SVDGetBV(svd,&svd->V,NULL));
     PetscCall(BVView(svd->V,viewer));
@@ -105,13 +106,13 @@ PetscErrorCode SVDView(SVD svd,PetscViewer viewer)
     PetscCall(DSView(svd->ds,viewer));
     PetscCall(PetscViewerPopFormat(viewer));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SVDViewFromOptions - View from options
 
-   Collective on SVD
+   Collective
 
    Input Parameters:
 +  svd  - the singular value solver context
@@ -127,13 +128,13 @@ PetscErrorCode SVDViewFromOptions(SVD svd,PetscObject obj,const char name[])
   PetscFunctionBegin;
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
   PetscCall(PetscObjectViewFromOptions((PetscObject)svd,obj,name));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SVDConvergedReasonView - Displays the reason an SVD solve converged or diverged.
 
-   Collective on svd
+   Collective
 
    Input Parameters:
 +  svd - the singular value solver context
@@ -167,14 +168,14 @@ PetscErrorCode SVDConvergedReasonView(SVD svd,PetscViewer viewer)
     else if (svd->reason <= 0) PetscCall(PetscViewerASCIIPrintf(viewer,"%s SVD solve did not converge due to %s; iterations %" PetscInt_FMT "\n",((PetscObject)svd)->prefix?((PetscObject)svd)->prefix:"",SVDConvergedReasons[svd->reason],svd->its));
     PetscCall(PetscViewerASCIISubtractTab(viewer,((PetscObject)svd)->tablevel));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDConvergedReasonViewFromOptions - Processes command line options to determine if/how
    the SVD converged reason is to be viewed.
 
-   Collective on svd
+   Collective
 
    Input Parameter:
 .  svd - the singular value solver context
@@ -191,7 +192,7 @@ PetscErrorCode SVDConvergedReasonViewFromOptions(SVD svd)
   PetscViewerFormat format;
 
   PetscFunctionBegin;
-  if (incall) PetscFunctionReturn(0);
+  if (incall) PetscFunctionReturn(PETSC_SUCCESS);
   incall = PETSC_TRUE;
   PetscCall(PetscOptionsGetViewer(PetscObjectComm((PetscObject)svd),((PetscObject)svd)->options,((PetscObject)svd)->prefix,"-svd_converged_reason",&viewer,&format,&flg));
   if (flg) {
@@ -201,7 +202,7 @@ PetscErrorCode SVDConvergedReasonViewFromOptions(SVD svd)
     PetscCall(PetscViewerDestroy(&viewer));
   }
   incall = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDErrorView_ASCII(SVD svd,SVDErrorType etype,PetscViewer viewer)
@@ -212,13 +213,13 @@ static PetscErrorCode SVDErrorView_ASCII(SVD svd,SVDErrorType etype,PetscViewer
   PetscFunctionBegin;
   if (svd->nconv<svd->nsv) {
     PetscCall(PetscViewerASCIIPrintf(viewer," Problem: less than %" PetscInt_FMT " singular values converged\n\n",svd->nsv));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   for (i=0;i<svd->nsv;i++) {
     PetscCall(SVDComputeError(svd,i,etype,&error));
     if (error>=5.0*svd->tol) {
       PetscCall(PetscViewerASCIIPrintf(viewer," Problem: some of the first %" PetscInt_FMT " relative errors are higher than the tolerance\n\n",svd->nsv));
-      PetscFunctionReturn(0);
+      PetscFunctionReturn(PETSC_SUCCESS);
     }
   }
   PetscCall(PetscViewerASCIIPrintf(viewer," All requested %ssingular values computed up to the required tolerance:",svd->isgeneralized?"generalized ":""));
@@ -231,7 +232,7 @@ static PetscErrorCode SVDErrorView_ASCII(SVD svd,SVDErrorType etype,PetscViewer
     }
   }
   PetscCall(PetscViewerASCIIPrintf(viewer,"\n\n"));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDErrorView_DETAIL(SVD svd,SVDErrorType etype,PetscViewer viewer)
@@ -241,7 +242,7 @@ static PetscErrorCode SVDErrorView_DETAIL(SVD svd,SVDErrorType etype,PetscViewer
   char           ex[30],sep[]=" ---------------------- --------------------\n";
 
   PetscFunctionBegin;
-  if (!svd->nconv) PetscFunctionReturn(0);
+  if (!svd->nconv) PetscFunctionReturn(PETSC_SUCCESS);
   switch (etype) {
     case SVD_ERROR_ABSOLUTE:
       PetscCall(PetscSNPrintf(ex,sizeof(ex)," absolute error"));
@@ -261,7 +262,7 @@ static PetscErrorCode SVDErrorView_DETAIL(SVD svd,SVDErrorType etype,PetscViewer
     PetscCall(PetscViewerASCIIPrintf(viewer,"       % 6f          %12g\n",(double)sigma,(double)error));
   }
   PetscCall(PetscViewerASCIIPrintf(viewer,"%s",sep));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDErrorView_MATLAB(SVD svd,SVDErrorType etype,PetscViewer viewer)
@@ -278,14 +279,14 @@ static PetscErrorCode SVDErrorView_MATLAB(SVD svd,SVDErrorType etype,PetscViewer
     PetscCall(PetscViewerASCIIPrintf(viewer,"%18.16e\n",(double)error));
   }
   PetscCall(PetscViewerASCIIPrintf(viewer,"];\n"));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SVDErrorView - Displays the errors associated with the computed solution
    (as well as the singular values).
 
-   Collective on svd
+   Collective
 
    Input Parameters:
 +  svd    - the singular value solver context
@@ -319,7 +320,7 @@ PetscErrorCode SVDErrorView(SVD svd,SVDErrorType etype,PetscViewer viewer)
   PetscCheckSameComm(svd,1,viewer,3);
   SVDCheckSolved(svd,1);
   PetscCall(PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii));
-  if (!isascii) PetscFunctionReturn(0);
+  if (!isascii) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscViewerGetFormat(viewer,&format));
   switch (format) {
@@ -336,14 +337,14 @@ PetscErrorCode SVDErrorView(SVD svd,SVDErrorType etype,PetscViewer viewer)
     default:
       PetscCall(PetscInfo(svd,"Unsupported viewer format %s\n",PetscViewerFormats[format]));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDErrorViewFromOptions - Processes command line options to determine if/how
    the errors of the computed solution are to be viewed.
 
-   Collective on svd
+   Collective
 
    Input Parameter:
 .  svd - the singular value solver context
@@ -360,7 +361,7 @@ PetscErrorCode SVDErrorViewFromOptions(SVD svd)
   PetscViewerFormat format;
 
   PetscFunctionBegin;
-  if (incall) PetscFunctionReturn(0);
+  if (incall) PetscFunctionReturn(PETSC_SUCCESS);
   incall = PETSC_TRUE;
   PetscCall(PetscOptionsGetViewer(PetscObjectComm((PetscObject)svd),((PetscObject)svd)->options,((PetscObject)svd)->prefix,"-svd_error_absolute",&viewer,&format,&flg));
   if (flg) {
@@ -384,7 +385,7 @@ PetscErrorCode SVDErrorViewFromOptions(SVD svd)
     PetscCall(PetscViewerDestroy(&viewer));
   }
   incall = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDValuesView_DRAW(SVD svd,PetscViewer viewer)
@@ -395,7 +396,7 @@ static PetscErrorCode SVDValuesView_DRAW(SVD svd,PetscViewer viewer)
   PetscInt       i;
 
   PetscFunctionBegin;
-  if (!svd->nconv) PetscFunctionReturn(0);
+  if (!svd->nconv) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscViewerDrawGetDraw(viewer,0,&draw));
   PetscCall(PetscDrawSetTitle(draw,"Computed singular values"));
   PetscCall(PetscDrawSPCreate(draw,1,&drawsp));
@@ -406,7 +407,7 @@ static PetscErrorCode SVDValuesView_DRAW(SVD svd,PetscViewer viewer)
   PetscCall(PetscDrawSPDraw(drawsp,PETSC_TRUE));
   PetscCall(PetscDrawSPSave(drawsp));
   PetscCall(PetscDrawSPDestroy(&drawsp));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDValuesView_BINARY(SVD svd,PetscViewer viewer)
@@ -422,7 +423,7 @@ static PetscErrorCode SVDValuesView_BINARY(SVD svd,PetscViewer viewer)
   }
   PetscCall(PetscViewerBinaryWrite(viewer,sv,svd->nconv,PETSC_REAL));
   PetscCall(PetscFree(sv));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #if defined(PETSC_HAVE_HDF5)
@@ -453,7 +454,7 @@ static PetscErrorCode SVDValuesView_HDF5(SVD svd,PetscViewer viewer)
   PetscCall(VecAssemblyEnd(v));
   PetscCall(VecView(v,viewer));
   PetscCall(VecDestroy(&v));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 #endif
 
@@ -465,7 +466,7 @@ static PetscErrorCode SVDValuesView_ASCII(SVD svd,PetscViewer viewer)
   PetscCall(PetscViewerASCIIPrintf(viewer,"Singular values = \n"));
   for (i=0;i<svd->nconv;i++) PetscCall(PetscViewerASCIIPrintf(viewer,"   %.5f\n",(double)svd->sigma[svd->perm[i]]));
   PetscCall(PetscViewerASCIIPrintf(viewer,"\n"));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SVDValuesView_MATLAB(SVD svd,PetscViewer viewer)
@@ -478,13 +479,13 @@ static PetscErrorCode SVDValuesView_MATLAB(SVD svd,PetscViewer viewer)
   PetscCall(PetscViewerASCIIPrintf(viewer,"Sigma_%s = [\n",name));
   for (i=0;i<svd->nconv;i++) PetscCall(PetscViewerASCIIPrintf(viewer,"%18.16e\n",(double)svd->sigma[svd->perm[i]]));
   PetscCall(PetscViewerASCIIPrintf(viewer,"];\n"));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SVDValuesView - Displays the computed singular values in a viewer.
 
-   Collective on svd
+   Collective
 
    Input Parameters:
 +  svd    - the singular value solver context
@@ -537,14 +538,14 @@ PetscErrorCode SVDValuesView(SVD svd,PetscViewer viewer)
         PetscCall(PetscInfo(svd,"Unsupported viewer format %s\n",PetscViewerFormats[format]));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDValuesViewFromOptions - Processes command line options to determine if/how
    the computed singular values are to be viewed.
 
-   Collective on svd
+   Collective
 
    Input Parameter:
 .  svd - the singular value solver context
@@ -561,7 +562,7 @@ PetscErrorCode SVDValuesViewFromOptions(SVD svd)
   PetscViewerFormat format;
 
   PetscFunctionBegin;
-  if (incall) PetscFunctionReturn(0);
+  if (incall) PetscFunctionReturn(PETSC_SUCCESS);
   incall = PETSC_TRUE;
   PetscCall(PetscOptionsGetViewer(PetscObjectComm((PetscObject)svd),((PetscObject)svd)->options,((PetscObject)svd)->prefix,"-svd_view_values",&viewer,&format,&flg));
   if (flg) {
@@ -571,13 +572,13 @@ PetscErrorCode SVDValuesViewFromOptions(SVD svd)
     PetscCall(PetscViewerDestroy(&viewer));
   }
   incall = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SVDVectorsView - Outputs computed singular vectors to a viewer.
 
-   Collective on svd
+   Collective
 
    Input Parameters:
 +  svd    - the singular value solver context
@@ -624,14 +625,14 @@ PetscErrorCode SVDVectorsView(SVD svd,PetscViewer viewer)
       PetscCall(BVRestoreColumn(svd->U,k,&x));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    SVDVectorsViewFromOptions - Processes command line options to determine if/how
    the computed singular vectors are to be viewed.
 
-   Collective on svd
+   Collective
 
    Input Parameter:
 .  svd - the singular value solver context
@@ -648,7 +649,7 @@ PetscErrorCode SVDVectorsViewFromOptions(SVD svd)
   PetscViewerFormat format;
 
   PetscFunctionBegin;
-  if (incall) PetscFunctionReturn(0);
+  if (incall) PetscFunctionReturn(PETSC_SUCCESS);
   incall = PETSC_TRUE;
   PetscCall(PetscOptionsGetViewer(PetscObjectComm((PetscObject)svd),((PetscObject)svd)->options,((PetscObject)svd)->prefix,"-svd_view_vectors",&viewer,&format,&flg));
   if (flg) {
@@ -658,5 +659,5 @@ PetscErrorCode SVDVectorsViewFromOptions(SVD svd)
     PetscCall(PetscViewerDestroy(&viewer));
   }
   incall = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
