@@ -27,6 +27,7 @@ int main(int argc,char **argv)
   PetscInt       m=100,n,p=14,i,j,d,Istart,Iend,nsv,maxit,its,nconv;
   PetscBool      flg,skiporth=PETSC_FALSE;
 
+  PetscFunctionBeginUser;
   PetscCall(SlepcInitialize(&argc,&argv,(char*)0,help));
 
   PetscCall(PetscOptionsGetInt(NULL,NULL,"-m",&m,NULL));
@@ -204,11 +205,14 @@ int main(int argc,char **argv)
       requires: double
       output_file: output/ex45_5.out
       test:
-         args: -svd_type trlanczos -svd_ncv 8 -svd_trlanczos_gbidiag {{upper lower}}
+         args: -svd_type trlanczos -svd_ncv 8 -svd_trlanczos_gbidiag {{upper lower}} -svd_trlanczos_oneside {{0 1}}
          suffix: 5
       test:
-         args: -svd_type cross -svd_ncv 10 -svd_cross_explicitmatrix {{0 1}}
+         args: -svd_type cross -svd_ncv 10 -svd_cross_explicitmatrix
          suffix: 5_cross
+      test:
+         args: -svd_type cross -svd_ncv 10 -svd_cross_eps_type krylovschur -svd_cross_st_type sinvert -svd_cross_eps_target 0 -svd_cross_st_ksp_type gmres -svd_cross_st_pc_type jacobi
+         suffix: 5_cross_implicit
       test:
          args: -svd_type cyclic -svd_ncv 12 -svd_cyclic_explicitmatrix {{0 1}}
          suffix: 5_cyclic
@@ -220,7 +224,7 @@ int main(int argc,char **argv)
       requires: double
       output_file: output/ex45_6.out
       test:
-         args: -svd_type trlanczos -svd_trlanczos_gbidiag {{single upper lower}} -svd_trlanczos_locking {{0 1}}
+         args: -svd_type trlanczos -svd_trlanczos_gbidiag {{single upper lower}} -svd_trlanczos_locking {{0 1}} -svd_trlanczos_oneside {{0 1}}
          suffix: 6
       test:
          args: -svd_type cross -svd_cross_explicitmatrix {{0 1}}
@@ -239,7 +243,7 @@ int main(int argc,char **argv)
       requires: double
       output_file: output/ex45_7.out
       test:
-         args: -svd_type trlanczos -svd_trlanczos_gbidiag {{single upper lower}} -svd_trlanczos_restart 0.4
+         args: -svd_type trlanczos -svd_trlanczos_gbidiag {{single upper lower}} -svd_trlanczos_restart 0.4 -svd_trlanczos_oneside {{0 1}}
          suffix: 7
       test:
          args: -svd_type cross -svd_cross_explicitmatrix {{0 1}}
@@ -252,4 +256,9 @@ int main(int argc,char **argv)
       suffix: 7_cyclic
       output_file: output/ex45_7_cyclic.out
 
+   test:
+       args: -m 25 -n 20 -p 21 -svd_smallest -svd_nsv 2 -svd_ncv 5 -svd_type trlanczos -svd_trlanczos_gbidiag {{upper lower}} -svd_trlanczos_scale {{0.1 -20}}
+       filter: grep -v "Solution method" | grep -v "Number of iterations" | grep -v "Stopping condition" | sed -e "s/, maxit=1[0]*$//" | sed -e "s/[0-9]\.[0-9]*e[+-]\([0-9]*\)/removed/g"
+       suffix: 8
+
 TEST*/
