@@ -24,7 +24,7 @@ int main(int argc,char **argv)
   Vec            u,v,vomega,*U,*V;
   MatType        Atype;
   PetscReal      tol,lev1=0.0,lev2=0.0;
-  PetscInt       M,N,p=0,i,Istart,Iend,nconv;
+  PetscInt       M,N,p=0,i,Istart,Iend,nconv,nsv;
   char           filename[PETSC_MAX_PATH_LEN];
   PetscViewer    viewer;
   PetscBool      flg,terse,skiporth=PETSC_FALSE,transpose=PETSC_FALSE;
@@ -105,7 +105,6 @@ int main(int argc,char **argv)
   PetscCall(MatCreateVecs(A,&v,&u));
   PetscCall(VecSet(u,1.0));
   PetscCall(VecSet(v,1.0));
-  PetscCall(SVDSetInitialSpaces(svd,1,&v,1,&u));
   PetscCall(SVDSolve(svd));
 
   /* show detailed info unless -terse option is given by user */
@@ -121,6 +120,8 @@ int main(int argc,char **argv)
   /* check orthogonality */
   PetscCall(PetscOptionsGetBool(NULL,NULL,"-skiporth",&skiporth,NULL));
   PetscCall(SVDGetConverged(svd,&nconv));
+  PetscCall(SVDGetDimensions(svd,&nsv,NULL,NULL));
+  nconv = PetscMin(nconv,nsv);
   if (nconv>0 && !skiporth) {
     PetscCall(SVDGetTolerances(svd,&tol,NULL));
     PetscCall(VecDuplicateVecs(u,nconv,&U));
@@ -158,6 +159,12 @@ int main(int argc,char **argv)
       test:
          args: -svd_type cyclic -svd_cyclic_explicitmatrix {{0 1}} -svd_ncv 300
          suffix: 1_cyclic
+      test:
+         args: -svd_type trlanczos -svd_trlanczos_explicitmatrix {{0 1}}
+         suffix: 1_trlanczos
+      test:
+         args: -svd_type lapack
+         suffix: 1_lapack
 
    testset:
       args: -file ${DATAFILESPATH}/matrices/real/illc1033.petsc -transpose -svd_nsv 6 -p 130 -terse
@@ -168,8 +175,11 @@ int main(int argc,char **argv)
          args: -svd_type cross -svd_cross_explicitmatrix {{0 1}} -svd_implicittranspose {{0 1}} -svd_ncv 100
          suffix: 2_cross
       test:
-         args: -svd_type cyclic -svd_cyclic_explicitmatrix {{0 1}}
+         args: -svd_type cyclic -svd_cyclic_explicitmatrix {{0 1}} -svd_ncv 25
          suffix: 2_cyclic
+      test:
+         args: -svd_type trlanczos -svd_trlanczos_explicitmatrix {{0 1}} -svd_implicittranspose {{0 1}}
+         suffix: 2_trlanczos
 
    testset:
       args: -file ${DATAFILESPATH}/matrices/complex/illc1033.petsc -svd_nsv 62 -p 40 -terse
@@ -180,8 +190,14 @@ int main(int argc,char **argv)
          args: -svd_type cross -svd_cross_explicitmatrix {{0 1}}
          suffix: 3_cross
       test:
-         args: -svd_type cyclic -svd_cyclic_explicitmatrix {{0 1}}
+         args: -svd_type cyclic -svd_cyclic_explicitmatrix {{0 1}} -svd_cyclic_bv_definite_tol 1e-13 -svd_cyclic_st_ksp_type gmres -svd_cyclic_st_pc_type jacobi -svd_ncv 250
          suffix: 3_cyclic
+      test:
+         args: -svd_type trlanczos -svd_trlanczos_explicitmatrix {{0 1}} -bv_definite_tol 1e-13
+         suffix: 3_trlanczos
+      test:
+         args: -svd_type lapack
+         suffix: 3_lapack
 
    testset:
       args: -file ${DATAFILESPATH}/matrices/complex/illc1033.petsc -transpose -svd_nsv 6 -p 130 -terse
@@ -189,11 +205,14 @@ int main(int argc,char **argv)
       filter: grep -v Reading
       output_file: output/ex52_2.out
       test:
-         args: -svd_type cross -svd_cross_explicitmatrix {{0 1}} -svd_ncv 100
+         args: -svd_type cross -svd_cross_explicitmatrix {{0 1}} -svd_ncv 100 -svd_cross_bv_definite_tol 1e-14
          suffix: 4_cross
       test:
-         args: -svd_type cyclic -svd_cyclic_explicitmatrix {{0 1}}
+         args: -svd_type cyclic -svd_cyclic_explicitmatrix {{0 1}} -svd_ncv 26
          suffix: 4_cyclic
+      test:
+         args: -svd_type trlanczos -svd_trlanczos_explicitmatrix {{0 1}}
+         suffix: 4_trlanczos
 
    testset:
       args: -file ${SLEPC_DIR}/share/slepc/datafiles/matrices/rdb200.petsc -svd_smallest -svd_nsv 3 -p 1 -terse
@@ -201,10 +220,16 @@ int main(int argc,char **argv)
       filter: grep -v Reading
       output_file: output/ex52_5.out
       test:
-         args: -svd_type cross -svd_max_it 1000
+         args: -svd_type cross -svd_max_it 1000 -svd_cross_bv_definite_tol 1e-14
          suffix: 5_cross
       test:
-         args: -svd_type cyclic -svd_max_it 4000 -svd_cyclic_st_ksp_type preonly -svd_cyclic_st_pc_type jacobi
+         args: -svd_type cyclic -svd_max_it 4000 -svd_ncv 30 -svd_cyclic_st_ksp_type preonly -svd_cyclic_st_pc_type jacobi -svd_cyclic_bv_definite_tol 1e-14
          suffix: 5_cyclic
+      test:
+         args: -svd_type trlanczos -svd_max_it 4000 -svd_ncv 28 -bv_definite_tol 1e-14
+         suffix: 5_trlanczos
+      test:
+         args: -svd_type lapack
+         suffix: 5_lapack
 
 TEST*/
