@@ -19,7 +19,7 @@ PetscFunctionList BVList = NULL;
 /*@C
    BVSetType - Selects the type for the BV object.
 
-   Logically Collective on bv
+   Logically Collective
 
    Input Parameters:
 +  bv   - the basis vectors context
@@ -42,7 +42,7 @@ PetscErrorCode BVSetType(BV bv,BVType type)
   PetscValidCharPointer(type,2);
 
   PetscCall(PetscObjectTypeCompare((PetscObject)bv,type,&match));
-  if (match) PetscFunctionReturn(0);
+  if (match) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscStrcmp(type,BVTENSOR,&match));
   PetscCheck(!match,PetscObjectComm((PetscObject)bv),PETSC_ERR_ORDER,"Use BVCreateTensor() to create a BV of type tensor");
 
@@ -60,7 +60,7 @@ PetscErrorCode BVSetType(BV bv,BVType type)
     PetscCall((*r)(bv));
     PetscCall(PetscLogEventEnd(BV_Create,bv,0,0,0));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -84,13 +84,13 @@ PetscErrorCode BVGetType(BV bv,BVType *type)
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
   PetscValidPointer(type,2);
   *type = ((PetscObject)bv)->type_name;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVSetSizes - Sets the local and global sizes, and the number of columns.
 
-   Collective on bv
+   Collective
 
    Input Parameters:
 +  bv - the basis vectors
@@ -141,14 +141,14 @@ PetscErrorCode BVSetSizes(BV bv,PetscInt n,PetscInt N,PetscInt m)
     bv->ops->create = NULL;
     bv->defersfo = PETSC_FALSE;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVSetSizesFromVec - Sets the local and global sizes, and the number of columns.
    Local and global sizes are specified indirectly by passing a template vector.
 
-   Collective on bv
+   Collective
 
    Input Parameters:
 +  bv - the basis vectors
@@ -185,7 +185,7 @@ PetscErrorCode BVSetSizesFromVec(BV bv,Vec t,PetscInt m)
     bv->ops->create = NULL;
     bv->defersfo = PETSC_FALSE;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -217,7 +217,7 @@ PetscErrorCode BVGetSizes(BV bv,PetscInt *n,PetscInt *N,PetscInt *m)
   PetscFunctionBegin;
   if (!bv) {
     if (m && !n && !N) *m = 0;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
   if (n || N) BVCheckSizes(bv,1);
@@ -225,13 +225,13 @@ PetscErrorCode BVGetSizes(BV bv,PetscInt *n,PetscInt *N,PetscInt *m)
   if (N) *N = bv->N;
   if (m) *m = bv->m;
   if (m && !n && !N && !((PetscObject)bv)->type_name) *m = 0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVSetNumConstraints - Set the number of constraints.
 
-   Logically Collective on V
+   Logically Collective
 
    Input Parameters:
 +  V  - basis vectors
@@ -263,7 +263,7 @@ PetscErrorCode BVSetNumConstraints(BV V,PetscInt nc)
   PetscCheck(V->ci[0]==-V->nc-1 && V->ci[1]==-V->nc-1,PetscObjectComm((PetscObject)V),PETSC_ERR_SUP,"Cannot call BVSetNumConstraints after BVGetColumn");
 
   diff = nc-V->nc;
-  if (!diff) PetscFunctionReturn(0);
+  if (!diff) PetscFunctionReturn(PETSC_SUCCESS);
   total = V->nc+V->m;
   PetscCheck(total-nc>0,PetscObjectComm((PetscObject)V),PETSC_ERR_ARG_OUTOFRANGE,"Not enough columns for the given nc value");
   if (diff<0) {  /* lessen constraints, shift contents of BV */
@@ -282,7 +282,7 @@ PetscErrorCode BVSetNumConstraints(BV V,PetscInt nc)
   V->l = PetscMin(V->l,V->m);
   V->k = PetscMin(V->k,V->m);
   PetscCall(PetscObjectStateIncrease((PetscObject)V));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -306,13 +306,13 @@ PetscErrorCode BVGetNumConstraints(BV bv,PetscInt *nc)
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
   PetscValidIntPointer(nc,2);
   *nc = bv->nc;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVResize - Change the number of columns.
 
-   Collective on bv
+   Collective
 
    Input Parameters:
 +  bv   - the basis vectors
@@ -340,7 +340,7 @@ PetscErrorCode BVResize(BV bv,PetscInt m,PetscBool copy)
   PetscValidType(bv,1);
   PetscCheck(m>0,PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_INCOMP,"Number of columns %" PetscInt_FMT " must be positive",m);
   PetscCheck(!bv->nc || bv->issplit,PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_WRONGSTATE,"Cannot resize a BV with constraints");
-  if (bv->m == m) PetscFunctionReturn(0);
+  if (bv->m == m) PetscFunctionReturn(PETSC_SUCCESS);
   BVCheckOp(bv,1,resize);
 
   PetscCall(PetscLogEventBegin(BV_Create,bv,0,0,0));
@@ -371,13 +371,13 @@ PetscErrorCode BVResize(BV bv,PetscInt m,PetscBool copy)
   bv->l = PetscMin(bv->l,m);
   PetscCall(PetscLogEventEnd(BV_Create,bv,0,0,0));
   PetscCall(PetscObjectStateIncrease((PetscObject)bv));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVSetActiveColumns - Specify the columns that will be involved in operations.
 
-   Logically Collective on bv
+   Logically Collective
 
    Input Parameters:
 +  bv - the basis vectors context
@@ -420,7 +420,7 @@ PetscErrorCode BVSetActiveColumns(BV bv,PetscInt l,PetscInt k)
     PetscCheck(l>=0 && l<=bv->k,PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of l (%" PetscInt_FMT "). Must be between 0 and k (%" PetscInt_FMT ")",l,bv->k);
     bv->l = l;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -445,13 +445,13 @@ PetscErrorCode BVGetActiveColumns(BV bv,PetscInt *l,PetscInt *k)
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
   if (l) *l = bv->l;
   if (k) *k = bv->k;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVSetMatrix - Specifies the inner product to be used in orthogonalization.
 
-   Collective on bv
+   Collective
 
    Input Parameters:
 +  bv    - the basis vectors context
@@ -499,13 +499,13 @@ PetscErrorCode BVSetMatrix(BV bv,Mat B,PetscBool indef)
     if (bv->Bx) PetscCall(PetscObjectStateIncrease((PetscObject)bv->Bx));
     if (bv->cached) PetscCall(PetscObjectStateIncrease((PetscObject)bv->cached));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVGetMatrix - Retrieves the matrix representation of the inner product.
 
-   Not collective, though a parallel Mat may be returned
+   Not Collective
 
    Input Parameter:
 .  bv    - the basis vectors context
@@ -524,14 +524,14 @@ PetscErrorCode BVGetMatrix(BV bv,Mat *B,PetscBool *indef)
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
   if (B)     *B     = bv->matrix;
   if (indef) *indef = bv->indef;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVApplyMatrix - Multiplies a vector by the matrix representation of the
    inner product.
 
-   Neighbor-wise Collective on bv
+   Neighbor-wise Collective
 
    Input Parameters:
 +  bv - the basis vectors context
@@ -557,14 +557,14 @@ PetscErrorCode BVApplyMatrix(BV bv,Vec x,Vec y)
     PetscCall(BV_IPMatMult(bv,x));
     PetscCall(VecCopy(bv->Bx,y));
   } else PetscCall(VecCopy(x,y));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVApplyMatrixBV - Multiplies the BV vectors by the matrix representation
    of the inner product.
 
-   Neighbor-wise Collective on X
+   Neighbor-wise Collective
 
    Input Parameter:
 .  X - the basis vectors context
@@ -592,13 +592,13 @@ PetscErrorCode BVApplyMatrixBV(BV X,BV Y)
     if (X->matrix) PetscCall(BVMatMult(X,X->matrix,Y));
     else PetscCall(BVCopy(X,Y));
   } else PetscCall(BV_IPMatMultBV(X));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVSetSignature - Sets the signature matrix to be used in orthogonalization.
 
-   Logically Collective on bv
+   Logically Collective
 
    Input Parameters:
 +  bv    - the basis vectors context
@@ -634,13 +634,13 @@ PetscErrorCode BVSetSignature(BV bv,Vec omega)
     PetscCall(VecRestoreArrayRead(omega,&pomega));
   } else PetscCall(PetscInfo(bv,"Ignoring signature because BV is not indefinite\n"));
   PetscCall(PetscObjectStateIncrease((PetscObject)bv));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVGetSignature - Retrieves the signature matrix from last orthogonalization.
 
-   Not collective
+   Not Collective
 
    Input Parameter:
 .  bv    - the basis vectors context
@@ -676,14 +676,14 @@ PetscErrorCode BVGetSignature(BV bv,Vec omega)
     PetscCall(VecRestoreArrayRead(bv->omega,&intern));
     PetscCall(VecRestoreArray(omega,&pomega));
   } else PetscCall(VecSet(omega,1.0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVSetBufferVec - Attach a vector object to be used as buffer space for
    several operations.
 
-   Collective on bv
+   Collective
 
    Input Parameters:
 +  bv     - the basis vectors context)
@@ -718,13 +718,13 @@ PetscErrorCode BVSetBufferVec(BV bv,Vec buffer)
   PetscCall(PetscObjectReference((PetscObject)buffer));
   PetscCall(VecDestroy(&bv->buffer));
   bv->buffer = buffer;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVGetBufferVec - Obtain the buffer vector associated with the BV object.
 
-   Not Collective, but Vec returned is parallel if BV is parallel
+   Collective
 
    Input Parameters:
 .  bv - the basis vectors context
@@ -770,14 +770,14 @@ PetscErrorCode BVGetBufferVec(BV bv,Vec *buffer)
     PetscCall(VecSetType(bv->buffer,((PetscObject)bv->t)->type_name));
   }
   *buffer = bv->buffer;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVSetRandomContext - Sets the PetscRandom object associated with the BV,
    to be used in operations that need random numbers.
 
-   Collective on bv
+   Collective
 
    Input Parameters:
 +  bv   - the basis vectors context
@@ -796,13 +796,13 @@ PetscErrorCode BVSetRandomContext(BV bv,PetscRandom rand)
   PetscCall(PetscObjectReference((PetscObject)rand));
   PetscCall(PetscRandomDestroy(&bv->rand));
   bv->rand = rand;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVGetRandomContext - Gets the PetscRandom object associated with the BV.
 
-   Not Collective
+   Collective
 
    Input Parameter:
 .  bv - the basis vectors context
@@ -829,13 +829,13 @@ PetscErrorCode BVGetRandomContext(BV bv,PetscRandom* rand)
     }
   }
   *rand = bv->rand;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVSetFromOptions - Sets BV options from the options database.
 
-   Collective on bv
+   Collective
 
    Input Parameter:
 .  bv - the basis vectors context
@@ -884,7 +884,7 @@ PetscErrorCode BVSetFromOptions(BV bv)
     PetscCall(PetscObjectProcessOptionsHandlers((PetscObject)bv,PetscOptionsObject));
   PetscOptionsEnd();
   bv->sfocalled = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -893,7 +893,7 @@ PetscErrorCode BVSetFromOptions(BV bv)
    for the block-orthogonalization (simultaneous orthogonalization of a set of
    vectors).
 
-   Logically Collective on bv
+   Logically Collective
 
    Input Parameters:
 +  bv     - the basis vectors context
@@ -949,7 +949,7 @@ PetscErrorCode BVSetOrthogonalization(BV bv,BVOrthogType type,BVOrthogRefineType
     default:
       SETERRQ(PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_WRONG,"Unknown refinement type");
   }
-  if (eta == PETSC_DEFAULT) {
+  if (eta == (PetscReal)PETSC_DEFAULT) {
     bv->orthog_eta = 0.7071;
   } else {
     PetscCheck(eta>0.0 && eta<=1.0,PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_OUTOFRANGE,"Invalid eta value");
@@ -966,7 +966,7 @@ PetscErrorCode BVSetOrthogonalization(BV bv,BVOrthogType type,BVOrthogRefineType
     default:
       SETERRQ(PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_WRONG,"Unknown block orthogonalization type");
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -995,13 +995,13 @@ PetscErrorCode BVGetOrthogonalization(BV bv,BVOrthogType *type,BVOrthogRefineTyp
   if (refine) *refine = bv->orthog_ref;
   if (eta)    *eta    = bv->orthog_eta;
   if (block)  *block  = bv->orthog_block;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVSetMatMultMethod - Specifies the method used for the BVMatMult() operation.
 
-   Logically Collective on bv
+   Logically Collective
 
    Input Parameters:
 +  bv     - the basis vectors context
@@ -1039,7 +1039,7 @@ PetscErrorCode BVSetMatMultMethod(BV bv,BVMatMultType method)
     default:
       SETERRQ(PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_WRONG,"Unknown matmult method");
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1063,14 +1063,14 @@ PetscErrorCode BVGetMatMultMethod(BV bv,BVMatMultType *method)
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
   PetscValidPointer(method,2);
   *method = bv->vmm;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVGetColumn - Returns a Vec object that contains the entries of the
    requested column of the basis vectors object.
 
-   Logically Collective on bv
+   Logically Collective
 
    Input Parameters:
 +  bv - the basis vectors context
@@ -1115,13 +1115,13 @@ PetscErrorCode BVGetColumn(BV bv,PetscInt j,Vec *v)
   PetscCall(PetscObjectStateGet((PetscObject)bv->cv[l],&bv->st[l]));
   PetscCall(PetscObjectGetId((PetscObject)bv->cv[l],&bv->id[l]));
   *v = bv->cv[l];
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVRestoreColumn - Restore a column obtained with BVGetColumn().
 
-   Logically Collective on bv
+   Logically Collective
 
    Input Parameters:
 +  bv - the basis vectors context
@@ -1161,14 +1161,14 @@ PetscErrorCode BVRestoreColumn(BV bv,PetscInt j,Vec *v)
   bv->st[l] = -1;
   bv->id[l] = 0;
   *v = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    BVGetArray - Returns a pointer to a contiguous array that contains this
    processor's portion of the BV data.
 
-   Logically Collective on bv
+   Logically Collective
 
    Input Parameters:
 .  bv - the basis vectors context
@@ -1196,13 +1196,13 @@ PetscErrorCode BVGetArray(BV bv,PetscScalar **a)
   BVCheckSizes(bv,1);
   BVCheckOp(bv,1,getarray);
   PetscUseTypeMethod(bv,getarray,a);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    BVRestoreArray - Restore the BV object after BVGetArray() has been called.
 
-   Logically Collective on bv
+   Logically Collective
 
    Input Parameters:
 +  bv - the basis vectors context
@@ -1225,7 +1225,7 @@ PetscErrorCode BVRestoreArray(BV bv,PetscScalar **a)
   PetscTryTypeMethod(bv,restorearray,a);
   if (a) *a = NULL;
   PetscCall(PetscObjectStateIncrease((PetscObject)bv));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1260,7 +1260,7 @@ PetscErrorCode BVGetArrayRead(BV bv,const PetscScalar **a)
   BVCheckSizes(bv,1);
   BVCheckOp(bv,1,getarrayread);
   PetscUseTypeMethod(bv,getarrayread,a);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1285,14 +1285,14 @@ PetscErrorCode BVRestoreArrayRead(BV bv,const PetscScalar **a)
   BVCheckSizes(bv,1);
   PetscTryTypeMethod(bv,restorearrayread,a);
   if (a) *a = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVCreateVec - Creates a new Vec object with the same type and dimensions
    as the columns of the basis vectors object.
 
-   Collective on bv
+   Collective
 
    Input Parameter:
 .  bv - the basis vectors context
@@ -1314,14 +1314,14 @@ PetscErrorCode BVCreateVec(BV bv,Vec *v)
   BVCheckSizes(bv,1);
   PetscValidPointer(v,2);
   PetscCall(VecDuplicate(bv->t,v));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVCreateMat - Creates a new Mat object of dense type and copies the contents
    of the BV object.
 
-   Collective on bv
+   Collective
 
    Input Parameter:
 .  bv - the basis vectors context
@@ -1354,7 +1354,7 @@ PetscErrorCode BVCreateMat(BV bv,Mat *A)
   PetscCall(PetscArraycpy(aa,vv,bv->m*bv->n));
   PetscCall(BVRestoreArrayRead(bv,&vv));
   PetscCall(MatDenseRestoreArrayWrite(*A,&aa));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode BVGetMat_Default(BV bv,Mat *A)
@@ -1382,14 +1382,14 @@ PetscErrorCode BVGetMat_Default(BV bv,Mat *A)
   }
   PetscCall(MatDensePlaceArray(bv->Aget,vv+(bv->nc+bv->l)*bv->n));  /* set the actual pointer */
   *A = bv->Aget;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVGetMat - Returns a Mat object of dense type that shares the memory of
    the BV object.
 
-   Collective on bv
+   Collective
 
    Input Parameter:
 .  bv - the basis vectors context
@@ -1416,7 +1416,7 @@ PetscErrorCode BVGetMat(BV bv,Mat *A)
   BVCheckSizes(bv,1);
   PetscValidPointer(A,2);
   PetscUseTypeMethod(bv,getmat,A);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode BVRestoreMat_Default(BV bv,Mat *A)
@@ -1429,13 +1429,13 @@ PetscErrorCode BVRestoreMat_Default(BV bv,Mat *A)
   PetscCall(MatDenseResetArray(bv->Aget));
   PetscCall(BVRestoreArray(bv,&vv));
   *A = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVRestoreMat - Restores the Mat obtained with BVGetMat().
 
-   Logically Collective on bv
+   Logically Collective
 
    Input Parameters:
 +  bv - the basis vectors context
@@ -1459,7 +1459,7 @@ PetscErrorCode BVRestoreMat(BV bv,Mat *A)
   PetscCheck(bv->Aget,PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_WRONGSTATE,"BVRestoreMat must match a previous call to BVGetMat");
   PetscCheck(bv->Aget==*A,PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_WRONGSTATE,"Mat argument is not the same as the one obtained with BVGetMat");
   PetscUseTypeMethod(bv,restoremat,A);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -1484,14 +1484,14 @@ static inline PetscErrorCode BVDuplicate_Private(BV V,BV W)
   W->sfocalled    = V->sfocalled;
   PetscTryTypeMethod(V,duplicate,W);
   PetscCall(PetscObjectStateIncrease((PetscObject)W));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVDuplicate - Creates a new basis vector object of the same type and
    dimensions as an existing one.
 
-   Collective on V
+   Collective
 
    Input Parameter:
 .  V - basis vectors context
@@ -1521,14 +1521,14 @@ PetscErrorCode BVDuplicate(BV V,BV *W)
   PetscCall(BVCreate(PetscObjectComm((PetscObject)V),W));
   PetscCall(BVSetSizesFromVec(*W,V->t,V->m));
   PetscCall(BVDuplicate_Private(V,*W));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVDuplicateResize - Creates a new basis vector object of the same type and
    dimensions as an existing one, but with possibly different number of columns.
 
-   Collective on V
+   Collective
 
    Input Parameters:
 +  V - basis vectors context
@@ -1556,14 +1556,14 @@ PetscErrorCode BVDuplicateResize(BV V,PetscInt m,BV *W)
   PetscCall(BVCreate(PetscObjectComm((PetscObject)V),W));
   PetscCall(BVSetSizesFromVec(*W,V->t,m));
   PetscCall(BVDuplicate_Private(V,*W));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVGetCachedBV - Returns a BV object stored internally that holds the
    result of B*X after a call to BVApplyMatrixBV().
 
-   Not collective
+   Collective
 
    Input Parameter:
 .  bv    - the basis vectors context
@@ -1590,13 +1590,13 @@ PetscErrorCode BVGetCachedBV(BV bv,BV *cached)
     PetscCall(BVDuplicate_Private(bv,bv->cached));
   }
   *cached = bv->cached;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVCopy - Copies a basis vector object into another one, W <- V.
 
-   Logically Collective on V
+   Logically Collective
 
    Input Parameter:
 .  V - basis vectors context
@@ -1630,7 +1630,7 @@ PetscErrorCode BVCopy(BV V,BV W)
   PetscCheckSameTypeAndComm(V,1,W,2);
   PetscCheck(V->n==W->n,PetscObjectComm((PetscObject)V),PETSC_ERR_ARG_INCOMP,"Mismatching local dimension V %" PetscInt_FMT ", W %" PetscInt_FMT,V->n,W->n);
   PetscCheck(V->k-V->l<=W->m-W->l,PetscObjectComm((PetscObject)V),PETSC_ERR_ARG_SIZ,"W has %" PetscInt_FMT " non-leading columns, not enough to store %" PetscInt_FMT " columns",W->m-W->l,V->k-V->l);
-  if (V==W || !V->n) PetscFunctionReturn(0);
+  if (V==W || !V->n) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscLogEventBegin(BV_Copy,V,W,0,0));
   if (V->indef && V->matrix && V->indef==W->indef && V->matrix==W->matrix) {
@@ -1645,13 +1645,13 @@ PetscErrorCode BVCopy(BV V,BV W)
   PetscUseTypeMethod(V,copy,W);
   PetscCall(PetscLogEventEnd(BV_Copy,V,W,0,0));
   PetscCall(PetscObjectStateIncrease((PetscObject)W));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVCopyVec - Copies one of the columns of a basis vectors object into a Vec.
 
-   Logically Collective on V
+   Logically Collective
 
    Input Parameters:
 +  V - basis vectors context
@@ -1689,13 +1689,13 @@ PetscErrorCode BVCopyVec(BV V,PetscInt j,Vec w)
   PetscCall(VecCopy(z,w));
   PetscCall(BVRestoreColumn(V,j,&z));
   PetscCall(PetscLogEventEnd(BV_Copy,V,w,0,0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVCopyColumn - Copies the values from one of the columns to another one.
 
-   Logically Collective on V
+   Logically Collective
 
    Input Parameters:
 +  V - basis vectors context
@@ -1716,7 +1716,7 @@ PetscErrorCode BVCopyColumn(BV V,PetscInt j,PetscInt i)
   BVCheckSizes(V,1);
   PetscValidLogicalCollectiveInt(V,j,2);
   PetscValidLogicalCollectiveInt(V,i,3);
-  if (j==i) PetscFunctionReturn(0);
+  if (j==i) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscLogEventBegin(BV_Copy,V,0,0,0));
   if (V->omega) {
@@ -1727,7 +1727,7 @@ PetscErrorCode BVCopyColumn(BV V,PetscInt j,PetscInt i)
   PetscUseTypeMethod(V,copycolumn,j,i);
   PetscCall(PetscLogEventEnd(BV_Copy,V,0,0,0));
   PetscCall(PetscObjectStateIncrease((PetscObject)V));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode BVGetSplit_Private(BV bv,PetscBool left,BV *split)
@@ -1754,7 +1754,7 @@ static PetscErrorCode BVGetSplit_Private(BV bv,PetscBool left,BV *split)
   }
   if (left) PetscCall(PetscObjectStateGet((PetscObject)*split,&bv->lstate));
   else PetscCall(PetscObjectStateGet((PetscObject)*split,&bv->rstate));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1762,7 +1762,7 @@ static PetscErrorCode BVGetSplit_Private(BV bv,PetscBool left,BV *split)
    internal data, one of them containing the leading columns and the other
    one containing the remaining columns.
 
-   Logically Collective on bv
+   Collective
 
    Input Parameter:
 .  bv - the basis vectors context
@@ -1802,13 +1802,13 @@ PetscErrorCode BVGetSplit(BV bv,BV *L,BV *R)
   PetscCall(BVGetSplit_Private(bv,PETSC_FALSE,&bv->R));
   if (L) *L = bv->L;
   if (R) *R = bv->R;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVRestoreSplit - Restore the BV objects obtained with BVGetSplit().
 
-   Logically Collective on bv
+   Logically Collective
 
    Input Parameters:
 +  bv - the basis vectors context
@@ -1838,14 +1838,14 @@ PetscErrorCode BVRestoreSplit(BV bv,BV *L,BV *R)
   bv->lsplit = 0;
   if (L) *L = NULL;
   if (R) *R = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVSetDefiniteTolerance - Set the tolerance to be used when checking a
    definite inner product.
 
-   Logically Collective on bv
+   Logically Collective
 
    Input Parameters:
 +  bv     - basis vectors
@@ -1875,12 +1875,12 @@ PetscErrorCode BVSetDefiniteTolerance(BV bv,PetscReal deftol)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
   PetscValidLogicalCollectiveReal(bv,deftol,2);
-  if (deftol == PETSC_DEFAULT) bv->deftol = 10*PETSC_MACHINE_EPSILON;
+  if (deftol == (PetscReal)PETSC_DEFAULT) bv->deftol = 10*PETSC_MACHINE_EPSILON;
   else {
     PetscCheck(deftol>0.0,PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of deftol. Must be > 0");
     bv->deftol = deftol;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1905,5 +1905,5 @@ PetscErrorCode BVGetDefiniteTolerance(BV bv,PetscReal *deftol)
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
   PetscValidRealPointer(deftol,2);
   *deftol = bv->deftol;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
