@@ -20,7 +20,7 @@
    BVScatter - Scatters the columns of a BV to another BV created in a
    subcommunicator.
 
-   Collective on Vin
+   Collective
 
    Input Parameters:
 +  Vin  - input basis vectors (defined on the whole communicator)
@@ -62,14 +62,14 @@ PetscErrorCode BVScatter(BV Vin,BV Vout,VecScatter scat,Vec xdup)
     PetscCall(VecResetArray(Vout->t));
     PetscCall(VecRestoreArrayRead(xdup,&array));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVSumQuadrature - Computes the sum of terms required in the quadrature
    rule to approximate the contour integral.
 
-   Collective on S
+   Collective
 
    Input Parameters:
 +  Y       - input basis vectors
@@ -141,14 +141,14 @@ PetscErrorCode BVSumQuadrature(BV S,BV Y,PetscInt M,PetscInt L,PetscInt L_max,Pe
   }
   PetscCall(PetscFree(ppk));
   PetscCall(VecDestroy(&v));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVDotQuadrature - Computes the projection terms required in the quadrature
    rule to approximate the contour integral.
 
-   Collective on Y
+   Collective
 
    Input Parameters:
 +  Y       - first basis vectors
@@ -231,7 +231,7 @@ PetscErrorCode BVDotQuadrature(BV Y,BV V,PetscScalar *Mu,PetscInt M,PetscInt L,P
   PetscCall(MPIU_Allreduce(temp2,Mu,count,MPIU_SCALAR,MPIU_SUM,parent));
   PetscCall(PetscFree3(temp,temp2,ppk));
   PetscCall(MatDestroy(&H));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -239,7 +239,7 @@ PetscErrorCode BVDotQuadrature(BV Y,BV V,PetscScalar *Mu,PetscInt M,PetscInt L,P
    inside a region via quantities computed in the quadrature rule of
    contour integral methods.
 
-   Collective on Y
+   Collective
 
    Input Parameters:
 +  Y       - first basis vectors
@@ -302,7 +302,7 @@ PetscErrorCode BVTraceQuadrature(BV Y,BV V,PetscInt L,PetscInt L_max,PetscScalar
   *est_eig = PetscAbsScalar(sum)/(PetscReal)L;
   PetscCall(VecDestroy(&y));
   PetscCall(VecDestroy(&yall));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode BVSVDAndRank_Refine(BV S,PetscReal delta,PetscScalar *pA,PetscReal *sigma,PetscInt *rank)
@@ -392,7 +392,7 @@ PetscErrorCode BVSVDAndRank_Refine(BV S,PetscReal delta,PetscScalar *pA,PetscRea
 #if defined(PETSC_USE_COMPLEX)
   PetscCall(PetscFree(rwork));
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode BVSVDAndRank_QR(BV S,PetscReal delta,PetscScalar *pA,PetscReal *sigma,PetscInt *rank)
@@ -440,7 +440,7 @@ PetscErrorCode BVSVDAndRank_QR(BV S,PetscReal delta,PetscScalar *pA,PetscReal *s
   PetscCall(BVMultInPlace(S,A,0,*rank));
   PetscCall(PetscFree2(work,rwork));
   PetscCall(MatDestroy(&A));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode BVSVDAndRank_QR_CAA(BV S,PetscInt M,PetscInt L,PetscReal delta,PetscScalar *pA,PetscReal *sigma,PetscInt *rank)
@@ -491,14 +491,14 @@ PetscErrorCode BVSVDAndRank_QR_CAA(BV S,PetscInt M,PetscInt L,PetscReal delta,Pe
   PetscCallBLAS("BLASgemm",BLASgemm_("C","N",&k_,&k_,&m,&sone,U,&m,T,&m,&zero,pA,&k_));
   for (j=0;j<k_;j++) for (i=0;i<k_;i++) pA[j*k_+i] /= sigma[j];
   PetscCall(PetscFree5(T,R,U,work,rwork));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVSVDAndRank - Compute the SVD (left singular vectors only, and singular
    values) and determine the numerical rank according to a tolerance.
 
-   Collective on S
+   Collective
 
    Input Parameters:
 +  S     - the basis vectors
@@ -559,13 +559,13 @@ PetscErrorCode BVSVDAndRank(BV S,PetscInt m,PetscInt l,PetscReal delta,BVSVDMeth
       break;
   }
   PetscCall(PetscLogEventEnd(BV_SVDAndRank,S,0,0,0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVCISSResizeBases - Resize the bases involved in CISS solvers when the L grows.
 
-   Collective on S
+   Logically Collective
 
    Input Parameters:
 +  S      - basis of L*M columns
@@ -600,5 +600,5 @@ PetscErrorCode BVCISSResizeBases(BV S,BV V,BV Y,PetscInt Lold,PetscInt Lnew,Pets
   for (i=npoints-1;i>=0;i--) {
     for (j=Lold-1;j>=0;j--) PetscCall(BVCopyColumn(Y,i*Lold+j,i*Lnew+j));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
