@@ -16,7 +16,7 @@
 /*@
    BVMatArnoldi - Computes an Arnoldi factorization associated with a matrix.
 
-   Collective on V
+   Collective
 
    Input Parameters:
 +  V - basis vectors context
@@ -109,13 +109,13 @@ PetscErrorCode BVMatArnoldi(BV V,Mat A,Mat H,PetscInt k,PetscInt *m,PetscReal *b
   }
 
   PetscCall(PetscObjectStateIncrease((PetscObject)V));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    BVMatLanczos - Computes a Lanczos factorization associated with a matrix.
 
-   Collective on V
+   Collective
 
    Input Parameters:
 +  V - basis vectors context
@@ -222,5 +222,5 @@ PetscErrorCode BVMatLanczos(BV V,Mat A,Mat T,PetscInt k,PetscInt *m,PetscReal *b
   }
 
   PetscCall(PetscObjectStateIncrease((PetscObject)V));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
