@@ -17,7 +17,7 @@
 /*@
    BVMult - Computes Y = beta*Y + alpha*X*Q.
 
-   Logically Collective on Y
+   Logically Collective
 
    Input Parameters:
 +  Y     - first basis vectors context (modified on output)
@@ -76,13 +76,13 @@ PetscErrorCode BVMult(BV Y,PetscScalar alpha,PetscScalar beta,BV X,Mat Q)
   PetscUseTypeMethod(Y,mult,alpha,beta,X,Q);
   PetscCall(PetscLogEventEnd(BV_Mult,X,Y,0,0));
   PetscCall(PetscObjectStateIncrease((PetscObject)Y));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVMultVec - Computes y = beta*y + alpha*X*q.
 
-   Logically Collective on X
+   Logically Collective
 
    Input Parameters:
 +  X     - a basis vectors object
@@ -130,14 +130,14 @@ PetscErrorCode BVMultVec(BV X,PetscScalar alpha,PetscScalar beta,Vec y,PetscScal
   PetscCall(PetscLogEventBegin(BV_MultVec,X,y,0,0));
   PetscUseTypeMethod(X,multvec,alpha,beta,y,q);
   PetscCall(PetscLogEventEnd(BV_MultVec,X,y,0,0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVMultColumn - Computes y = beta*y + alpha*X*q, where y is the j-th column
    of X.
 
-   Logically Collective on X
+   Logically Collective
 
    Input Parameters:
 +  X     - a basis vectors object
@@ -188,13 +188,13 @@ PetscErrorCode BVMultColumn(BV X,PetscScalar alpha,PetscScalar beta,PetscInt j,P
   X->k = ksave;
   PetscCall(PetscLogEventEnd(BV_MultVec,X,0,0,0));
   PetscCall(PetscObjectStateIncrease((PetscObject)X));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVMultInPlace - Update a set of vectors as V(:,s:e-1) = V*Q(:,s:e-1).
 
-   Logically Collective on V
+   Logically Collective
 
    Input Parameters:
 +  Q - a sequential dense matrix
@@ -236,19 +236,19 @@ PetscErrorCode BVMultInPlace(BV V,Mat Q,PetscInt s,PetscInt e)
   PetscCall(MatGetSize(Q,&m,&n));
   PetscCheck(m>=V->k,PetscObjectComm((PetscObject)V),PETSC_ERR_ARG_SIZ,"Mat argument has %" PetscInt_FMT " rows, should have at least %" PetscInt_FMT,m,V->k);
   PetscCheck(e<=n,PetscObjectComm((PetscObject)V),PETSC_ERR_ARG_SIZ,"Mat argument only has %" PetscInt_FMT " columns, the requested value of e is larger: %" PetscInt_FMT,n,e);
-  if (s>=e) PetscFunctionReturn(0);
+  if (s>=e) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscLogEventBegin(BV_MultInPlace,V,Q,0,0));
   PetscUseTypeMethod(V,multinplace,Q,s,e);
   PetscCall(PetscLogEventEnd(BV_MultInPlace,V,Q,0,0));
   PetscCall(PetscObjectStateIncrease((PetscObject)V));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVMultInPlaceHermitianTranspose - Update a set of vectors as V(:,s:e-1) = V*Q'(:,s:e-1).
 
-   Logically Collective on V
+   Logically Collective
 
    Input Parameters:
 +  Q - a sequential dense matrix
@@ -285,19 +285,19 @@ PetscErrorCode BVMultInPlaceHermitianTranspose(BV V,Mat Q,PetscInt s,PetscInt e)
   PetscCall(MatGetSize(Q,&m,&n));
   PetscCheck(n>=V->k,PetscObjectComm((PetscObject)V),PETSC_ERR_ARG_SIZ,"Mat argument has %" PetscInt_FMT " columns, should have at least %" PetscInt_FMT,n,V->k);
   PetscCheck(e<=m,PetscObjectComm((PetscObject)V),PETSC_ERR_ARG_SIZ,"Mat argument only has %" PetscInt_FMT " rows, the requested value of e is larger: %" PetscInt_FMT,m,e);
-  if (s>=e || !V->n) PetscFunctionReturn(0);
+  if (s>=e || !V->n) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscLogEventBegin(BV_MultInPlace,V,Q,0,0));
   PetscUseTypeMethod(V,multinplacetrans,Q,s,e);
   PetscCall(PetscLogEventEnd(BV_MultInPlace,V,Q,0,0));
   PetscCall(PetscObjectStateIncrease((PetscObject)V));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVScale - Multiply the BV entries by a scalar value.
 
-   Logically Collective on bv
+   Logically Collective
 
    Input Parameters:
 +  bv    - basis vectors
@@ -317,19 +317,19 @@ PetscErrorCode BVScale(BV bv,PetscScalar alpha)
   PetscValidLogicalCollectiveScalar(bv,alpha,2);
   PetscValidType(bv,1);
   BVCheckSizes(bv,1);
-  if (alpha == (PetscScalar)1.0) PetscFunctionReturn(0);
+  if (alpha == (PetscScalar)1.0) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscLogEventBegin(BV_Scale,bv,0,0,0));
   if (bv->n) PetscUseTypeMethod(bv,scale,-1,alpha);
   PetscCall(PetscLogEventEnd(BV_Scale,bv,0,0,0));
   PetscCall(PetscObjectStateIncrease((PetscObject)bv));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVScaleColumn - Scale one column of a BV.
 
-   Logically Collective on bv
+   Logically Collective
 
    Input Parameters:
 +  bv    - basis vectors
@@ -350,13 +350,13 @@ PetscErrorCode BVScaleColumn(BV bv,PetscInt j,PetscScalar alpha)
   BVCheckSizes(bv,1);
 
   PetscCheck(j>=0 && j<bv->m,PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_OUTOFRANGE,"Argument j has wrong value %" PetscInt_FMT ", the number of columns is %" PetscInt_FMT,j,bv->m);
-  if (alpha == (PetscScalar)1.0) PetscFunctionReturn(0);
+  if (alpha == (PetscScalar)1.0) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscLogEventBegin(BV_Scale,bv,0,0,0));
   if (bv->n) PetscUseTypeMethod(bv,scale,j,alpha);
   PetscCall(PetscLogEventEnd(BV_Scale,bv,0,0,0));
   PetscCall(PetscObjectStateIncrease((PetscObject)bv));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static inline PetscErrorCode BVSetRandomColumn_Private(BV bv,PetscInt k)
@@ -377,7 +377,7 @@ static inline PetscErrorCode BVSetRandomColumn_Private(BV bv,PetscInt k)
     PetscCall(VecRestoreArray(x,&px));
   } else PetscCall(VecSetRandom(x,bv->rand));
   PetscCall(BVRestoreColumn(bv,k,&x));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static inline PetscErrorCode BVSetRandomNormalColumn_Private(BV bv,PetscInt k,Vec w1,Vec w2)
@@ -405,7 +405,7 @@ static inline PetscErrorCode BVSetRandomNormalColumn_Private(BV bv,PetscInt k,Ve
     PetscCall(VecRestoreArray(x,&px));
   } else PetscCall(VecSetRandomNormal(x,bv->rand,w1,w2));
   PetscCall(BVRestoreColumn(bv,k,&x));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static inline PetscErrorCode BVSetRandomSignColumn_Private(BV bv,PetscInt k)
@@ -433,13 +433,13 @@ static inline PetscErrorCode BVSetRandomSignColumn_Private(BV bv,PetscInt k)
     PetscCall(VecRestoreArray(x,&px));
   }
   PetscCall(BVRestoreColumn(bv,k,&x));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVSetRandom - Set the columns of a BV to random numbers.
 
-   Logically Collective on bv
+   Logically Collective
 
    Input Parameters:
 .  bv - basis vectors
@@ -465,13 +465,13 @@ PetscErrorCode BVSetRandom(BV bv)
   for (k=bv->l;k<bv->k;k++) PetscCall(BVSetRandomColumn_Private(bv,k));
   PetscCall(PetscLogEventEnd(BV_SetRandom,bv,0,0,0));
   PetscCall(PetscObjectStateIncrease((PetscObject)bv));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVSetRandomColumn - Set one column of a BV to random numbers.
 
-   Logically Collective on bv
+   Logically Collective
 
    Input Parameters:
 +  bv - basis vectors
@@ -495,14 +495,14 @@ PetscErrorCode BVSetRandomColumn(BV bv,PetscInt j)
   PetscCall(BVSetRandomColumn_Private(bv,j));
   PetscCall(PetscLogEventEnd(BV_SetRandom,bv,0,0,0));
   PetscCall(PetscObjectStateIncrease((PetscObject)bv));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVSetRandomNormal - Set the columns of a BV to random numbers with a normal
    distribution.
 
-   Logically Collective on bv
+   Logically Collective
 
    Input Parameter:
 .  bv - basis vectors
@@ -545,14 +545,14 @@ PetscErrorCode BVSetRandomNormal(BV bv)
     PetscCall(VecDestroy(&w2));
   }
   PetscCall(PetscObjectStateIncrease((PetscObject)bv));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVSetRandomSign - Set the entries of a BV to values 1 or -1 with equal
    probability.
 
-   Logically Collective on bv
+   Logically Collective
 
    Input Parameter:
 .  bv - basis vectors
@@ -589,14 +589,14 @@ PetscErrorCode BVSetRandomSign(BV bv)
   for (k=bv->l;k<bv->k;k++) PetscCall(BVSetRandomSignColumn_Private(bv,k));
   PetscCall(PetscLogEventEnd(BV_SetRandom,bv,0,0,0));
   PetscCall(PetscObjectStateIncrease((PetscObject)bv));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVSetRandomCond - Set the columns of a BV to random numbers, in a way that
    the generated matrix has a given condition number.
 
-   Logically Collective on bv
+   Logically Collective
 
    Input Parameters:
 +  bv    - basis vectors
@@ -662,13 +662,13 @@ PetscErrorCode BVSetRandomCond(BV bv,PetscReal condn)
   PetscCall(DSDestroy(&ds));
   PetscCall(PetscLogEventEnd(BV_SetRandom,bv,0,0,0));
   PetscCall(PetscObjectStateIncrease((PetscObject)bv));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVMatMult - Computes the matrix-vector product for each column, Y=A*V.
 
-   Neighbor-wise Collective on A
+   Neighbor-wise Collective
 
    Input Parameters:
 +  V - basis vectors context
@@ -720,14 +720,14 @@ PetscErrorCode BVMatMult(BV V,Mat A,BV Y)
   PetscUseTypeMethod(V,matmult,A,Y);
   PetscCall(PetscLogEventEnd(BV_MatMult,V,A,Y,0));
   PetscCall(PetscObjectStateIncrease((PetscObject)Y));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVMatMultTranspose - Computes the matrix-vector product with the transpose
    of a matrix for each column, Y=A^T*V.
 
-   Neighbor-wise Collective on A
+   Neighbor-wise Collective
 
    Input Parameters:
 +  V - basis vectors context
@@ -777,14 +777,14 @@ PetscErrorCode BVMatMultTranspose(BV V,Mat A,BV Y)
   PetscCall(MatCreateTranspose(A,&AT));
   PetscCall(BVMatMult(V,AT,Y));
   PetscCall(MatDestroy(&AT));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVMatMultHermitianTranspose - Computes the matrix-vector product with the
    conjugate transpose of a matrix for each column, Y=A^H*V.
 
-   Neighbor-wise Collective on A
+   Neighbor-wise Collective
 
    Input Parameters:
 +  V - basis vectors context
@@ -843,14 +843,14 @@ PetscErrorCode BVMatMultHermitianTranspose(BV V,Mat A,BV Y)
     PetscCall(BVRestoreColumn(V,V->l+j,&v));
     PetscCall(BVRestoreColumn(Y,Y->l+j,&y));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVMatMultColumn - Computes the matrix-vector product for a specified
    column, storing the result in the next column v_{j+1}=A*v_j.
 
-   Neighbor-wise Collective on A
+   Neighbor-wise Collective
 
    Input Parameters:
 +  V - basis vectors context
@@ -883,14 +883,14 @@ PetscErrorCode BVMatMultColumn(BV V,Mat A,PetscInt j)
   PetscCall(BVRestoreColumn(V,j+1,&vj1));
   PetscCall(PetscLogEventEnd(BV_MatMultVec,V,A,0,0));
   PetscCall(PetscObjectStateIncrease((PetscObject)V));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVMatMultTransposeColumn - Computes the transpose matrix-vector product for a
    specified column, storing the result in the next column v_{j+1}=A^T*v_j.
 
-   Neighbor-wise Collective on A
+   Neighbor-wise Collective
 
    Input Parameters:
 +  V - basis vectors context
@@ -923,14 +923,14 @@ PetscErrorCode BVMatMultTransposeColumn(BV V,Mat A,PetscInt j)
   PetscCall(BVRestoreColumn(V,j+1,&vj1));
   PetscCall(PetscLogEventEnd(BV_MatMultVec,V,A,0,0));
   PetscCall(PetscObjectStateIncrease((PetscObject)V));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    BVMatMultHermitianTransposeColumn - Computes the conjugate-transpose matrix-vector
    product for a specified column, storing the result in the next column v_{j+1}=A^H*v_j.
 
-   Neighbor-wise Collective on A
+   Neighbor-wise Collective
 
    Input Parameters:
 +  V - basis vectors context
@@ -963,5 +963,5 @@ PetscErrorCode BVMatMultHermitianTransposeColumn(BV V,Mat A,PetscInt j)
   PetscCall(BVRestoreColumn(V,j+1,&vj1));
   PetscCall(PetscLogEventEnd(BV_MatMultVec,V,A,0,0));
   PetscCall(PetscObjectStateIncrease((PetscObject)V));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
