@@ -1,7 +1,7 @@
 !
 !  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 !  SLEPc - Scalable Library for Eigenvalue Problem Computations
-!  Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+!  Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 !
 !  This file is part of SLEPc.
 !  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -51,3 +51,6 @@
       PetscEnum, parameter :: DS_PARALLEL_SYNCHRONIZED = 1
       PetscEnum, parameter :: DS_PARALLEL_DISTRIBUTED  = 2
 
+#if defined(_WIN32) && defined(PETSC_USE_SHARED_LIBRARIES)
+!DEC$ ATTRIBUTES DLLEXPORT::SLEPC_NULL_DS
+#endif
