@@ -44,14 +44,14 @@ static PetscErrorCode HRGen(PetscReal x1,PetscReal x2,PetscInt *type,PetscReal *
   if (x2==0.0) {
     *r = PetscAbsReal(x1); *c = (x1>=0.0)?1.0:-1.0; *s = 0.0;
     if (type) *type = 1;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   if (PetscAbsReal(x1) == PetscAbsReal(x2)) {
     /* hyperbolic rotation doesn't exist */
     *c = *s = *r = 0.0;
     if (type) *type = 0;
     *cond = PETSC_MAX_REAL;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   if (PetscAbsReal(x1)>PetscAbsReal(x2)) {
@@ -67,7 +67,7 @@ static PetscErrorCode HRGen(PetscReal x1,PetscReal x2,PetscInt *type,PetscReal *
   if (type_ == 2) *r *= -1;
   if (type) *type = type_;
   if (cond) *cond = (PetscAbsReal(*c) + PetscAbsReal(*s))/PetscAbsReal(PetscAbsReal(*c) - PetscAbsReal(*s));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -97,7 +97,7 @@ static PetscErrorCode HRApply(PetscInt n,PetscScalar *x1,PetscInt inc1,PetscScal
       x2[i*inc2] = t*x1[i*inc1] + tmp/s;
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -127,7 +127,7 @@ static PetscErrorCode TridiagDiag_HHR(PetscInt n,PetscScalar *A,PetscInt lda,Pet
       Q[0] = Q[1+ldq] = 1;
       Q[1] = Q[ldq] = 0;
     }
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   PetscCall(PetscBLASIntCast(lda,&lda_));
   PetscCall(PetscBLASIntCast(n,&n_));
@@ -271,7 +271,7 @@ static PetscErrorCode TridiagDiag_HHR(PetscInt n,PetscScalar *A,PetscInt lda,Pet
     s[n-1] = ss[n-1];
     d[n-1] = PetscRealPart(A[n-1 + (n-1)*lda]);
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MadeHRtr(PetscInt sz,PetscInt n,PetscInt idx0,PetscInt n0,PetscInt idx1,PetscInt n1,struct HRtr *tr1,struct HRtr *tr2,PetscReal *ncond,PetscScalar *work)
@@ -333,7 +333,7 @@ static PetscErrorCode MadeHRtr(PetscInt sz,PetscInt n,PetscInt idx0,PetscInt n0,
     }
     if (ncond2>*ncond) *ncond = ncond2;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -346,7 +346,7 @@ static PetscErrorCode TryHRIt(PetscInt n,PetscInt j,PetscInt sz,PetscScalar *H,P
 {
   struct HRtr    *tr1,*tr2,tr1_t,tr2_t,tr1_te,tr2_te;
   PetscScalar    *x,*y;
-  PetscReal      ncond,ncond_e;
+  PetscReal      ncond=0,ncond_e;
   PetscInt       nwu=0,i,d=1;
   PetscBLASInt   n0_,n1_,inc=1,mh,mr,n_,ldr_,ldh_;
   PetscReal      tolD = 1e+5;
@@ -477,13 +477,14 @@ static PetscErrorCode TryHRIt(PetscInt n,PetscInt j,PetscInt sz,PetscScalar *H,P
       (*n1)--; (*idx1)++; *idx0 = *idx1;
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
   compute V = HR whit H s-orthogonal and R upper triangular
+  (work: work space of minimum size 6*nv)
 */
-static PetscErrorCode PseudoOrthog_HR(PetscInt *nv,PetscScalar *V,PetscInt ldv,PetscReal *s,PetscScalar *R,PetscInt ldr,PetscBLASInt *perm,PetscBLASInt *cmplxEig,PetscBool *breakdown,PetscScalar *work)
+PetscErrorCode DSPseudoOrthog_HR(PetscInt *nv,PetscScalar *V,PetscInt ldv,PetscReal *s,PetscScalar *R,PetscInt ldr,PetscBLASInt *perm,PetscBLASInt *cmplxEig,PetscBool *breakdown,PetscScalar *work)
 {
   PetscInt       i,j,n,n0,n1,np,idx0,idx1,sz=1,k=0,t1,t2,nwu=0;
   PetscScalar    *col1,*col2;
@@ -565,7 +566,7 @@ static PetscErrorCode PseudoOrthog_HR(PetscInt *nv,PetscScalar *V,PetscInt ldv,P
     if (breakdown) *breakdown = PETSC_TRUE;
     *nv = n-k;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode DSGHIEPOrthogEigenv(DS ds,DSMatType mat,PetscScalar *wr,PetscScalar *wi,PetscBool accum)
@@ -603,7 +604,7 @@ PetscErrorCode DSGHIEPOrthogEigenv(DS ds,DSMatType mat,PetscScalar *wr,PetscScal
 #if defined(PETSC_USE_COMPLEX)
     vi = PetscImaginaryPart(wr[l+i]);
 #else
-    vi = PetscRealPart(wi[l+i]);
+    vi = wi?PetscRealPart(wi[l+i]):0.0;
 #endif
     if (vi!=0) {
       cmplxEig[i] = 1;
@@ -615,14 +616,16 @@ PetscErrorCode DSGHIEPOrthogEigenv(DS ds,DSMatType mat,PetscScalar *wr,PetscScal
 
   /* Perform HR decomposition */
   /* Hyperbolic rotators */
-  PetscCall(PseudoOrthog_HR(&nv,X+off,ld,s+l,R,ldr,perm,cmplxEig,NULL,ds->work+nwus));
+  PetscCall(DSPseudoOrthog_HR(&nv,X+off,ld,s+l,R,ldr,perm,cmplxEig,NULL,ds->work+nwus));
   /* Sort wr,wi perm */
   ts = ds->work+nwus;
   PetscCall(PetscArraycpy(ts,wr+l,n));
   for (i=0;i<n;i++) wr[i+l] = ts[perm[i]];
 #if !defined(PETSC_USE_COMPLEX)
-  PetscCall(PetscArraycpy(ts,wi+l,n));
-  for (i=0;i<n;i++) wi[i+l] = ts[perm[i]];
+  if (wi) {
+    PetscCall(PetscArraycpy(ts,wi+l,n));
+    for (i=0;i<n;i++) wi[i+l] = ts[perm[i]];
+  }
 #endif
   /* Projected Matrix */
   PetscCall(DSGetArrayReal(ds,DS_MAT_T,&d));
@@ -638,7 +641,7 @@ PetscErrorCode DSGHIEPOrthogEigenv(DS ds,DSMatType mat,PetscScalar *wr,PetscScal
 #if defined(PETSC_USE_COMPLEX)
       vi = PetscImaginaryPart(wr[l+i]);
 #else
-      vi = PetscRealPart(wi[l+i]);
+      vi = wi?PetscRealPart(wi[l+i]):0.0;
 #endif
       if (cmplxEig[i]==-1) vi = -vi;
       tr = PetscRealPart((R[i+(i+1)*ldr]/R[i+i*ldr]))*vi;
@@ -652,24 +655,20 @@ PetscErrorCode DSGHIEPOrthogEigenv(DS ds,DSMatType mat,PetscScalar *wr,PetscScal
   PetscCall(DSRestoreArrayReal(ds,DS_MAT_T,&d));
   PetscCall(DSRestoreArrayReal(ds,DS_MAT_D,&s));
   /* accumulate previous Q */
-  PetscCall(MatDenseGetArray(ds->omat[DS_MAT_Q],&Q));
   if (accum) {
+    PetscCall(MatDenseGetArray(ds->omat[DS_MAT_Q],&Q));
     PetscCall(PetscBLASIntCast(nv,&nv_));
     PetscCall(DSAllocateMat_Private(ds,DS_MAT_W));
     PetscCall(MatCopy(ds->omat[DS_MAT_Q],ds->omat[DS_MAT_W],SAME_NONZERO_PATTERN));
     PetscCall(MatDenseGetArrayRead(ds->omat[DS_MAT_W],&W));
     PetscCallBLAS("BLASgemm",BLASgemm_("N","N",&n_,&nv_,&n_,&sone,W+off,&ld_,X+off,&ld_,&szero,Q+off,&ld_));
     PetscCall(MatDenseRestoreArrayRead(ds->omat[DS_MAT_W],&W));
-  } else {
-    PetscCall(PetscArrayzero(Q,ld*ld));
-    for (i=0;i<ds->l;i++) Q[i+i*ld] = 1.0;
-    for (i=0;i<n;i++) PetscCall(PetscArraycpy(Q+off+i*ld,X+off+i*ld,n));
+    PetscCall(MatDenseRestoreArray(ds->omat[DS_MAT_Q],&Q));
   }
-  PetscCall(MatDenseRestoreArray(ds->omat[DS_MAT_Q],&Q));
   ds->t = nv+l;
   PetscCall(MatDenseRestoreArray(ds->omat[mat],&X));
   if (!ds->compact) PetscCall(DSSwitchFormat_GHIEP(ds,PETSC_FALSE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -719,5 +718,5 @@ PetscErrorCode DSIntermediate_GHIEP(DS ds)
   PetscCall(MatDenseRestoreArray(ds->omat[DS_MAT_Q],&Q));
   PetscCall(DSRestoreArrayReal(ds,DS_MAT_T,&d));
   PetscCall(DSRestoreArrayReal(ds,DS_MAT_D,&s));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
