@@ -9,7 +9,6 @@
 */
 
 #include <slepc/private/dsimpl.h>       /*I "slepcds.h" I*/
-#include <slepc/private/rgimpl.h>       /*I "slepcrg.h" I*/
 #include <slepcblaslapack.h>
 
 typedef struct {
@@ -33,10 +32,11 @@ typedef struct {
 */
 static PetscErrorCode DSNEPComputeMatrix(DS ds,PetscScalar lambda,PetscBool deriv,DSMatType mat)
 {
-  DS_NEP         *ctx = (DS_NEP*)ds->data;
-  PetscScalar    *T,*E,alpha;
-  PetscInt       i,ld,n;
-  PetscBLASInt   k,inc=1;
+  DS_NEP            *ctx = (DS_NEP*)ds->data;
+  PetscScalar       *T,alpha;
+  const PetscScalar *E;
+  PetscInt          i,ld,n;
+  PetscBLASInt      k,inc=1;
 
   PetscFunctionBegin;
   PetscCall(PetscLogEventBegin(DS_Other,ds,0,0,0));
@@ -45,18 +45,19 @@ static PetscErrorCode DSNEPComputeMatrix(DS ds,PetscScalar lambda,PetscBool deri
     PetscCall(DSGetDimensions(ds,&n,NULL,NULL,NULL));
     PetscCall(DSGetLeadingDimension(ds,&ld));
     PetscCall(PetscBLASIntCast(ld*n,&k));
-    PetscCall(DSGetArray(ds,mat,&T));
+    PetscCall(MatDenseGetArray(ds->omat[mat],&T));
     PetscCall(PetscArrayzero(T,k));
     for (i=0;i<ctx->nf;i++) {
       if (deriv) PetscCall(FNEvaluateDerivative(ctx->f[i],lambda,&alpha));
       else PetscCall(FNEvaluateFunction(ctx->f[i],lambda,&alpha));
-      E = ds->mat[DSMatExtra[i]];
-      PetscStackCallBLAS("BLASaxpy",BLASaxpy_(&k,&alpha,E,&inc,T,&inc));
+      PetscCall(MatDenseGetArrayRead(ds->omat[DSMatExtra[i]],&E));
+      PetscCallBLAS("BLASaxpy",BLASaxpy_(&k,&alpha,E,&inc,T,&inc));
+      PetscCall(MatDenseRestoreArrayRead(ds->omat[DSMatExtra[i]],&E));
     }
-    PetscCall(DSRestoreArray(ds,mat,&T));
+    PetscCall(MatDenseRestoreArray(ds->omat[mat],&T));
   }
   PetscCall(PetscLogEventEnd(DS_Other,ds,0,0,0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode DSAllocate_NEP(DS ds,PetscInt ld)
@@ -69,8 +70,7 @@ PetscErrorCode DSAllocate_NEP(DS ds,PetscInt ld)
   for (i=0;i<ctx->nf;i++) PetscCall(DSAllocateMat_Private(ds,DSMatExtra[i]));
   PetscCall(PetscFree(ds->perm));
   PetscCall(PetscMalloc1(ld*ctx->max_mid,&ds->perm));
-  PetscCall(PetscLogObjectMemory((PetscObject)ds,ld*ctx->max_mid*sizeof(PetscInt)));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode DSView_NEP(DS ds,PetscViewer viewer)
@@ -82,7 +82,7 @@ PetscErrorCode DSView_NEP(DS ds,PetscViewer viewer)
                      "Successive Linear Problems",
                      "Contour Integral"
   };
-  const int         nmeth=sizeof(methodname)/sizeof(methodname[0]);
+  const int         nmeth=PETSC_STATIC_ARRAY_LENGTH(methodname);
 
   PetscFunctionBegin;
   PetscCall(PetscViewerGetFormat(viewer,&format));
@@ -98,14 +98,14 @@ PetscErrorCode DSView_NEP(DS ds,PetscViewer viewer)
     }
 #endif
     if (format == PETSC_VIEWER_ASCII_INFO_DETAIL) PetscCall(PetscViewerASCIIPrintf(viewer,"number of functions: %" PetscInt_FMT "\n",ctx->nf));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   for (i=0;i<ctx->nf;i++) {
     PetscCall(FNView(ctx->f[i],viewer));
     PetscCall(DSViewMat(ds,viewer,DSMatExtra[i]));
   }
   if (ds->state>DS_STATE_INTERMEDIATE) PetscCall(DSViewMat(ds,viewer,DS_MAT_X));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode DSVectors_NEP(DS ds,DSMatType mat,PetscInt *j,PetscReal *rnorm)
@@ -120,30 +120,32 @@ PetscErrorCode DSVectors_NEP(DS ds,DSMatType mat,PetscInt *j,PetscReal *rnorm)
     default:
       SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"Invalid mat parameter");
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode DSSort_NEP(DS ds,PetscScalar *wr,PetscScalar *wi,PetscScalar *rr,PetscScalar *ri,PetscInt *dummy)
 {
   DS_NEP         *ctx = (DS_NEP*)ds->data;
   PetscInt       n,l,i,*perm,lds;
-  PetscScalar    *A;
+  PetscScalar    *Q;
 
   PetscFunctionBegin;
-  if (!ds->sc) PetscFunctionReturn(0);
+  if (!ds->sc) PetscFunctionReturn(PETSC_SUCCESS);
+  if (!ds->method) PetscFunctionReturn(PETSC_SUCCESS);  /* SLP computes just one eigenvalue */
   n = ds->n*ctx->max_mid;
   lds = ds->ld*ctx->max_mid;
   l = ds->l;
-  A = ds->mat[DS_MAT_A];
   perm = ds->perm;
   for (i=0;i<n;i++) perm[i] = i;
   if (rr) PetscCall(DSSortEigenvalues_Private(ds,rr,ri,perm,PETSC_FALSE));
   else PetscCall(DSSortEigenvalues_Private(ds,wr,NULL,perm,PETSC_FALSE));
-  for (i=l;i<ds->t;i++) A[i+i*lds] = wr[perm[i]];
-  for (i=l;i<ds->t;i++) wr[i] = A[i+i*lds];
+  PetscCall(MatDenseGetArray(ds->omat[DS_MAT_Q],&Q));
+  for (i=l;i<ds->t;i++) Q[i+i*lds] = wr[perm[i]];
+  for (i=l;i<ds->t;i++) wr[i] = Q[i+i*lds];
+  PetscCall(MatDenseRestoreArray(ds->omat[DS_MAT_Q],&Q));
   /* n != ds->n */
   PetscCall(DSPermuteColumns_Private(ds,0,ds->t,ds->n,DS_MAT_X,perm));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode DSSolve_NEP_SLP(DS ds,PetscScalar *wr,PetscScalar *wi)
@@ -160,9 +162,6 @@ PetscErrorCode DSSolve_NEP_SLP(DS ds,PetscScalar *wr,PetscScalar *wi)
 #endif
 
   PetscFunctionBegin;
-  if (!ds->mat[DS_MAT_A]) PetscCall(DSAllocateMat_Private(ds,DS_MAT_A));
-  if (!ds->mat[DS_MAT_B]) PetscCall(DSAllocateMat_Private(ds,DS_MAT_B));
-  if (!ds->mat[DS_MAT_W]) PetscCall(DSAllocateMat_Private(ds,DS_MAT_W));
   PetscCall(PetscBLASIntCast(ds->n,&n));
   PetscCall(PetscBLASIntCast(ds->ld,&ld));
 #if defined(PETSC_USE_COMPLEX)
@@ -182,10 +181,13 @@ PetscErrorCode DSSolve_NEP_SLP(DS ds,PetscScalar *wr,PetscScalar *wi)
   work = ds->work + 3*ds->n;
   lwork -= 3*ds->n;
 #endif
-  A = ds->mat[DS_MAT_A];
-  B = ds->mat[DS_MAT_B];
-  W = ds->mat[DS_MAT_W];
-  X = ds->mat[DS_MAT_X];
+  PetscCall(DSAllocateMat_Private(ds,DS_MAT_A));
+  PetscCall(DSAllocateMat_Private(ds,DS_MAT_B));
+  PetscCall(DSAllocateMat_Private(ds,DS_MAT_W));
+  PetscCall(MatDenseGetArray(ds->omat[DS_MAT_A],&A));
+  PetscCall(MatDenseGetArray(ds->omat[DS_MAT_B],&B));
+  PetscCall(MatDenseGetArray(ds->omat[DS_MAT_W],&W));
+  PetscCall(MatDenseGetArray(ds->omat[DS_MAT_X],&X));
 
   sigma = 0.0;
   if (ds->sc->comparison==SlepcCompareTargetMagnitude || ds->sc->comparison==SlepcCompareTargetReal) sigma = *(PetscScalar*)ds->sc->comparisonctx;
@@ -197,7 +199,7 @@ PetscErrorCode DSSolve_NEP_SLP(DS ds,PetscScalar *wr,PetscScalar *wi)
     /* evaluate T and T' */
     PetscCall(DSNEPComputeMatrix(ds,lambda,PETSC_FALSE,DS_MAT_A));
     if (it) {
-      PetscStackCallBLAS("BLASgemv",BLASgemv_("N",&n,&n,&sone,A,&ld,X,&one,&szero,X+ld,&one));
+      PetscCallBLAS("BLASgemv",BLASgemv_("N",&n,&n,&sone,A,&ld,X,&one,&szero,X+ld,&one));
       norm = BLASnrm2_(&n,X+ld,&one);
       if (norm/PetscAbsScalar(lambda)<=tol) break;
     }
@@ -206,9 +208,9 @@ PetscErrorCode DSSolve_NEP_SLP(DS ds,PetscScalar *wr,PetscScalar *wi)
     /* compute eigenvalue correction mu and eigenvector u */
 #if defined(PETSC_USE_COMPLEX)
     rwork = ds->rwork;
-    PetscStackCallBLAS("LAPACKggev",LAPACKggev_("N","V",&n,A,&ld,B,&ld,alpha,beta,NULL,&ld,W,&ld,work,&lwork,rwork,&info));
+    PetscCallBLAS("LAPACKggev",LAPACKggev_("N","V",&n,A,&ld,B,&ld,alpha,beta,NULL,&ld,W,&ld,work,&lwork,rwork,&info));
 #else
-    PetscStackCallBLAS("LAPACKggev",LAPACKggev_("N","V",&n,A,&ld,B,&ld,alpha,alphai,beta,NULL,&ld,W,&ld,work,&lwork,&info));
+    PetscCallBLAS("LAPACKggev",LAPACKggev_("N","V",&n,A,&ld,B,&ld,alpha,alphai,beta,NULL,&ld,W,&ld,work,&lwork,&info));
 #endif
     SlepcCheckLapackInfo("ggev",info);
 
@@ -246,18 +248,22 @@ PetscErrorCode DSSolve_NEP_SLP(DS ds,PetscScalar *wr,PetscScalar *wi)
     mu = alpha[pos]/beta[pos];
     PetscCall(PetscArraycpy(X,W+pos*ld,n));
     norm = BLASnrm2_(&n,X,&one);
-    PetscStackCallBLAS("LAPACKlascl",LAPACKlascl_("G",&zero,&zero,&norm,&done,&n,&one,X,&n,&info));
+    PetscCallBLAS("LAPACKlascl",LAPACKlascl_("G",&zero,&zero,&norm,&done,&n,&one,X,&n,&info));
     SlepcCheckLapackInfo("lascl",info);
 
     /* correct eigenvalue approximation */
     lambda = lambda - mu;
   }
+  PetscCall(MatDenseRestoreArray(ds->omat[DS_MAT_A],&A));
+  PetscCall(MatDenseRestoreArray(ds->omat[DS_MAT_B],&B));
+  PetscCall(MatDenseRestoreArray(ds->omat[DS_MAT_W],&W));
+  PetscCall(MatDenseRestoreArray(ds->omat[DS_MAT_X],&X));
 
   PetscCheck(it<maxit,PETSC_COMM_SELF,PETSC_ERR_CONV_FAILED,"DSNEP did not converge");
   ds->t = 1;
   wr[0] = lambda;
   if (wi) wi[0] = 0.0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #if defined(PETSC_USE_COMPLEX)
@@ -278,8 +284,7 @@ static PetscErrorCode DSNEPNewtonRefine(DS ds,PetscInt k,PetscScalar *wr)
   PetscLayout    map;
 
   PetscFunctionBegin;
-  X = ds->mat[DS_MAT_X];
-  W = ds->mat[DS_MAT_W];
+  PetscCall(MatDenseGetArray(ds->omat[DS_MAT_X],&X));
   PetscCall(PetscBLASIntCast(ds->n,&n));
   PetscCall(PetscBLASIntCast(ds->ld,&ld));
   n1 = n+1;
@@ -297,24 +302,30 @@ static PetscErrorCode DSNEPNewtonRefine(DS ds,PetscInt k,PetscScalar *wr)
     for (j=jstart;j<jend;j++) {
       if (p[j]<2) {
         PetscCall(DSNEPComputeMatrix(ds,wr[j],PETSC_FALSE,DS_MAT_W));
-        PetscStackCallBLAS("BLASgemv",BLASgemv_("N",&n,&n,&sone,W,&ld,X+ld*j,&one,&szero,R,&one));
+        PetscCall(MatDenseGetArray(ds->omat[DS_MAT_W],&W));
+        PetscCallBLAS("BLASgemv",BLASgemv_("N",&n,&n,&sone,W,&ld,X+ld*j,&one,&szero,R,&one));
+        PetscCall(MatDenseRestoreArray(ds->omat[DS_MAT_W],&W));
         norm = BLASnrm2_(&n,R,&one);
         if (norm/PetscAbsScalar(wr[j]) > ctx->rtol) {
-          PetscCall(PetscInfo(NULL,"Refining eigenpair %" PetscInt_FMT ", residual=%g\n",j,(double)norm/PetscAbsScalar(wr[j])));
+          PetscCall(PetscInfo(NULL,"Refining eigenpair %" PetscInt_FMT ", residual=%g\n",j,(double)(norm/PetscAbsScalar(wr[j]))));
           p[j] = 1;
           R[n] = 0.0;
+          PetscCall(MatDenseGetArray(ds->omat[DS_MAT_W],&W));
           for (i=0;i<n;i++) {
             PetscCall(PetscArraycpy(U+i*n1,W+i*ld,n));
             U[n+i*n1] = PetscConj(X[j*ld+i]);
           }
+          PetscCall(MatDenseRestoreArray(ds->omat[DS_MAT_W],&W));
           U[n+n*n1] = 0.0;
           PetscCall(DSNEPComputeMatrix(ds,wr[j],PETSC_TRUE,DS_MAT_W));
-          PetscStackCallBLAS("BLASgemv",BLASgemv_("N",&n,&n,&sone,W,&ld,X+ld*j,&one,&szero,U+n*(n+1),&one));
+          PetscCall(MatDenseGetArray(ds->omat[DS_MAT_W],&W));
+          PetscCallBLAS("BLASgemv",BLASgemv_("N",&n,&n,&sone,W,&ld,X+ld*j,&one,&szero,U+n*(n+1),&one));
+          PetscCall(MatDenseRestoreArray(ds->omat[DS_MAT_W],&W));
           /* solve system  */
           PetscCall(PetscFPTrapPush(PETSC_FP_TRAP_OFF));
-          PetscStackCallBLAS("LAPACKgetrf",LAPACKgetrf_(&n1,&n1,U,&n1,perm,&info));
+          PetscCallBLAS("LAPACKgetrf",LAPACKgetrf_(&n1,&n1,U,&n1,perm,&info));
           SlepcCheckLapackInfo("getrf",info);
-          PetscStackCallBLAS("LAPACKgetrs",LAPACKgetrs_("N",&n1,&one,U,&n1,perm,R,&n1,&info));
+          PetscCallBLAS("LAPACKgetrs",LAPACKgetrs_("N",&n1,&one,U,&n1,perm,R,&n1,&info));
           SlepcCheckLapackInfo("getrs",info);
           PetscCall(PetscFPTrapPop());
           wr[j] -= R[n];
@@ -342,13 +353,14 @@ static PetscErrorCode DSNEPNewtonRefine(DS ds,PetscInt k,PetscScalar *wr)
     }
     PetscCall(PetscLayoutDestroy(&map));
   }
-  PetscFunctionReturn(0);
+  PetscCall(MatDenseRestoreArray(ds->omat[DS_MAT_X],&X));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode DSSolve_NEP_Contour(DS ds,PetscScalar *wr,PetscScalar *wi)
 {
   DS_NEP         *ctx = (DS_NEP*)ds->data;
-  PetscScalar    *alpha,*beta,*A,*B,*X,*W,*work,*Rc,*R,*w,*z,*zn,*S,*U,*V;
+  PetscScalar    *alpha,*beta,*Q,*Z,*X,*U,*V,*W,*work,*Rc,*R,*w,*z,*zn,*S;
   PetscScalar    sone=1.0,szero=0.0,center;
   PetscReal      *rwork,norm,radius,vscale,rgscale,*sigma;
   PetscBLASInt   info,n,*perm,p,pp,ld,lwork,k_,rk_,colA,rowA,one=1;
@@ -369,17 +381,15 @@ PetscErrorCode DSSolve_NEP_Contour(DS ds,PetscScalar *wr,PetscScalar *wi)
     PetscCall(PetscLayoutGetRange(ctx->map,&kstart,&kend));
   }
 
-  if (!ds->mat[DS_MAT_A]) PetscCall(DSAllocateMat_Private(ds,DS_MAT_A)); /* size mid*n */
-  if (!ds->mat[DS_MAT_B]) PetscCall(DSAllocateMat_Private(ds,DS_MAT_B)); /* size mid*n */
-  if (!ds->mat[DS_MAT_W]) PetscCall(DSAllocateMat_Private(ds,DS_MAT_W)); /* size mid*n */
-  if (!ds->mat[DS_MAT_U]) PetscCall(DSAllocateMat_Private(ds,DS_MAT_U)); /* size mid*n */
-  if (!ds->mat[DS_MAT_V]) PetscCall(DSAllocateMat_Private(ds,DS_MAT_V)); /* size n */
-  A = ds->mat[DS_MAT_A];
-  B = ds->mat[DS_MAT_B];
-  W = ds->mat[DS_MAT_W];
-  U = ds->mat[DS_MAT_U];
-  V = ds->mat[DS_MAT_V];
-  X = ds->mat[DS_MAT_X];
+  PetscCall(DSAllocateMat_Private(ds,DS_MAT_W)); /* size n */
+  PetscCall(DSAllocateMat_Private(ds,DS_MAT_Q)); /* size mid*n */
+  PetscCall(DSAllocateMat_Private(ds,DS_MAT_Z)); /* size mid*n */
+  PetscCall(DSAllocateMat_Private(ds,DS_MAT_U)); /* size mid*n */
+  PetscCall(DSAllocateMat_Private(ds,DS_MAT_V)); /* size mid*n */
+  PetscCall(MatDenseGetArray(ds->omat[DS_MAT_Q],&Q));
+  PetscCall(MatDenseGetArray(ds->omat[DS_MAT_Z],&Z));
+  PetscCall(MatDenseGetArray(ds->omat[DS_MAT_U],&U));
+  PetscCall(MatDenseGetArray(ds->omat[DS_MAT_V],&V));
   mid  = ctx->max_mid;
   PetscCall(PetscBLASIntCast(ds->n,&n));
   p    = n;   /* maximum number of columns for the probing matrix */
@@ -417,15 +427,17 @@ PetscErrorCode DSSolve_NEP_Contour(DS ds,PetscScalar *wr,PetscScalar *wi)
   for (k=kstart;k<kend;k++) {
     PetscCall(PetscInfo(NULL,"Solving integration point %" PetscInt_FMT "\n",k));
     PetscCall(PetscArraycpy(R,Rc,p*n));
-    PetscCall(DSNEPComputeMatrix(ds,z[k],PETSC_FALSE,DS_MAT_V));
+    PetscCall(DSNEPComputeMatrix(ds,z[k],PETSC_FALSE,DS_MAT_W));
 
     /* LU factorization */
+    PetscCall(MatDenseGetArray(ds->omat[DS_MAT_W],&W));
     PetscCall(PetscFPTrapPush(PETSC_FP_TRAP_OFF));
-    PetscStackCallBLAS("LAPACKgetrf",LAPACKgetrf_(&n,&n,V,&ld,perm,&info));
+    PetscCallBLAS("LAPACKgetrf",LAPACKgetrf_(&n,&n,W,&ld,perm,&info));
     SlepcCheckLapackInfo("getrf",info);
-    PetscStackCallBLAS("LAPACKgetrs",LAPACKgetrs_("N",&n,&p,V,&ld,perm,R,&n,&info));
+    PetscCallBLAS("LAPACKgetrs",LAPACKgetrs_("N",&n,&p,W,&ld,perm,R,&n,&info));
     SlepcCheckLapackInfo("getrs",info);
     PetscCall(PetscFPTrapPop());
+    PetscCall(MatDenseRestoreArray(ds->omat[DS_MAT_W],&W));
 
     /* Moments computation */
     for (s=0;s<2*ctx->max_mid;s++) {
@@ -451,11 +463,11 @@ PetscErrorCode DSSolve_NEP_Contour(DS ds,PetscScalar *wr,PetscScalar *wi)
       for (ii=0;ii<mid;ii++) {
         off = jj*p*rowA+ii*n;
         for (j=0;j<p;j++)
-          for (i=0;i<n;i++) A[off+j*rowA+i] = S[((jj+ii)*n+j)*n+i];
+          for (i=0;i<n;i++) Q[off+j*rowA+i] = S[((jj+ii)*n+j)*n+i];
       }
     }
     PetscCall(PetscFPTrapPush(PETSC_FP_TRAP_OFF));
-    PetscStackCallBLAS("LAPACKgesvd",LAPACKgesvd_("S","S",&rowA,&colA,A,&rowA,sigma,U,&rowA,W,&colA,work,&lwork,rwork,&info));
+    PetscCallBLAS("LAPACKgesvd",LAPACKgesvd_("S","S",&rowA,&colA,Q,&rowA,sigma,U,&rowA,V,&colA,work,&lwork,rwork,&info));
     SlepcCheckLapackInfo("gesvd",info);
     PetscCall(PetscFPTrapPop());
 
@@ -469,15 +481,15 @@ PetscErrorCode DSSolve_NEP_Contour(DS ds,PetscScalar *wr,PetscScalar *wi)
     for (ii=0;ii<mid;ii++) {
       off = jj*p*rowA+ii*n;
       for (j=0;j<p;j++)
-        for (i=0;i<n;i++) A[off+j*rowA+i] = S[((jj+ii+1)*n+j)*n+i];
+        for (i=0;i<n;i++) Q[off+j*rowA+i] = S[((jj+ii+1)*n+j)*n+i];
     }
   }
   PetscCall(PetscBLASIntCast(rk,&rk_));
-  PetscStackCallBLAS("BLASgemm",BLASgemm_("N","C",&rowA,&rk_,&colA,&sone,A,&rowA,W,&colA,&szero,B,&rowA));
-  PetscStackCallBLAS("BLASgemm",BLASgemm_("C","N",&rk_,&rk_,&rowA,&sone,U,&rowA,B,&rowA,&szero,A,&rk_));
-  PetscCall(PetscArrayzero(B,n*mid*n*mid));
-  for (j=0;j<rk;j++) B[j+j*rk_] = sigma[j];
-  PetscStackCallBLAS("LAPACKggev",LAPACKggev_("N","V",&rk_,A,&rk_,B,&rk_,alpha,beta,NULL,&ld,W,&rk_,work,&lwork,rwork,&info));
+  PetscCallBLAS("BLASgemm",BLASgemm_("N","C",&rowA,&rk_,&colA,&sone,Q,&rowA,V,&colA,&szero,Z,&rowA));
+  PetscCallBLAS("BLASgemm",BLASgemm_("C","N",&rk_,&rk_,&rowA,&sone,U,&rowA,Z,&rowA,&szero,Q,&rk_));
+  PetscCall(PetscArrayzero(Z,n*mid*n*mid));
+  for (j=0;j<rk;j++) Z[j+j*rk_] = sigma[j];
+  PetscCallBLAS("LAPACKggev",LAPACKggev_("N","V",&rk_,Q,&rk_,Z,&rk_,alpha,beta,NULL,&ld,V,&rk_,work,&lwork,rwork,&info));
   for (i=0;i<rk;i++) wr[i] = (center+radius*alpha[i]/beta[i])*rgscale;
   PetscCall(PetscMalloc1(rk,&inside));
   PetscCall(RGCheckInside(ctx->rg,rk,wr,wi,inside));
@@ -486,34 +498,42 @@ PetscErrorCode DSSolve_NEP_Contour(DS ds,PetscScalar *wr,PetscScalar *wi)
     if (inside[i]==1) inside[k++] = i;
   /* Discard values outside region */
   lds = ld*mid;
-  PetscCall(PetscArrayzero(A,lds*lds));
-  PetscCall(PetscArrayzero(B,lds*lds));
-  for (i=0;i<k;i++) A[i+i*lds] = (center*beta[inside[i]]+radius*alpha[inside[i]])*rgscale;
-  for (i=0;i<k;i++) B[i+i*lds] = beta[inside[i]];
-  for (i=0;i<k;i++) wr[i] = A[i+i*lds]/B[i+i*lds];
-  for (j=0;j<k;j++) for (i=0;i<rk;i++) W[j*rk+i] = sigma[i]*W[inside[j]*rk+i];
+  PetscCall(PetscArrayzero(Q,lds*lds));
+  PetscCall(PetscArrayzero(Z,lds*lds));
+  for (i=0;i<k;i++) Q[i+i*lds] = (center*beta[inside[i]]+radius*alpha[inside[i]])*rgscale;
+  for (i=0;i<k;i++) Z[i+i*lds] = beta[inside[i]];
+  for (i=0;i<k;i++) wr[i] = Q[i+i*lds]/Z[i+i*lds];
+  for (j=0;j<k;j++) for (i=0;i<rk;i++) V[j*rk+i] = sigma[i]*V[inside[j]*rk+i];
   PetscCall(PetscBLASIntCast(k,&k_));
-  PetscStackCallBLAS("BLASgemm",BLASgemm_("N","N",&n,&k_,&rk_,&sone,U,&rowA,W,&rk_,&szero,X,&ld));
-
+  PetscCall(MatDenseGetArray(ds->omat[DS_MAT_X],&X));
+  PetscCallBLAS("BLASgemm",BLASgemm_("N","N",&n,&k_,&rk_,&sone,U,&rowA,V,&rk_,&szero,X,&ld));
   /* Normalize */
   for (j=0;j<k;j++) {
     norm = BLASnrm2_(&n,X+ld*j,&one);
     for (i=0;i<n;i++) X[ld*j+i] /= norm;
   }
   PetscCall(PetscFree(inside));
+  PetscCall(MatDenseRestoreArray(ds->omat[DS_MAT_X],&X));
+  PetscCall(MatDenseRestoreArray(ds->omat[DS_MAT_Q],&Q));
+  PetscCall(MatDenseRestoreArray(ds->omat[DS_MAT_Z],&Z));
+  PetscCall(MatDenseRestoreArray(ds->omat[DS_MAT_U],&U));
+  PetscCall(MatDenseRestoreArray(ds->omat[DS_MAT_V],&V));
+
   /* Newton refinement */
-  PetscCall(DSNEPNewtonRefine(ds,k,wr));
+  if (ctx->Nit) PetscCall(DSNEPNewtonRefine(ds,k,wr));
   ds->t = k;
   PetscCall(PetscRandomDestroy(&rand));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 #endif
 
+#if !defined(PETSC_HAVE_MPIUNI)
 PetscErrorCode DSSynchronize_NEP(DS ds,PetscScalar eigr[],PetscScalar eigi[])
 {
   DS_NEP         *ctx = (DS_NEP*)ds->data;
   PetscInt       ld=ds->ld,k=0;
   PetscMPIInt    n,n2,rank,size,off=0;
+  PetscScalar    *X;
 
   PetscFunctionBegin;
   if (!ds->method) { /* SLP */
@@ -531,9 +551,10 @@ PetscErrorCode DSSynchronize_NEP(DS ds,PetscScalar eigr[],PetscScalar eigi[])
   }
   PetscCall(DSAllocateWork_Private(ds,k,0,0));
   PetscCall(PetscMPIIntCast(k*sizeof(PetscScalar),&size));
+  if (ds->state>=DS_STATE_CONDENSED) PetscCall(MatDenseGetArray(ds->omat[DS_MAT_X],&X));
   PetscCallMPI(MPI_Comm_rank(PetscObjectComm((PetscObject)ds),&rank));
   if (!rank) {
-    if (ds->state>=DS_STATE_CONDENSED) PetscCallMPI(MPI_Pack(ds->mat[DS_MAT_X],n2,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds)));
+    if (ds->state>=DS_STATE_CONDENSED) PetscCallMPI(MPI_Pack(X,n2,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds)));
     if (eigr) PetscCallMPI(MPI_Pack(eigr,n,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds)));
 #if !defined(PETSC_USE_COMPLEX)
     if (eigi) PetscCallMPI(MPI_Pack(eigi,n,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds)));
@@ -541,14 +562,16 @@ PetscErrorCode DSSynchronize_NEP(DS ds,PetscScalar eigr[],PetscScalar eigi[])
   }
   PetscCallMPI(MPI_Bcast(ds->work,size,MPI_BYTE,0,PetscObjectComm((PetscObject)ds)));
   if (rank) {
-    if (ds->state>=DS_STATE_CONDENSED) PetscCallMPI(MPI_Unpack(ds->work,size,&off,ds->mat[DS_MAT_X],n2,MPIU_SCALAR,PetscObjectComm((PetscObject)ds)));
+    if (ds->state>=DS_STATE_CONDENSED) PetscCallMPI(MPI_Unpack(ds->work,size,&off,X,n2,MPIU_SCALAR,PetscObjectComm((PetscObject)ds)));
     if (eigr) PetscCallMPI(MPI_Unpack(ds->work,size,&off,eigr,n,MPIU_SCALAR,PetscObjectComm((PetscObject)ds)));
 #if !defined(PETSC_USE_COMPLEX)
     if (eigi) PetscCallMPI(MPI_Unpack(ds->work,size,&off,eigi,n,MPIU_SCALAR,PetscObjectComm((PetscObject)ds)));
 #endif
   }
-  PetscFunctionReturn(0);
+  if (ds->state>=DS_STATE_CONDENSED) PetscCall(MatDenseRestoreArray(ds->omat[DS_MAT_X],&X));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
+#endif
 
 static PetscErrorCode DSNEPSetFN_NEP(DS ds,PetscInt n,FN fn[])
 {
@@ -563,14 +586,14 @@ static PetscErrorCode DSNEPSetFN_NEP(DS ds,PetscInt n,FN fn[])
   for (i=0;i<ctx->nf;i++) PetscCall(FNDestroy(&ctx->f[i]));
   for (i=0;i<n;i++) ctx->f[i] = fn[i];
   ctx->nf = n;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSNEPSetFN - Sets a number of functions that define the nonlinear
    eigenproblem.
 
-   Collective on ds
+   Collective
 
    Input Parameters:
 +  ds - the direct solver context
@@ -588,7 +611,7 @@ static PetscErrorCode DSNEPSetFN_NEP(DS ds,PetscInt n,FN fn[])
    Level: advanced
 
 .seealso: DSNEPGetFN(), DSAllocate()
- @*/
+@*/
 PetscErrorCode DSNEPSetFN(DS ds,PetscInt n,FN fn[])
 {
   PetscInt       i;
@@ -602,7 +625,7 @@ PetscErrorCode DSNEPSetFN(DS ds,PetscInt n,FN fn[])
     PetscCheckSameComm(ds,1,fn[i],3);
   }
   PetscTryMethod(ds,"DSNEPSetFN_C",(DS,PetscInt,FN[]),(ds,n,fn));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DSNEPGetFN_NEP(DS ds,PetscInt k,FN *fn)
@@ -612,13 +635,13 @@ static PetscErrorCode DSNEPGetFN_NEP(DS ds,PetscInt k,FN *fn)
   PetscFunctionBegin;
   PetscCheck(k>=0 && k<ctx->nf,PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"k must be between 0 and %" PetscInt_FMT,ctx->nf-1);
   *fn = ctx->f[k];
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSNEPGetFN - Gets the functions associated with the nonlinear DS.
 
-   Not collective, though parallel FNs are returned if the DS is parallel
+   Not Collective
 
    Input Parameters:
 +  ds - the direct solver context
@@ -637,7 +660,7 @@ PetscErrorCode DSNEPGetFN(DS ds,PetscInt k,FN *fn)
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidPointer(fn,3);
   PetscUseMethod(ds,"DSNEPGetFN_C",(DS,PetscInt,FN*),(ds,k,fn));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DSNEPGetNumFN_NEP(DS ds,PetscInt *n)
@@ -646,14 +669,14 @@ static PetscErrorCode DSNEPGetNumFN_NEP(DS ds,PetscInt *n)
 
   PetscFunctionBegin;
   *n = ctx->nf;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSNEPGetNumFN - Returns the number of functions stored internally by
    the DS.
 
-   Not collective
+   Not Collective
 
    Input Parameter:
 .  ds - the direct solver context
@@ -671,7 +694,7 @@ PetscErrorCode DSNEPGetNumFN(DS ds,PetscInt *n)
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidIntPointer(n,2);
   PetscUseMethod(ds,"DSNEPGetNumFN_C",(DS,PetscInt*),(ds,n));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DSNEPSetMinimality_NEP(DS ds,PetscInt n)
@@ -684,14 +707,14 @@ static PetscErrorCode DSNEPSetMinimality_NEP(DS ds,PetscInt n)
     PetscCheck(n>0,PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"The minimality value must be > 0");
     ctx->max_mid = n;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSNEPSetMinimality - Sets the maximum minimality index used internally by
    the DSNEP.
 
-   Logically Collective on ds
+   Logically Collective
 
    Input Parameters:
 +  ds - the direct solver context
@@ -716,7 +739,7 @@ PetscErrorCode DSNEPSetMinimality(DS ds,PetscInt n)
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidLogicalCollectiveInt(ds,n,2);
   PetscTryMethod(ds,"DSNEPSetMinimality_C",(DS,PetscInt),(ds,n));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DSNEPGetMinimality_NEP(DS ds,PetscInt *n)
@@ -725,14 +748,14 @@ static PetscErrorCode DSNEPGetMinimality_NEP(DS ds,PetscInt *n)
 
   PetscFunctionBegin;
   *n = ctx->max_mid;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSNEPGetMinimality - Returns the maximum minimality index used internally by
    the DSNEP.
 
-   Not collective
+   Not Collective
 
    Input Parameter:
 .  ds - the direct solver context
@@ -750,7 +773,7 @@ PetscErrorCode DSNEPGetMinimality(DS ds,PetscInt *n)
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidIntPointer(n,2);
   PetscUseMethod(ds,"DSNEPGetMinimality_C",(DS,PetscInt*),(ds,n));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DSNEPSetRefine_NEP(DS ds,PetscReal tol,PetscInt its)
@@ -758,24 +781,24 @@ static PetscErrorCode DSNEPSetRefine_NEP(DS ds,PetscReal tol,PetscInt its)
   DS_NEP *ctx = (DS_NEP*)ds->data;
 
   PetscFunctionBegin;
-  if (tol == PETSC_DEFAULT) ctx->rtol = PETSC_MACHINE_EPSILON/PetscSqrtReal(PETSC_SQRT_MACHINE_EPSILON);
+  if (tol == (PetscReal)PETSC_DEFAULT) ctx->rtol = PETSC_MACHINE_EPSILON/PetscSqrtReal(PETSC_SQRT_MACHINE_EPSILON);
   else {
     PetscCheck(tol>0.0,PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"The tolerance must be > 0");
     ctx->rtol = tol;
   }
   if (its == PETSC_DECIDE || its == PETSC_DEFAULT) ctx->Nit = 3;
   else {
-    PetscCheck(its>0,PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"The number of iterations must be >= 0");
+    PetscCheck(its>=0,PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"The number of iterations must be >= 0");
     ctx->Nit = its;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSNEPSetRefine - Sets the tolerance and the number of iterations of Newton iterative
    refinement for eigenpairs.
 
-   Logically Collective on ds
+   Logically Collective
 
    Input Parameters:
 +  ds  - the direct solver context
@@ -801,7 +824,7 @@ PetscErrorCode DSNEPSetRefine(DS ds,PetscReal tol,PetscInt its)
   PetscValidLogicalCollectiveReal(ds,tol,2);
   PetscValidLogicalCollectiveInt(ds,its,3);
   PetscTryMethod(ds,"DSNEPSetRefine_C",(DS,PetscReal,PetscInt),(ds,tol,its));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DSNEPGetRefine_NEP(DS ds,PetscReal *tol,PetscInt *its)
@@ -811,14 +834,14 @@ static PetscErrorCode DSNEPGetRefine_NEP(DS ds,PetscReal *tol,PetscInt *its)
   PetscFunctionBegin;
   if (tol) *tol = ctx->rtol;
   if (its) *its = ctx->Nit;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSNEPGetRefine - Returns the tolerance and the number of iterations of Newton iterative
    refinement for eigenpairs.
 
-   Not collective
+   Not Collective
 
    Input Parameter:
 .  ds - the direct solver context
@@ -836,7 +859,7 @@ PetscErrorCode DSNEPGetRefine(DS ds,PetscReal *tol,PetscInt *its)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscUseMethod(ds,"DSNEPGetRefine_C",(DS,PetscReal*,PetscInt*),(ds,tol,its));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DSNEPSetIntegrationPoints_NEP(DS ds,PetscInt ip)
@@ -850,14 +873,14 @@ static PetscErrorCode DSNEPSetIntegrationPoints_NEP(DS ds,PetscInt ip)
     ctx->nnod = ip;
   }
   PetscCall(PetscLayoutDestroy(&ctx->map));  /* need to redistribute at next solve */
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSNEPSetIntegrationPoints - Sets the number of integration points to be
    used in the contour integral method.
 
-   Logically Collective on ds
+   Logically Collective
 
    Input Parameters:
 +  ds - the direct solver context
@@ -879,7 +902,7 @@ PetscErrorCode DSNEPSetIntegrationPoints(DS ds,PetscInt ip)
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidLogicalCollectiveInt(ds,ip,2);
   PetscTryMethod(ds,"DSNEPSetIntegrationPoints_C",(DS,PetscInt),(ds,ip));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DSNEPGetIntegrationPoints_NEP(DS ds,PetscInt *ip)
@@ -888,14 +911,14 @@ static PetscErrorCode DSNEPGetIntegrationPoints_NEP(DS ds,PetscInt *ip)
 
   PetscFunctionBegin;
   *ip = ctx->nnod;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSNEPGetIntegrationPoints - Returns the number of integration points used
    in the contour integral method.
 
-   Not collective
+   Not Collective
 
    Input Parameter:
 .  ds - the direct solver context
@@ -913,7 +936,7 @@ PetscErrorCode DSNEPGetIntegrationPoints(DS ds,PetscInt *ip)
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidIntPointer(ip,2);
   PetscUseMethod(ds,"DSNEPGetIntegrationPoints_C",(DS,PetscInt*),(ds,ip));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DSNEPSetSamplingSize_NEP(DS ds,PetscInt p)
@@ -926,14 +949,14 @@ static PetscErrorCode DSNEPSetSamplingSize_NEP(DS ds,PetscInt p)
     PetscCheck(p>=20,PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"The sample size cannot be smaller than 20");
     ctx->spls = p;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSNEPSetSamplingSize - Sets the number of sampling columns to be
    used in the contour integral method.
 
-   Logically Collective on ds
+   Logically Collective
 
    Input Parameters:
 +  ds - the direct solver context
@@ -955,7 +978,7 @@ PetscErrorCode DSNEPSetSamplingSize(DS ds,PetscInt p)
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidLogicalCollectiveInt(ds,p,2);
   PetscTryMethod(ds,"DSNEPSetSamplingSize_C",(DS,PetscInt),(ds,p));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DSNEPGetSamplingSize_NEP(DS ds,PetscInt *p)
@@ -964,14 +987,14 @@ static PetscErrorCode DSNEPGetSamplingSize_NEP(DS ds,PetscInt *p)
 
   PetscFunctionBegin;
   *p = ctx->spls;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSNEPGetSamplingSize - Returns the number of sampling columns used
    in the contour integral method.
 
-   Not collective
+   Not Collective
 
    Input Parameter:
 .  ds - the direct solver context
@@ -989,7 +1012,7 @@ PetscErrorCode DSNEPGetSamplingSize(DS ds,PetscInt *p)
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidIntPointer(p,2);
   PetscUseMethod(ds,"DSNEPGetSamplingSize_C",(DS,PetscInt*),(ds,p));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DSNEPSetComputeMatrixFunction_NEP(DS ds,PetscErrorCode (*fun)(DS,PetscScalar,PetscBool,DSMatType,void*),void *ctx)
@@ -999,23 +1022,22 @@ static PetscErrorCode DSNEPSetComputeMatrixFunction_NEP(DS ds,PetscErrorCode (*f
   PetscFunctionBegin;
   dsctx->computematrix    = fun;
   dsctx->computematrixctx = ctx;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    DSNEPSetComputeMatrixFunction - Sets a user-provided subroutine to compute
    the matrices T(lambda) or T'(lambda).
 
-   Logically Collective on ds
+   Logically Collective
 
    Input Parameters:
 +  ds  - the direct solver context
 .  fun - a pointer to the user function
 -  ctx - a context pointer (the last parameter to the user function)
 
-   Calling Sequence of fun:
-$   fun(DS ds,PetscScalar lambda,PetscBool deriv,DSMatType mat,void *ctx)
-
+   Calling sequence of fun:
+$  PetscErrorCode fun(DS ds,PetscScalar lambda,PetscBool deriv,DSMatType mat,void *ctx)
 +   ds     - the direct solver object
 .   lambda - point where T(lambda) or T'(lambda) must be evaluated
 .   deriv  - if true compute T'(lambda), otherwise compute T(lambda)
@@ -1030,12 +1052,12 @@ $   fun(DS ds,PetscScalar lambda,PetscBool deriv,DSMatType mat,void *ctx)
 
 .seealso: DSNEPGetComputeMatrixFunction()
 @*/
-PetscErrorCode DSNEPSetComputeMatrixFunction(DS ds,PetscErrorCode (*fun)(DS,PetscScalar,PetscBool,DSMatType,void*),void *ctx)
+PetscErrorCode DSNEPSetComputeMatrixFunction(DS ds,PetscErrorCode (*fun)(DS ds,PetscScalar lambda,PetscBool deriv,DSMatType mat,void *ctx),void *ctx)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscTryMethod(ds,"DSNEPSetComputeMatrixFunction_C",(DS,PetscErrorCode (*)(DS,PetscScalar,PetscBool,DSMatType,void*),void*),(ds,fun,ctx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DSNEPGetComputeMatrixFunction_NEP(DS ds,PetscErrorCode (**fun)(DS,PetscScalar,PetscBool,DSMatType,void*),void **ctx)
@@ -1045,7 +1067,7 @@ static PetscErrorCode DSNEPGetComputeMatrixFunction_NEP(DS ds,PetscErrorCode (**
   PetscFunctionBegin;
   if (fun) *fun = dsctx->computematrix;
   if (ctx) *ctx = dsctx->computematrixctx;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1070,7 +1092,7 @@ PetscErrorCode DSNEPGetComputeMatrixFunction(DS ds,PetscErrorCode (**fun)(DS,Pet
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscUseMethod(ds,"DSNEPGetComputeMatrixFunction_C",(DS,PetscErrorCode (**)(DS,PetscScalar,PetscBool,DSMatType,void*),void**),(ds,fun,ctx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DSNEPSetRG_NEP(DS ds,RG rg)
@@ -1081,14 +1103,13 @@ static PetscErrorCode DSNEPSetRG_NEP(DS ds,RG rg)
   PetscCall(PetscObjectReference((PetscObject)rg));
   PetscCall(RGDestroy(&dsctx->rg));
   dsctx->rg = rg;
-  PetscCall(PetscLogObjectParent((PetscObject)ds,(PetscObject)dsctx->rg));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSNEPSetRG - Associates a region object to the DSNEP solver.
 
-   Logically Collective on ds
+   Collective
 
    Input Parameters:
 +  ds  - the direct solver context
@@ -1111,7 +1132,7 @@ PetscErrorCode DSNEPSetRG(DS ds,RG rg)
     PetscCheckSameComm(ds,1,rg,2);
   }
   PetscTryMethod(ds,"DSNEPSetRG_C",(DS,RG),(ds,rg));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DSNEPGetRG_NEP(DS ds,RG *rg)
@@ -1124,17 +1145,16 @@ static PetscErrorCode DSNEPGetRG_NEP(DS ds,RG *rg)
     PetscCall(PetscObjectIncrementTabLevel((PetscObject)ctx->rg,(PetscObject)ds,1));
     PetscCall(RGSetOptionsPrefix(ctx->rg,((PetscObject)ds)->prefix));
     PetscCall(RGAppendOptionsPrefix(ctx->rg,"ds_nep_"));
-    PetscCall(PetscLogObjectParent((PetscObject)ds,(PetscObject)ctx->rg));
     PetscCall(PetscObjectSetOptions((PetscObject)ctx->rg,((PetscObject)ds)->options));
   }
   *rg = ctx->rg;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSNEPGetRG - Obtain the region object associated to the DSNEP solver.
 
-   Not Collective
+   Collective
 
    Input Parameter:
 .  ds  - the direct solver context
@@ -1152,10 +1172,10 @@ PetscErrorCode DSNEPGetRG(DS ds,RG *rg)
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidPointer(rg,2);
   PetscUseMethod(ds,"DSNEPGetRG_C",(DS,RG*),(ds,rg));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode DSSetFromOptions_NEP(PetscOptionItems *PetscOptionsObject,DS ds)
+PetscErrorCode DSSetFromOptions_NEP(DS ds,PetscOptionItems *PetscOptionsObject)
 {
   PetscInt       k;
   PetscBool      flg;
@@ -1166,7 +1186,7 @@ PetscErrorCode DSSetFromOptions_NEP(PetscOptionItems *PetscOptionsObject,DS ds)
 #endif
 
   PetscFunctionBegin;
-  PetscCall(PetscOptionsHead(PetscOptionsObject,"DS NEP Options"));
+  PetscOptionsHeadBegin(PetscOptionsObject,"DS NEP Options");
 
     PetscCall(PetscOptionsInt("-ds_nep_minimality","Maximum minimality index","DSNEPSetMinimality",4,&k,&flg));
     if (flg) PetscCall(DSNEPSetMinimality(ds,k));
@@ -1190,8 +1210,8 @@ PetscErrorCode DSSetFromOptions_NEP(PetscOptionItems *PetscOptionsObject,DS ds)
     }
 #endif
 
-  PetscCall(PetscOptionsTail());
-  PetscFunctionReturn(0);
+  PetscOptionsHeadEnd();
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode DSDestroy_NEP(DS ds)
@@ -1219,7 +1239,7 @@ PetscErrorCode DSDestroy_NEP(DS ds)
   PetscCall(PetscObjectComposeFunction((PetscObject)ds,"DSNEPGetRG_C",NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)ds,"DSNEPSetComputeMatrixFunction_C",NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)ds,"DSNEPGetComputeMatrixFunction_C",NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode DSMatGetSize_NEP(DS ds,DSMatType t,PetscInt *rows,PetscInt *cols)
@@ -1228,9 +1248,10 @@ PetscErrorCode DSMatGetSize_NEP(DS ds,DSMatType t,PetscInt *rows,PetscInt *cols)
 
   PetscFunctionBegin;
   *rows = ds->n;
+  if (t==DS_MAT_Q || t==DS_MAT_Z || t==DS_MAT_U || t==DS_MAT_V) *rows *= ctx->max_mid;
   *cols = ds->n;
-  if (t==DS_MAT_X || t==DS_MAT_Y) *cols *= ctx->max_mid;
-  PetscFunctionReturn(0);
+  if (t==DS_MAT_Q || t==DS_MAT_Z || t==DS_MAT_U || t==DS_MAT_V || t==DS_MAT_X || t==DS_MAT_Y) *cols *= ctx->max_mid;
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -1250,9 +1271,13 @@ PetscErrorCode DSMatGetSize_NEP(DS ds,DSMatType t,PetscInt *rows,PetscInt *cols)
 
    Used DS matrices:
 +  DS_MAT_Ex - coefficient matrices of the split form of T(lambda)
-.  DS_MAT_A  - (workspace) T(lambda) evaluated at a given lambda
-.  DS_MAT_B  - (workspace) T'(lambda) evaluated at a given lambda
--  DS_MAT_W  - (workspace) eigenvectors of linearization in SLP
+.  DS_MAT_A  - (workspace) T(lambda) evaluated at a given lambda (SLP only)
+.  DS_MAT_B  - (workspace) T'(lambda) evaluated at a given lambda (SLP only)
+.  DS_MAT_Q  - (workspace) left Hankel matrix (contour only)
+.  DS_MAT_Z  - (workspace) right Hankel matrix (contour only)
+.  DS_MAT_U  - (workspace) left singular vectors (contour only)
+.  DS_MAT_V  - (workspace) right singular vectors (contour only)
+-  DS_MAT_W  - (workspace) auxiliary matrix of size nxn
 
    Implemented methods:
 +  0 - Successive Linear Problems (SLP), computes just one eigenpair
@@ -1265,7 +1290,7 @@ SLEPC_EXTERN PetscErrorCode DSCreate_NEP(DS ds)
   DS_NEP         *ctx;
 
   PetscFunctionBegin;
-  PetscCall(PetscNewLog(ds,&ctx));
+  PetscCall(PetscNew(&ctx));
   ds->data = (void*)ctx;
   ctx->max_mid = 4;
   ctx->nnod    = 64;
@@ -1281,7 +1306,9 @@ SLEPC_EXTERN PetscErrorCode DSCreate_NEP(DS ds)
   ds->ops->solve[1]       = DSSolve_NEP_Contour;
 #endif
   ds->ops->sort           = DSSort_NEP;
+#if !defined(PETSC_HAVE_MPIUNI)
   ds->ops->synchronize    = DSSynchronize_NEP;
+#endif
   ds->ops->destroy        = DSDestroy_NEP;
   ds->ops->matgetsize     = DSMatGetSize_NEP;
 
@@ -1300,5 +1327,5 @@ SLEPC_EXTERN PetscErrorCode DSCreate_NEP(DS ds)
   PetscCall(PetscObjectComposeFunction((PetscObject)ds,"DSNEPGetRG_C",DSNEPGetRG_NEP));
   PetscCall(PetscObjectComposeFunction((PetscObject)ds,"DSNEPSetComputeMatrixFunction_C",DSNEPSetComputeMatrixFunction_NEP));
   PetscCall(PetscObjectComposeFunction((PetscObject)ds,"DSNEPGetComputeMatrixFunction_C",DSNEPGetComputeMatrixFunction_NEP));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
