@@ -38,7 +38,7 @@ PetscErrorCode DSFinalizePackage(void)
   PetscCall(PetscFunctionListDestroy(&DSList));
   DSPackageInitialized = PETSC_FALSE;
   DSRegisterAllCalled  = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -57,7 +57,7 @@ PetscErrorCode DSInitializePackage(void)
   PetscClassId   classids[1];
 
   PetscFunctionBegin;
-  if (DSPackageInitialized) PetscFunctionReturn(0);
+  if (DSPackageInitialized) PetscFunctionReturn(PETSC_SUCCESS);
   DSPackageInitialized = PETSC_TRUE;
   /* Register Classes */
   PetscCall(PetscClassIdRegister("Direct Solver",&DS_CLASSID));
@@ -79,7 +79,7 @@ PetscErrorCode DSInitializePackage(void)
   }
   /* Register package finalizer */
   PetscCall(PetscRegisterFinalize(DSFinalizePackage));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -138,14 +138,14 @@ PetscErrorCode DSCreate(MPI_Comm comm,DS *newds)
   ds->liwork        = 0;
 
   *newds = ds;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    DSSetOptionsPrefix - Sets the prefix used for searching for all
    DS options in the database.
 
-   Logically Collective on ds
+   Logically Collective
 
    Input Parameters:
 +  ds - the direct solver context
@@ -165,14 +165,14 @@ PetscErrorCode DSSetOptionsPrefix(DS ds,const char *prefix)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscCall(PetscObjectSetOptionsPrefix((PetscObject)ds,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    DSAppendOptionsPrefix - Appends to the prefix used for searching for all
    DS options in the database.
 
-   Logically Collective on ds
+   Logically Collective
 
    Input Parameters:
 +  ds - the direct solver context
@@ -191,7 +191,7 @@ PetscErrorCode DSAppendOptionsPrefix(DS ds,const char *prefix)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscCall(PetscObjectAppendOptionsPrefix((PetscObject)ds,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -220,13 +220,13 @@ PetscErrorCode DSGetOptionsPrefix(DS ds,const char *prefix[])
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidPointer(prefix,2);
   PetscCall(PetscObjectGetOptionsPrefix((PetscObject)ds,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    DSSetType - Selects the type for the DS object.
 
-   Logically Collective on ds
+   Logically Collective
 
    Input Parameters:
 +  ds   - the direct solver context
@@ -246,7 +246,7 @@ PetscErrorCode DSSetType(DS ds,DSType type)
   PetscValidCharPointer(type,2);
 
   PetscCall(PetscObjectTypeCompare((PetscObject)ds,type,&match));
-  if (match) PetscFunctionReturn(0);
+  if (match) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscFunctionListFind(DSList,type,&r));
   PetscCheck(r,PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_UNKNOWN_TYPE,"Unable to find requested DS type %s",type);
@@ -255,7 +255,7 @@ PetscErrorCode DSSetType(DS ds,DSType type)
 
   PetscCall(PetscObjectChangeTypeName((PetscObject)ds,type));
   PetscCall((*r)(ds));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -279,14 +279,14 @@ PetscErrorCode DSGetType(DS ds,DSType *type)
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidPointer(type,2);
   *type = ((PetscObject)ds)->type_name;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSDuplicate - Creates a new direct solver object with the same options as
    an existing one.
 
-   Collective on ds
+   Collective
 
    Input Parameter:
 .  ds - direct solver context
@@ -317,13 +317,13 @@ PetscErrorCode DSDuplicate(DS ds,DS *dsnew)
   (*dsnew)->extrarow = ds->extrarow;
   (*dsnew)->bs       = ds->bs;
   (*dsnew)->pmode    = ds->pmode;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSSetMethod - Selects the method to be used to solve the problem.
 
-   Logically Collective on ds
+   Logically Collective
 
    Input Parameters:
 +  ds   - the direct solver context
@@ -344,7 +344,7 @@ PetscErrorCode DSSetMethod(DS ds,PetscInt meth)
   PetscCheck(meth>=0,PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"The method must be a non-negative integer");
   PetscCheck(meth<=DS_MAX_SOLVE,PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"Too large value for the method");
   ds->method = meth;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -368,13 +368,13 @@ PetscErrorCode DSGetMethod(DS ds,PetscInt *meth)
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidIntPointer(meth,2);
   *meth = ds->method;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSSetParallel - Selects the mode of operation in parallel runs.
 
-   Logically Collective on ds
+   Logically Collective
 
    Input Parameters:
 +  ds    - the direct solver context
@@ -409,7 +409,7 @@ PetscErrorCode DSSetParallel(DS ds,DSParallelType pmode)
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidLogicalCollectiveEnum(ds,pmode,2);
   ds->pmode = pmode;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -433,13 +433,13 @@ PetscErrorCode DSGetParallel(DS ds,DSParallelType *pmode)
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidPointer(pmode,2);
   *pmode = ds->pmode;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSSetCompact - Switch to compact storage of matrices.
 
-   Logically Collective on ds
+   Logically Collective
 
    Input Parameters:
 +  ds   - the direct solver context
@@ -463,7 +463,7 @@ PetscErrorCode DSSetCompact(DS ds,PetscBool comp)
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidLogicalCollectiveBool(ds,comp,2);
   ds->compact = comp;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -487,14 +487,14 @@ PetscErrorCode DSGetCompact(DS ds,PetscBool *comp)
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidBoolPointer(comp,2);
   *comp = ds->compact;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSSetExtraRow - Sets a flag to indicate that the matrix has one extra
    row.
 
-   Logically Collective on ds
+   Logically Collective
 
    Input Parameters:
 +  ds  - the direct solver context
@@ -519,7 +519,7 @@ PetscErrorCode DSSetExtraRow(DS ds,PetscBool ext)
   PetscValidLogicalCollectiveBool(ds,ext,2);
   PetscCheck(!ext || ds->n==0 || ds->n!=ds->ld,PetscObjectComm((PetscObject)ds),PETSC_ERR_ORDER,"Cannot set extra row after setting n=ld");
   ds->extrarow = ext;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -543,14 +543,14 @@ PetscErrorCode DSGetExtraRow(DS ds,PetscBool *ext)
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidBoolPointer(ext,2);
   *ext = ds->extrarow;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSSetRefined - Sets a flag to indicate that refined vectors must be
    computed.
 
-   Logically Collective on ds
+   Logically Collective
 
    Input Parameters:
 +  ds  - the direct solver context
@@ -576,7 +576,7 @@ PetscErrorCode DSSetRefined(DS ds,PetscBool ref)
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidLogicalCollectiveBool(ds,ref,2);
   ds->refined = ref;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -600,13 +600,13 @@ PetscErrorCode DSGetRefined(DS ds,PetscBool *ref)
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidBoolPointer(ref,2);
   *ref = ds->refined;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSSetBlockSize - Sets the block size.
 
-   Logically Collective on ds
+   Logically Collective
 
    Input Parameters:
 +  ds - the direct solver context
@@ -626,7 +626,7 @@ PetscErrorCode DSSetBlockSize(DS ds,PetscInt bs)
   PetscValidLogicalCollectiveInt(ds,bs,2);
   PetscCheck(bs>0,PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"The block size must be at least one");
   ds->bs = bs;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -650,13 +650,13 @@ PetscErrorCode DSGetBlockSize(DS ds,PetscInt *bs)
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidIntPointer(bs,2);
   *bs = ds->bs;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    DSSetSlepcSC - Sets the sorting criterion context.
 
-   Not Collective
+   Logically Collective
 
    Input Parameters:
 +  ds - the direct solver context
@@ -674,7 +674,7 @@ PetscErrorCode DSSetSlepcSC(DS ds,SlepcSC sc)
   if (ds->sc && !ds->scset) PetscCall(PetscFree(ds->sc));
   ds->sc    = sc;
   ds->scset = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -699,13 +699,13 @@ PetscErrorCode DSGetSlepcSC(DS ds,SlepcSC *sc)
   PetscValidPointer(sc,2);
   if (!ds->sc) PetscCall(PetscNew(&ds->sc));
   *sc = ds->sc;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSSetFromOptions - Sets DS options from the options database.
 
-   Collective on ds
+   Collective
 
    Input Parameters:
 .  ds - the direct solver context
@@ -742,13 +742,13 @@ PetscErrorCode DSSetFromOptions(DS ds)
     PetscTryTypeMethod(ds,setfromoptions,PetscOptionsObject);
     PetscCall(PetscObjectProcessOptionsHandlers((PetscObject)ds,PetscOptionsObject));
   PetscOptionsEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    DSView - Prints the DS data structure.
 
-   Collective on ds
+   Collective
 
    Input Parameters:
 +  ds - the direct solver context
@@ -797,13 +797,13 @@ PetscErrorCode DSView(DS ds,PetscViewer viewer)
     PetscTryTypeMethod(ds,view,viewer);
     PetscCall(PetscViewerASCIIPopTab(viewer));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    DSViewFromOptions - View from options
 
-   Collective on DS
+   Collective
 
    Input Parameters:
 +  ds   - the direct solver context
@@ -819,13 +819,13 @@ PetscErrorCode DSViewFromOptions(DS ds,PetscObject obj,const char name[])
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscCall(PetscObjectViewFromOptions((PetscObject)ds,obj,name));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSAllocate - Allocates memory for internal storage or matrices in DS.
 
-   Logically Collective on ds
+   Logically Collective
 
    Input Parameters:
 +  ds - the direct solver context
@@ -853,13 +853,13 @@ PetscErrorCode DSAllocate(DS ds,PetscInt ld)
     ds->ld = ld;
     PetscUseTypeMethod(ds,allocate,ld);
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DSReset - Resets the DS context to the initial state.
 
-   Collective on ds
+   Collective
 
    Input Parameter:
 .  ds - the direct solver context
@@ -878,7 +878,7 @@ PetscErrorCode DSReset(DS ds)
 
   PetscFunctionBegin;
   if (ds) PetscValidHeaderSpecific(ds,DS_CLASSID,1);
-  if (!ds) PetscFunctionReturn(0);
+  if (!ds) PetscFunctionReturn(PETSC_SUCCESS);
   ds->state    = DS_STATE_RAW;
   ds->ld       = 0;
   ds->l        = 0;
@@ -886,13 +886,13 @@ PetscErrorCode DSReset(DS ds)
   ds->k        = 0;
   for (i=0;i<DS_NUM_MAT;i++) PetscCall(MatDestroy(&ds->omat[i]));
   PetscCall(PetscFree(ds->perm));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    DSDestroy - Destroys DS context that was created with DSCreate().
 
-   Collective on ds
+   Collective
 
    Input Parameter:
 .  ds - the direct solver context
@@ -904,9 +904,9 @@ PetscErrorCode DSReset(DS ds)
 PetscErrorCode DSDestroy(DS *ds)
 {
   PetscFunctionBegin;
-  if (!*ds) PetscFunctionReturn(0);
+  if (!*ds) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeaderSpecific(*ds,DS_CLASSID,1);
-  if (--((PetscObject)(*ds))->refct > 0) { *ds = NULL; PetscFunctionReturn(0); }
+  if (--((PetscObject)(*ds))->refct > 0) { *ds = NULL; PetscFunctionReturn(PETSC_SUCCESS); }
   PetscCall(DSReset(*ds));
   PetscTryTypeMethod(*ds,destroy);
   PetscCall(PetscFree((*ds)->work));
@@ -914,13 +914,13 @@ PetscErrorCode DSDestroy(DS *ds)
   PetscCall(PetscFree((*ds)->iwork));
   if (!(*ds)->scset) PetscCall(PetscFree((*ds)->sc));
   PetscCall(PetscHeaderDestroy(ds));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    DSRegister - Adds a direct solver to the DS package.
 
-   Not collective
+   Not Collective
 
    Input Parameters:
 +  name - name of a new user-defined DS
@@ -939,7 +939,7 @@ PetscErrorCode DSRegister(const char *name,PetscErrorCode (*function)(DS))
   PetscFunctionBegin;
   PetscCall(DSInitializePackage());
   PetscCall(PetscFunctionListAdd(&DSList,name,function));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 SLEPC_EXTERN PetscErrorCode DSCreate_HEP(DS);
@@ -949,6 +949,7 @@ SLEPC_EXTERN PetscErrorCode DSCreate_GHIEP(DS);
 SLEPC_EXTERN PetscErrorCode DSCreate_GNHEP(DS);
 SLEPC_EXTERN PetscErrorCode DSCreate_NHEPTS(DS);
 SLEPC_EXTERN PetscErrorCode DSCreate_SVD(DS);
+SLEPC_EXTERN PetscErrorCode DSCreate_HSVD(DS);
 SLEPC_EXTERN PetscErrorCode DSCreate_GSVD(DS);
 SLEPC_EXTERN PetscErrorCode DSCreate_PEP(DS);
 SLEPC_EXTERN PetscErrorCode DSCreate_NEP(DS);
@@ -965,7 +966,7 @@ SLEPC_EXTERN PetscErrorCode DSCreate_NEP(DS);
 PetscErrorCode DSRegisterAll(void)
 {
   PetscFunctionBegin;
-  if (DSRegisterAllCalled) PetscFunctionReturn(0);
+  if (DSRegisterAllCalled) PetscFunctionReturn(PETSC_SUCCESS);
   DSRegisterAllCalled = PETSC_TRUE;
   PetscCall(DSRegister(DSHEP,DSCreate_HEP));
   PetscCall(DSRegister(DSNHEP,DSCreate_NHEP));
@@ -974,8 +975,9 @@ PetscErrorCode DSRegisterAll(void)
   PetscCall(DSRegister(DSGNHEP,DSCreate_GNHEP));
   PetscCall(DSRegister(DSNHEPTS,DSCreate_NHEPTS));
   PetscCall(DSRegister(DSSVD,DSCreate_SVD));
+  PetscCall(DSRegister(DSHSVD,DSCreate_HSVD));
   PetscCall(DSRegister(DSGSVD,DSCreate_GSVD));
   PetscCall(DSRegister(DSPEP,DSCreate_PEP));
   PetscCall(DSRegister(DSNEP,DSCreate_NEP));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
