@@ -18,12 +18,13 @@ int main(int argc,char **argv)
   SlepcSC        sc;
   Mat            X;
   Vec            x0;
-  PetscReal      sigma,rnorm;
+  PetscReal      sigma,rnorm,cond;
   PetscScalar    *A,*B,*w;
   PetscInt       i,j,k,n=15,m=10,p=10,m1,p1,ld;
   PetscViewer    viewer;
   PetscBool      verbose;
 
+  PetscFunctionBeginUser;
   PetscCall(SlepcInitialize(&argc,&argv,(char*)0,help));
   PetscCall(PetscOptionsGetInt(NULL,NULL,"-n",&n,NULL));
   PetscCall(PetscOptionsGetInt(NULL,NULL,"-m",&m,NULL));
@@ -76,6 +77,10 @@ int main(int argc,char **argv)
   }
   PetscCall(DSView(ds,viewer));
 
+  /* Condition number */
+  PetscCall(DSCond(ds,&cond));
+  PetscCall(PetscPrintf(PETSC_COMM_WORLD,"Condition number = %.3f\n",(double)cond));
+
   /* Solve */
   PetscCall(PetscMalloc1(m,&w));
   PetscCall(DSGetSlepcSC(ds,&sc));
@@ -104,7 +109,7 @@ int main(int argc,char **argv)
   PetscCall(MatCreateVecs(X,NULL,&x0));
   PetscCall(MatGetColumnVector(X,x0,0));
   PetscCall(VecNorm(x0,NORM_2,&rnorm));
-  PetscCall(MatDestroy(&X));
+  PetscCall(DSRestoreMat(ds,DS_MAT_X,&X));
   PetscCall(VecDestroy(&x0));
   PetscCall(PetscPrintf(PETSC_COMM_WORLD,"Norm of 1st X vector = %.3f\n",(double)rnorm));
 
@@ -112,7 +117,7 @@ int main(int argc,char **argv)
   PetscCall(MatCreateVecs(X,NULL,&x0));
   PetscCall(MatGetColumnVector(X,x0,0));
   PetscCall(VecNorm(x0,NORM_2,&rnorm));
-  PetscCall(MatDestroy(&X));
+  PetscCall(DSRestoreMat(ds,DS_MAT_U,&X));
   PetscCall(VecDestroy(&x0));
   if (PetscAbs(rnorm-1.0)>10*PETSC_MACHINE_EPSILON) PetscCall(PetscPrintf(PETSC_COMM_WORLD,"Warning: the 1st U vector has norm %g\n",(double)rnorm));
 
@@ -120,7 +125,7 @@ int main(int argc,char **argv)
   PetscCall(MatCreateVecs(X,NULL,&x0));
   PetscCall(MatGetColumnVector(X,x0,0));
   PetscCall(VecNorm(x0,NORM_2,&rnorm));
-  PetscCall(MatDestroy(&X));
+  PetscCall(DSRestoreMat(ds,DS_MAT_V,&X));
   PetscCall(VecDestroy(&x0));
   if (PetscAbs(rnorm-1.0)>10*PETSC_MACHINE_EPSILON) PetscCall(PetscPrintf(PETSC_COMM_WORLD,"Warning: the 1st V vector has norm %g\n",(double)rnorm));
 
@@ -136,7 +141,7 @@ int main(int argc,char **argv)
       output_file: output/test21_1.out
       requires: !single
       nsize: {{1 2 3}}
-      filter: grep -v "parallel operation mode" | grep -v "MPI processes"
+      filter: grep -v "parallel operation mode" | grep -v " MPI process"
       test:
          suffix: 1
          args: -ds_parallel redundant
