@@ -18,12 +18,13 @@ int main(int argc,char **argv)
   Mat            X;
   Vec            x0;
   SlepcSC        sc;
-  PetscReal      *T,*D,sigma,rnorm,aux;
+  PetscReal      *T,*D,sigma,rnorm,aux,cond;
   PetscScalar    *U,*V,*w,d;
   PetscInt       i,n=10,m,l=0,k=0,ld;
   PetscViewer    viewer;
   PetscBool      verbose,extrarow;
 
+  PetscFunctionBeginUser;
   PetscCall(SlepcInitialize(&argc,&argv,(char*)0,help));
   PetscCall(PetscOptionsGetInt(NULL,NULL,"-n",&n,NULL));
   PetscCall(PetscPrintf(PETSC_COMM_WORLD,"Solve a Dense System of type GSVD with compact storage - dimension %" PetscInt_FMT "x%" PetscInt_FMT ".\n",n+1,n));
@@ -86,6 +87,10 @@ int main(int argc,char **argv)
     PetscCall(DSView(ds,viewer));
   }
 
+  /* Condition number */
+  PetscCall(DSCond(ds,&cond));
+  PetscCall(PetscPrintf(PETSC_COMM_WORLD,"Condition number = %.3f\n",(double)cond));
+
   /* Solve */
   PetscCall(DSGetSlepcSC(ds,&sc));
   sc->comparison    = SlepcCompareLargestReal;
@@ -130,7 +135,7 @@ int main(int argc,char **argv)
   PetscCall(MatCreateVecs(X,NULL,&x0));
   PetscCall(MatGetColumnVector(X,x0,0));
   PetscCall(VecNorm(x0,NORM_2,&rnorm));
-  PetscCall(MatDestroy(&X));
+  PetscCall(DSRestoreMat(ds,DS_MAT_X,&X));
   PetscCall(VecDestroy(&x0));
   PetscCall(PetscPrintf(PETSC_COMM_WORLD,"Norm of 1st X vector = %.3f\n",(double)rnorm));
 
@@ -138,7 +143,7 @@ int main(int argc,char **argv)
   PetscCall(MatCreateVecs(X,NULL,&x0));
   PetscCall(MatGetColumnVector(X,x0,0));
   PetscCall(VecNorm(x0,NORM_2,&rnorm));
-  PetscCall(MatDestroy(&X));
+  PetscCall(DSRestoreMat(ds,DS_MAT_U,&X));
   PetscCall(VecDestroy(&x0));
   if (PetscAbs(rnorm-1.0)>10*PETSC_MACHINE_EPSILON) PetscCall(PetscPrintf(PETSC_COMM_WORLD,"Warning: the 1st U vector has norm %g\n",(double)rnorm));
 
@@ -146,7 +151,7 @@ int main(int argc,char **argv)
   PetscCall(MatCreateVecs(X,NULL,&x0));
   PetscCall(MatGetColumnVector(X,x0,0));
   PetscCall(VecNorm(x0,NORM_2,&rnorm));
-  PetscCall(MatDestroy(&X));
+  PetscCall(DSRestoreMat(ds,DS_MAT_V,&X));
   PetscCall(VecDestroy(&x0));
   if (PetscAbs(rnorm-1.0)>10*PETSC_MACHINE_EPSILON) PetscCall(PetscPrintf(PETSC_COMM_WORLD,"Warning: the 1st V vector has norm %g\n",(double)rnorm));
 
