@@ -73,7 +73,7 @@ PetscErrorCode TestMatInvSqrt(FN fn,Mat A,PetscViewer viewer,PetscBool verbose,P
   PetscCall(MatDestroy(&S));
   PetscCall(VecDestroy(&v));
   PetscCall(VecDestroy(&f0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 int main(int argc,char **argv)
