@@ -32,7 +32,7 @@ PetscErrorCode RGFinalizePackage(void)
   PetscCall(PetscFunctionListDestroy(&RGList));
   RGPackageInitialized = PETSC_FALSE;
   RGRegisterAllCalled  = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -51,7 +51,7 @@ PetscErrorCode RGInitializePackage(void)
   PetscClassId   classids[1];
 
   PetscFunctionBegin;
-  if (RGPackageInitialized) PetscFunctionReturn(0);
+  if (RGPackageInitialized) PetscFunctionReturn(PETSC_SUCCESS);
   RGPackageInitialized = PETSC_TRUE;
   /* Register Classes */
   PetscCall(PetscClassIdRegister("Region",&RG_CLASSID));
@@ -68,7 +68,7 @@ PetscErrorCode RGInitializePackage(void)
   }
   /* Register package finalizer */
   PetscCall(PetscRegisterFinalize(RGFinalizePackage));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -101,14 +101,14 @@ PetscErrorCode RGCreate(MPI_Comm comm,RG *newrg)
   rg->data       = NULL;
 
   *newrg = rg;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    RGSetOptionsPrefix - Sets the prefix used for searching for all
    RG options in the database.
 
-   Logically Collective on rg
+   Logically Collective
 
    Input Parameters:
 +  rg     - the region context
@@ -128,14 +128,14 @@ PetscErrorCode RGSetOptionsPrefix(RG rg,const char *prefix)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(rg,RG_CLASSID,1);
   PetscCall(PetscObjectSetOptionsPrefix((PetscObject)rg,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    RGAppendOptionsPrefix - Appends to the prefix used for searching for all
    RG options in the database.
 
-   Logically Collective on rg
+   Logically Collective
 
    Input Parameters:
 +  rg     - the region context
@@ -154,7 +154,7 @@ PetscErrorCode RGAppendOptionsPrefix(RG rg,const char *prefix)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(rg,RG_CLASSID,1);
   PetscCall(PetscObjectAppendOptionsPrefix((PetscObject)rg,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -183,13 +183,13 @@ PetscErrorCode RGGetOptionsPrefix(RG rg,const char *prefix[])
   PetscValidHeaderSpecific(rg,RG_CLASSID,1);
   PetscValidPointer(prefix,2);
   PetscCall(PetscObjectGetOptionsPrefix((PetscObject)rg,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    RGSetType - Selects the type for the RG object.
 
-   Logically Collective on rg
+   Logically Collective
 
    Input Parameters:
 +  rg   - the region context
@@ -209,7 +209,7 @@ PetscErrorCode RGSetType(RG rg,RGType type)
   PetscValidCharPointer(type,2);
 
   PetscCall(PetscObjectTypeCompare((PetscObject)rg,type,&match));
-  if (match) PetscFunctionReturn(0);
+  if (match) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscFunctionListFind(RGList,type,&r));
   PetscCheck(r,PetscObjectComm((PetscObject)rg),PETSC_ERR_ARG_UNKNOWN_TYPE,"Unable to find requested RG type %s",type);
@@ -219,7 +219,7 @@ PetscErrorCode RGSetType(RG rg,RGType type)
 
   PetscCall(PetscObjectChangeTypeName((PetscObject)rg,type));
   PetscCall((*r)(rg));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -243,13 +243,13 @@ PetscErrorCode RGGetType(RG rg,RGType *type)
   PetscValidHeaderSpecific(rg,RG_CLASSID,1);
   PetscValidPointer(type,2);
   *type = ((PetscObject)rg)->type_name;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    RGSetFromOptions - Sets RG options from the options database.
 
-   Collective on rg
+   Collective
 
    Input Parameters:
 .  rg - the region context
@@ -283,13 +283,13 @@ PetscErrorCode RGSetFromOptions(RG rg)
     PetscTryTypeMethod(rg,setfromoptions,PetscOptionsObject);
     PetscCall(PetscObjectProcessOptionsHandlers((PetscObject)rg,PetscOptionsObject));
   PetscOptionsEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    RGView - Prints the RG data structure.
 
-   Collective on rg
+   Collective
 
    Input Parameters:
 +  rg - the region context
@@ -329,13 +329,13 @@ PetscErrorCode RGView(RG rg,PetscViewer viewer)
     if (rg->complement) PetscCall(PetscViewerASCIIPrintf(viewer,"  selected region is the complement of the specified one\n"));
     if (rg->sfactor!=1.0) PetscCall(PetscViewerASCIIPrintf(viewer,"  scaling factor = %g\n",(double)rg->sfactor));
   } else if (isdraw) PetscTryTypeMethod(rg,view,viewer);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    RGViewFromOptions - View from options
 
-   Collective on RG
+   Collective
 
    Input Parameters:
 +  rg   - the region context
@@ -351,7 +351,7 @@ PetscErrorCode RGViewFromOptions(RG rg,PetscObject obj,const char name[])
   PetscFunctionBegin;
   PetscValidHeaderSpecific(rg,RG_CLASSID,1);
   PetscCall(PetscObjectViewFromOptions((PetscObject)rg,obj,name));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -379,7 +379,7 @@ PetscErrorCode RGIsTrivial(RG rg,PetscBool *trivial)
   PetscValidBoolPointer(trivial,2);
   *trivial = PETSC_FALSE;
   PetscTryTypeMethod(rg,istrivial,trivial);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -436,7 +436,7 @@ PetscErrorCode RGCheckInside(RG rg,PetscInt n,PetscScalar *ar,PetscScalar *ai,Pe
     PetscUseTypeMethod(rg,checkinside,px,py,inside+i);
     if (PetscUnlikely(rg->complement)) inside[i] = -inside[i];
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -468,7 +468,7 @@ PetscErrorCode RGIsAxisymmetric(RG rg,PetscBool vertical,PetscBool *symm)
   PetscValidBoolPointer(symm,3);
   *symm = PETSC_FALSE;
   PetscTryTypeMethod(rg,isaxisymmetric,vertical,symm);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -516,7 +516,7 @@ PetscErrorCode RGCanUseConjugates(RG rg,PetscBool realmats,PetscBool *useconj)
     }
   }
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -560,7 +560,7 @@ PetscErrorCode RGComputeContour(RG rg,PetscInt n,PetscScalar cr[],PetscScalar ci
     if (cr) cr[i] *= rg->sfactor;
     if (ci) ci[i] *= rg->sfactor;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -605,7 +605,7 @@ PetscErrorCode RGComputeBoundingBox(RG rg,PetscReal *a,PetscReal *b,PetscReal *c
     if (c && *c!=-PETSC_MAX_REAL) *c *= rg->sfactor;
     if (d && *d!= PETSC_MAX_REAL) *d *= rg->sfactor;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -647,14 +647,14 @@ PetscErrorCode RGComputeQuadrature(RG rg,RGQuadRule quad,PetscInt n,PetscScalar
 
   PetscCall(RGComputeContour(rg,n,z,NULL));
   PetscUseTypeMethod(rg,computequadrature,quad,n,z,zn,w);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    RGSetComplement - Sets a flag to indicate that the region is the complement
    of the specified one.
 
-   Logically Collective on rg
+   Logically Collective
 
    Input Parameters:
 +  rg  - the region context
@@ -673,7 +673,7 @@ PetscErrorCode RGSetComplement(RG rg,PetscBool flg)
   PetscValidHeaderSpecific(rg,RG_CLASSID,1);
   PetscValidLogicalCollectiveBool(rg,flg,2);
   rg->complement = flg;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -698,14 +698,14 @@ PetscErrorCode RGGetComplement(RG rg,PetscBool *flg)
   PetscValidHeaderSpecific(rg,RG_CLASSID,1);
   PetscValidBoolPointer(flg,2);
   *flg = rg->complement;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    RGSetScale - Sets the scaling factor to be used when checking that a
    point is inside the region and when computing the contour.
 
-   Logically Collective on rg
+   Logically Collective
 
    Input Parameters:
 +  rg      - the region context
@@ -723,12 +723,10 @@ PetscErrorCode RGSetScale(RG rg,PetscReal sfactor)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(rg,RG_CLASSID,1);
   PetscValidLogicalCollectiveReal(rg,sfactor,2);
-  if (sfactor == PETSC_DEFAULT || sfactor == PETSC_DECIDE) rg->sfactor = 1.0;
-  else {
-    PetscCheck(sfactor>0.0,PetscObjectComm((PetscObject)rg),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of scaling factor. Must be > 0");
-    rg->sfactor = sfactor;
-  }
-  PetscFunctionReturn(0);
+  if (sfactor == (PetscReal)PETSC_DEFAULT || sfactor == (PetscReal)PETSC_DECIDE) sfactor = 1.0;
+  PetscCheck(sfactor>0.0,PetscObjectComm((PetscObject)rg),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of scaling factor. Must be > 0");
+  rg->sfactor = sfactor;
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -752,14 +750,14 @@ PetscErrorCode RGGetScale(RG rg,PetscReal *sfactor)
   PetscValidHeaderSpecific(rg,RG_CLASSID,1);
   PetscValidRealPointer(sfactor,2);
   *sfactor = rg->sfactor;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    RGPushScale - Sets an additional scaling factor, that will multiply the
    user-defined scaling factor.
 
-   Logically Collective on rg
+   Logically Collective
 
    Input Parameters:
 +  rg      - the region context
@@ -784,13 +782,13 @@ PetscErrorCode RGPushScale(RG rg,PetscReal sfactor)
   PetscCheck(!rg->osfactor,PetscObjectComm((PetscObject)rg),PETSC_ERR_SUP,"Current implementation does not allow pushing several scaling factors");
   rg->osfactor = rg->sfactor;
   rg->sfactor *= sfactor;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    RGPopScale - Pops the scaling factor set with RGPushScale().
 
-   Not Collective
+   Logically Collective
 
    Input Parameter:
 .  rg - the region context
@@ -806,13 +804,13 @@ PetscErrorCode RGPopScale(RG rg)
   PetscCheck(rg->osfactor,PetscObjectComm((PetscObject)rg),PETSC_ERR_ORDER,"Must call RGPushScale first");
   rg->sfactor  = rg->osfactor;
   rg->osfactor = 0.0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    RGDestroy - Destroys RG context that was created with RGCreate().
 
-   Collective on rg
+   Collective
 
    Input Parameter:
 .  rg - the region context
@@ -824,18 +822,18 @@ PetscErrorCode RGPopScale(RG rg)
 PetscErrorCode RGDestroy(RG *rg)
 {
   PetscFunctionBegin;
-  if (!*rg) PetscFunctionReturn(0);
+  if (!*rg) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeaderSpecific(*rg,RG_CLASSID,1);
-  if (--((PetscObject)(*rg))->refct > 0) { *rg = NULL; PetscFunctionReturn(0); }
+  if (--((PetscObject)(*rg))->refct > 0) { *rg = NULL; PetscFunctionReturn(PETSC_SUCCESS); }
   PetscTryTypeMethod(*rg,destroy);
   PetscCall(PetscHeaderDestroy(rg));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    RGRegister - Adds a region to the RG package.
 
-   Not collective
+   Not Collective
 
    Input Parameters:
 +  name - name of a new user-defined RG
@@ -853,5 +851,5 @@ PetscErrorCode RGRegister(const char *name,PetscErrorCode (*function)(RG))
   PetscFunctionBegin;
   PetscCall(RGInitializePackage());
   PetscCall(PetscFunctionListAdd(&RGList,name,function));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
