@@ -33,7 +33,7 @@ PetscErrorCode STFinalizePackage(void)
   PetscCall(PetscFunctionListDestroy(&STList));
   STPackageInitialized = PETSC_FALSE;
   STRegisterAllCalled  = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -52,7 +52,7 @@ PetscErrorCode STInitializePackage(void)
   PetscClassId   classids[1];
 
   PetscFunctionBegin;
-  if (STPackageInitialized) PetscFunctionReturn(0);
+  if (STPackageInitialized) PetscFunctionReturn(PETSC_SUCCESS);
   STPackageInitialized = PETSC_TRUE;
   /* Register Classes */
   PetscCall(PetscClassIdRegister("Spectral Transform",&ST_CLASSID));
@@ -79,14 +79,14 @@ PetscErrorCode STInitializePackage(void)
   }
   /* Register package finalizer */
   PetscCall(PetscRegisterFinalize(STFinalizePackage));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    STReset - Resets the ST context to the initial state (prior to setup)
    and destroys any allocated Vecs and Mats.
 
-   Collective on st
+   Collective
 
    Input Parameter:
 .  st - the spectral transformation context
@@ -99,7 +99,7 @@ PetscErrorCode STReset(ST st)
 {
   PetscFunctionBegin;
   if (st) PetscValidHeaderSpecific(st,ST_CLASSID,1);
-  if (!st) PetscFunctionReturn(0);
+  if (!st) PetscFunctionReturn(PETSC_SUCCESS);
   STCheckNotSeized(st,1);
   PetscTryTypeMethod(st,reset);
   if (st->ksp) PetscCall(KSPReset(st->ksp));
@@ -119,13 +119,13 @@ PetscErrorCode STReset(ST st)
   PetscCall(VecDestroy(&st->D));
   st->state   = ST_STATE_INITIAL;
   st->opready = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    STDestroy - Destroys ST context that was created with STCreate().
 
-   Collective on st
+   Collective
 
    Input Parameter:
 .  st - the spectral transformation context
@@ -137,14 +137,14 @@ PetscErrorCode STReset(ST st)
 PetscErrorCode STDestroy(ST *st)
 {
   PetscFunctionBegin;
-  if (!*st) PetscFunctionReturn(0);
+  if (!*st) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeaderSpecific(*st,ST_CLASSID,1);
-  if (--((PetscObject)(*st))->refct > 0) { *st = NULL; PetscFunctionReturn(0); }
+  if (--((PetscObject)(*st))->refct > 0) { *st = NULL; PetscFunctionReturn(PETSC_SUCCESS); }
   PetscCall(STReset(*st));
   PetscTryTypeMethod(*st,destroy);
   PetscCall(KSPDestroy(&(*st)->ksp));
   PetscCall(PetscHeaderDestroy(st));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -206,7 +206,7 @@ PetscErrorCode STCreate(MPI_Comm comm,ST *newst)
   st->data         = NULL;
 
   *newst = st;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -240,13 +240,13 @@ static inline PetscErrorCode STMatIsSymmetricKnown(ST st,PetscBool *symm,PetscBo
 #else
   *herm = *symm;
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    STSetMatrices - Sets the matrices associated with the eigenvalue problem.
 
-   Collective on st
+   Collective
 
    Input Parameters:
 +  st - the spectral transformation context
@@ -305,13 +305,13 @@ PetscErrorCode STSetMatrices(ST st,PetscInt n,Mat A[])
   PetscCheck(!same || !st->Psplit,PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"Support for changing the matrices while using a split preconditioner is not implemented yet");
   st->opready = PETSC_FALSE;
   if (!same) PetscCall(STMatIsSymmetricKnown(st,&st->asymm,&st->aherm));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    STGetMatrix - Gets the matrices associated with the original eigensystem.
 
-   Not collective, though parallel Mats are returned if the ST is parallel
+   Not Collective
 
    Input Parameters:
 +  st - the spectral transformation context
@@ -334,13 +334,13 @@ PetscErrorCode STGetMatrix(ST st,PetscInt k,Mat *A)
   PetscCheck(k>=0 && k<st->nmat,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_OUTOFRANGE,"k must be between 0 and %" PetscInt_FMT,st->nmat-1);
   PetscCheck(((PetscObject)st->A[k])->state==st->Astate[k],PetscObjectComm((PetscObject)st),PETSC_ERR_SUP,"Cannot retrieve original matrices (have been modified)");
   *A = st->A[k];
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    STGetMatrixTransformed - Gets the matrices associated with the transformed eigensystem.
 
-   Not collective, though parallel Mats are returned if the ST is parallel
+   Not Collective
 
    Input Parameters:
 +  st - the spectral transformation context
@@ -363,13 +363,13 @@ PetscErrorCode STGetMatrixTransformed(ST st,PetscInt k,Mat *T)
   PetscCheck(k>=0 && k<st->nmat,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_OUTOFRANGE,"k must be between 0 and %" PetscInt_FMT,st->nmat-1);
   PetscCheck(st->T,PetscObjectComm((PetscObject)st),PETSC_ERR_POINTER,"There are no transformed matrices");
   *T = st->T[k];
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    STGetNumMatrices - Returns the number of matrices stored in the ST.
 
-   Not collective
+   Not Collective
 
    Input Parameter:
 .  st - the spectral transformation context
@@ -387,13 +387,13 @@ PetscErrorCode STGetNumMatrices(ST st,PetscInt *n)
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidIntPointer(n,2);
   *n = st->nmat;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    STResetMatrixState - Resets the stored state of the matrices in the ST.
 
-   Logically Collective on st
+   Logically Collective
 
    Input Parameter:
 .  st - the spectral transformation context
@@ -415,13 +415,13 @@ PetscErrorCode STResetMatrixState(ST st)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   for (i=0;i<st->nmat;i++) st->Astate[i] = ((PetscObject)st->A[i])->state;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    STSetPreconditionerMat - Sets the matrix to be used to build the preconditioner.
 
-   Collective on st
+   Collective
 
    Input Parameters:
 +  st  - the spectral transformation context
@@ -469,7 +469,7 @@ PetscErrorCode STSetPreconditionerMat(ST st,Mat mat)
   st->Pmat_set = mat? PETSC_TRUE: PETSC_FALSE;
   st->state    = ST_STATE_INITIAL;
   st->opready  = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -494,14 +494,14 @@ PetscErrorCode STGetPreconditionerMat(ST st,Mat *mat)
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidPointer(mat,2);
   *mat = st->Pmat_set? st->Pmat: NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    STSetSplitPreconditioner - Sets the matrices from which to build the preconditioner
    in split form.
 
-   Collective on st
+   Collective
 
    Input Parameters:
 +  st     - the spectral transformation context
@@ -569,14 +569,14 @@ PetscErrorCode STSetSplitPreconditioner(ST st,PetscInt n,Mat Psplit[],MatStructu
   st->nsplit = n;
   st->strp   = strp;
   st->state  = ST_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    STGetSplitPreconditionerTerm - Gets the matrices associated with
    the split preconditioner.
 
-   Not collective, though parallel Mats are returned if the ST is parallel
+   Not Collective
 
    Input Parameters:
 +  st - the spectral transformation context
@@ -598,14 +598,14 @@ PetscErrorCode STGetSplitPreconditionerTerm(ST st,PetscInt k,Mat *Psplit)
   PetscCheck(k>=0 && k<st->nsplit,PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_OUTOFRANGE,"k must be between 0 and %" PetscInt_FMT,st->nsplit-1);
   PetscCheck(st->Psplit,PetscObjectComm((PetscObject)st),PETSC_ERR_ORDER,"You have not called STSetSplitPreconditioner()");
   *Psplit = st->Psplit[k];
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    STGetSplitPreconditionerInfo - Returns the number of matrices of the split
    preconditioner, as well as the structure flag.
 
-   Not collective
+   Not Collective
 
    Input Parameter:
 .  st - the spectral transformation context
@@ -624,13 +624,13 @@ PetscErrorCode STGetSplitPreconditionerInfo(ST st,PetscInt *n,MatStructure *strp
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   if (n)    *n    = st->nsplit;
   if (strp) *strp = st->strp;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    STSetShift - Sets the shift associated with the spectral transformation.
 
-   Logically Collective on st
+   Collective
 
    Input Parameters:
 +  st - the spectral transformation context
@@ -659,7 +659,7 @@ PetscErrorCode STSetShift(ST st,PetscScalar shift)
     st->sigma = shift;
   }
   st->sigma_set = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -683,14 +683,14 @@ PetscErrorCode STGetShift(ST st,PetscScalar* shift)
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidScalarPointer(shift,2);
   *shift = st->sigma;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    STSetDefaultShift - Sets the value of the shift that should be employed if
    the user did not specify one.
 
-   Logically Collective on st
+   Logically Collective
 
    Input Parameters:
 +  st - the spectral transformation context
@@ -710,13 +710,13 @@ PetscErrorCode STSetDefaultShift(ST st,PetscScalar defaultshift)
     st->state    = ST_STATE_INITIAL;
     st->opready  = PETSC_FALSE;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    STScaleShift - Multiply the shift with a given factor.
 
-   Logically Collective on st
+   Logically Collective
 
    Input Parameters:
 +  st     - the spectral transformation context
@@ -736,13 +736,13 @@ PetscErrorCode STScaleShift(ST st,PetscScalar factor)
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidLogicalCollectiveScalar(st,factor,2);
   st->sigma *= factor;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    STSetBalanceMatrix - Sets the diagonal matrix to be used for balancing.
 
-   Collective on st
+   Collective
 
    Input Parameters:
 +  st - the spectral transformation context
@@ -763,7 +763,7 @@ PetscErrorCode STSetBalanceMatrix(ST st,Vec D)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
-  if (st->D == D) PetscFunctionReturn(0);
+  if (st->D == D) PetscFunctionReturn(PETSC_SUCCESS);
   STCheckNotSeized(st,1);
   if (D) {
     PetscValidHeaderSpecific(D,VEC_CLASSID,2);
@@ -774,13 +774,13 @@ PetscErrorCode STSetBalanceMatrix(ST st,Vec D)
   st->D = D;
   st->state   = ST_STATE_INITIAL;
   st->opready = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    STGetBalanceMatrix - Gets the balance matrix used by the spectral transformation.
 
-   Not collective, but vector is shared by all processors that share the ST
+   Not Collective
 
    Input Parameter:
 .  st - the spectral transformation context
@@ -801,13 +801,13 @@ PetscErrorCode STGetBalanceMatrix(ST st,Vec *D)
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidPointer(D,2);
   *D = st->D;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    STMatCreateVecs - Get vector(s) compatible with the ST matrices.
 
-   Collective on st
+   Collective
 
    Input Parameter:
 .  st - the spectral transformation context
@@ -825,14 +825,14 @@ PetscErrorCode STMatCreateVecs(ST st,Vec *right,Vec *left)
   PetscFunctionBegin;
   STCheckMatrices(st,1);
   PetscCall(MatCreateVecs(st->A[0],right,left));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    STMatCreateVecsEmpty - Get vector(s) compatible with the ST matrices, i.e. with the same
    parallel layout, but without internal array.
 
-   Collective on st
+   Collective
 
    Input Parameter:
 .  st - the spectral transformation context
@@ -850,7 +850,7 @@ PetscErrorCode STMatCreateVecsEmpty(ST st,Vec *right,Vec *left)
   PetscFunctionBegin;
   STCheckMatrices(st,1);
   PetscCall(MatCreateVecsEmpty(st->A[0],right,left));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -874,7 +874,7 @@ PetscErrorCode STMatGetSize(ST st,PetscInt *m,PetscInt *n)
   PetscFunctionBegin;
   STCheckMatrices(st,1);
   PetscCall(MatGetSize(st->A[0],m,n));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -898,14 +898,14 @@ PetscErrorCode STMatGetLocalSize(ST st,PetscInt *m,PetscInt *n)
   PetscFunctionBegin;
   STCheckMatrices(st,1);
   PetscCall(MatGetLocalSize(st->A[0],m,n));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    STSetOptionsPrefix - Sets the prefix used for searching for all
    ST options in the database.
 
-   Logically Collective on st
+   Logically Collective
 
    Input Parameters:
 +  st     - the spectral transformation context
@@ -928,14 +928,14 @@ PetscErrorCode STSetOptionsPrefix(ST st,const char *prefix)
   PetscCall(KSPSetOptionsPrefix(st->ksp,prefix));
   PetscCall(KSPAppendOptionsPrefix(st->ksp,"st_"));
   PetscCall(PetscObjectSetOptionsPrefix((PetscObject)st,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    STAppendOptionsPrefix - Appends to the prefix used for searching for all
    ST options in the database.
 
-   Logically Collective on st
+   Logically Collective
 
    Input Parameters:
 +  st     - the spectral transformation context
@@ -958,7 +958,7 @@ PetscErrorCode STAppendOptionsPrefix(ST st,const char *prefix)
   if (!st->ksp) PetscCall(STGetKSP(st,&st->ksp));
   PetscCall(KSPSetOptionsPrefix(st->ksp,((PetscObject)st)->prefix));
   PetscCall(KSPAppendOptionsPrefix(st->ksp,"st_"));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -987,13 +987,13 @@ PetscErrorCode STGetOptionsPrefix(ST st,const char *prefix[])
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidPointer(prefix,2);
   PetscCall(PetscObjectGetOptionsPrefix((PetscObject)st,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    STView - Prints the ST data structure.
 
-   Collective on st
+   Collective
 
    Input Parameters:
 +  st - the ST context
@@ -1060,13 +1060,13 @@ PetscErrorCode STView(ST st,PetscViewer viewer)
     PetscCall(KSPView(st->ksp,viewer));
     PetscCall(PetscViewerASCIIPopTab(viewer));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    STViewFromOptions - View from options
 
-   Collective on ST
+   Collective
 
    Input Parameters:
 +  st   - the spectral transformation context
@@ -1082,13 +1082,13 @@ PetscErrorCode STViewFromOptions(ST st,PetscObject obj,const char name[])
   PetscFunctionBegin;
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscCall(PetscObjectViewFromOptions((PetscObject)st,obj,name));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    STRegister - Adds a method to the spectral transformation package.
 
-   Not collective
+   Not Collective
 
    Input Parameters:
 +  name - name of a new user-defined transformation
@@ -1098,7 +1098,7 @@ PetscErrorCode STViewFromOptions(ST st,PetscObject obj,const char name[])
    STRegister() may be called multiple times to add several user-defined
    spectral transformations.
 
-   Sample usage:
+   Example Usage:
 .vb
     STRegister("my_transform",MyTransformCreate);
 .ve
@@ -1117,5 +1117,5 @@ PetscErrorCode STRegister(const char *name,PetscErrorCode (*function)(ST))
   PetscFunctionBegin;
   PetscCall(STInitializePackage());
   PetscCall(PetscFunctionListAdd(&STList,name,function));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
