@@ -112,7 +112,7 @@ static PetscErrorCode MatCreateTile_Seq(PetscScalar a,Mat A,PetscScalar b,Mat B,
     }
   }
   PetscCall(PetscFree2(buf,scols));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatCreateTile_MPI(PetscScalar a,Mat A,PetscScalar b,Mat B,PetscScalar c,Mat C,PetscScalar d,Mat D,Mat G)
@@ -248,13 +248,13 @@ static PetscErrorCode MatCreateTile_MPI(PetscScalar a,Mat A,PetscScalar b,Mat B,
     }
   }
   PetscCall(PetscFree4(buf,scols,map1,map2));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatCreateTile - Explicitly build a matrix from four blocks, G = [ a*A b*B; c*C d*D ].
 
-   Collective on A
+   Collective
 
    Input Parameters:
 +  A - matrix for top-left block
@@ -352,14 +352,14 @@ PetscErrorCode MatCreateTile(PetscScalar a,Mat A,PetscScalar b,Mat B,PetscScalar
   else PetscCall(MatCreateTile_Seq(a,A,b,B,c,C,d,D,*G));
   PetscCall(MatAssemblyBegin(*G,MAT_FINAL_ASSEMBLY));
   PetscCall(MatAssemblyEnd(*G,MAT_FINAL_ASSEMBLY));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    MatCreateVecsEmpty - Get vector(s) compatible with the matrix, i.e. with the same
    parallel layout, but without internal array.
 
-   Collective on mat
+   Collective
 
    Input Parameter:
 .  mat - the matrix
@@ -430,13 +430,13 @@ PetscErrorCode MatCreateVecsEmpty(Mat mat,Vec *right,Vec *left)
       }
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    MatNormEstimate - Estimate the 2-norm of a matrix.
 
-   Collective on A
+   Collective
 
    Input Parameters:
 +  A   - the matrix
@@ -487,5 +487,5 @@ PetscErrorCode MatNormEstimate(Mat A,Vec vrn,Vec w,PetscReal *nrm)
 
   PetscCall(VecDestroy(&vv));
   PetscCall(VecDestroy(&ww));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
