@@ -20,6 +20,7 @@ int main(int argc,char **argv)
   PetscCall(PetscInitialized(&pInitialized));
   PetscCall(SlepcInitialized(&sInitialized));
   PetscCall(PetscPrintf(PETSC_COMM_WORLD,"PetscInitialized=%d, SlepcInitialized=%d.\n",(int)pInitialized,(int)sInitialized));
+  PetscFunctionBeginUser;
   PetscCall(SlepcInitialize(&argc,&argv,(char*)0,help));
   PetscCall(PetscInitialized(&pInitialized));
   PetscCall(SlepcInitialized(&sInitialized));
@@ -35,6 +36,7 @@ int main(int argc,char **argv)
   PetscCall(SlepcFinalize());
   PetscCall(SlepcFinalized(&sFinalized));
   if (!sFinalized) printf("Unexpected value: SlepcFinalized() returned False after SlepcFinalize()\n");
+  if (skip_petsc_finalize) PetscCall(PetscFinalize());
   return 0;
 }
 
@@ -47,6 +49,5 @@ int main(int argc,char **argv)
       test:
          suffix: 2
          args: -skip_petsc_finalize
-         TODO: shows an mpiexec error message in C++ jobs
 
 TEST*/
