@@ -13,7 +13,7 @@
 /*@
    VecNormalizeComplex - Normalizes a possibly complex vector by the 2-norm.
 
-   Collective on xr
+   Collective
 
    Input Parameters:
 +  xr - the real part of the vector (overwritten on output)
@@ -50,7 +50,7 @@ PetscErrorCode VecNormalizeComplex(Vec xr,Vec xi,PetscBool iscomplex,PetscReal *
   } else
 #endif
     PetscCall(VecNormalize(xr,norm));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecCheckOrthogonality_Private(Vec V[],PetscInt nv,Vec W[],PetscInt nw,Mat B,PetscViewer viewer,PetscReal *lev,PetscBool norm)
@@ -66,7 +66,7 @@ static PetscErrorCode VecCheckOrthogonality_Private(Vec V[],PetscInt nv,Vec W[],
     PetscValidHeaderSpecific(viewer,PETSC_VIEWER_CLASSID,6);
     PetscCheckSameComm(*V,1,viewer,6);
     PetscCall(PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii));
-    if (!isascii) PetscFunctionReturn(0);
+    if (!isascii) PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   PetscCall(PetscMalloc1(nv,&vals));
@@ -100,14 +100,14 @@ static PetscErrorCode VecCheckOrthogonality_Private(Vec V[],PetscInt nv,Vec W[],
   }
   PetscCall(PetscFree(vals));
   if (B) PetscCall(VecDestroy(&w));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    VecCheckOrthogonality - Checks (or prints) the level of (bi-)orthogonality
    of a set of vectors.
 
-   Collective on V
+   Collective
 
    Input Parameters:
 +  V  - a set of vectors
@@ -142,21 +142,21 @@ PetscErrorCode VecCheckOrthogonality(Vec V[],PetscInt nv,Vec W[],PetscInt nw,Mat
   PetscValidHeaderSpecific(*V,VEC_CLASSID,1);
   PetscValidLogicalCollectiveInt(*V,nv,2);
   PetscValidLogicalCollectiveInt(*V,nw,4);
-  if (nv<=0 || nw<=0) PetscFunctionReturn(0);
+  if (nv<=0 || nw<=0) PetscFunctionReturn(PETSC_SUCCESS);
   if (W) {
     PetscValidPointer(W,3);
     PetscValidHeaderSpecific(*W,VEC_CLASSID,3);
     PetscCheckSameComm(*V,1,*W,3);
   }
   PetscCall(VecCheckOrthogonality_Private(V,nv,W,nw,B,viewer,lev,PETSC_FALSE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    VecCheckOrthonormality - Checks (or prints) the level of (bi-)orthonormality
    of a set of vectors.
 
-   Collective on V
+   Collective
 
    Input Parameters:
 +  V  - a set of vectors
@@ -184,21 +184,21 @@ PetscErrorCode VecCheckOrthonormality(Vec V[],PetscInt nv,Vec W[],PetscInt nw,Ma
   PetscValidHeaderSpecific(*V,VEC_CLASSID,1);
   PetscValidLogicalCollectiveInt(*V,nv,2);
   PetscValidLogicalCollectiveInt(*V,nw,4);
-  if (nv<=0 || nw<=0) PetscFunctionReturn(0);
+  if (nv<=0 || nw<=0) PetscFunctionReturn(PETSC_SUCCESS);
   if (W) {
     PetscValidPointer(W,3);
     PetscValidHeaderSpecific(*W,VEC_CLASSID,3);
     PetscCheckSameComm(*V,1,*W,3);
   }
   PetscCall(VecCheckOrthogonality_Private(V,nv,W,nw,B,viewer,lev,PETSC_TRUE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    VecDuplicateEmpty - Creates a new vector of the same type as an existing vector,
    but without internal array.
 
-   Collective on v
+   Collective
 
    Input Parameters:
 .  v - a vector to mimic
@@ -241,13 +241,13 @@ PetscErrorCode VecDuplicateEmpty(Vec v,Vec *newv)
       else PetscCall(VecCreateSeqWithArray(PetscObjectComm((PetscObject)v),bs,N,NULL,newv));
     }
   } else PetscCall(VecDuplicate(v,newv)); /* standard duplicate, with internal array */
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    VecSetRandomNormal - Sets all components of a vector to normally distributed random values.
 
-   Logically Collective on v
+   Logically Collective
 
    Input Parameters:
 +  v    - the vector to be filled with random values
@@ -255,9 +255,6 @@ PetscErrorCode VecDuplicateEmpty(Vec v,Vec *newv)
 .  w1   - first work vector (can be NULL)
 -  w2   - second work vector (can be NULL)
 
-   Output Parameter:
-.  v    - the vector
-
    Notes:
    Fills the two work vectors with uniformly distributed random values (VecSetRandom)
    and then applies the Box-Muller transform to get normally distributed values on v.
@@ -317,5 +314,5 @@ PetscErrorCode VecSetRandomNormal(Vec v,PetscRandom rctx,Vec w1,Vec w2)
   PetscCall(VecDestroy(&v1));
   PetscCall(VecDestroy(&v2));
   if (!rctx) PetscCall(PetscRandomDestroy(&rand));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
